(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1424728,      44511]*)
(*NotebookOutlinePosition[   1425653,      44542]*)
(*  CellTagsIndexPosition[   1425609,      44538]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Combinatorial Ornithology", "Title",
  FontColor->GrayLevel[1],
  Background->RGBColor[0, 0.25098, 0.501961]],

Cell["by Jaime Rangel-Mondrag\[OAcute]n", "Author",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Autonomous University of Queretaro. Faculty of Informatics
Queretaro\.b4s Institute of Technology. Mechatronics Department

jrangel@sunserver.uaq.mx\
\>", "Address"],

Cell["\<\


Copyright \[Copyright] May 2003
Permission is hereby granted to reproduce part or all of this file for any \
purpose other than direct profit providing that the source is acknowledged.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Abstract", "SectionFirst"],

Cell["\<\
This work is an exploration into the fascinating world of Combinatory Logic, \
inspired by the novel ornithological viewpoint introduced by Raymond \
Smullyan. The work begins with historical details and is followed by an \
introduction to the combinatorial properties of bracketed expressions; it \
continues to the computing of behaviours and genealogies, the solution of \
combinatorial equations and the development of propositional birds including \
an assortment of illustrative examples throughout. Finally, comments on the \
use of birds to algorithmic complexity are mentioned and a list of references \
is included. The author has developed and made repeated use of this work in \
his teachings on Functional Programming, Programming Paradigms and Automata \
and Formal Languages.
\
\>", "Abstract"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Acknowledgments", "Section"],

Cell["\<\
This work was developed at Wolfram Research Inc., in Champaign IL, USA, while \
the author was spending two months as a Visiting Scholar. Their assistance \
and enthusiastic support is gratefully acknowledged. My thanks are also \
extended for the continuous support received from the University of Queretaro \
in Mexico.\
\>", "Text"],

Cell["\<\
Mathematics is the art of giving the same name to different things. 
- Henri Poincare

Poetry is the art of giving different names to the same thing. 
- Anonymous
\
\>", "Reference",
  TextAlignment->Right,
  TextJustification->0]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "At the beginning of the XX century, a young German physicist was set onto \
discovering a theory that radically changed the ideas about the nature of \
time and space held so far. In a not very different way, mathematicians were \
also confronting the need for fundamental changes in their own field. \n\n\
Since Greek times the concept of infinity and its uses (mostly rhetorical \
initially, but nonetheless disturbing), had spawned paradoxes that posed \
definite barriers to any advance on the study of the foundations of \
mathematics. Extraordinary minds applied themselves to the ambitious task of \
producing a paradox-free set of axioms on which to base all mathematical \
results so far known and aimed at shaping anything to be later known. Hilbert \
- the originator of the program, Frege, Russell, G\[ODoubleDot]del, Turing, \
Kleene, Church, Curry, Markov and Post are some of the extraordinary \
intellects that lead this effort in which a solid formalization of the notion \
of computability was called for. Turing proposed, in the 1930s, an abstract \
concept of machine, now known as the ",
  StyleBox["Turing Machine",
    FontSlant->"Italic"],
  ", that aimed to incorporate this sought-after notion of computability. \
Markov also proposed his own model, the ",
  StyleBox["Markov Algorithms",
    FontSlant->"Italic"],
  ", and Post put forward his model of ",
  StyleBox["Production Systems",
    FontSlant->"Italic"],
  ", both of which enjoyed the same success Turing had. Those models, along \
with scores of others less renowned, were later shown all to be equivalent, a \
fact that resulted remarkable as they were independently formulated. In 1934, \
G\[ODoubleDot]del (which was a very close friend of Einstein in his last \
years at Princeton) collapsed all hope to attain a satisfactory answer for \
Hilbert's program through his famous ",
  StyleBox["Incompleteness theorem",
    FontSlant->"Italic"],
  "; despite this he also contributed with the development of the foundations \
of what was later called the ",
  StyleBox["theory of recursive functions",
    FontSlant->"Italic"],
  ", aimed at providing the mathematical formulation of the notion of \
algorithm, which nevertheless retained its importance. Later,this model was \
also shown to be equivalent to the other ones. \n\nIn 1936, in an effort to \
unify all the plethora of theories, Church proposed what became to be known \
as the ",
  StyleBox["Church Thesis",
    FontSlant->"Italic"],
  ", establishing that the notion of computability should be identified with \
the model of recursive functions. Church thesis has since been adopted as a \
unifying principle and it has been recognized as a legitimate synthesis from \
the past proliferation and successive failures at attempting to find an \
alternative, more powerful model. By its very nature, the Church Thesis \
cannot be proven, although its overthrown has been compared with the \
discovery of a three-sided square, or an instance of the non-applicability of \
the law of excluded middle (two things equal to a third are equal to each \
other), both events representing a fundamental flaw in universal logical \
processes. The contribution of Church went further on. Along with his student \
Kleene, Church proposed the \[Lambda]-calculus as an additional \
all-encompassing model. Simultaneously, Curry developed the important branch \
of computer science that we now know as ",
  StyleBox["Combinatory Logic",
    FontSlant->"Italic"],
  ", whose relevance to the analysis and description of concurrent processes \
is widely recognized and is still undergoing an extraordinary development. \
For our purposes here we only made brief remarks about the basic properties \
of the \[Lambda]-calculus, which are covered nowadays in a large amount of \
texts.\n\nAn important part of Combinatory Logic deals with the \
representation of arbitrary functions through the use of ",
  StyleBox["combinators",
    FontSlant->"Italic"],
  ". A combinator is a multi-argument functional; its inner mechanism, or ",
  StyleBox["behavior",
    FontSlant->"Italic"],
  ", is represented by a string describing its effect on several arguments. \
Combinators are usually represented by upper-case English letters and their \
behavior is described by their application to a string of lower-case letters \
(typically x, y, z and w) representing its arguments, following the \
left-associative convention. Adopting the elegant terminology proposed by \
Smullyan, we choose bird names for some particular combinators. For example, \
the Bluebird  ",
  StyleBox["B",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" ",
    FontWeight->"Bold"],
  " has behavior  Bxyz \[Rule] x(yz), which establishes that B acts as a \
string rewriting mechanism transforming the string xyz into the string x(yz). \
We iterate this application until no further work can be done. For example, \
B(Bx)(yz)a(bc) \[Rule] Bx(yza)(bc) \[Rule]  x(yza(bc)). We will replace the \
arrow by an equal sign as is customary bearing in mind the difference with \
ordinary equality.\n\nSome birds are derived from others; for example, \
consider bird P with behaviour Pxyzwv = xyz(wv). It is easily shown that P \
accomplishes the same effect as B(BB). We then say that the ",
  StyleBox["genealogy",
    FontSlant->"Italic"],
  " of P is B(BB). A subtler example is the following. Assume the basic birds \
are our former B, a ",
  StyleBox["Thrush",
    FontSlant->"Italic"],
  " T with behaviour Txy = yx and a ",
  StyleBox["Mockingbird",
    FontSlant->"Italic"],
  " M such that Mx = xx (we notice M is unary, T is binary, and B is \
tertiary). Now, given the bird A with behaviour Axy = yxx,we find its \
genealogy through the following reverse process:"
}], "Text"],

Cell["\<\
Axy \t=\tyxx
\t=\tTx(yx)
\t=\tB(Tx)yx
\t=\tTx(B(Tx)y)
\t=\tB(Tx)(B(Tx))y
\t=\tM(B(Tx))y
\t=\tBMB(Tx)y
\t=\tB(BMB)Txy\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Hence, A's genealogy is obtained as B(BMB)T. Besides being slightly \
laborious, this example illustrates the merit and subtleties of the problems \
facing any genealogy seeker. It is our aim in this work to apply a functional \
design methodology towards solving the general combinatorial parsing problem: \
given a bird in the forest (the universal set of combinators), we want to \
find its genealogy in terms of a set of basic birds, specified through their \
respective behaviors. It is known that birds S, K and I are enough to find \
the genealogy of any other bird (in fact, as I = SKK, only the first two are \
needed). Moreover, there is a recursive algorithm, due to \
Sch\[ODoubleDot]nfinkel, that readily finds it. The surprising fact that only \
two birds suffice to construct all computational processes anticipates what \
was later discovered by Stephen Wolfram in his work on cellular automata (a \
growing field he helped to consolidate about twenty years ago), namely that \
from simple rules we can produce processes of great complexity, that is, we \
do not need to resort to a powerful theoretical set to explain complex \
physical or mathematical processes. \n\nIn the following, we describe our \
functional algorithms within the computational framework of the symbolic \
advantages offered by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". We start by describing the mechanism of bracket manipulation to be \
followed by birds."
}], "Text"],

Cell[BoxData[{
    \(<< Graphics`Colors`\), "\[IndentingNewLine]", 
    \(<< Graphics`Spline`\), "\[IndentingNewLine]", 
    \(Off[General::"\<spell\>", General::"\<spell1\>"]\), "\n", 
    \(\(SetOptions[Graphics, \ AspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] All];\)\)}], "Input",
  CellLabel->"In[256]:=",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Excursion on Brackets", "Section"],

Cell[TextData[{
  "The handling of brackets in combinatory logic is often a source of \
difficulty to the beginner. In this section we develop several computational \
methodologies to deal with this problem. We start by generating all valid \
patterns made out of opening and matching closing brackets. Function ",
  StyleBox["patterns",
    FontSlant->"Italic"],
  " computes the required list:"
}], "Text"],

Cell[BoxData[{
    \(validQ[{}] := True\), "\[IndentingNewLine]", 
    \(validQ[{"\<(\>", x___, "\<)\>", y___}] := 
      validQ[{y}]\  /; \ validQ[{x}]\), "\[IndentingNewLine]", 
    \(\(\(validQ[_] := False\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(patterns[n_] := 
      Distribute[Table[{"\<(\>", "\<)\>"}, {2\ n}], List]\)}], "Input",
  CellLabel->"In[196]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(s = 
      StringJoin\  /@ \ 
        Select[patterns[4], validQ]\), "\[IndentingNewLine]", 
    \(Length[s]\)}], "Input",
  CellLabel->"In[260]:="],

Cell[BoxData[
    \({"(((())))", "((()()))", "((())())", "((()))()", "(()(()))", 
      "(()()())", "(()())()", "(())(())", "(())()()", "()((()))", "()(()())", 
      "()(())()", "()()(())", "()()()()"}\)], "Output",
  CellLabel->"Out[260]="],

Cell[BoxData[
    \(14\)], "Output",
  CellLabel->"Out[261]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[Select[patterns[n], validQ]], {n, 10}]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({1, 2, 5, 14, 42, 132, 429, 1430, 4862, 16796}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  "The amount of such patterns is known to be Catalan numbers. Another way of \
generating these patterns is to include variables in such a way that each \
bracket surrounds a pair of arguments, and thus can be thought of as standing \
for all ways of applying a binary operation on a set of arguments. Function \
",
  StyleBox["brackets",
    FontSlant->"Italic"],
  ", accomplishes this:"
}], "Text"],

Cell[BoxData[{
    \(brk[{a_, b_}] := {"\<(\>" <> a <> b <> "\<)\>"}\), "\n", 
    \(\(\(brk[arg_] := 
      Module[{u = {}, i, 
          b}, \[IndentingNewLine]Do[\[IndentingNewLine]b = 
            brk[Join[Take[arg, i - 1], 
                brk[{arg\[LeftDoubleBracket]i\[RightDoubleBracket], 
                    arg\[LeftDoubleBracket]i + 1\[RightDoubleBracket]}], 
                Drop[arg, i + 1]]]; \[IndentingNewLine]u = Join[u, b], {i, 
            Length[arg] - 1}]; \[IndentingNewLine]Union[
          u]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(brackets[arg_List] := brk[ToString\  /@ arg]\)}], "Input",
  CellLabel->"In[200]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(brackets[CharacterRange["\<a\>", "\<e\>"]]\), "\[IndentingNewLine]", 
    \(Length[%]\)}], "Input",
  CellLabel->"In[262]:="],

Cell[BoxData[
    \({"((((ab)c)d)e)", "(((a(bc))d)e)", "(((ab)(cd))e)", "(((ab)c)(de))", 
      "((a((bc)d))e)", "((a(b(cd)))e)", "((a(bc))(de))", "((ab)((cd)e))", 
      "((ab)(c(de)))", "(a(((bc)d)e))", "(a((b(cd))e))", "(a((bc)(de)))", 
      "(a(b((cd)e)))", "(a(b(c(de))))"}\)], "Output",
  CellLabel->"Out[262]="],

Cell[BoxData[
    \(14\)], "Output",
  CellLabel->"Out[263]="]
}, Open  ]],

Cell[TextData[{
  "A further generalization of this approach involving an arbitrary binary \
operation f (non-necessarily commutative or associative) is carried out  \
through function ",
  StyleBox["functional",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[BoxData[
    \(functional[s_String] := 
      Module[{u}, \[IndentingNewLine]u = 
          StringJoin[
            Map[# <> "\<,\>" &, 
              Characters[s]]]; \[IndentingNewLine]ToExpression[
          StringDrop[
            FixedPoint[
              StringReplace[#, {"\<(,\>" \[Rule] "\<f[\>", "\<,)\>" \[Rule] "\
\<]\>"}] &, u], \(-1\)]]]\)], "Input",
  CellLabel->"In[203]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(F = 
      functional\  /@ \ brackets[CharacterRange["\<a\>", "\<e\>"]]\)], "Input",\

  CellLabel->"In[264]:="],

Cell[BoxData[
    \({f[f[f[f[a, b], c], d], e], f[f[f[a, f[b, c]], d], e], 
      f[f[f[a, b], f[c, d]], e], f[f[f[a, b], c], f[d, e]], 
      f[f[a, f[f[b, c], d]], e], f[f[a, f[b, f[c, d]]], e], 
      f[f[a, f[b, c]], f[d, e]], f[f[a, b], f[f[c, d], e]], 
      f[f[a, b], f[c, f[d, e]]], f[a, f[f[f[b, c], d], e]], 
      f[a, f[f[b, f[c, d]], e]], f[a, f[f[b, c], f[d, e]]], 
      f[a, f[b, f[f[c, d], e]]], f[a, f[b, f[c, f[d, e]]]]}\)], "Output",
  CellLabel->"Out[264]="]
}, Open  ]],

Cell["For instance:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Union[Expand[F\  //. \ f[x_, y_] \[Rule] x + 1\/y]]\)], "Input",
  CellLabel->"In[265]:="],

Cell[BoxData[
    \({a + 1\/\(b + 1\/\(c + 1\/\(d + 1\/e\)\)\), 
      a + 1\/\(b + 1\/\(c + 1\/d + 1\/e\)\), 
      a + 1\/\(b + 1\/c + 1\/\(d + 1\/e\)\), 
      a + 1\/b + 1\/\(c + 1\/\(d + 1\/e\)\), 
      a + 1\/\(b + 1\/\(c + 1\/d\) + 1\/e\), 
      a + 1\/\(b + 1\/c + 1\/d + 1\/e\), a + 1\/b + 1\/\(c + 1\/d + 1\/e\), 
      a + 1\/\(b + 1\/c\) + 1\/\(d + 1\/e\), 
      a + 1\/b + 1\/c + 1\/\(d + 1\/e\), 
      a + 1\/\(b + 1\/\(c + 1\/d\)\) + 1\/e, 
      a + 1\/\(b + 1\/c + 1\/d\) + 1\/e, a + 1\/b + 1\/\(c + 1\/d\) + 1\/e, 
      a + 1\/\(b + 1\/c\) + 1\/d + 1\/e, 
      a + 1\/b + 1\/c + 1\/d + 1\/e}\)], "Output",
  CellLabel->"Out[265]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Triangulations", "Subsubsection"],

Cell["\<\
A fascinating geometrical representation of properly bracketed patterns, i. \
e. binary operations, is accomplished through the triangulations of convex \
n-gons:\
\>", "Text"],

Cell[BoxData[{
    \(numVar[f[x_, y_]] := numVar[x] + numVar[y]\), "\[IndentingNewLine]", 
    \(\(\(numVar[_] := 1\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(tri[f[a_, b_], v_] := 
      tri[a, Take[v, numVar[a] + 1]] \[Union] 
        tri[b, Take[v, {numVar[a] + 1, Length[v]}]] \[Union] {{First[v], 
            v\_\(\(\[LeftDoubleBracket]\)\(numVar[a] + 1\)\(\
\[RightDoubleBracket]\)\), Last[v]}}\), "\[IndentingNewLine]", 
    \(\(\(tri[_, _] := {}\)\(\n\)
    \)\), "\n", 
    \(triangulation[s_String] := 
      Module[{u = functional[s], n, v, x, y}, \[IndentingNewLine]n = 
          numVar[u] + 
            1; \[IndentingNewLine]v = \({Cos[\(\(\ \)\(2\ \[Pi]\ #\)\)\/n], 
                Sin[\(\(\ \)\(2\ \[Pi]\ #\)\)\/n]} &\) /@ 
            Range[n]; \[IndentingNewLine]Graphics[\(Line[# /. \ {x___, 
                      y_} \[Rule] \ {x, y, x}] &\)\  /@ \ tri[u, v], 
          AspectRatio \[Rule] Automatic]]\)}], "Input",
  CellLabel->"In[204]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[
          Partition[
            triangulation\  /@ \ brackets[CharacterRange["\<a\>", "\<e\>"]], 
            7]]];\)\)], "Input",
  CellLabel->"In[266]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2393 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.00569754 0.136054 [
[ 0 0 0 0 ]
[ 1 .2393 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2393 L
0 .2393 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00569754 0.149123 0.114222 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.433013 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .43301 m
.2619 .02062 L
.7381 .02062 L
.02381 .43301 L
.2619 .02062 L
s
.02381 .43301 m
.7381 .02062 L
.97619 .43301 L
.02381 .43301 L
.7381 .02062 L
s
.7381 .84541 m
.02381 .43301 L
.97619 .43301 L
.7381 .84541 L
.02381 .43301 L
s
.7381 .84541 m
.2619 .84541 L
.02381 .43301 L
.7381 .84541 L
.2619 .84541 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.00569754 0.286967 0.114222 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.433013 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .43301 m
.2619 .02062 L
.97619 .43301 L
.02381 .43301 L
.2619 .02062 L
s
.2619 .02062 m
.7381 .02062 L
.97619 .43301 L
.2619 .02062 L
.7381 .02062 L
s
.7381 .84541 m
.02381 .43301 L
.97619 .43301 L
.7381 .84541 L
.02381 .43301 L
s
.7381 .84541 m
.2619 .84541 L
.02381 .43301 L
.7381 .84541 L
.2619 .84541 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.00569754 0.424812 0.114222 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.433013 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.2619 .84541 m
.02381 .43301 L
.2619 .02062 L
.2619 .84541 L
.02381 .43301 L
s
.2619 .84541 m
.2619 .02062 L
.7381 .02062 L
.2619 .84541 L
.2619 .02062 L
s
.2619 .84541 m
.7381 .02062 L
.97619 .43301 L
.2619 .84541 L
.7381 .02062 L
s
.7381 .84541 m
.2619 .84541 L
.97619 .43301 L
.7381 .84541 L
.2619 .84541 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.00569754 0.562657 0.114222 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.433013 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .43301 m
.2619 .02062 L
.7381 .02062 L
.02381 .43301 L
.2619 .02062 L
s
.2619 .84541 m
.02381 .43301 L
.7381 .02062 L
.2619 .84541 L
.02381 .43301 L
s
.2619 .84541 m
.7381 .02062 L
.97619 .43301 L
.2619 .84541 L
.7381 .02062 L
s
.7381 .84541 m
.2619 .84541 L
.97619 .43301 L
.7381 .84541 L
.2619 .84541 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.00569754 0.700501 0.114222 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.433013 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.2619 .02062 m
.7381 .02062 L
.97619 .43301 L
.2619 .02062 L
.7381 .02062 L
s
.2619 .84541 m
.02381 .43301 L
.2619 .02062 L
.2619 .84541 L
.02381 .43301 L
s
.2619 .84541 m
.2619 .02062 L
.97619 .43301 L
.2619 .84541 L
.2619 .02062 L
s
.7381 .84541 m
.2619 .84541 L
.97619 .43301 L
.7381 .84541 L
.2619 .84541 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.00569754 0.838346 0.114222 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.433013 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .43301 m
.2619 .02062 L
.7381 .02062 L
.02381 .43301 L
.2619 .02062 L
s
.02381 .43301 m
.7381 .02062 L
.97619 .43301 L
.02381 .43301 L
.7381 .02062 L
s
.2619 .84541 m
.02381 .43301 L
.97619 .43301 L
.2619 .84541 L
.02381 .43301 L
s
.7381 .84541 m
.2619 .84541 L
.97619 .43301 L
.7381 .84541 L
.2619 .84541 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.00569754 0.97619 0.114222 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.433013 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .43301 m
.2619 .02062 L
.97619 .43301 L
.02381 .43301 L
.2619 .02062 L
s
.2619 .02062 m
.7381 .02062 L
.97619 .43301 L
.2619 .02062 L
.7381 .02062 L
s
.2619 .84541 m
.02381 .43301 L
.97619 .43301 L
.2619 .84541 L
.02381 .43301 L
s
.7381 .84541 m
.2619 .84541 L
.97619 .43301 L
.7381 .84541 L
.2619 .84541 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.125074 0.149123 0.233599 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.433013 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .84541 m
.02381 .43301 L
.2619 .02062 L
.7381 .84541 L
.02381 .43301 L
s
.7381 .84541 m
.2619 .02062 L
.7381 .02062 L
.7381 .84541 L
.2619 .02062 L
s
.7381 .84541 m
.2619 .84541 L
.02381 .43301 L
.7381 .84541 L
.2619 .84541 L
s
.7381 .84541 m
.7381 .02062 L
.97619 .43301 L
.7381 .84541 L
.7381 .02062 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.125074 0.286967 0.233599 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.433013 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.2619 .84541 m
.02381 .43301 L
.2619 .02062 L
.2619 .84541 L
.02381 .43301 L
s
.7381 .84541 m
.2619 .02062 L
.7381 .02062 L
.7381 .84541 L
.2619 .02062 L
s
.7381 .84541 m
.2619 .84541 L
.2619 .02062 L
.7381 .84541 L
.2619 .84541 L
s
.7381 .84541 m
.7381 .02062 L
.97619 .43301 L
.7381 .84541 L
.7381 .02062 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.125074 0.424812 0.233599 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.433013 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .43301 m
.2619 .02062 L
.7381 .02062 L
.02381 .43301 L
.2619 .02062 L
s
.7381 .84541 m
.02381 .43301 L
.7381 .02062 L
.7381 .84541 L
.02381 .43301 L
s
.7381 .84541 m
.2619 .84541 L
.02381 .43301 L
.7381 .84541 L
.2619 .84541 L
s
.7381 .84541 m
.7381 .02062 L
.97619 .43301 L
.7381 .84541 L
.7381 .02062 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.125074 0.562657 0.233599 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.433013 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.2619 .02062 m
.7381 .02062 L
.97619 .43301 L
.2619 .02062 L
.7381 .02062 L
s
.7381 .84541 m
.02381 .43301 L
.2619 .02062 L
.7381 .84541 L
.02381 .43301 L
s
.7381 .84541 m
.2619 .02062 L
.97619 .43301 L
.7381 .84541 L
.2619 .02062 L
s
.7381 .84541 m
.2619 .84541 L
.02381 .43301 L
.7381 .84541 L
.2619 .84541 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.125074 0.700501 0.233599 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.433013 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.2619 .84541 m
.02381 .43301 L
.2619 .02062 L
.2619 .84541 L
.02381 .43301 L
s
.2619 .84541 m
.2619 .02062 L
.7381 .02062 L
.2619 .84541 L
.2619 .02062 L
s
.7381 .84541 m
.2619 .84541 L
.7381 .02062 L
.7381 .84541 L
.2619 .84541 L
s
.7381 .84541 m
.7381 .02062 L
.97619 .43301 L
.7381 .84541 L
.7381 .02062 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.125074 0.838346 0.233599 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.433013 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .43301 m
.2619 .02062 L
.7381 .02062 L
.02381 .43301 L
.2619 .02062 L
s
.2619 .84541 m
.02381 .43301 L
.7381 .02062 L
.2619 .84541 L
.02381 .43301 L
s
.7381 .84541 m
.2619 .84541 L
.7381 .02062 L
.7381 .84541 L
.2619 .84541 L
s
.7381 .84541 m
.7381 .02062 L
.97619 .43301 L
.7381 .84541 L
.7381 .02062 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.125074 0.97619 0.233599 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.433013 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.2619 .02062 m
.7381 .02062 L
.97619 .43301 L
.2619 .02062 L
.7381 .02062 L
s
.2619 .84541 m
.02381 .43301 L
.2619 .02062 L
.2619 .84541 L
.02381 .43301 L
s
.7381 .84541 m
.2619 .02062 L
.97619 .43301 L
.7381 .84541 L
.2619 .02062 L
s
.7381 .84541 m
.2619 .84541 L
.2619 .02062 L
.7381 .84541 L
.2619 .84541 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[266]:=",
  ImageSize->{523.625, 125.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008;0000OB000`400?l00000o`00003oo`3ooooo
0?ooo`d0oooo003o0?ooool0oooo3@3oool00?l0ooooo`3oool=0?ooo`00o`3ooooo0?ooo`d0oooo
003o0?ooool0oooo3@3oool001h0oooo8000000X0?ooob000000:03ooolP000002L0oooo8000000X
0?ooob000000:03ooolP000002L0oooo8000000O0?ooo`007@3oool00`000000oooo0?ooo`0K0?oo
o`80000000<0oooo0000003oool09@3oool010000000oooo00000000000M0?ooo`030000003oool0
oooo02@0oooo0P00000M0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool06`3oool2
000000030?ooo`000000oooo02D0oooo1000000M0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool06`3oool2000000030?ooo`000000oooo02@0oooo00@000000?ooo`00000000007@3o
ool00`000000oooo0?ooo`0L0?ooo`007@3oool00`000000oooo0?ooo`0I0?ooo`8000000`3oool0
0`000000oooo0?ooo`0T0?ooo`040000003oool0oooo0?ooo`8000006`3oool00`000000oooo0?oo
o`0T0?ooo`8000007@3oool00`000000oooo0000000U0?ooo`030000003oool0oooo01T0oooo0P00
0000103oool000000?ooo`00000V0?ooo`8000000P3oool2000001/0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0I0?ooo`8000000`3oool00`000000oooo0?ooo`0S0?ooo`040000
003oool0oooo0?ooo`8000006`3oool00`000000oooo0?ooo`0L0?ooo`00703oool00`000000oooo
0?ooo`0H0?ooo`8000001P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo
0P00000J0?ooo`030000003oool0oooo0280oooo00<000000?ooo`000000703oool01@000000oooo
0?ooo`3oool0000002<0oooo00<000000?ooo`3oool0603oool200000080oooo00D000000?ooo`3o
ool0oooo0000000T0?ooo`030000003oool0000000@0oooo0P00000J0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0603oool2000000H0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`040?ooo`8000006P3oool00`000000oooo0?ooo`0K0?ooo`00703oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`060?ooo`800000603oool00`000000oooo0?ooo`0R0?ooo`030000003oool0000001`0
oooo00D000000?ooo`3oool0oooo0000000S0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000002@0oooo00<000000?ooo`0000001P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool05P3oool2
000000P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`800000603oool0
0`000000oooo0?ooo`0K0?ooo`006`3oool00`000000oooo0?ooo`0F0?ooo`8000002P3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0P0?ooo`040000003oool0oooo000001/0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo0P0000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0803oool010000000oooo0?ooo`0000070?ooo`800000603o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`0D0?ooo`8000003@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00X0oooo0P00000G0?ooo`030000003oool0
oooo01h0oooo00D000000?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0D0?ooo`8000001@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000090?ooo`800000
5P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01D0oooo0P00000<0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool02P3oool2000001L0oooo00<000000?ooo`3oool0
6@3oool001X0oooo00<000000?ooo`3oool04`3oool2000000l0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0=0?ooo`8000005@3oool00`000000oooo0?ooo`0N0?ooo`050000003o
ool0oooo0?ooo`0000006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool04`3oool2000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000002`3oool2000001D0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0C0?ooo`8000003`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00d0oooo0P00000E0?ooo`030000003oool0oooo01T0oooo000I0?ooo`030000
003oool0oooo0180oooo0P00000B0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
403oool2000001@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0180oooo0P0000080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo0P00000D0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool04P3oool200000180oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0@0?ooo`800000503oool00`000000oooo0?ooo`0H0?ooo`006@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0B0?ooo`8000004`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0140oooo0P00000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04P3o
ool2000001<0oooo00<000000?ooo`3oool05`3oool001P0oooo00<000000?ooo`3oool0403oool2
000001H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0100oooo0P00000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo0P00000B0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo01L0oooo000H0?ooo`030000003oool0oooo00h0oooo0P00000I0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool05P3oool200000140oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo0P00000<0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0100oooo0P00000@0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool20000
01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0F0?ooo`8000004@3oool00`00
0000oooo0?ooo`0F0?ooo`005`3oool00`000000oooo0?ooo`0=0?ooo`8000006`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo0P00000?0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0=0?ooo`8000003@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0B0?ooo`8000003`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00d0
oooo0P00000K0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool2000000l0
oooo00<000000?ooo`3oool05P3oool001H0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0703oool2000000h0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`8000007@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo01`0oooo0P00000>0?ooo`030000003oool0oooo01D0oooo
000F0?ooo`030000003oool0oooo00/0oooo0P00000P0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool07P3oool2000000d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00/0oooo0P00000?0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo0P00
000=0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02`3oool200000200oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0N0?ooo`8000003@3oool00`000000oooo0?oo
o`0D0?ooo`005@3oool00`000000oooo0?ooo`0:0?ooo`8000008P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0240oooo0P00000;0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`800000403oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0G
0?ooo`800000303oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo0P00000S
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool08@3oool2000000/0oooo00<00000
0?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0203oool2000002D0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo0P00000B0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01T0oooo0P00000:0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01<0oooo000D0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo02D0oooo0P0000090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool01`3oool2000002L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`80
00002@3oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`060?ooo`800000
:@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02L0oooo0P0000080?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`800000
4`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0L0?ooo`800000203oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00H0oooo0P00000Y0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
9`3oool2000000P0oooo00<000000?ooo`3oool04P3oool001<0oooo00<000000?ooo`3oool01@3o
ool2000002`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Z0?ooo`8000001`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3o
ool2000001D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool07P3oool2000000L0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`050?ooo`800000;03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo02X0oooo0P0000070?ooo`030000003oool0oooo0140oooo000B0?ooo`030000003oool0
oooo00@0oooo0P00000^0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;@3oool2
000000D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00@0oooo0P00000F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0200oooo0P0000060?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool2000002l0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0]0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`00
0000oooo0?ooo`020?ooo`800000<@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00P3oool2000001P0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08P3oool20000
00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0403oool00140oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0<@3oool2000000@0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`800000<`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0340oooo0P0000040?ooo`030000003oool0oooo00l0
oooo000A0?ooo`030000003oool0oooo00800000=@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo03<0oooo0P0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`02000001X0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool200000080oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02000003D0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0c0?ooo`8000000P3oool00`000000oooo0?ooo`0?0?ooo`00403o
ool010000000oooo00000000000h0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
=P3oool2000000030?ooo`000000oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool010000000oooo
00000000000K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo02L0oooo0P0000000`3oool000000?ooo`0:0?ooo`04
0000003oool00000000003P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0f0?oo
o`80000000<0oooo0000003oool03`3oool00100oooo0P00000j0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0>03oool2000000X0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02@3oool2000001`0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0:@3oool2000000/0oooo0P00000j0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0>03oool200000100oooo000?0?ooocl000002@3ooolo000000P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool01`3ooolo000000T0oooo?`00000?0?ooo`00403oool2000003X0oooo00<0
00000?ooo`3oool02@3oool2000003X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06P3oool2000000/0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`8000002P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo02T0oooo0P00000;0?ooo`030000003oool0oooo03P0oooo0P00
000;0?ooo`030000003oool0oooo03P0oooo0P00000@0?ooo`00403oool010000000oooo00000000
000h0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`0000000000>03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0H0?ooo`80000000<0oooo0000003oool02P3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01T0oooo0P0000000`3oool000000?ooo`090?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool09`3oool2000000030?ooo`000000oooo00X0oooo00<000000?ooo`3oool0
=P3oool2000000030?ooo`000000oooo00X0oooo00<000000?ooo`3oool0=P3oool2000000030?oo
o`000000oooo00l0oooo000A0?ooo`040000003oool0oooo000003H0oooo00<000000?ooo`3oool0
2`3oool010000000oooo0?ooo`00000f0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3o
ool000003@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo0P0000020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?oo
o`040000003oool0oooo000000d0oooo00<000000?ooo`3oool0=03oool010000000oooo0?ooo`00
000=0?ooo`030000003oool0oooo03<0oooo0P0000020?ooo`030000003oool0oooo00l0oooo000A
0?ooo`040000003oool0oooo0?ooo`800000=03oool00`000000oooo0?ooo`0;0?ooo`040000003o
ool0oooo0?ooo`800000=03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0G0?ooo`8000000`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0T0?ooo`8000000`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0380oooo
0P0000030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00l0oooo000B0?ooo`030000003oool0oooo0080oooo0P00
000a0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool200000340oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool05@3oool2000000@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01H0oooo0P0000040?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0R0?ooo`800000103oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo02l0oooo0P0000040?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0;`3oool2000000@0oooo00<000000?ooo`3oool0403oool00180oooo00<00000
0?ooo`3oool0103oool2000002h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`800000;P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0D0?ooo`8000001P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool2000000D0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0200oooo0P000006
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;03oool2000000H0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0]0?ooo`8000001@3oool00`000000oooo0?ooo`0A
0?ooo`004`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0C0?ooo`8000001`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0:P3oool2000000L0oooo00<000000?oo
o`3oool04@3oool001<0oooo00<000000?ooo`3oool01P3oool2000002X0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`060?ooo`800000:P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`80
0000203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0M0?ooo`800000203oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo02P0oooo0P0000080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo000D0?ooo`030000
003oool0oooo00L0oooo0P00000X0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
1`3oool2000002P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0403oool2000000T0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo0P0000090?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`800000
2@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02H0oooo0P0000090?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool09P3oool2000000T0oooo00<000000?ooo`3oool0
4P3oool001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0403oool2000000X0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo0P00000:0?ooo`030000003o
ool0oooo01<0oooo000E0?ooo`030000003oool0oooo00T0oooo0P00000S0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool02@3oool2000002<0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool2
000000/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00l0oooo0P00000;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0H0?ooo`8000002`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0240oooo0P00000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool08@3oool2
000000/0oooo00<000000?ooo`3oool0503oool001H0oooo00<000000?ooo`3oool02P3oool20000
0240oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`8000008@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0=0?ooo`800000303oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`800000303oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01l0oooo0P00000<0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01@0oooo000F0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo0P00000=0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0M0?ooo`8000003@3oool00`000000
oooo0?ooo`0E0?ooo`005`3oool00`000000oooo0?ooo`0<0?ooo`8000007@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00`0oooo0P00000M0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo
0P00000>0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0;0?ooo`8000003`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool04`3oool2000000h0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0K0?ooo`8000003P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01X0oooo
0P00000?0?ooo`030000003oool0oooo01D0oooo000G0?ooo`030000003oool0oooo00h0oooo0P00
000J0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03P3oool2000001X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02P3oool200000100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool200000100oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`800000403oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0F0?ooo`00603oool00`000000oooo0?ooo`0?0?ooo`800000603oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00l0oooo0P00000H0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo0P00000A
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`8000004@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03`3oool200000140oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0F
0?ooo`8000004@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01H0oooo0P00000A
0?ooo`030000003oool0oooo01H0oooo000H0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo0P00000B0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0D0?oo
o`8000004P3oool00`000000oooo0?ooo`0G0?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`80
00004`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0140oooo0P00000C0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo0P00000C0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`8000004`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0303oool2000001<0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0A0?ooo`8000004`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0140oooo0P00000C0?ooo`030000003oool0oooo01P0oooo000J0?ooo`030000
003oool0oooo0180oooo0P00000A0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
4P3oool200000140oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01@3oool2000001@0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool2000001@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0?0?ooo`800000
503oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0H0?ooo`006P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`8000005@3oool00`000000oooo
0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool03@3oool2000001D0oooo00<000000?ooo`3o
ool06@3oool001/0oooo00<000000?ooo`3oool0503oool2000000d0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0D0?ooo`8000003@3oool00`000000oooo0?ooo`0N0?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`8000005P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000001L0
oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool0000000T0oooo0P00000F0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool02`3oool2000001H0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0:0?ooo`8000005`3oool00`000000oooo0?ooo`0I0?oo
o`006`3oool00`000000oooo0?ooo`0F0?ooo`8000002P3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo01H0oooo0P00000:0?ooo`030000003oool0oooo0200oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`020?ooo`800000603oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool2000001P0oooo00<000000?oo
o`3oool0803oool010000000oooo0?ooo`0000070?ooo`800000603oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo00P0oooo0P00000H0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0203oool2000001P0oooo00<000000?ooo`3oool06P3oool001`0oooo00<000000?oo
o`3oool05`3oool2000000L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0G0?oo
o`8000001`3oool00`000000oooo0?ooo`0R0?ooo`050000003oool000000?ooo`0000000`3oool2
000001T0oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0000000D0oooo0P00
000I0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool2000001T0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool06`3oool001`0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0280oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool000000080oooo
0P00000J0?ooo`030000003oool0oooo0280oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0103oool2000001X0oooo
00<000000?ooo`3oool06`3oool001d0oooo00<000000?ooo`3oool06@3oool2000000<0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0I0?ooo`8000000`3oool00`000000oooo0?oo
o`0T0?ooo`<0000000<0oooo0000000000006`3oool00`000000oooo0?ooo`0S0?ooo`040000003o
ool000000?ooo`8000006`3oool00`000000oooo0?ooo`0T0?ooo`8000000P3oool2000001/0oooo
00<000000?ooo`3oool0903oool010000000oooo0?ooo`3oool2000001/0oooo00<000000?ooo`3o
ool08`3oool010000000oooo0?ooo`3oool2000001/0oooo00<000000?ooo`3oool0703oool001d0
oooo00<000000?ooo`3oool06`3oool2000000030?ooo`000000oooo02D0oooo00<000000?ooo`3o
ool06`3oool2000000030?ooo`000000oooo02D0oooo1000000M0?ooo`030000003oool0oooo02<0
oooo00@000000?ooo`00000000007@3oool00`000000oooo0?ooo`0T0?ooo`@000007@3oool00`00
0000oooo0?ooo`0T0?ooo`040000003oool00000000001d0oooo00<000000?ooo`3oool08`3oool0
10000000oooo00000000000M0?ooo`030000003oool0oooo01`0oooo000N0?ooob000000:03ooolP
000002P0oooo8000000W0?ooob000000:03ooolP000002P0oooo8000000W0?ooob0000007`3oool0
0?l0ooooo`3oool=0?ooo`00o`3ooooo0?ooo`d0oooo003o0?ooool0oooo3@3oool00?l0ooooo`3o
ool=0?ooo`00o`3ooooo0?ooo`d0oooo003o0?ooool0oooo3@3oool00?l0ooooo`3oool=0?ooo`00
o`3ooooo0?ooo`d0oooo000N0?ooob000000:03ooolP000002P0oooo8000000W0?ooob000000:03o
oolP000002P0oooo8000000W0?ooob0000007`3oool001d0oooo00<000000?ooo`0000007@3oool2
000002H0oooo0`00000M0?ooo`8000009P3oool00`000000oooo0?ooo`0K0?ooo`@000009@3oool0
10000000oooo00000000000M0?ooo`030000003oool0oooo02@0oooo0P00000M0?ooo`<000009P3o
ool00`000000oooo0?ooo`0K0?ooo`@000009@3oool4000001d0oooo00<000000?ooo`3oool0703o
ool001d0oooo00<000000?ooo`0000007@3oool2000002H0oooo0`00000M0?ooo`8000009P3oool0
0`000000oooo0?ooo`0I0?ooo`8000000P3oool2000002D0oooo00@000000?ooo`000000oooo0P00
000K0?ooo`030000003oool0oooo02@0oooo0P00000M0?ooo`<000009P3oool00`000000oooo0?oo
o`0I0?ooo`80000000@0oooo00000000000000009@3oool3000000030?ooo`000000000001/0oooo
00<000000?ooo`3oool0703oool001`0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000
003oool0000002@0oooo00D000000?ooo`000000oooo0000000L0?ooo`030000003oool0000002@0
oooo00<000000?ooo`3oool0603oool2000000@0oooo00<000000?ooo`0000008`3oool01@000000
oooo0?ooo`3oool000000080oooo0P00000J0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`000000703oool01@000000oooo0000003oool0000002@0oooo00<000000?ooo`3oool0603oool2
00000080oooo00D000000?ooo`000000oooo0000000S0?ooo`050000003oool000000?ooo`000000
0P3oool2000001X0oooo00<000000?ooo`3oool06`3oool001`0oooo00D000000?ooo`3oool0oooo
0000000L0?ooo`030000003oool0000002@0oooo00D000000?ooo`000000oooo0000000L0?ooo`03
0000003oool0000002@0oooo00<000000?ooo`3oool05P3oool2000000H0oooo00<000000?ooo`00
00008`3oool01@000000oooo0?ooo`3oool0000000@0oooo0P00000H0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`000000703oool01@000000oooo0000003oool0000002@0oooo00<00000
0?ooo`3oool05P3oool2000000@0oooo00D000000?ooo`000000oooo0000000S0?ooo`050000003o
ool000000?ooo`000000103oool2000001P0oooo00<000000?ooo`3oool06`3oool001/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo00000280oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo0000
0280oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo
00000240oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0803oool010000000oooo0?ooo`00000K0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0O0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo01X0oooo000K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0603oool01@000000oooo0?ooo`3oool000000240oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`000000803oool00`000000oooo0?oo
o`0E0?ooo`8000002@3oool010000000oooo0?ooo`00000Q0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool2000001L0oooo00<000000?ooo`3oool07P3oool01@000000oooo
0?ooo`3oool0000001X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool05@3oool2000000D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo01l0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`030?ooo`8000005`3oool00`000000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01P0oooo00D000000?ooo`3oool0oooo0000000P0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`00
0000803oool00`000000oooo0?ooo`0C0?ooo`8000002`3oool01@000000oooo0?ooo`3oool00000
01l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`8000005@3oool00`00
0000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000006P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooo`8000001`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool07@3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01@3oool2000001D0oooo00<000000?ooo`3o
ool06@3oool001T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool04P3oool2000000d0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool2000001@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool04P3oool2000000P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo0P00000D0?ooo`030000
003oool0oooo01P0oooo000I0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0140oooo0P00000?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo0P00000C0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0140oooo0P00000:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`8000004`3o
ool00`000000oooo0?ooo`0G0?ooo`00603oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo01L0oooo000H0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo0P00000B0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo0P00000A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo0P00000<0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`8000004@3oool00`00
0000oooo0?ooo`0F0?ooo`005`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0=0?ooo`800000503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`8000003`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0=0?ooo`8000003@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool2000000l0
oooo00<000000?ooo`3oool05P3oool001H0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool2000001H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0303oool2000000h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo
0P00000>0?ooo`030000003oool0oooo01D0oooo000F0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo0P00
000H0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00h0oooo0P00000=0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00/0oooo0P00
000@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0>0?ooo`8000003@3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`09
0?ooo`8000006P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`8000002`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`09
0?ooo`8000004@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool03`3oool2000000/0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`80
00007@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0A0?ooo`8000002@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`80
00004`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool04@3oool2000000T0oooo00<000000?ooo`3oool04`3oool001@0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1P3oool2000001l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool04P3oool2000000P0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
1P3oool2000001@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0180oooo0P0000080?ooo`030000003oool0oooo0180oooo000C0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00D0oooo0P00000Q0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo0P0000070?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00D0oooo0P00000F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0D0?ooo`8000001`3oool00`000000oooo0?ooo`0A0?ooo`004P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`030?ooo`8000008`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`8000001@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`030?ooo`8000005`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool05@3oool2000000D0oooo00<000000?ooo`3oool04@3oool0
0180oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`020?ooo`8000009P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`800000103oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`8000006@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool05`3oool2000000@0oooo00<000000?ooo`3oool03`3oool00140oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P00000X0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo0P0000020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo008000006`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool06@3oool200000080oooo00<000000?ooo`3oool03`3oool00100oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`0000000000:P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`80000000<0oooo0000003oool0
2@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`000000
0000703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool06P3oool2000000030?ooo`000000oooo00l0oooo000@0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`800000;03oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0K0?ooo`8000002P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo
0P00000M0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0K0?ooo`800000403oool000l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03@3oool00100oooo0P00000L
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool2000002`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`800000703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03P3oool00100oooo00@000000?oo
o`00000000006P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00@00000
0?ooo`0000000000:P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00@0
00000?ooo`00000000006P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool03P3oool00140oooo00@000000?ooo`3oool000006P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P00000X0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00000J0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`00
4@3oool010000000oooo0?ooo`3oool2000001T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool0oooo0P00000I0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?oo
o`004P3oool00`000000oooo0?ooo`020?ooo`8000005`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool2000002D0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo0P00000G0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`00
4P3oool00`000000oooo0?ooo`040?ooo`8000005P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool2000002<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo0P00000F0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`004`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo0P00000Q0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0140oooo000C0?ooo`030000003oool0oooo00H0oooo0P00000D0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00H0oooo0P00000D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0B0?ooo`00503oool00`000000oooo0?ooo`070?ooo`8000004P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3oool20000
01h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00L0oooo0P00000B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0B0?ooo`005@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0
oooo0P00000L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo000E0?ooo`030000003oool0oooo00T0oooo
0P00000A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`090?ooo`8000006P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool02@3oool200000140oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01@0oooo000F0?ooo`030000003oool0oooo00X0oooo0P00
000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00X0oooo0P00000?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`005P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00/0oooo0P00000G0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo000G0?oo
o`030000003oool0oooo00`0oooo0P00000=0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`8000005@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0303oool2000000d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo000G0?ooo`03
0000003oool0oooo00h0oooo0P00000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00h0oooo0P00000<0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0F0?ooo`00
603oool00`000000oooo0?ooo`0?0?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool200000180oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo0P00000;0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0F0?ooo`00603o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0100oooo0P00000@0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01L0oooo000I0?ooo`030000003oool0oooo0140oooo0P0000090?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0A0?ooo`8000003P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04@3oool2
000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01P0oooo000J0?ooo`030000003oool0oooo0180oooo0P0000070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`050000003oool0oooo
0?ooo`0000006@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo00D00000
0?ooo`3oool0oooo0000000O0?ooo`030000003oool0oooo0180oooo0P0000070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool05`3oool01@000000oooo0?ooo`3oool0000001l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`00
00007`3oool01@000000oooo0?ooo`3oool0000001T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0H0?ooo`006P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo01h0oooo00D000000?oo
o`3oool0oooo0000000J0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo01<0oooo0P00000;0?ooo`050000003oool0oooo0?ooo`000000
7`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`000000803oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01P0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`050000003oool0
oooo0?ooo`0000006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo000K
0?ooo`030000003oool0oooo01@0oooo0P0000050?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000001X0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05@3oool2000000T0
oooo00@000000?ooo`3oool000008@3oool00`000000oooo0?ooo`0D0?ooo`8000001@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool000008@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool000008@3oool010000000oooo
0?ooo`00000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool001/0oooo
00<000000?ooo`3oool05P3oool2000000@0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0P0?ooo`040000003oool0oooo000001/0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01H0oooo0P0000070?ooo`040000003oool0
oooo00000240oooo00<000000?ooo`3oool05P3oool2000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
6@3oool010000000oooo0?ooo`00000R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool06@3oool010000000oooo0?ooo`00000Q0?ooo`040000003oool0oooo000001/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`00703oool00`000000oooo0?ooo`0G0?oo
o`8000000`3oool01@000000oooo0000003oool0000002@0oooo00<000000?ooo`000000703oool0
1@000000oooo0000003oool0000002@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool05`3oool2000000<0oooo00D0
00000?ooo`3oool0oooo0000000T0?ooo`050000003oool000000?ooo`000000703oool00`000000
oooo0000000T0?ooo`050000003oool0oooo0?ooo`000000703oool00`000000oooo0000000S0?oo
o`030000003oool0000001`0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`00703oool00`00
0000oooo0?ooo`0I0?ooo`080000003oool0oooo0000003oool000000?ooo`00000T0?ooo`030000
003oool0000001`0oooo00D000000?ooo`000000oooo0000000T0?ooo`030000003oool0oooo01P0
oooo0P0000040?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool06@3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0280oooo00D000000?ooo`000000oooo0000000L
0?ooo`030000003oool0000002@0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000003o
ool0000002<0oooo00<000000?ooo`000000703oool01@000000oooo0?ooo`3oool0000001d0oooo
000M0?ooo`030000003oool0oooo01T0oooo0P000000103oool0000000000000000V0?ooo`800000
7@3oool3000002H0oooo00<000000?ooo`3oool06@3oool200000080oooo0P00000U0?ooo`030000
003oool0oooo01T0oooo0P000000103oool000000?ooo`00000V0?ooo`<000007@3oool2000002H0
oooo00<000000?ooo`0000007@3oool2000002D0oooo0P00000M0?ooo`030000003oool0000001h0
oooo000M0?ooo`030000003oool0oooo01/0oooo1000000V0?ooo`8000007@3oool3000002H0oooo
00<000000?ooo`3oool06`3oool4000002D0oooo00<000000?ooo`3oool06`3oool2000000030?oo
o`000000oooo02D0oooo0`00000M0?ooo`8000009P3oool00`000000oooo0000000M0?ooo`800000
9@3oool2000001d0oooo00<000000?ooo`0000007P3oool001h0oooo8000000X0?ooob000000:03o
oolP000002L0oooo8000000X0?ooob000000:03ooolP000002L0oooo8000000O0?ooo`00o`3ooooo
0?ooo`d0oooo003o0?ooool0oooo3@3oool00?l0ooooo`3oool=0?ooo`00o`3ooooo0?ooo`d0oooo
0000\
\>"],
  ImageRangeCache->{{{0, 522.625}, {124.313, 0}} -> {-0.197259, -0.0418858, \
0.0141488, 0.0141488}, {{13.9375, 79}, {121.313, 64.9375}} -> {-1.49987, \
-1.00664, 0.032277, 0.032277}, {{85.5, 150.625}, {121.313, 64.9375}} -> \
{-3.80875, -1.00612, 0.0322605, 0.0322605}, {{157.125, 222.25}, {121.313, \
64.9375}} -> {-6.1194, -1.00612, 0.0322605, 0.0322605}, {{228.75, 293.813}, \
{121.313, 64.9375}} -> {-8.43338, -1.00664, 0.032277, 0.032277}, {{300.313, \
365.438}, {121.313, 64.9375}} -> {-10.7387, -1.00612, 0.0322605, 0.0322605}, \
{{371.938, 437.063}, {121.313, 64.9375}} -> {-13.0494, -1.00612, 0.0322605, \
0.0322605}, {{443.563, 508.625}, {121.313, 64.9375}} -> {-15.3669, -1.00664, \
0.032277, 0.032277}, {{13.9375, 79}, {59.3125, 2.9375}} -> {-1.49987, \
-3.00781, 0.032277, 0.032277}, {{85.5, 150.625}, {59.3125, 2.9375}} -> \
{-3.80875, -3.00627, 0.0322605, 0.0322605}, {{157.125, 222.25}, {59.3125, \
2.9375}} -> {-6.1194, -3.00627, 0.0322605, 0.0322605}, {{228.75, 293.813}, \
{59.3125, 2.9375}} -> {-8.43338, -3.00781, 0.032277, 0.032277}, {{300.313, \
365.438}, {59.3125, 2.9375}} -> {-10.7387, -3.00627, 0.0322605, 0.0322605}, \
{{371.938, 437.063}, {59.3125, 2.9375}} -> {-13.0494, -3.00627, 0.0322605, \
0.0322605}, {{443.563, 508.625}, {59.3125, 2.9375}} -> {-15.3669, -3.00781, \
0.032277, 0.032277}}]
}, Open  ]],

Cell["To each expression we associate triads of vertices:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({#, tri[functional[#], Range[6]]} &\)\  /@ \ 
      brackets[CharacterRange["\<a\>", "\<e\>"]]\)], "Input",
  CellLabel->"In[267]:="],

Cell[BoxData[
    \({{"((((ab)c)d)e)", {{1, 2, 3}, {1, 3, 4}, {1, 4, 5}, {1, 5, 
            6}}}, {"(((a(bc))d)e)", {{1, 2, 4}, {1, 4, 5}, {1, 5, 6}, {2, 3, 
            4}}}, {"(((ab)(cd))e)", {{1, 2, 3}, {1, 3, 5}, {1, 5, 6}, {3, 4, 
            5}}}, {"(((ab)c)(de))", {{1, 2, 3}, {1, 3, 4}, {1, 4, 6}, {4, 5, 
            6}}}, {"((a((bc)d))e)", {{1, 2, 5}, {1, 5, 6}, {2, 3, 4}, {2, 4, 
            5}}}, {"((a(b(cd)))e)", {{1, 2, 5}, {1, 5, 6}, {2, 3, 5}, {3, 4, 
            5}}}, {"((a(bc))(de))", {{1, 2, 4}, {1, 4, 6}, {2, 3, 4}, {4, 5, 
            6}}}, {"((ab)((cd)e))", {{1, 2, 3}, {1, 3, 6}, {3, 4, 5}, {3, 5, 
            6}}}, {"((ab)(c(de)))", {{1, 2, 3}, {1, 3, 6}, {3, 4, 6}, {4, 5, 
            6}}}, {"(a(((bc)d)e))", {{1, 2, 6}, {2, 3, 4}, {2, 4, 5}, {2, 5, 
            6}}}, {"(a((b(cd))e))", {{1, 2, 6}, {2, 3, 5}, {2, 5, 6}, {3, 4, 
            5}}}, {"(a((bc)(de)))", {{1, 2, 6}, {2, 3, 4}, {2, 4, 6}, {4, 5, 
            6}}}, {"(a(b((cd)e)))", {{1, 2, 6}, {2, 3, 6}, {3, 4, 5}, {3, 5, 
            6}}}, {"(a(b(c(de))))", {{1, 2, 6}, {2, 3, 6}, {3, 4, 6}, {4, 5, 
            6}}}}\)], "Output",
  CellLabel->"Out[267]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Selecting Non-isomorphic Triangulations", "Subsubsection"],

Cell["\<\
The second triangulation is isomorphic to the ninth one. Triangle 124 appears \
as triangle 136. That is, the set of triangulations becomes the second under \
a rotation. The second and fourth suggests a second class of equivalence, \
which in turn suggests the definition of a ''triangulation isomorphism'' on \
all possible applications of a binary operation. For the case of five \
variables we have three classes arising under equivalence by the dihedral \
group.\
\>", "Text"],

Cell[BoxData[
    \(group[n_] := 
      Module[{rot = NestList[RotateLeft[#] &, Range[n], n - 1], u, 
          refl}, \[IndentingNewLine]u = 
          Range[3, 
            1 + \[LeftFloor]n\/2\[RightFloor]]; \[IndentingNewLine]refl = 
          Join[{1 \[Rule] 2, 2 \[Rule] 1}, Thread[u \[Rule] n + 3 - u], 
            Thread[n + 3 - u \[Rule] u]]; \[IndentingNewLine]Union[\(Thread[
                Range[n] \[Rule] #] &\)\  /@ 
            Join[rot, rot\  /. \ refl]]]\)], "Input",
  CellLabel->"In[209]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(group[7]\)], "Input",
  CellLabel->"In[268]:="],

Cell[BoxData[
    \({{1 \[Rule] 1, 2 \[Rule] 2, 3 \[Rule] 3, 4 \[Rule] 4, 5 \[Rule] 5, 
        6 \[Rule] 6, 7 \[Rule] 7}, {1 \[Rule] 1, 2 \[Rule] 7, 3 \[Rule] 6, 
        4 \[Rule] 5, 5 \[Rule] 4, 6 \[Rule] 3, 7 \[Rule] 2}, {1 \[Rule] 2, 
        2 \[Rule] 1, 3 \[Rule] 7, 4 \[Rule] 6, 5 \[Rule] 5, 6 \[Rule] 4, 
        7 \[Rule] 3}, {1 \[Rule] 2, 2 \[Rule] 3, 3 \[Rule] 4, 4 \[Rule] 5, 
        5 \[Rule] 6, 6 \[Rule] 7, 7 \[Rule] 1}, {1 \[Rule] 3, 2 \[Rule] 2, 
        3 \[Rule] 1, 4 \[Rule] 7, 5 \[Rule] 6, 6 \[Rule] 5, 
        7 \[Rule] 4}, {1 \[Rule] 3, 2 \[Rule] 4, 3 \[Rule] 5, 4 \[Rule] 6, 
        5 \[Rule] 7, 6 \[Rule] 1, 7 \[Rule] 2}, {1 \[Rule] 4, 2 \[Rule] 3, 
        3 \[Rule] 2, 4 \[Rule] 1, 5 \[Rule] 7, 6 \[Rule] 6, 
        7 \[Rule] 5}, {1 \[Rule] 4, 2 \[Rule] 5, 3 \[Rule] 6, 4 \[Rule] 7, 
        5 \[Rule] 1, 6 \[Rule] 2, 7 \[Rule] 3}, {1 \[Rule] 5, 2 \[Rule] 4, 
        3 \[Rule] 3, 4 \[Rule] 2, 5 \[Rule] 1, 6 \[Rule] 7, 
        7 \[Rule] 6}, {1 \[Rule] 5, 2 \[Rule] 6, 3 \[Rule] 7, 4 \[Rule] 1, 
        5 \[Rule] 2, 6 \[Rule] 3, 7 \[Rule] 4}, {1 \[Rule] 6, 2 \[Rule] 5, 
        3 \[Rule] 4, 4 \[Rule] 3, 5 \[Rule] 2, 6 \[Rule] 1, 
        7 \[Rule] 7}, {1 \[Rule] 6, 2 \[Rule] 7, 3 \[Rule] 1, 4 \[Rule] 2, 
        5 \[Rule] 3, 6 \[Rule] 4, 7 \[Rule] 5}, {1 \[Rule] 7, 2 \[Rule] 1, 
        3 \[Rule] 2, 4 \[Rule] 3, 5 \[Rule] 4, 6 \[Rule] 5, 
        7 \[Rule] 6}, {1 \[Rule] 7, 2 \[Rule] 6, 3 \[Rule] 5, 4 \[Rule] 4, 
        5 \[Rule] 3, 6 \[Rule] 2, 7 \[Rule] 1}}\)], "Output",
  CellLabel->"Out[268]="]
}, Open  ]],

Cell[BoxData[
    \(sweep[s_] := 
      Module[{br = brackets[Characters[s]], n = StringLength[s] + 1, m, 
          o = {}, h, k, 
          g}, \[IndentingNewLine]m = \({#, 
                tri[functional[#], Range[n]]} &\)\  /@ \ 
            br; \[IndentingNewLine]g = group[n]; \[IndentingNewLine]While[
          m \[NotEqual] {}, \[IndentingNewLine]h = 
            Last[First[m]]; \[IndentingNewLine]AppendTo[o, 
            m\[LeftDoubleBracket]1, 
              1\[RightDoubleBracket]]; \[IndentingNewLine]k = 
            Union[\(Sort[Sort\  /@ \ \((h\  /. #)\)] &\) /@ \ 
                g]; \[IndentingNewLine]m = 
            Select[m, 
              Not[MemberQ[k, Last[#]]] &]]; \[IndentingNewLine]o]\)], "Input",\

  CellLabel->"In[210]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(sweep["\<abcdef\>"]\)], "Input",
  CellLabel->"In[269]:="],

Cell[BoxData[
    \({"(((((ab)c)d)e)f)", "((((a(bc))d)e)f)", "((((ab)(cd))e)f)", 
      "(((a((bc)d))e)f)"}\)], "Output",
  CellLabel->"Out[269]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[
          triangulation\  /@ \ sweep["\<abcdef\>"]]];\)\)], "Input",
  CellLabel->"In[270]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .23854 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0056795 0.238095 [
[ 0 0 0 0 ]
[ 1 .23854 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .23854 L
0 .23854 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0056795 0.245293 0.232859 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
.78756 .90455 m
.02381 .73023 L
.02381 .29548 L
.78756 .90455 L
.02381 .73023 L
s
.78756 .90455 m
.02381 .29548 L
.36371 .02442 L
.78756 .90455 L
.02381 .29548 L
s
.78756 .90455 m
.36371 .02442 L
.78756 .12116 L
.78756 .90455 L
.36371 .02442 L
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0056795 0.488926 0.232859 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.78756 .90455 m
.36371 1.0013 L
.02381 .29548 L
.78756 .90455 L
.36371 1.0013 L
s
.78756 .90455 m
.02381 .29548 L
.36371 .02442 L
.78756 .90455 L
.02381 .29548 L
s
.78756 .90455 m
.36371 .02442 L
.78756 .12116 L
.78756 .90455 L
.36371 .02442 L
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0056795 0.732558 0.232859 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
.78756 .90455 m
.02381 .73023 L
.36371 .02442 L
.78756 .90455 L
.02381 .73023 L
s
.78756 .90455 m
.36371 .02442 L
.78756 .12116 L
.78756 .90455 L
.36371 .02442 L
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0056795 0.97619 0.232859 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.78756 .90455 m
.36371 1.0013 L
.36371 .02442 L
.78756 .90455 L
.36371 1.0013 L
s
.78756 .90455 m
.36371 .02442 L
.78756 .12116 L
.78756 .90455 L
.36371 .02442 L
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.36371 1.0013 m
.02381 .29548 L
.36371 .02442 L
.36371 1.0013 L
.02381 .29548 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[270]:=",
  ImageSize->{288, 68.6875},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000A2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`007`3oool300000480oooo0`0000120?ooo`<00000
@P3oool3000002l0oooo000N0?ooo`8000000P3oool4000003d0oooo0P0000020?ooo`@00000?@3o
ool200000080oooo1000000m0?ooo`8000000P3oool4000002/0oooo000L0?ooo`8000000P3oool0
0`000000oooo0?ooo`030?ooo`@00000=`3oool200000080oooo00<000000?ooo`3oool00`3oool4
000003L0oooo0`0000000`3oool000000?ooo`040?ooo`D00000=P3oool2000000030?ooo`000000
000000D0oooo1@00000V0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo1@00000a0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool50000
0340oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`@00000<@3oool010000000oooo0?oo
o`3oool2000000X0oooo1000000R0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00/0oooo1000000/0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3o
ool4000002`0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0;0?ooo`D00000
:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000d0oooo1@00000M0?ooo`00603o
ool2000000L0oooo00<000000?ooo`3oool03`3oool4000002H0oooo0P0000070?ooo`030000003o
ool0oooo00l0oooo1000000W0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`0@0?ooo`@000009P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000180oooo
1000000I0?ooo`005`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo0`00
000R0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool300000280oooo0P00
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool300000240oooo0P00
00060?ooo`040000003oool0oooo000001D0oooo0`00000F0?ooo`005P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000005`3oool00`000000oooo
0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01<0oooo0P00
000O0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool2000001l0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo0P00
000N0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000F0?ooo`800000
5@3oool001<0oooo0P00000>0?ooo`030000003oool0oooo01<0oooo0P00000M0?ooo`8000003P3o
ool00`000000oooo0?ooo`0C0?ooo`8000007P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0503oool2000001d0oooo00<000000?ooo`3oool0203o
ool01@000000oooo0?ooo`3oool0000001H0oooo0P00000E0?ooo`004P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`0000006`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`000000703oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0000
000K0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0000001@0oooo000A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0000000J0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0000000J0?ooo`8000001`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`0000006@3oool2000000`0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0000001@0oooo000?0?oo
o`800000503oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000001L0oooo0P00000D
0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool00000603oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool010000000oooo0?oo
o`00000G0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0B0?ooo`040000003oool0oooo000001<0oooo000>0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00000F0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo
000001H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0180oooo00@000000?ooo`3oool000004`3oool000d0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000503oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`050000
003oool0oooo0?ooo`000000503oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool000000180oooo000;0?ooo`80
00006@3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool20000
01T0oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000001<0oooo0P00000:
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3o
ool000000180oooo0P00000A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3o
ool01@000000oooo0?ooo`3oool000000180oooo000:0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0?0?ooo`002@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool000T0oooo0P00000M0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`8000007@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0>0?ooo`002@3oool010000000oooo00000000000K0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`@000006`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo0P00000C0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00h0oooo00090?ooo`050000003oool0oooo0?ooo`0000006P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool200000080oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo0P00000C
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00d0oooo00090?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo000000020?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool000000180oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03@3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`00
2@3oool00`000000oooo0?ooo`040?ooo`800000603oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000030?ooo`80
0000603oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3o
ool000004@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`002@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00T0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000A
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00/0oooo00090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000
000@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00/0oooo00090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo
0000000@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00X0oooo00090?ooo`030000003oool0oooo00T0oooo0P00
000E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000001D0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`002@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`002@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`002@3oool00`000000oooo0?ooo`0=0?ooo`80
00004P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0P00000B0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool000T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool000T0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
00T0oooo00<000000?ooo`3oool04P3oool2000000l0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0:0?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00X0oooo00090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool01@000000
oooo0?ooo`3oool000000240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00X0oooo00090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02P3oool01@000000oooo0?ooo`3oool000000280oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00090?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000S0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`002@3oool00`000000
oooo0?ooo`0G0?ooo`800000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0
oooo0P00000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0;0?ooo`040000003oool0oooo000002@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00090?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0000000U0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`002@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000009P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool000T0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`8000009`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool000T0oooo00<00000
0?ooo`3oool0703oool2000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@
0?ooo`8000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03@3oool2000002P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00h0oooo00090?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`002@3oool3000001l0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03P3oool3000002P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00l0oooo000:0?ooo`030000003oool0000000<00000703oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0000000<00000903oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool000/0oooo0P0000030?ooo`@000006@3o
ool2000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0100oooo
0P00000:0?ooo`030000003oool0oooo01<0oooo0P0000060?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`0A0?ooo`8000000`3oool400000240oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0100oooo0P00000:0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0403oool000d0oooo00<000000?ooo`3oool0103oool5000001H0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`040?ooo`D00000703oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
503oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0403oool000h0oooo
00<000000?ooo`3oool0203oool4000001<0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00P0oooo1000000I0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0140oooo000?0?ooo`800000303oool400000100oooo0P0000030?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool05@3oool2000000P0oooo00<000000?ooo`3oool05@3o
ool2000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00/0oooo1000000E0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool05@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0140oooo000A0?ooo`03
0000003oool0oooo00d0oooo1@00000=0?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000001X0oooo0P00000?0?ooo`D000004@3oool01@00
0000oooo0000003oool0000001T0oooo0P0000070?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool05P3oool01@000000oooo0000003oool0000001@0oooo000B0?ooo`030000003oool0
oooo0140oooo1000000:0?ooo`080000003oool0oooo0000003oool000000?ooo`00000K0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool05`3oool020000000oooo0?ooo`000000oooo
0000003oool00000703oool00`000000oooo0?ooo`0A0?ooo`@000003@3oool01@000000oooo0000
003oool0000001/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01H0oooo00D000000?ooo`000000oooo0000000D0?ooo`004`3oool00`000000oooo
0?ooo`0D0?ooo`D000001P3oool00`000000oooo0?ooo`03000001d0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00<000007P3oool00`000000oooo
0?ooo`0D0?ooo`D000002@3oool3000001d0oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool0000001T0oooo0`00000E0?ooo`00503oool2000001T0oooo100000030?ooo`D00000
7P3oool2000000D0oooo00<000000?ooo`3oool0603oool5000001l0oooo00<000000?ooo`3oool0
603oool4000000D0oooo0`00000N0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo0000000I0?ooo`<000005@3oool001H0oooo00<000000?ooo`3oool06P3oool4000000030?oo
o`00000000000240oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`800000
8@3oool00`000000oooo0?ooo`0K0?ooo`@000000P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`0D0?ooo`00
5`3oool00`000000oooo0?ooo`0M0?ooo`<000008P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01P0oooo0`00000R0?ooo`8000007`3oool300000240oooo0P0000030?ooo`040000
003oool0oooo000001P0oooo0`00000F0?ooo`00603oool2000001T0oooo1000000V0?ooo`800000
0P3oool00`000000oooo0?ooo`0D0?ooo`@000009`3oool00`000000oooo0?ooo`0H0?ooo`@00000
9P3oool01`000000oooo0?ooo`3oool000000?ooo`000000503oool4000001T0oooo000J0?ooo`03
0000003oool0oooo0180oooo1000000/0?ooo`040000003oool0oooo00000140oooo1000000/0?oo
o`030000003oool0oooo0180oooo1@00000[0?ooo`060000003oool0oooo0000003oool000003`3o
ool5000001d0oooo000K0?ooo`030000003oool0oooo00`0oooo1@00000a0?ooo`030000003oool0
000000`0oooo1@00000a0?ooo`030000003oool0oooo00d0oooo1000000a0?ooo`030000003oool0
oooo008000002`3oool400000280oooo000L0?ooo`800000203oool4000003L0oooo0`0000070?oo
o`@00000=`3oool2000000P0oooo1@00000f0?ooo`@000001P3oool5000002H0oooo000N0?ooo`04
0000003oool0oooo0?ooo`@00000?@3oool010000000oooo0?ooo`3oool4000003d0oooo00@00000
0?ooo`3oool0oooo1000000m0?ooo`8000000P3oool4000002/0oooo000O0?ooo`<00000@P3oool3
00000480oooo0`0000120?ooo`<00000;`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {67.6875, 0}} -> {-0.124018, -0.0238589, \
0.0148015, 0.0148015}, {{8.375, 71.1875}, {66.0625, 1.5625}} -> {-1.21464, \
-1.07647, 0.0317777, 0.0317777}, {{77.5, 140.313}, {66.0625, 1.5625}} -> \
{-3.41127, -1.07647, 0.0317777, 0.0317777}, {{146.625, 209.438}, {66.0625, \
1.5625}} -> {-5.60791, -1.07647, 0.0317777, 0.0317777}, {{215.75, 278.563}, \
{66.0625, 1.5625}} -> {-7.80454, -1.07647, 0.0317777, 0.0317777}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      Length[sweep[StringJoin[ToString\  /@ \ Range[n]]]], {n, 3, 
        10}]\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \({1, 1, 3, 4, 12, 27, 82, 733}\)], "Output",
  CellLabel->"Out[107]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Decorating Triangulations", "Subsubsection"],

Cell[TextData[{
  "Function ",
  StyleBox["dis",
    FontSlant->"Italic"],
  " computes the distance from point {x,y} to segment AB. Given the vertices \
of a triangle A, B and C, function ",
  StyleBox["decorateT",
    FontSlant->"Italic"],
  " computes the value {c, r}, where c is the center of the incircle to the \
given triangle and r is its radius. "
}], "Text"],

Cell[BoxData[{
    \(\(\(dis[{x_, y_}, {A_, B_}] := 
      N[{x, y} - 
          A - \(\(({x, y} - A)\) . \((B - A)\)\/\((B - A)\) . \((B - 
                      A)\)\) \((B - A)\)]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(decorateT[{A_, B_, C_}] := 
      Module[{v, s, u, sol, x, y, d, m, 
          i}, \[IndentingNewLine]v = {{A, B}, {B, C}, {C, 
              A}}; \[IndentingNewLine]s = 
          Map[\((u = dis[{x, y}, #]; u . u)\) &, 
            v]; \[IndentingNewLine]sol = \(({x, y} /. 
              NSolve[{s\[LeftDoubleBracket]1\[RightDoubleBracket] \[Equal] 
                    s\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\
\)\), s\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\) \[Equal] 
                    s\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\
\)\)}, {x, 
                  y}])\); \[IndentingNewLine]d = \((\(\@\(\((u = dis[#, {A, \
B}])\) . u\) &\) /@ \ sol)\); \[IndentingNewLine]m = 
          Min[d]; \[IndentingNewLine]i = \(Position[d, 
              m]\)\[LeftDoubleBracket]1, 
            1\[RightDoubleBracket]; \[IndentingNewLine]{sol\
\[LeftDoubleBracket]i\[RightDoubleBracket], 
          d\[LeftDoubleBracket]i\[RightDoubleBracket]}]\)}], "Input",
  CellLabel->"In[211]:=",
  InitializationCell->True],

Cell["\<\
With their help, we can decorate the interior of each triangle in the \
triangulation with incircles.\
\>", "Text"],

Cell[BoxData[
    \(triangulation2[s_String] := 
      Module[{u = functional[s], n, v, d, t}, \[IndentingNewLine]n = 
          numVar[u] + 
            1; \[IndentingNewLine]v = \(N[{Cos[\(\(\ \)\(2\ \[Pi]\ #\)\)\/n], 
                  Sin[\(\(\ \)\(2\ \[Pi]\ #\)\)\/n]}] &\) /@ 
            Range[n]; \[IndentingNewLine]Graphics[\(\((d = 
                  decorateT[#]; \[IndentingNewLine]\ {{PowderBlue, 
                    Disk[First[d], Last[d]]}, Circle[First[d], Last[d]], 
                  Line[# /. \ {x___, y_} \[Rule] {x, y, x}]})\) &\) /@ \ 
            tri[u, v], AspectRatio \[Rule] Automatic]]\)], "Input",
  CellLabel->"In[213]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[
          Partition[triangulation2\  /@ \ brackets[Characters["\<abcdef\>"]], 
            7]]];\)\)], "Input",
  CellLabel->"In[271]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .87726 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0208871 0.136054 [
[ 0 0 0 0 ]
[ 1 .87726 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .87726 L
0 .87726 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0208871 0.149123 0.149423 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.38579 .12116 m
.38579 .12116 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.38579 .12116 .0894 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.78756 .12116 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.70361 .29548 m
.70361 .29548 .15127 0 365.73 arc
F
0 g
newpath
.70361 .29548 .15127 0 365.73 arc
s
.02381 .29548 m
.78756 .12116 L
.97619 .51286 L
.02381 .29548 L
.78756 .12116 L
s
.69 .878 .902 r
.44766 .63349 m
.44766 .63349 .23522 0 365.73 arc
F
0 g
newpath
.44766 .63349 .23522 0 365.73 arc
s
.36371 1.0013 m
.02381 .29548 L
.97619 .51286 L
.36371 1.0013 L
.02381 .29548 L
s
.69 .878 .902 r
.11321 .68718 m
.11321 .68718 .0894 0 365.73 arc
F
0 g
newpath
.11321 .68718 .0894 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.72569 .82697 m
.72569 .82697 .0894 0 365.73 arc
F
0 g
newpath
.72569 .82697 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.97619 .51286 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0208871 0.286967 0.149423 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.36371 .2179 m
.36371 .2179 .15127 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.36371 .2179 .15127 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.97619 .51286 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.72569 .19874 m
.72569 .19874 .0894 0 365.73 arc
F
0 g
newpath
.72569 .19874 .0894 0 365.73 arc
s
.36371 .02442 m
.78756 .12116 L
.97619 .51286 L
.36371 .02442 L
.78756 .12116 L
s
.69 .878 .902 r
.44766 .63349 m
.44766 .63349 .23522 0 365.73 arc
F
0 g
newpath
.44766 .63349 .23522 0 365.73 arc
s
.36371 1.0013 m
.02381 .29548 L
.97619 .51286 L
.36371 1.0013 L
.02381 .29548 L
s
.69 .878 .902 r
.11321 .68718 m
.11321 .68718 .0894 0 365.73 arc
F
0 g
newpath
.11321 .68718 .0894 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.72569 .82697 m
.72569 .82697 .0894 0 365.73 arc
F
0 g
newpath
.72569 .82697 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.97619 .51286 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0208871 0.424812 0.149423 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .33854 m
.11321 .33854 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .33854 .0894 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.44766 .19874 m
.44766 .19874 .15127 0 365.73 arc
F
0 g
newpath
.44766 .19874 .15127 0 365.73 arc
s
.02381 .73023 m
.36371 .02442 L
.78756 .12116 L
.02381 .73023 L
.36371 .02442 L
s
.69 .878 .902 r
.72569 .39222 m
.72569 .39222 .17335 0 365.73 arc
F
0 g
newpath
.72569 .39222 .17335 0 365.73 arc
s
.02381 .73023 m
.78756 .12116 L
.97619 .51286 L
.02381 .73023 L
.78756 .12116 L
s
.69 .878 .902 r
.36371 .80781 m
.36371 .80781 .15127 0 365.73 arc
F
0 g
newpath
.36371 .80781 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.97619 .51286 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.72569 .82697 m
.72569 .82697 .0894 0 365.73 arc
F
0 g
newpath
.72569 .82697 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.97619 .51286 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0208871 0.562657 0.149423 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.38579 .12116 m
.38579 .12116 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.38579 .12116 .0894 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.78756 .12116 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.17508 .41612 m
.17508 .41612 .15127 0 365.73 arc
F
0 g
newpath
.17508 .41612 .15127 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.78756 .12116 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.72569 .39222 m
.72569 .39222 .17335 0 365.73 arc
F
0 g
newpath
.72569 .39222 .17335 0 365.73 arc
s
.02381 .73023 m
.78756 .12116 L
.97619 .51286 L
.02381 .73023 L
.78756 .12116 L
s
.69 .878 .902 r
.36371 .80781 m
.36371 .80781 .15127 0 365.73 arc
F
0 g
newpath
.36371 .80781 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.97619 .51286 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.72569 .82697 m
.72569 .82697 .0894 0 365.73 arc
F
0 g
newpath
.72569 .82697 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.97619 .51286 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0208871 0.700501 0.149423 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .33854 m
.11321 .33854 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .33854 .0894 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.44766 .39222 m
.44766 .39222 .23522 0 365.73 arc
F
0 g
newpath
.44766 .39222 .23522 0 365.73 arc
s
.02381 .73023 m
.36371 .02442 L
.97619 .51286 L
.02381 .73023 L
.36371 .02442 L
s
.69 .878 .902 r
.72569 .19874 m
.72569 .19874 .0894 0 365.73 arc
F
0 g
newpath
.72569 .19874 .0894 0 365.73 arc
s
.36371 .02442 m
.78756 .12116 L
.97619 .51286 L
.36371 .02442 L
.78756 .12116 L
s
.69 .878 .902 r
.36371 .80781 m
.36371 .80781 .15127 0 365.73 arc
F
0 g
newpath
.36371 .80781 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.97619 .51286 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.72569 .82697 m
.72569 .82697 .0894 0 365.73 arc
F
0 g
newpath
.72569 .82697 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.97619 .51286 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0208871 0.838346 0.149423 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.38579 .12116 m
.38579 .12116 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.38579 .12116 .0894 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.78756 .12116 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.70361 .29548 m
.70361 .29548 .15127 0 365.73 arc
F
0 g
newpath
.70361 .29548 .15127 0 365.73 arc
s
.02381 .29548 m
.78756 .12116 L
.97619 .51286 L
.02381 .29548 L
.78756 .12116 L
s
.69 .878 .902 r
.19716 .51286 m
.19716 .51286 .17335 0 365.73 arc
F
0 g
newpath
.19716 .51286 .17335 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.97619 .51286 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.36371 .80781 m
.36371 .80781 .15127 0 365.73 arc
F
0 g
newpath
.36371 .80781 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.97619 .51286 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.72569 .82697 m
.72569 .82697 .0894 0 365.73 arc
F
0 g
newpath
.72569 .82697 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.97619 .51286 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0208871 0.97619 0.149423 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.36371 .2179 m
.36371 .2179 .15127 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.36371 .2179 .15127 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.97619 .51286 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.19716 .51286 m
.19716 .51286 .17335 0 365.73 arc
F
0 g
newpath
.19716 .51286 .17335 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.97619 .51286 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.72569 .19874 m
.72569 .19874 .0894 0 365.73 arc
F
0 g
newpath
.72569 .19874 .0894 0 365.73 arc
s
.36371 .02442 m
.78756 .12116 L
.97619 .51286 L
.36371 .02442 L
.78756 .12116 L
s
.69 .878 .902 r
.36371 .80781 m
.36371 .80781 .15127 0 365.73 arc
F
0 g
newpath
.36371 .80781 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.97619 .51286 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.72569 .82697 m
.72569 .82697 .0894 0 365.73 arc
F
0 g
newpath
.72569 .82697 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.97619 .51286 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.162277 0.149123 0.290813 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.21244 .33854 m
.21244 .33854 .15127 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.21244 .33854 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .29548 L
.36371 .02442 L
.36371 1.0013 L
.02381 .29548 L
s
.69 .878 .902 r
.11321 .68718 m
.11321 .68718 .0894 0 365.73 arc
F
0 g
newpath
.11321 .68718 .0894 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.53706 .2418 m
.53706 .2418 .17335 0 365.73 arc
F
0 g
newpath
.53706 .2418 .17335 0 365.73 arc
s
.36371 1.0013 m
.36371 .02442 L
.78756 .12116 L
.36371 1.0013 L
.36371 .02442 L
s
.69 .878 .902 r
.78756 .4698 m
.78756 .4698 .15127 0 365.73 arc
F
0 g
newpath
.78756 .4698 .15127 0 365.73 arc
s
.36371 1.0013 m
.78756 .12116 L
.97619 .51286 L
.36371 1.0013 L
.78756 .12116 L
s
.69 .878 .902 r
.72569 .82697 m
.72569 .82697 .0894 0 365.73 arc
F
0 g
newpath
.72569 .82697 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.97619 .51286 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.162277 0.286967 0.290813 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .33854 m
.11321 .33854 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .33854 .0894 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.21244 .68718 m
.21244 .68718 .15127 0 365.73 arc
F
0 g
newpath
.21244 .68718 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.36371 .02442 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.53706 .2418 m
.53706 .2418 .17335 0 365.73 arc
F
0 g
newpath
.53706 .2418 .17335 0 365.73 arc
s
.36371 1.0013 m
.36371 .02442 L
.78756 .12116 L
.36371 1.0013 L
.36371 .02442 L
s
.69 .878 .902 r
.78756 .4698 m
.78756 .4698 .15127 0 365.73 arc
F
0 g
newpath
.78756 .4698 .15127 0 365.73 arc
s
.36371 1.0013 m
.78756 .12116 L
.97619 .51286 L
.36371 1.0013 L
.78756 .12116 L
s
.69 .878 .902 r
.72569 .82697 m
.72569 .82697 .0894 0 365.73 arc
F
0 g
newpath
.72569 .82697 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.97619 .51286 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.162277 0.424812 0.290813 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.38579 .12116 m
.38579 .12116 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.38579 .12116 .0894 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.78756 .12116 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.36371 .45917 m
.36371 .45917 .23522 0 365.73 arc
F
0 g
newpath
.36371 .45917 .23522 0 365.73 arc
s
.36371 1.0013 m
.02381 .29548 L
.78756 .12116 L
.36371 1.0013 L
.02381 .29548 L
s
.69 .878 .902 r
.11321 .68718 m
.11321 .68718 .0894 0 365.73 arc
F
0 g
newpath
.11321 .68718 .0894 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.78756 .4698 m
.78756 .4698 .15127 0 365.73 arc
F
0 g
newpath
.78756 .4698 .15127 0 365.73 arc
s
.36371 1.0013 m
.78756 .12116 L
.97619 .51286 L
.36371 1.0013 L
.78756 .12116 L
s
.69 .878 .902 r
.72569 .82697 m
.72569 .82697 .0894 0 365.73 arc
F
0 g
newpath
.72569 .82697 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.97619 .51286 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.162277 0.562657 0.290813 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.72569 .19874 m
.72569 .19874 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.72569 .19874 .0894 0 365.73 arc
s
.36371 .02442 m
.78756 .12116 L
.97619 .51286 L
.36371 .02442 L
.78756 .12116 L
s
.69 .878 .902 r
.21244 .33854 m
.21244 .33854 .15127 0 365.73 arc
F
0 g
newpath
.21244 .33854 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .29548 L
.36371 .02442 L
.36371 1.0013 L
.02381 .29548 L
s
.69 .878 .902 r
.11321 .68718 m
.11321 .68718 .0894 0 365.73 arc
F
0 g
newpath
.11321 .68718 .0894 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.59893 .51286 m
.59893 .51286 .23522 0 365.73 arc
F
0 g
newpath
.59893 .51286 .23522 0 365.73 arc
s
.36371 1.0013 m
.36371 .02442 L
.97619 .51286 L
.36371 1.0013 L
.36371 .02442 L
s
.69 .878 .902 r
.72569 .82697 m
.72569 .82697 .0894 0 365.73 arc
F
0 g
newpath
.72569 .82697 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.97619 .51286 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.162277 0.700501 0.290813 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .33854 m
.11321 .33854 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .33854 .0894 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.44766 .19874 m
.44766 .19874 .15127 0 365.73 arc
F
0 g
newpath
.44766 .19874 .15127 0 365.73 arc
s
.02381 .73023 m
.36371 .02442 L
.78756 .12116 L
.02381 .73023 L
.36371 .02442 L
s
.69 .878 .902 r
.30184 .73023 m
.30184 .73023 .17335 0 365.73 arc
F
0 g
newpath
.30184 .73023 .17335 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.78756 .12116 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.78756 .4698 m
.78756 .4698 .15127 0 365.73 arc
F
0 g
newpath
.78756 .4698 .15127 0 365.73 arc
s
.36371 1.0013 m
.78756 .12116 L
.97619 .51286 L
.36371 1.0013 L
.78756 .12116 L
s
.69 .878 .902 r
.72569 .82697 m
.72569 .82697 .0894 0 365.73 arc
F
0 g
newpath
.72569 .82697 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.97619 .51286 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.162277 0.838346 0.290813 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.38579 .12116 m
.38579 .12116 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.38579 .12116 .0894 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.78756 .12116 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.17508 .41612 m
.17508 .41612 .15127 0 365.73 arc
F
0 g
newpath
.17508 .41612 .15127 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.78756 .12116 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.30184 .73023 m
.30184 .73023 .17335 0 365.73 arc
F
0 g
newpath
.30184 .73023 .17335 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.78756 .12116 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.78756 .4698 m
.78756 .4698 .15127 0 365.73 arc
F
0 g
newpath
.78756 .4698 .15127 0 365.73 arc
s
.36371 1.0013 m
.78756 .12116 L
.97619 .51286 L
.36371 1.0013 L
.78756 .12116 L
s
.69 .878 .902 r
.72569 .82697 m
.72569 .82697 .0894 0 365.73 arc
F
0 g
newpath
.72569 .82697 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.97619 .51286 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.162277 0.97619 0.290813 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .33854 m
.11321 .33854 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .33854 .0894 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.72569 .19874 m
.72569 .19874 .0894 0 365.73 arc
F
0 g
newpath
.72569 .19874 .0894 0 365.73 arc
s
.36371 .02442 m
.78756 .12116 L
.97619 .51286 L
.36371 .02442 L
.78756 .12116 L
s
.69 .878 .902 r
.21244 .68718 m
.21244 .68718 .15127 0 365.73 arc
F
0 g
newpath
.21244 .68718 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.36371 .02442 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.59893 .51286 m
.59893 .51286 .23522 0 365.73 arc
F
0 g
newpath
.59893 .51286 .23522 0 365.73 arc
s
.36371 1.0013 m
.36371 .02442 L
.97619 .51286 L
.36371 1.0013 L
.36371 .02442 L
s
.69 .878 .902 r
.72569 .82697 m
.72569 .82697 .0894 0 365.73 arc
F
0 g
newpath
.72569 .82697 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.97619 .51286 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.303666 0.149123 0.432202 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.38579 .12116 m
.38579 .12116 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.38579 .12116 .0894 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.78756 .12116 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.70361 .29548 m
.70361 .29548 .15127 0 365.73 arc
F
0 g
newpath
.70361 .29548 .15127 0 365.73 arc
s
.02381 .29548 m
.78756 .12116 L
.97619 .51286 L
.02381 .29548 L
.78756 .12116 L
s
.69 .878 .902 r
.11321 .68718 m
.11321 .68718 .0894 0 365.73 arc
F
0 g
newpath
.11321 .68718 .0894 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.72569 .63349 m
.72569 .63349 .17335 0 365.73 arc
F
0 g
newpath
.72569 .63349 .17335 0 365.73 arc
s
.78756 .90455 m
.02381 .29548 L
.97619 .51286 L
.78756 .90455 L
.02381 .29548 L
s
.69 .878 .902 r
.44766 .82697 m
.44766 .82697 .15127 0 365.73 arc
F
0 g
newpath
.44766 .82697 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .29548 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.303666 0.286967 0.432202 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.36371 .2179 m
.36371 .2179 .15127 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.36371 .2179 .15127 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.97619 .51286 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.72569 .19874 m
.72569 .19874 .0894 0 365.73 arc
F
0 g
newpath
.72569 .19874 .0894 0 365.73 arc
s
.36371 .02442 m
.78756 .12116 L
.97619 .51286 L
.36371 .02442 L
.78756 .12116 L
s
.69 .878 .902 r
.11321 .68718 m
.11321 .68718 .0894 0 365.73 arc
F
0 g
newpath
.11321 .68718 .0894 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.72569 .63349 m
.72569 .63349 .17335 0 365.73 arc
F
0 g
newpath
.72569 .63349 .17335 0 365.73 arc
s
.78756 .90455 m
.02381 .29548 L
.97619 .51286 L
.78756 .90455 L
.02381 .29548 L
s
.69 .878 .902 r
.44766 .82697 m
.44766 .82697 .15127 0 365.73 arc
F
0 g
newpath
.44766 .82697 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .29548 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.303666 0.424812 0.432202 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .33854 m
.11321 .33854 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .33854 .0894 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.44766 .19874 m
.44766 .19874 .15127 0 365.73 arc
F
0 g
newpath
.44766 .19874 .15127 0 365.73 arc
s
.02381 .73023 m
.36371 .02442 L
.78756 .12116 L
.02381 .73023 L
.36371 .02442 L
s
.69 .878 .902 r
.72569 .39222 m
.72569 .39222 .17335 0 365.73 arc
F
0 g
newpath
.72569 .39222 .17335 0 365.73 arc
s
.02381 .73023 m
.78756 .12116 L
.97619 .51286 L
.02381 .73023 L
.78756 .12116 L
s
.69 .878 .902 r
.70361 .73023 m
.70361 .73023 .15127 0 365.73 arc
F
0 g
newpath
.70361 .73023 .15127 0 365.73 arc
s
.78756 .90455 m
.02381 .73023 L
.97619 .51286 L
.78756 .90455 L
.02381 .73023 L
s
.69 .878 .902 r
.38579 .90455 m
.38579 .90455 .0894 0 365.73 arc
F
0 g
newpath
.38579 .90455 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.303666 0.562657 0.432202 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.38579 .12116 m
.38579 .12116 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.38579 .12116 .0894 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.78756 .12116 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.17508 .41612 m
.17508 .41612 .15127 0 365.73 arc
F
0 g
newpath
.17508 .41612 .15127 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.78756 .12116 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.72569 .39222 m
.72569 .39222 .17335 0 365.73 arc
F
0 g
newpath
.72569 .39222 .17335 0 365.73 arc
s
.02381 .73023 m
.78756 .12116 L
.97619 .51286 L
.02381 .73023 L
.78756 .12116 L
s
.69 .878 .902 r
.70361 .73023 m
.70361 .73023 .15127 0 365.73 arc
F
0 g
newpath
.70361 .73023 .15127 0 365.73 arc
s
.78756 .90455 m
.02381 .73023 L
.97619 .51286 L
.78756 .90455 L
.02381 .73023 L
s
.69 .878 .902 r
.38579 .90455 m
.38579 .90455 .0894 0 365.73 arc
F
0 g
newpath
.38579 .90455 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.303666 0.700501 0.432202 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .33854 m
.11321 .33854 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .33854 .0894 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.44766 .39222 m
.44766 .39222 .23522 0 365.73 arc
F
0 g
newpath
.44766 .39222 .23522 0 365.73 arc
s
.02381 .73023 m
.36371 .02442 L
.97619 .51286 L
.02381 .73023 L
.36371 .02442 L
s
.69 .878 .902 r
.72569 .19874 m
.72569 .19874 .0894 0 365.73 arc
F
0 g
newpath
.72569 .19874 .0894 0 365.73 arc
s
.36371 .02442 m
.78756 .12116 L
.97619 .51286 L
.36371 .02442 L
.78756 .12116 L
s
.69 .878 .902 r
.70361 .73023 m
.70361 .73023 .15127 0 365.73 arc
F
0 g
newpath
.70361 .73023 .15127 0 365.73 arc
s
.78756 .90455 m
.02381 .73023 L
.97619 .51286 L
.78756 .90455 L
.02381 .73023 L
s
.69 .878 .902 r
.38579 .90455 m
.38579 .90455 .0894 0 365.73 arc
F
0 g
newpath
.38579 .90455 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.303666 0.838346 0.432202 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.38579 .12116 m
.38579 .12116 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.38579 .12116 .0894 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.78756 .12116 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.70361 .29548 m
.70361 .29548 .15127 0 365.73 arc
F
0 g
newpath
.70361 .29548 .15127 0 365.73 arc
s
.02381 .29548 m
.78756 .12116 L
.97619 .51286 L
.02381 .29548 L
.78756 .12116 L
s
.69 .878 .902 r
.19716 .51286 m
.19716 .51286 .17335 0 365.73 arc
F
0 g
newpath
.19716 .51286 .17335 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.97619 .51286 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.70361 .73023 m
.70361 .73023 .15127 0 365.73 arc
F
0 g
newpath
.70361 .73023 .15127 0 365.73 arc
s
.78756 .90455 m
.02381 .73023 L
.97619 .51286 L
.78756 .90455 L
.02381 .73023 L
s
.69 .878 .902 r
.38579 .90455 m
.38579 .90455 .0894 0 365.73 arc
F
0 g
newpath
.38579 .90455 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.303666 0.97619 0.432202 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.36371 .2179 m
.36371 .2179 .15127 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.36371 .2179 .15127 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.97619 .51286 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.19716 .51286 m
.19716 .51286 .17335 0 365.73 arc
F
0 g
newpath
.19716 .51286 .17335 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.97619 .51286 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.72569 .19874 m
.72569 .19874 .0894 0 365.73 arc
F
0 g
newpath
.72569 .19874 .0894 0 365.73 arc
s
.36371 .02442 m
.78756 .12116 L
.97619 .51286 L
.36371 .02442 L
.78756 .12116 L
s
.69 .878 .902 r
.70361 .73023 m
.70361 .73023 .15127 0 365.73 arc
F
0 g
newpath
.70361 .73023 .15127 0 365.73 arc
s
.78756 .90455 m
.02381 .73023 L
.97619 .51286 L
.78756 .90455 L
.02381 .73023 L
s
.69 .878 .902 r
.38579 .90455 m
.38579 .90455 .0894 0 365.73 arc
F
0 g
newpath
.38579 .90455 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.445056 0.149123 0.573592 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.21244 .33854 m
.21244 .33854 .15127 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.21244 .33854 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .29548 L
.36371 .02442 L
.36371 1.0013 L
.02381 .29548 L
s
.69 .878 .902 r
.11321 .68718 m
.11321 .68718 .0894 0 365.73 arc
F
0 g
newpath
.11321 .68718 .0894 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.53706 .2418 m
.53706 .2418 .17335 0 365.73 arc
F
0 g
newpath
.53706 .2418 .17335 0 365.73 arc
s
.36371 1.0013 m
.36371 .02442 L
.78756 .12116 L
.36371 1.0013 L
.36371 .02442 L
s
.69 .878 .902 r
.63629 .78392 m
.63629 .78392 .15127 0 365.73 arc
F
0 g
newpath
.63629 .78392 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.78756 .12116 L
.78756 .90455 L
.36371 1.0013 L
s
.69 .878 .902 r
.87696 .51286 m
.87696 .51286 .0894 0 365.73 arc
F
0 g
newpath
.87696 .51286 .0894 0 365.73 arc
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.445056 0.286967 0.573592 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .33854 m
.11321 .33854 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .33854 .0894 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.21244 .68718 m
.21244 .68718 .15127 0 365.73 arc
F
0 g
newpath
.21244 .68718 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.36371 .02442 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.53706 .2418 m
.53706 .2418 .17335 0 365.73 arc
F
0 g
newpath
.53706 .2418 .17335 0 365.73 arc
s
.36371 1.0013 m
.36371 .02442 L
.78756 .12116 L
.36371 1.0013 L
.36371 .02442 L
s
.69 .878 .902 r
.63629 .78392 m
.63629 .78392 .15127 0 365.73 arc
F
0 g
newpath
.63629 .78392 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.78756 .12116 L
.78756 .90455 L
.36371 1.0013 L
s
.69 .878 .902 r
.87696 .51286 m
.87696 .51286 .0894 0 365.73 arc
F
0 g
newpath
.87696 .51286 .0894 0 365.73 arc
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.445056 0.424812 0.573592 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.38579 .12116 m
.38579 .12116 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.38579 .12116 .0894 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.78756 .12116 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.36371 .45917 m
.36371 .45917 .23522 0 365.73 arc
F
0 g
newpath
.36371 .45917 .23522 0 365.73 arc
s
.36371 1.0013 m
.02381 .29548 L
.78756 .12116 L
.36371 1.0013 L
.02381 .29548 L
s
.69 .878 .902 r
.11321 .68718 m
.11321 .68718 .0894 0 365.73 arc
F
0 g
newpath
.11321 .68718 .0894 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.63629 .78392 m
.63629 .78392 .15127 0 365.73 arc
F
0 g
newpath
.63629 .78392 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.78756 .12116 L
.78756 .90455 L
.36371 1.0013 L
s
.69 .878 .902 r
.87696 .51286 m
.87696 .51286 .0894 0 365.73 arc
F
0 g
newpath
.87696 .51286 .0894 0 365.73 arc
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.445056 0.562657 0.573592 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.72569 .19874 m
.72569 .19874 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.72569 .19874 .0894 0 365.73 arc
s
.36371 .02442 m
.78756 .12116 L
.97619 .51286 L
.36371 .02442 L
.78756 .12116 L
s
.69 .878 .902 r
.21244 .33854 m
.21244 .33854 .15127 0 365.73 arc
F
0 g
newpath
.21244 .33854 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .29548 L
.36371 .02442 L
.36371 1.0013 L
.02381 .29548 L
s
.69 .878 .902 r
.11321 .68718 m
.11321 .68718 .0894 0 365.73 arc
F
0 g
newpath
.11321 .68718 .0894 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.78756 .55591 m
.78756 .55591 .15127 0 365.73 arc
F
0 g
newpath
.78756 .55591 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 .02442 L
.97619 .51286 L
.78756 .90455 L
.36371 .02442 L
s
.69 .878 .902 r
.53706 .78392 m
.53706 .78392 .17335 0 365.73 arc
F
0 g
newpath
.53706 .78392 .17335 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.36371 .02442 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.445056 0.700501 0.573592 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .33854 m
.11321 .33854 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .33854 .0894 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.44766 .19874 m
.44766 .19874 .15127 0 365.73 arc
F
0 g
newpath
.44766 .19874 .15127 0 365.73 arc
s
.02381 .73023 m
.36371 .02442 L
.78756 .12116 L
.02381 .73023 L
.36371 .02442 L
s
.69 .878 .902 r
.30184 .73023 m
.30184 .73023 .17335 0 365.73 arc
F
0 g
newpath
.30184 .73023 .17335 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.78756 .12116 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.63629 .78392 m
.63629 .78392 .15127 0 365.73 arc
F
0 g
newpath
.63629 .78392 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.78756 .12116 L
.78756 .90455 L
.36371 1.0013 L
s
.69 .878 .902 r
.87696 .51286 m
.87696 .51286 .0894 0 365.73 arc
F
0 g
newpath
.87696 .51286 .0894 0 365.73 arc
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.445056 0.838346 0.573592 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.38579 .12116 m
.38579 .12116 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.38579 .12116 .0894 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.78756 .12116 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.17508 .41612 m
.17508 .41612 .15127 0 365.73 arc
F
0 g
newpath
.17508 .41612 .15127 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.78756 .12116 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.30184 .73023 m
.30184 .73023 .17335 0 365.73 arc
F
0 g
newpath
.30184 .73023 .17335 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.78756 .12116 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.63629 .78392 m
.63629 .78392 .15127 0 365.73 arc
F
0 g
newpath
.63629 .78392 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.78756 .12116 L
.78756 .90455 L
.36371 1.0013 L
s
.69 .878 .902 r
.87696 .51286 m
.87696 .51286 .0894 0 365.73 arc
F
0 g
newpath
.87696 .51286 .0894 0 365.73 arc
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.445056 0.97619 0.573592 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .33854 m
.11321 .33854 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .33854 .0894 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.72569 .19874 m
.72569 .19874 .0894 0 365.73 arc
F
0 g
newpath
.72569 .19874 .0894 0 365.73 arc
s
.36371 .02442 m
.78756 .12116 L
.97619 .51286 L
.36371 .02442 L
.78756 .12116 L
s
.69 .878 .902 r
.21244 .68718 m
.21244 .68718 .15127 0 365.73 arc
F
0 g
newpath
.21244 .68718 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.36371 .02442 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.78756 .55591 m
.78756 .55591 .15127 0 365.73 arc
F
0 g
newpath
.78756 .55591 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 .02442 L
.97619 .51286 L
.78756 .90455 L
.36371 .02442 L
s
.69 .878 .902 r
.53706 .78392 m
.53706 .78392 .17335 0 365.73 arc
F
0 g
newpath
.53706 .78392 .17335 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.36371 .02442 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.586445 0.149123 0.714981 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.38579 .12116 m
.38579 .12116 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.38579 .12116 .0894 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.78756 .12116 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.11321 .68718 m
.11321 .68718 .0894 0 365.73 arc
F
0 g
newpath
.11321 .68718 .0894 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.55234 .41612 m
.55234 .41612 .23522 0 365.73 arc
F
0 g
newpath
.55234 .41612 .23522 0 365.73 arc
s
.78756 .90455 m
.02381 .29548 L
.78756 .12116 L
.78756 .90455 L
.02381 .29548 L
s
.69 .878 .902 r
.44766 .82697 m
.44766 .82697 .15127 0 365.73 arc
F
0 g
newpath
.44766 .82697 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .29548 L
.78756 .90455 L
.36371 1.0013 L
s
.69 .878 .902 r
.87696 .51286 m
.87696 .51286 .0894 0 365.73 arc
F
0 g
newpath
.87696 .51286 .0894 0 365.73 arc
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.586445 0.286967 0.714981 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.72569 .19874 m
.72569 .19874 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.72569 .19874 .0894 0 365.73 arc
s
.36371 .02442 m
.78756 .12116 L
.97619 .51286 L
.36371 .02442 L
.78756 .12116 L
s
.69 .878 .902 r
.11321 .68718 m
.11321 .68718 .0894 0 365.73 arc
F
0 g
newpath
.11321 .68718 .0894 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.30184 .29548 m
.30184 .29548 .17335 0 365.73 arc
F
0 g
newpath
.30184 .29548 .17335 0 365.73 arc
s
.78756 .90455 m
.02381 .29548 L
.36371 .02442 L
.78756 .90455 L
.02381 .29548 L
s
.69 .878 .902 r
.78756 .55591 m
.78756 .55591 .15127 0 365.73 arc
F
0 g
newpath
.78756 .55591 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 .02442 L
.97619 .51286 L
.78756 .90455 L
.36371 .02442 L
s
.69 .878 .902 r
.44766 .82697 m
.44766 .82697 .15127 0 365.73 arc
F
0 g
newpath
.44766 .82697 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .29548 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.586445 0.424812 0.714981 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .33854 m
.11321 .33854 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .33854 .0894 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.44766 .19874 m
.44766 .19874 .15127 0 365.73 arc
F
0 g
newpath
.44766 .19874 .15127 0 365.73 arc
s
.02381 .73023 m
.36371 .02442 L
.78756 .12116 L
.02381 .73023 L
.36371 .02442 L
s
.69 .878 .902 r
.55234 .6096 m
.55234 .6096 .23522 0 365.73 arc
F
0 g
newpath
.55234 .6096 .23522 0 365.73 arc
s
.78756 .90455 m
.02381 .73023 L
.78756 .12116 L
.78756 .90455 L
.02381 .73023 L
s
.69 .878 .902 r
.38579 .90455 m
.38579 .90455 .0894 0 365.73 arc
F
0 g
newpath
.38579 .90455 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
.69 .878 .902 r
.87696 .51286 m
.87696 .51286 .0894 0 365.73 arc
F
0 g
newpath
.87696 .51286 .0894 0 365.73 arc
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.586445 0.562657 0.714981 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.38579 .12116 m
.38579 .12116 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.38579 .12116 .0894 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.78756 .12116 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.17508 .41612 m
.17508 .41612 .15127 0 365.73 arc
F
0 g
newpath
.17508 .41612 .15127 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.78756 .12116 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.55234 .6096 m
.55234 .6096 .23522 0 365.73 arc
F
0 g
newpath
.55234 .6096 .23522 0 365.73 arc
s
.78756 .90455 m
.02381 .73023 L
.78756 .12116 L
.78756 .90455 L
.02381 .73023 L
s
.69 .878 .902 r
.38579 .90455 m
.38579 .90455 .0894 0 365.73 arc
F
0 g
newpath
.38579 .90455 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
.69 .878 .902 r
.87696 .51286 m
.87696 .51286 .0894 0 365.73 arc
F
0 g
newpath
.87696 .51286 .0894 0 365.73 arc
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.586445 0.700501 0.714981 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .33854 m
.11321 .33854 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .33854 .0894 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.72569 .19874 m
.72569 .19874 .0894 0 365.73 arc
F
0 g
newpath
.72569 .19874 .0894 0 365.73 arc
s
.36371 .02442 m
.78756 .12116 L
.97619 .51286 L
.36371 .02442 L
.78756 .12116 L
s
.69 .878 .902 r
.36371 .56655 m
.36371 .56655 .23522 0 365.73 arc
F
0 g
newpath
.36371 .56655 .23522 0 365.73 arc
s
.78756 .90455 m
.02381 .73023 L
.36371 .02442 L
.78756 .90455 L
.02381 .73023 L
s
.69 .878 .902 r
.78756 .55591 m
.78756 .55591 .15127 0 365.73 arc
F
0 g
newpath
.78756 .55591 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 .02442 L
.97619 .51286 L
.78756 .90455 L
.36371 .02442 L
s
.69 .878 .902 r
.38579 .90455 m
.38579 .90455 .0894 0 365.73 arc
F
0 g
newpath
.38579 .90455 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.586445 0.838346 0.714981 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.38579 .12116 m
.38579 .12116 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.38579 .12116 .0894 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.78756 .12116 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.70361 .29548 m
.70361 .29548 .15127 0 365.73 arc
F
0 g
newpath
.70361 .29548 .15127 0 365.73 arc
s
.02381 .29548 m
.78756 .12116 L
.97619 .51286 L
.02381 .29548 L
.78756 .12116 L
s
.69 .878 .902 r
.72569 .63349 m
.72569 .63349 .17335 0 365.73 arc
F
0 g
newpath
.72569 .63349 .17335 0 365.73 arc
s
.78756 .90455 m
.02381 .29548 L
.97619 .51286 L
.78756 .90455 L
.02381 .29548 L
s
.69 .878 .902 r
.17508 .6096 m
.17508 .6096 .15127 0 365.73 arc
F
0 g
newpath
.17508 .6096 .15127 0 365.73 arc
s
.78756 .90455 m
.02381 .73023 L
.02381 .29548 L
.78756 .90455 L
.02381 .73023 L
s
.69 .878 .902 r
.38579 .90455 m
.38579 .90455 .0894 0 365.73 arc
F
0 g
newpath
.38579 .90455 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.586445 0.97619 0.714981 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.36371 .2179 m
.36371 .2179 .15127 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.36371 .2179 .15127 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.97619 .51286 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.72569 .19874 m
.72569 .19874 .0894 0 365.73 arc
F
0 g
newpath
.72569 .19874 .0894 0 365.73 arc
s
.36371 .02442 m
.78756 .12116 L
.97619 .51286 L
.36371 .02442 L
.78756 .12116 L
s
.69 .878 .902 r
.72569 .63349 m
.72569 .63349 .17335 0 365.73 arc
F
0 g
newpath
.72569 .63349 .17335 0 365.73 arc
s
.78756 .90455 m
.02381 .29548 L
.97619 .51286 L
.78756 .90455 L
.02381 .29548 L
s
.69 .878 .902 r
.17508 .6096 m
.17508 .6096 .15127 0 365.73 arc
F
0 g
newpath
.17508 .6096 .15127 0 365.73 arc
s
.78756 .90455 m
.02381 .73023 L
.02381 .29548 L
.78756 .90455 L
.02381 .73023 L
s
.69 .878 .902 r
.38579 .90455 m
.38579 .90455 .0894 0 365.73 arc
F
0 g
newpath
.38579 .90455 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.727835 0.149123 0.856371 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.30184 .29548 m
.30184 .29548 .17335 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.30184 .29548 .17335 0 365.73 arc
s
.78756 .90455 m
.02381 .29548 L
.36371 .02442 L
.78756 .90455 L
.02381 .29548 L
s
.69 .878 .902 r
.17508 .6096 m
.17508 .6096 .15127 0 365.73 arc
F
0 g
newpath
.17508 .6096 .15127 0 365.73 arc
s
.78756 .90455 m
.02381 .73023 L
.02381 .29548 L
.78756 .90455 L
.02381 .73023 L
s
.69 .878 .902 r
.63629 .2418 m
.63629 .2418 .15127 0 365.73 arc
F
0 g
newpath
.63629 .2418 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 .02442 L
.78756 .12116 L
.78756 .90455 L
.36371 .02442 L
s
.69 .878 .902 r
.38579 .90455 m
.38579 .90455 .0894 0 365.73 arc
F
0 g
newpath
.38579 .90455 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
.69 .878 .902 r
.87696 .51286 m
.87696 .51286 .0894 0 365.73 arc
F
0 g
newpath
.87696 .51286 .0894 0 365.73 arc
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.727835 0.286967 0.856371 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .68718 m
.11321 .68718 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .68718 .0894 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.30184 .29548 m
.30184 .29548 .17335 0 365.73 arc
F
0 g
newpath
.30184 .29548 .17335 0 365.73 arc
s
.78756 .90455 m
.02381 .29548 L
.36371 .02442 L
.78756 .90455 L
.02381 .29548 L
s
.69 .878 .902 r
.63629 .2418 m
.63629 .2418 .15127 0 365.73 arc
F
0 g
newpath
.63629 .2418 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 .02442 L
.78756 .12116 L
.78756 .90455 L
.36371 .02442 L
s
.69 .878 .902 r
.44766 .82697 m
.44766 .82697 .15127 0 365.73 arc
F
0 g
newpath
.44766 .82697 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .29548 L
.78756 .90455 L
.36371 1.0013 L
s
.69 .878 .902 r
.87696 .51286 m
.87696 .51286 .0894 0 365.73 arc
F
0 g
newpath
.87696 .51286 .0894 0 365.73 arc
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.727835 0.424812 0.856371 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .33854 m
.11321 .33854 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .33854 .0894 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.36371 .56655 m
.36371 .56655 .23522 0 365.73 arc
F
0 g
newpath
.36371 .56655 .23522 0 365.73 arc
s
.78756 .90455 m
.02381 .73023 L
.36371 .02442 L
.78756 .90455 L
.02381 .73023 L
s
.69 .878 .902 r
.63629 .2418 m
.63629 .2418 .15127 0 365.73 arc
F
0 g
newpath
.63629 .2418 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 .02442 L
.78756 .12116 L
.78756 .90455 L
.36371 .02442 L
s
.69 .878 .902 r
.38579 .90455 m
.38579 .90455 .0894 0 365.73 arc
F
0 g
newpath
.38579 .90455 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
.69 .878 .902 r
.87696 .51286 m
.87696 .51286 .0894 0 365.73 arc
F
0 g
newpath
.87696 .51286 .0894 0 365.73 arc
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.727835 0.562657 0.856371 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.38579 .12116 m
.38579 .12116 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.38579 .12116 .0894 0 365.73 arc
s
.02381 .29548 m
.36371 .02442 L
.78756 .12116 L
.02381 .29548 L
.36371 .02442 L
s
.69 .878 .902 r
.55234 .41612 m
.55234 .41612 .23522 0 365.73 arc
F
0 g
newpath
.55234 .41612 .23522 0 365.73 arc
s
.78756 .90455 m
.02381 .29548 L
.78756 .12116 L
.78756 .90455 L
.02381 .29548 L
s
.69 .878 .902 r
.17508 .6096 m
.17508 .6096 .15127 0 365.73 arc
F
0 g
newpath
.17508 .6096 .15127 0 365.73 arc
s
.78756 .90455 m
.02381 .73023 L
.02381 .29548 L
.78756 .90455 L
.02381 .73023 L
s
.69 .878 .902 r
.38579 .90455 m
.38579 .90455 .0894 0 365.73 arc
F
0 g
newpath
.38579 .90455 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
.69 .878 .902 r
.87696 .51286 m
.87696 .51286 .0894 0 365.73 arc
F
0 g
newpath
.87696 .51286 .0894 0 365.73 arc
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.727835 0.700501 0.856371 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.72569 .19874 m
.72569 .19874 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.72569 .19874 .0894 0 365.73 arc
s
.36371 .02442 m
.78756 .12116 L
.97619 .51286 L
.36371 .02442 L
.78756 .12116 L
s
.69 .878 .902 r
.30184 .29548 m
.30184 .29548 .17335 0 365.73 arc
F
0 g
newpath
.30184 .29548 .17335 0 365.73 arc
s
.78756 .90455 m
.02381 .29548 L
.36371 .02442 L
.78756 .90455 L
.02381 .29548 L
s
.69 .878 .902 r
.17508 .6096 m
.17508 .6096 .15127 0 365.73 arc
F
0 g
newpath
.17508 .6096 .15127 0 365.73 arc
s
.78756 .90455 m
.02381 .73023 L
.02381 .29548 L
.78756 .90455 L
.02381 .73023 L
s
.69 .878 .902 r
.78756 .55591 m
.78756 .55591 .15127 0 365.73 arc
F
0 g
newpath
.78756 .55591 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 .02442 L
.97619 .51286 L
.78756 .90455 L
.36371 .02442 L
s
.69 .878 .902 r
.38579 .90455 m
.38579 .90455 .0894 0 365.73 arc
F
0 g
newpath
.38579 .90455 .0894 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.02381 .73023 L
.78756 .90455 L
.36371 1.0013 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.727835 0.838346 0.856371 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.21244 .33854 m
.21244 .33854 .15127 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.21244 .33854 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .29548 L
.36371 .02442 L
.36371 1.0013 L
.02381 .29548 L
s
.69 .878 .902 r
.11321 .68718 m
.11321 .68718 .0894 0 365.73 arc
F
0 g
newpath
.11321 .68718 .0894 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.02381 .29548 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.63629 .2418 m
.63629 .2418 .15127 0 365.73 arc
F
0 g
newpath
.63629 .2418 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 .02442 L
.78756 .12116 L
.78756 .90455 L
.36371 .02442 L
s
.69 .878 .902 r
.53706 .78392 m
.53706 .78392 .17335 0 365.73 arc
F
0 g
newpath
.53706 .78392 .17335 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.36371 .02442 L
.78756 .90455 L
.36371 1.0013 L
s
.69 .878 .902 r
.87696 .51286 m
.87696 .51286 .0894 0 365.73 arc
F
0 g
newpath
.87696 .51286 .0894 0 365.73 arc
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.727835 0.97619 0.856371 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.475193 0.500998 0.512858 0.500998 [
[ 0 0 0 0 ]
[ 1 1.02572 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .878 .902 r
.11321 .33854 m
.11321 .33854 .0894 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.11321 .33854 .0894 0 365.73 arc
s
.02381 .73023 m
.02381 .29548 L
.36371 .02442 L
.02381 .73023 L
.02381 .29548 L
s
.69 .878 .902 r
.21244 .68718 m
.21244 .68718 .15127 0 365.73 arc
F
0 g
newpath
.21244 .68718 .15127 0 365.73 arc
s
.36371 1.0013 m
.02381 .73023 L
.36371 .02442 L
.36371 1.0013 L
.02381 .73023 L
s
.69 .878 .902 r
.63629 .2418 m
.63629 .2418 .15127 0 365.73 arc
F
0 g
newpath
.63629 .2418 .15127 0 365.73 arc
s
.78756 .90455 m
.36371 .02442 L
.78756 .12116 L
.78756 .90455 L
.36371 .02442 L
s
.69 .878 .902 r
.53706 .78392 m
.53706 .78392 .17335 0 365.73 arc
F
0 g
newpath
.53706 .78392 .17335 0 365.73 arc
s
.78756 .90455 m
.36371 1.0013 L
.36371 .02442 L
.78756 .90455 L
.36371 1.0013 L
s
.69 .878 .902 r
.87696 .51286 m
.87696 .51286 .0894 0 365.73 arc
F
0 g
newpath
.87696 .51286 .0894 0 365.73 arc
s
.78756 .90455 m
.78756 .12116 L
.97619 .51286 L
.78756 .90455 L
.78756 .12116 L
s
0 0 m
1 0 L
1 1.02572 L
0 1.02572 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[271]:=",
  ImageSize->{506.75, 444.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007j0001_2000`400?l00000o`00003oo`3ooook
0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook
0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook
0?ooo`00o`3ooook0?ooo`008`3oool300000480oooo0`0000130?ooo`<00000@`3oool300000480
oooo0`0000130?ooo`<00000@`3oool300000380oooo000R0?ooo`P00000?@3oool010000000oooo
0000003oool4000003h0oooo0P0000020?ooo`@00000?P3oool8000003d0oooo0`0000000`3oool0
000000000002000003h0oooo2000000n0?ooo`040000003oool000000?ooo`@00000;P3oool00200
oooo0P0000050;3PiP030000003oool0oooo00@00000=`3oool2000000<0oooo0P0000030?ooo`D0
0000=`3oool300000080oooo2P00000g0?ooo`8000001@2`h>H00`000000oooo0?ooo`05000003H0
oooo0`0000020?ooo`8000000`3oool5000003L0oooo0`0000050;3PiP030000003oool0000000@0
0000=`3oool2000000<0oooo0P0000030?ooo`D00000:@3oool001l0oooo00<000000;3PiP2`h>H0
1P2`h>H00`000000oooo0?ooo`030?ooo`D00000<@3oool9000000L0oooo1000000b0?ooo`060000
003oool0oooo0000003oool000001`2`h>H2000000030?ooo`000000000000800000<P3oool00`00
0000/>3V0;3PiP060;3PiP030000003oool0oooo00@0oooo1000000a0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool01@3oool400000380oooo0P0000080;3PiP030000003oool0
oooo00<0oooo1000000b0?ooo`L0000000<0oooo0000003oool01P3oool4000002D0oooo000N0?oo
o`800000202`h>H00`000000oooo0?ooo`080?ooo`@00000;03oool2000000L0/>3V0P00000:0?oo
o`D00000;03oool00`000000oooo0?ooo`03000000X0/>3V0P0000030?ooo`D00000;03oool20000
00T0/>3V00<000000?ooo`3oool01`3oool5000002/0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`080?ooo`D00000;03oool2000000T0/>3V00<000000?ooo`3oool01`3oool5
000002`0oooo0P0000060;3PiP<000002P3oool500000200oooo000L0?ooo`<000002P2`h>H00`00
0000oooo0?ooo`0;0?ooo`@000009`3oool2000000X0/>3V0P00000=0?ooo`@000009`3oool01@00
0000oooo0?ooo`3oool0000000h0/>3V00<000000?ooo`3oool01@3oool4000002H0oooo0`00000;
0;3PiP030000003oool0oooo00/0oooo1000000V0?ooo`050000003oool0oooo0?ooo`0000001`3o
ool00`000000oooo0?ooo`0<0?ooo`@000009`3oool00`000000oooo0000000:0;3PiP030000003o
ool0oooo00/0oooo1000000V0?ooo`8000002P2`h>H2000000h0oooo1000000L0?ooo`006`3oool0
10000000oooo0?ooo`00000:0;3PiP800000403oool300000280oooo0P00000=0;3PiP800000303o
ool700000280oooo0P0000030?ooo`8000003P2`h>H00`000000oooo0?ooo`090?ooo`<000008P3o
ool010000000oooo0?ooo`00000;0;3PiP030000003oool0oooo00l0oooo0`00000Q0?ooo`800000
0`3oool00`000000oooo0?ooo`070?ooo`8000003@3oool600000280oooo0P0000020?ooo`030000
002`h>H0/>3V00P0/>3V00<000000?ooo`3oool03`3oool300000280oooo00<000000;3PiP2`h>H0
302`h>H2000000`0oooo1`00000I0?ooo`006P3oool01@000000oooo0?ooo`3oool0000000X0/>3V
0P00000<0?ooo`@000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000h0/>3V
0P00000:0?ooo`030000002`h>H0/>3V00@0/>3V00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`030?ooo`030000002`h>H0/>3V00h0/>3V00<000000?ooo`3oool02@3oool200000240oooo
00D000000?ooo`3oool0oooo0000000:0;3PiP8000003@3oool4000000030?ooo`00000000000200
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0
oooo0P0000050;3PiP030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool00`000000
/>3V0;3PiP080;3PiP030000003oool0oooo00/0oooo100000020?ooo`030000003oool0oooo01l0
oooo0P00000>0;3PiP030000003oool0000000T0oooo0P0000050;3PiP8000006@3oool001T0oooo
00<000000?ooo`3oool00`3oool00`000000/>3V0;3PiP070;3PiP030000003oool0oooo00L0oooo
2@0000020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`000000402`h>H2000000P0oooo
00<000000;3PiP2`h>H01P2`h>H00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo
00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`070?ooo`8000000P3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00<0oooo00<000000;3PiP2`h>H01`2`h>H00`000000oooo
0?ooo`070?ooo`D000000`3oool200000080oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000/>3V
0;3PiP060;3PiP030000003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool00`000000/>3V
0;3PiP080;3PiP030000003oool0oooo00L0oooo200000030?ooo`030000003oool0oooo01d0oooo
0P00000@0;3PiP030000003oool0000000L0oooo00<000000;3PiP2`h>H01P2`h>H2000001P0oooo
000G0?ooo`8000001P3oool00`000000/>3V0;3PiP060;3PiP030000003oool0oooo00<0oooo1`00
00070;3PiP<000007P3oool00`000000oooo0000000A0;3PiP030000003oool0000000H0oooo00<0
00000;3PiP2`h>H01`2`h>H00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00@0oooo00<0
00000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool06`3oool2000000H0oooo00<000000;3PiP2`h>H01P2`h>H00`000000oooo0?oo
o`040?ooo`@000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`/000001P3oool00`000000/>3V0;3P
iP070;3PiP030000003oool0oooo01`0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3P
iP070;3PiP030000003oool0oooo00<0oooo1`0000060;3PiP80000000<0oooo0000003oool0703o
ool300000140/>3V00@000000?ooo`3oool000001P3oool00`000000/>3V0;3PiP060;3PiP800000
603oool001H0oooo00<000000?ooo`3oool01`3oool00`000000/>3V0;3PiP050;3PiP030000003o
ool0000000<00000103oool00`000000/>3V0;3PiP090;3PiP800000703oool010000000oooo0?oo
o`00000A0;3PiP030000003oool0oooo00800000103oool00`000000/>3V0;3PiP080;3PiP030000
003oool0oooo01X0oooo00<000000?ooo`3oool0103oool200000180/>3V00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
1`3oool00`000000/>3V0;3PiP050;3PiP030000003oool0000000@000002P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`3oool2000000/0/>3V0P0000040?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`060?ooo`030000002`h>H0/>3V00D0/>3V00<000000?ooo`3o
ool0100000030?ooo`8000002P2`h>H3000001/0oooo00@000000?ooo`3oool000004P2`h>H00`00
0000oooo0?ooo`02000000<0oooo00<000000;3PiP2`h>H0202`h>H2000001L0oooo000E0?ooo`03
0000003oool0oooo00T0oooo0P0000030;3PiP@000001`3oool00`000000/>3V0;3PiP0;0;3PiP80
00006@3oool2000000<0oooo00<000000;3PiP2`h>H0402`h>H01@000000oooo0?ooo`3oool00000
00<0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`0H0?ooo`8000001`3oool20000
0180/>3V00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool02@3oool2000000<0/>3V1000000>0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool05`3oool2000000L0oooo00@000000?ooo`3oool000003`2`h>H0
1@000000oooo0?ooo`3oool0000000X0/>3V00<000000?ooo`3oool0603oool2000000X0oooo0P00
00040;3PiP@000001P3oool00`000000/>3V0;3PiP0<0;3PiP030000003oool0oooo01P0oooo00D0
00000?ooo`3oool0oooo0000000B0;3PiP030000003oool0oooo0080oooo00@000000?ooo`3oool0
00002P2`h>H2000001L0oooo000C0?ooo`800000303oool6000000X0oooo00<000000;3PiP2`h>H0
302`h>H00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<000000;3PiP2`h>H0
402`h>H00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000T0/>3V0`00000H0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`0000004P2`h>H00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0E0?ooo`8000003@3oool50000
00l0oooo0P0000020?ooo`8000001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00H0oooo00@000000?ooo`00000000004@2`h>H010000000oooo0?ooo`00000:0;3PiP800000603o
ool00`000000oooo0?ooo`0;0?ooo`H000002@3oool00`000000/>3V0;3PiP0<0;3PiP8000005`3o
ool2000000@0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo0?ooo`030?ooo`030000003o
ool0000000X0/>3V00<000000?ooo`0000005P3oool00180oooo00<000000?ooo`3oool0203oool4
000000l0oooo00<000000;3PiP2`h>H03@2`h>H2000001H0oooo00<000000?ooo`3oool0103oool0
0`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo00<0oooo00<000000?ooo`0000002@2`h>H0
0`000000oooo0000000G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000004P2`h>H0
0`000000oooo0?ooo`06000000030;3PiP000000000000<0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`080?ooo`D000004`3oool500000080/>3V0P0000030?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01`3oool2000001@0/>3V00<000000?ooo`0000002P2`h>H2
000001L0oooo00<000000?ooo`3oool0203oool4000000h0oooo00<000000;3PiP2`h>H03P2`h>H0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000;3PiP2`h>H0402`h>H0
0`000000oooo0?ooo`040?ooo`8000002P2`h>H00`000000oooo0000000F0?ooo`004@3oool00`00
0000oooo0?ooo`040?ooo`D000004P3oool00`000000/>3V0;3PiP0?0;3PiP030000003oool0oooo
01<0oooo00<000000?ooo`3oool01@3oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo
00@0oooo0P0000080;3PiP050000003oool0oooo0?ooo`0000005@3oool3000000L0oooo00@00000
0?ooo`3oool000004@2`h>H00`000000oooo0?ooo`02000000P0/>3V0P0000020?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool01@3oool4000001L0oooo0P0000080;3PiP8000000P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0000000L0oooo0P00000F0;3PiP8000002@2`
h>H010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00@0oooo1@00000A0?ooo`030000
002`h>H0/>3V0100/>3V00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000
002`h>H0/>3V0100/>3V00<000000?ooo`3oool01@3oool2000000P0/>3V00D000000?ooo`3oool0
oooo0000000E0?ooo`003`3oool2000000<0oooo1000000G0?ooo`030000002`h>H0/>3V00l0/>3V
00<000000?ooo`3oool04@3oool2000000P0oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo
0?ooo`070?ooo`030000002`h>H0/>3V00D0/>3V00D000000?ooo`3oool0oooo0000000C0?ooo`<0
00000P2`h>H2000000D0oooo00@000000?ooo`3oool000004@2`h>H00`000000oooo0000000<0;3P
iP<000004P3oool2000000<0oooo1@00000I0?ooo`800000302`h>H00`000000oooo0000000B0?oo
o`@0000000<0/>3V0000000000001@3oool00`000000/>3V0;3PiP0F0;3PiP8000001`2`h>H01@00
0000oooo0?ooo`3oool0000001<0oooo0P0000030?ooo`@000005P3oool00`000000/>3V0;3PiP0@
0;3PiP030000003oool0oooo0100oooo0P0000080?ooo`030000002`h>H0/>3V0100/>3V00<00000
0?ooo`3oool01`3oool00`000000/>3V0;3PiP050;3PiP050000003oool0oooo0?ooo`0000005@3o
ool000h0oooo00<000000?ooo`0000000`00000K0?ooo`030000002`h>H0/>3V0100/>3V00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000002`h>H0/>3V00l0/>3V00<00000
0?ooo`3oool0203oool2000000<0/>3V0P0000050?ooo`030000003oool0oooo00l0oooo0P000006
0;3PiP8000000`3oool01@000000oooo0?ooo`3oool0000000l0/>3V00<000000?ooo`0000003`2`
h>H200000100oooo00<000000?ooo`0000001@0000020;3PiP@000005@3oool2000000h0/>3V0P00
000A0?ooo`<000001@2`h>H2000000<0oooo00<000000;3PiP2`h>H05`2`h>H3000000<0/>3V0P00
00050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`0000000`00000J0?ooo`030000002`
h>H0/>3V0100/>3V0P00000@0?ooo`030000003oool0oooo00T0oooo00<000000;3PiP2`h>H03`2`
h>H00`000000oooo0?ooo`080?ooo`8000000`2`h>H2000000D0oooo00<000000?ooo`3oool04P3o
ool000d0oooo0`00000O0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool03P3oool3
000000X0oooo00<000000;3PiP2`h>H03@2`h>H00`000000oooo0?ooo`0:0?ooo`@000001`3oool0
0`000000oooo0?ooo`0>0?ooo`030000002`h>H0/>3V00L0/>3V00@000000?ooo`3oool00000103o
ool00`000000/>3V0;3PiP0=0;3PiP8000004@2`h>H00`000000oooo0?ooo`0=0?ooo`<000000P3o
ool2000000P0/>3V00<000000?ooo`3oool04@3oool200000100/>3V0P00000?0?ooo`800000202`
h>H010000000oooo0?ooo`00000J0;3PiP030000003oool0000000<000001`3oool00`000000oooo
0?ooo`0>0?ooo`<000007P3oool00`000000/>3V0;3PiP0@0;3PiP8000003`3oool3000000/0oooo
00<000000;3PiP2`h>H03@2`h>H00`000000oooo0?ooo`0:0?ooo`@000001`3oool00`000000oooo
0?ooo`0B0?ooo`003@3oool00`000000oooo0?ooo`04000001/0oooo00<000000;3PiP2`h>H0402`
h>H2000000l0oooo00<000000?ooo`3oool0100000060?ooo`030000002`h>H0/>3V00d0/>3V00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<0
00000;3PiP2`h>H0202`h>H00`000000oooo000000050?ooo`030000002`h>H0/>3V00/0/>3V0P00
000C0;3PiP030000003oool0oooo00`0oooo00<000000?ooo`3oool00P00000;0;3PiP030000003o
ool0oooo00l0oooo0P00000B0;3PiP030000003oool0oooo00d0oooo00<000000;3PiP2`h>H0202`
h>H00`000000oooo0000000K0;3PiP040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`04000001X0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo
0000000>0?ooo`030000003oool0oooo00@000001`3oool00`000000/>3V0;3PiP0=0;3PiP030000
003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`003@3o
ool2000000D0oooo1000000G0?ooo`030000002`h>H0/>3V0100/>3V0P00000?0?ooo`8000001@3o
ool4000000<0oooo00<000000;3PiP2`h>H02`2`h>H00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000/>3V0;3PiP080;3PiP8000001`3o
ool2000000X0/>3V00<000000?ooo`0000004`2`h>H00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000000h0/>3V00<000000?ooo`3oool03@3oool00`000000oooo0000000B0;3PiP8000003P3o
ool00`000000/>3V0;3PiP080;3PiP800000702`h>H01@000000oooo0?ooo`3oool0000000P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`@000005P3oool00`000000/>3V
0;3PiP0@0;3PiP030000003oool0000000h0oooo00<000000?ooo`3oool0103oool4000000@0oooo
00<000000;3PiP2`h>H02P2`h>H200000100oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0A0?ooo`003@3oool2000000T0oooo1000000C0?ooo`030000002`h>H0/>3V00l0/>3V00@0
00000?ooo`3oool000003P3oool2000000T0oooo1P00000:0;3PiP030000003oool0oooo0100oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000002`h>H0/>3V00P0/>3V
0P0000090?ooo`030000002`h>H0/>3V00D0/>3V0P0000000`3oool000000;3PiP0C0;3PiP800000
3@3oool00`000000oooo0000000?0;3PiP030000003oool0oooo00X0oooo0P0000000`3oool00000
0;3PiP0C0;3PiP030000003oool0oooo00`0oooo00<000000;3PiP2`h>H0202`h>H2000001`0/>3V
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool01P3oool600000180oooo00<000000;3PiP2`h>H03`2`h>H01@000000oooo
0?ooo`3oool0000000d0oooo00<000000?ooo`3oool01`3oool7000000X0/>3V00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo000=0?ooo`030000
003oool0000000`0oooo1@00000>0?ooo`030000002`h>H0/>3V00l0/>3V00@000000?ooo`3oool0
00003P3oool00`000000oooo0000000<0?ooo`D000001@2`h>H2000001@0oooo0P0000060?ooo`03
0000003oool0oooo00`0oooo00<000000;3PiP2`h>H01`2`h>H2000000/0oooo200000020?ooo`03
0000002`h>H0/>3V0180/>3V0P00000=0?ooo`800000402`h>H00`000000oooo0?ooo`090?ooo`05
0000003oool0oooo0?ooo`000000502`h>H2000000d0oooo00<000000;3PiP2`h>H0202`h>H20000
01d0/>3V00<000000?ooo`3oool00P3oool2000000H0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`040?ooo`8000001P2`h>H5000000h0oooo00<000000;3PiP2`h>H03P2`h>H01@00
0000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool01@3oool2000000D0/>3V1@000005
0;3PiP8000005@3oool2000000H0oooo00<000000?ooo`3oool0403oool000d0oooo00<000000?oo
o`0000004@3oool4000000/0oooo00<000000;3PiP2`h>H03@2`h>H00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`0000003`3oool7000001P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000002`h>H0/>3V00L0/>3V0P00000@0?oo
o`030000003oool0oooo0080oooo00<000000;3PiP2`h>H04`2`h>H2000000`0oooo00<000000;3P
iP2`h>H0402`h>H00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000;3P
iP2`h>H04`2`h>H00`000000oooo0?ooo`0;0?ooo`030000002`h>H0/>3V00P0/>3V0P00000M0;3P
iP030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0080oooo0P00000:0;3PiP030000003oool0oooo00@000002P3oool00`00
0000/>3V0;3PiP0>0;3PiP030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`030?ooo`8000002@2`h>H8000001T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0?0?ooo`003@3oool010000000oooo0?ooo`00000D0?ooo`@000001`3oool00`00
0000/>3V0;3PiP0=0;3PiP030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`00000D0?ooo`@000005P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00/0oooo00<000000;3PiP2`h>H01P2`h>H200000100oooo00<000000?ooo`3oool00`3oool0
0`000000/>3V0;3PiP0C0;3PiP800000303oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0
oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3PiP0C0;3PiP030000003oool0
oooo00/0oooo00<000000;3PiP2`h>H01`2`h>H00`000000oooo0000000M0;3PiP030000003oool0
oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo008000003@2`h>H00`000000oooo0?ooo`030?ooo`@000001`3oool00`000000/>3V0;3PiP0=
0;3PiP030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`3o
ool2000000d0/>3V00<000000?ooo`3oool00P3oool5000001H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0?0?ooo`003@3oool010000000oooo0?ooo`00000D0?ooo`T000000`3o
ool00`000000/>3V0;3PiP0;0;3PiP030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3o
ool010000000oooo0?ooo`00000D0?ooo`T000004P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00X0oooo0P0000070;3PiP8000003`3oool00`000000oooo0?ooo`040?ooo`030000
002`h>H0/>3V01<0/>3V00<000000?ooo`0000002`3oool00`000000/>3V0;3PiP0@0;3PiP030000
003oool0oooo00@0oooo0P0000060?ooo`030000002`h>H0/>3V01<0/>3V0P00000<0?ooo`800000
1`2`h>H2000000030?ooo`000000/>3V01`0/>3V00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000402`h>H00`000000oooo
0?ooo`060?ooo`D000000`3oool00`000000/>3V0;3PiP0:0;3PiP8000001P3oool00`000000oooo
0?ooo`090?ooo`040000003oool0000000000100/>3V00<000000?ooo`3oool01P3oool4000001<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`003@3oool01@000000oooo
0?ooo`3oool000000140oooo0P0000090;3PiPH000002@2`h>H2000000L0oooo00<000000?ooo`3o
ool02P3oool01@000000oooo0?ooo`3oool000000100oooo0`0000080;3PiPD000003`3oool20000
00<0oooo00<000000?ooo`3oool02P3oool010000000oooo0000000000030;3PiP<000003`3oool0
0`000000oooo0?ooo`050?ooo`030000002`h>H0/>3V01<0/>3V00<000000?ooo`0000002`3oool0
0`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000/>3V0;3PiP0B0;3PiP<00000303oool010000000oooo0000000000030;3PiP<000000P3o
ool00`000000/>3V0;3PiP0J0;3PiP8000002@3oool2000000<0oooo00<000000?ooo`3oool02P3o
ool200000140/>3V00<000000?ooo`3oool02`3oool5000000X0/>3V00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`090?ooo`8000004P2`h>H00`000000oooo0?ooo`0:0?ooo`D000003`3o
ool2000000<0oooo00<000000?ooo`3oool03P3oool000d0oooo00D000000?ooo`3oool0oooo0000
000?0?ooo`8000003@2`h>H00`000000oooo00000003000000H0/>3V00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000003P3oool2000000d0/>3V
0P0000000`3oool0000000000002000000d0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`04
0000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`0;0?ooo`800000203oool00`00
0000/>3V0;3PiP0C0;3PiP040000003oool0oooo000000X0oooo00<000000;3PiP2`h>H0402`h>H0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000;3PiP2`h>H04P2`h>H0
10000000oooo0?ooo`00000;0?ooo`040000003oool0oooo0?ooo`<000000P3oool010000000oooo
0?ooo`00000L0;3PiP030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`8000004P2`h>H00`000000oooo0?ooo`0>0?ooo`@000001@2`h>H2000000X0oooo00<000000?oo
o`3oool0203oool2000001<0/>3V00<000000?ooo`3oool03P3oool4000000d0oooo00D000000?oo
o`3oool0oooo0000000?0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo0P00000@0;3PiP040000003oool0oooo0?ooo`L000002`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000/>3V0;3PiP0?
0;3PiP030000003oool0oooo0080oooo1000000:0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<0
00000;3PiP2`h>H04@2`h>H01@000000oooo0?ooo`3oool0000000X0oooo00<000000;3PiP2`h>H0
402`h>H00`000000oooo0?ooo`02000000X0oooo00<000000;3PiP2`h>H04P2`h>H010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000L0;3P
iP030000003oool0oooo00/0oooo00@000000?ooo`3oool000002`3oool00`000000/>3V0;3PiP0A
0;3PiP030000003oool0oooo0140oooo1P00000<0?ooo`030000003oool0oooo00P0oooo0P00000C
0;3PiP030000003oool0oooo0180oooo1000000:0?ooo`040000003oool0oooo000000l0oooo000=
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000/>3V0;3PiP0A
0;3PiP030000003oool0oooo00D0oooo1@0000090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000002`h>H0/>3V0140/>3V00<00000
0?ooo`3oool01@3oool5000000H0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000/>3V0;3P
iP0A0;3PiP030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool200000140/>3V00<0
00000?ooo`000000303oool00`000000/>3V0;3PiP0B0;3PiP050000003oool0oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000;3PiP2`h>H0
602`h>H00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000X0oooo00<000000;3PiP2`
h>H04P2`h>H00`000000oooo0?ooo`0E0?ooo`D000002@3oool00`000000oooo0?ooo`070?ooo`80
0000502`h>H00`000000oooo0?ooo`0E0?ooo`D000001P3oool010000000oooo0?ooo`00000>0?oo
o`003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000;3PiP2`
h>H04`2`h>H00`000000oooo0?ooo`090?ooo`@000001@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000/>3V0;3PiP0C0;3PiP03
0000003oool0oooo00T0oooo100000030?ooo`<000002P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool00`000000/>3V0;3PiP0?0;3PiP03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool200000140/>3V0P00000>0?ooo`03
0000002`h>H0/>3V0100/>3V00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3PiP0H0;3PiP03
0000003oool0oooo00h0oooo0`00000:0?ooo`030000002`h>H0/>3V0180/>3V00<000000?ooo`3o
ool06P3oool4000000D0oooo00<000000?ooo`3oool01`3oool2000001@0/>3V00<000000?ooo`3o
ool06P3oool4000000<0oooo0`00000>0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000;3PiP2`h>H05@2`h>H00`000000oooo0?ooo`0<0?ooo`@00000
0P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000/>3V0;3PiP0E0;3PiP030000003oool0oooo00`0oooo100000000`3oool00000
000000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool2000000l0oooo
00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`0000003`2`h>H200000100oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000002`h>H0/>3V01P0/>3V00<000000?ooo`3oool0403oool2000000T0oooo
00<000000;3PiP2`h>H04P2`h>H00`000000oooo0?ooo`0N0?ooo`@000000P3oool00`000000oooo
0?ooo`060?ooo`030000002`h>H0/>3V01<0/>3V00<000000?ooo`3oool07P3oool4000000030?oo
o`000000000000d0oooo000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000/>3V0;3PiP0F0;3PiP030000003oool0oooo0100oooo0`0000090?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP0F0;3PiP030000003o
ool0oooo0100oooo0`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0@0?ooo`030000002`h>H0/>3V00d0/>3V00<000000?ooo`3oool00`3o
ool3000000P0oooo00@000000?ooo`3oool000003@2`h>H200000180oooo00<000000;3PiP2`h>H0
302`h>H2000000@0oooo0`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000/>3V0;3PiP0F0;3PiP030000003oool0oooo0100oooo0`0000090?ooo`030000
002`h>H0/>3V0180/>3V0P00000S0?ooo`<00000203oool00`000000/>3V0;3PiP0C0;3PiP030000
003oool0oooo0280oooo0`00000=0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000;3PiP2`h>H05`2`h>H00`000000oooo0?ooo`0@0?ooo`8000002@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000;3PiP2`h>H0602`
h>H00`000000oooo0?ooo`0@0?ooo`8000002@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool04P3oool2000000`0/>3V00<000000?ooo`3oool01000
00000`3oool00000000000080?ooo`040000003oool0oooo000000`0/>3V00<000000?ooo`3oool0
4`3oool00`000000/>3V0;3PiP0:0;3PiP030000003oool0oooo00@0000000<0oooo000000000000
2@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000;3PiP2`h>H0
5@2`h>H00`000000oooo0?ooo`0<0?ooo`@0000000<0oooo0000000000002@3oool00`000000/>3V
0;3PiP0B0;3PiP030000003oool0oooo01h0oooo100000000`3oool00000000000080?ooo`030000
002`h>H0/>3V01<0/>3V00<000000?ooo`3oool07P3oool4000000030?ooo`000000000000d0oooo
000=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3P
iP0G0;3PiP030000003oool0oooo00h0oooo0`00000:0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000/>3V0;3PiP0H0;3PiP030000003oool0oooo00h0oooo0`00
000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0E0?ooo`8000002@2`h>H4000000<0oooo0`0000090?ooo`050000003oool0oooo0?ooo`000000
2P2`h>H00`000000oooo0?ooo`0E0?ooo`8000002@2`h>H4000000<0oooo0`00000:0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000/>3V0;3PiP0D0;3PiP030000
003oool0oooo00T0oooo100000030?ooo`<000002P3oool00`000000/>3V0;3PiP0B0;3PiP030000
003oool0oooo01X0oooo100000030?ooo`<000002@3oool00`000000/>3V0;3PiP0C0;3PiP030000
003oool0oooo01X0oooo100000030?ooo`<000003P3oool000d0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000002`h>H0/>3V01T0/>3V00<000000?ooo`3oool0303o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0
oooo0000000L0;3PiP030000003oool0oooo00`0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P00000J0?ooo`T000001P3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo100000020;3PiP@000006P3oool:
000000D0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00<000000;3PiP2`h>H04P2`h>H00`000000oooo0?ooo`060?ooo`@000001P3o
ool010000000oooo0?ooo`00000:0?ooo`030000002`h>H0/>3V0180/>3V00<000000?ooo`3oool0
5P3oool4000000H0oooo00@000000?ooo`3oool000002@3oool00`000000/>3V0;3PiP0B0;3PiP03
0000003oool0oooo01H0oooo1@0000060?ooo`040000003oool0oooo000000h0oooo000=0?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000000K0;3PiP030000003oool0oooo
00/0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`050?ooo`050000003oool0
oooo0?ooo`000000702`h>H00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo
1@0000090?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool01P3oool200000003
0?ooo`000000000001/0oooo1@0000090?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000002`h>H0/>3V0100/>3V00<000000?oo
o`3oool00P3oool5000000T0oooo00@000000?ooo`3oool000002`3oool00`000000/>3V0;3PiP0B
0;3PiP030000003oool0oooo0140oooo1@0000090?ooo`040000003oool0oooo000000X0oooo0P00
000C0;3PiP030000003oool0oooo0180oooo1000000:0?ooo`040000003oool0oooo000000l0oooo
000=0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000/>3V
0;3PiP0J0;3PiP030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000/>3V0;3PiP0J0;3P
iP030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0G0?ooo`@000003@3oool01@000000oooo0?oo
o`3oool0000000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`@00000
3@3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`8000003P2`h>H2000000030?ooo`0000000000008000003@3oool01@000000oooo0?ooo`3oool0
000000/0oooo00<000000;3PiP2`h>H04@2`h>H00`000000oooo0?ooo`0>0?ooo`@000003@3oool0
1@000000oooo0?ooo`3oool0000000X0oooo0P00000B0;3PiP030000003oool0oooo00l0oooo1000
000=0?ooo`050000003oool0oooo0?ooo`0000003`3oool000d0oooo00@000000?ooo`3oool0oooo
0P0000001`2`h>H000000000003oool000000?ooo`0000007@2`h>H00`000000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`000000303oool010000000oooo0?ooo`3oool2000000040;3PiP00
0000000000000080oooo00<000000;3PiP2`h>H06P2`h>H00`000000oooo0?ooo`080?ooo`800000
0`3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`0D0?ooo`@000003`3oool2000000<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo1000000@0?ooo`050000003oool0oooo0?oo
o`000000303oool01@000000oooo0?ooo`3oool0000000l0oooo0P0000090;3PiPH000003`3oool2
000000<0oooo00<000000?ooo`3oool02P3oool200000180/>3V00<000000?ooo`3oool02P3oool4
000000l0oooo0P0000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000004@2`h>H0
0`000000oooo0?ooo`0:0?ooo`D000003`3oool2000000<0oooo00<000000?ooo`3oool03P3oool0
00d0oooo00@000000?ooo`00000000001@2`h>H2000000030?ooo`000000/>3V01`0/>3V00<00000
0?ooo`3oool01P3oool2000000@0oooo00<000000?ooo`3oool02P3oool010000000oooo00000000
00050;3PiP80000000<0oooo0000002`h>H06`2`h>H00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo0100oooo1@00000B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo1@00000B0?ooo`800000
103oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000180oooo2`00000B0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000000@0;3PiP03
0000003oool0oooo00H0oooo1@00000B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0000000@0;3PiP030000003oool0oooo00L0oooo1000000C0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool000d0oooo0P0000080;3PiP<00000
7@2`h>H00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2`3oool2000000P0/>3V00<000000?ooo`000000702`h>H2000000L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000<0oooo0P00000?0?ooo`@0
00005P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0103oool2000000l0oooo1000000F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02`3oool010000000oooo0?ooo`00000D0?ooo`@000005P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00/0oooo00@000000?ooo`3oool000003P2`h>H00`000000oooo0?ooo`03
0?ooo`@000005P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00@00000
0?ooo`3oool000003`2`h>H00`000000oooo0?ooo`020?ooo`D000005P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00l0oooo000=0?ooo`8000002@2`h>H2000001d0/>3V00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<00000
0;3PiP2`h>H0202`h>H2000001`0/>3V0P0000060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo000000030?ooo`030000003oool0oooo00/0oooo1000000I
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00/0oooo1000000I0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0000000A0?ooo`@000006@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000<0;3PiP030000003o
ool0oooo00@000006@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00@0
00000?ooo`3oool0oooo0P00000;0;3PiP80000000<0oooo0000000000000P00000J0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000;3PiP2`h>H0202`
h>H2000001d0/>3V00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00`0oooo00<000000;3PiP2`h>H0202`h>H2000001`0/>3V00<000000?ooo`3oool00`3o
ool2000000H0oooo00<000000?ooo`3oool0303oool00`000000oooo000000020?ooo`030000003o
ool0oooo00P0oooo100000030;3PiP<000005@3oool2000000H0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo1@0000020;3PiP@000005@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000003@3o
ool4000000<0/>3V1000000D0?ooo`8000001P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0080oooo0P0000070;3PiPH000000`2`h>H3000001D0oooo0P0000060?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00`3oool2000000L0/>3V1P0000020;3PiP@000005@3o
ool2000000H0oooo00<000000?ooo`3oool0403oool000d0oooo00<000000;3PiP2`h>H0202`h>H2
000001d0/>3V00@000000?ooo`3oool0oooo0P0000070?ooo`030000003oool0oooo00`0oooo00<0
00000;3PiP2`h>H0202`h>H2000001`0/>3V00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00`0oooo0P0000020?ooo`030000003oool0oooo00@0oooo1@00
000:0;3PiP030000003oool0oooo0140oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0;0?ooo`050000003oool0oooo0?ooo`0000001P3oool6000000X0/>3V00<000000?ooo`3oool0
403oool2000000L0oooo00<000000?ooo`3oool0303oool2000000T0oooo1P00000:0;3PiP030000
003oool0oooo0100oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00@0oooo2@00000:0;3PiP030000003oool0oooo0140oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo2@00000:0;3PiP030000
003oool0oooo0140oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`003@3o
ool00`000000/>3V0;3PiP080;3PiP030000003oool0000001/0/>3V00D000000?ooo`3oool0oooo
000000080?ooo`030000003oool0oooo00d0oooo00<000000;3PiP2`h>H0202`h>H3000001X0/>3V
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo
100000030?ooo`@00000103oool00`000000/>3V0;3PiP090;3PiP030000003oool0oooo00l0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool00000000000<0
oooo100000040?ooo`030000002`h>H0/>3V00X0/>3V00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo0P0000050?ooo`@00000103oool00`000000
/>3V0;3PiP0:0;3PiP030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo100000040?ooo`030000002`h>H0/>3V00T0
/>3V00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0103oool4000000@0oooo00<000000;3PiP2`h>H02P2`h>H00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool000d0oooo
00<000000;3PiP2`h>H0202`h>H00`000000oooo0000000K0;3PiP040000003oool0oooo000000T0
oooo00<000000?ooo`3oool03@3oool00`000000/>3V0;3PiP080;3PiP030000003oool0000001X0
/>3V00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00d0oooo0P0000000`3o
ool0000000000002000000L0oooo00<000000;3PiP2`h>H02`2`h>H00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool2000000030?ooo`0000000000
008000001`3oool00`000000/>3V0;3PiP0<0;3PiP030000003oool0oooo00`0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@000001`3oool00`00
0000/>3V0;3PiP0<0;3PiP030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00@000001`3oool00`000000/>3V0;3PiP0;0;3P
iP030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00@000001`3oool00`000000/>3V0;3PiP0<0;3PiP030000003oool0oooo
00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`003@3oool2000000P0
/>3V00<000000?ooo`3oool00P00000I0;3PiP060000003oool0oooo0000003oool000001`3oool0
0`000000oooo0?ooo`0>0?ooo`030000002`h>H0/>3V00L0/>3V00@000000?ooo`3oool000006P2`
h>H00`000000oooo00000003000000L0oooo00<000000?ooo`3oool03P3oool3000000X0oooo00<0
00000;3PiP2`h>H03@2`h>H00`000000oooo0?ooo`0:0?ooo`@000001`3oool00`000000oooo0?oo
o`0=0?ooo`<000002`3oool00`000000/>3V0;3PiP0=0;3PiP030000003oool0oooo00X0oooo00<0
00000?ooo`000000203oool00`000000oooo0?ooo`0=0?ooo`<000002`3oool00`000000/>3V0;3P
iP0=0;3PiP030000003oool0oooo00T0oooo0P0000000`3oool000000?ooo`060?ooo`030000003o
ool0oooo00h0oooo0`00000:0?ooo`030000002`h>H0/>3V00d0/>3V0P00000;0?ooo`@000001`3o
ool00`000000oooo0?ooo`0=0?ooo`<000002`3oool00`000000/>3V0;3PiP0=0;3PiP030000003o
ool0oooo00X0oooo0`0000080?ooo`030000003oool0oooo0180oooo000>0?ooo`8000001`2`h>H0
1@000000oooo0?ooo`3oool0000001T0/>3V00<000000?ooo`0000000P0000000`2`h>H000000000
00050?ooo`030000003oool0oooo00l0oooo00<000000;3PiP2`h>H01@2`h>H00`000000oooo0?oo
o`020?ooo`030000002`h>H0/>3V01H0/>3V00<000000?ooo`0000000P0000020;3PiP8000001@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<000000;3PiP2`h>H03P2`
h>H00`000000oooo0?ooo`090?ooo`<000000P2`h>H2000000D0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`090?ooo`030000002`h>H0/>3V00h0/>3V00<000000?ooo`3oool02@3o
ool3000000030;3PiP000000000000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`090?ooo`030000002`h>H0/>3V00h0/>3V00<000000?ooo`3oool0203oool01@000000oooo0000
00000000/>3V008000001@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo
00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`080?ooo`<000000P2`h>H2000000D0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000002`h>H0/>3V00h0/>3V
00<000000?ooo`3oool02@3oool3000000030;3PiP000000000000H0oooo00<000000?ooo`3oool0
4P3oool000l0oooo0`0000030;3PiP8000001@3oool00`000000/>3V0;3PiP0E0;3PiP@000001@2`
h>H200000080oooo00<000000?ooo`3oool04@3oool2000000<0/>3V0P0000050?ooo`8000005`2`
h>H3000000H0/>3V0P0000020?ooo`030000003oool0oooo0140oooo0P0000080?ooo`030000002`
h>H0/>3V00l0/>3V00<000000?ooo`3oool01`3oool2000000H0/>3V00D000000?ooo`3oool0oooo
0000000B0?ooo`800000203oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo00H0oooo
0`0000050;3PiP8000000`3oool00`000000oooo0?ooo`0@0?ooo`800000203oool00`000000/>3V
0;3PiP0@0;3PiP030000003oool0oooo00H0oooo0`0000050;3PiP8000000P3oool00`000000oooo
0?ooo`0A0?ooo`800000203oool00`000000/>3V0;3PiP0?0;3PiP030000003oool0oooo00L0oooo
0P0000060;3PiP050000003oool0oooo0?ooo`0000004P3oool2000000P0oooo00<000000;3PiP2`
h>H0402`h>H00`000000oooo0?ooo`070?ooo`8000001@2`h>H2000000<0oooo00<000000?ooo`3o
ool04`3oool00140oooo100000070?ooo`030000002`h>H0/>3V01@0/>3V0`0000080;3PiP040000
003oool0oooo000001D0oooo0`0000070?ooo`8000005P2`h>H3000000P0/>3V00@000000?ooo`3o
ool000005@3oool00`000000oooo0?ooo`040?ooo`030000002`h>H0/>3V0100/>3V00<000000?oo
o`3oool01@3oool2000000P0/>3V00D000000?ooo`3oool0oooo0000000D0?ooo`030000003oool0
oooo00D0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo0?ooo`050?ooo`800000202`h>H0
1@000000oooo0?ooo`3oool0000001@0oooo00<000000?ooo`3oool01@3oool00`000000/>3V0;3P
iP0@0;3PiP030000003oool0oooo00@0oooo0`0000080;3PiP040000003oool0oooo000001D0oooo
00<000000?ooo`3oool01@3oool00`000000/>3V0;3PiP0?0;3PiP030000003oool0oooo00D0oooo
0P0000080;3PiP050000003oool0oooo0?ooo`000000503oool00`000000oooo0?ooo`050?ooo`03
0000002`h>H0/>3V0100/>3V00<000000?ooo`3oool01@3oool2000000P0/>3V00D000000?ooo`3o
ool0oooo0000000E0?ooo`004P3oool00`000000oooo0?ooo`080?ooo`030000002`h>H0/>3V0180
/>3V0`00000:0;3PiP8000005`3oool00`000000oooo0?ooo`070?ooo`800000502`h>H00`000000
oooo0000000:0;3PiP8000005`3oool00`000000oooo0?ooo`030?ooo`030000002`h>H0/>3V0140
/>3V00<000000?ooo`3oool00`3oool00`000000oooo000000090;3PiP030000003oool0000001H0
oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo00@0
oooo00<000000?ooo`0000002@2`h>H00`000000oooo0000000F0?ooo`030000003oool0oooo00@0
oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo0?ooo`030?ooo`030000003oool0000000X0
/>3V0P00000G0?ooo`030000003oool0oooo00@0oooo00<000000;3PiP2`h>H0402`h>H00`000000
oooo0?ooo`030?ooo`030000003oool0000000T0/>3V00<000000?ooo`0000005P3oool00`000000
oooo0?ooo`040?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool0103oool00`000000
oooo000000090;3PiP030000003oool0000001H0oooo000C0?ooo`800000203oool200000180/>3V
0P0000000`3oool000000;3PiP090;3PiP800000603oool00`000000oooo0?ooo`060?ooo`030000
003oool000000180/>3V00@000000?ooo`3oool000002P2`h>H2000001P0oooo00<000000?ooo`3o
ool00P3oool00`000000/>3V0;3PiP0A0;3PiP030000003oool0oooo0080oooo00<000000?ooo`00
00002P2`h>H00`000000oooo0000000G0?ooo`800000103oool00`000000/>3V0;3PiP0@0;3PiP03
0000003oool0oooo00<0oooo00<000000?ooo`0000002P2`h>H00`000000oooo0000000G0?ooo`03
0000003oool0oooo00<0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000X0/>3V0P00000H0?ooo`030000003oool0oooo00<0oooo00<000000;3P
iP2`h>H0402`h>H00`000000oooo0?ooo`020?ooo`030000003oool0000000X0/>3V00<000000?oo
o`0000005`3oool2000000@0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo0?ooo`030?oo
o`030000003oool0000000X0/>3V00<000000?ooo`0000005P3oool001D0oooo00<000000?ooo`3o
ool01P3oool3000000l0/>3V0P0000020?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3o
ool0603oool2000000L0oooo00@000000?ooo`00000000003`2`h>H01@000000oooo0?ooo`3oool0
000000X0/>3V00<000000?ooo`3oool0603oool2000000<0oooo00<000000;3PiP2`h>H03`2`h>H2
000000<0oooo00@000000?ooo`3oool000002`2`h>H00`000000oooo0?ooo`0H0?ooo`050000003o
ool0oooo0?ooo`0000004P2`h>H010000000oooo0?ooo`3oool200000080oooo00<000000;3PiP2`
h>H0202`h>H2000001T0oooo0P0000030?ooo`030000002`h>H0/>3V0100/>3V00D000000?ooo`3o
ool0oooo000000030?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool0603oool20000
00<0oooo00<000000;3PiP2`h>H03`2`h>H2000000<0oooo00@000000?ooo`3oool000002`2`h>H0
0`000000oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`0000004P2`h>H00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000X0/>3V0P00000G0?ooo`005P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<000002P2`h>H2000000@0oooo00<000000;3PiP2`h>H0202`
h>H00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo
0P00000;0;3PiP800000103oool00`000000/>3V0;3PiP070;3PiP800000703oool010000000oooo
0?ooo`00000A0;3PiP030000003oool0oooo008000000`3oool00`000000/>3V0;3PiP080;3PiP80
00006`3oool010000000oooo0?ooo`00000B0;3PiP040000003oool0oooo000000@0oooo00<00000
0;3PiP2`h>H0202`h>H2000001/0oooo00@000000?ooo`3oool000004P2`h>H010000000oooo0000
000000040?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool06P3oool010000000oooo
0?ooo`00000A0;3PiP030000003oool0oooo008000000`3oool00`000000/>3V0;3PiP080;3PiP80
00006`3oool010000000oooo0?ooo`00000B0;3PiP030000003oool0oooo008000000`3oool00`00
0000/>3V0;3PiP080;3PiP8000005`3oool001L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`<000000`2`h>H5000000D0oooo00<000000;3PiP2`h>H01`2`h>H2000001d0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`<000000`2`h>H5000000H0
oooo00<000000;3PiP2`h>H01`2`h>H00`000000oooo0?ooo`0L0?ooo`030000003oool000000140
/>3V00<000000?ooo`0000001P3oool00`000000/>3V0;3PiP070;3PiP030000003oool0oooo01/0
oooo00@000000?ooo`3oool000004@2`h>H00`000000oooo000000050?ooo`030000002`h>H0/>3V
00P0/>3V00<000000?ooo`3oool06`3oool00`000000oooo0000000A0;3PiP030000003oool00000
00H0oooo00<000000;3PiP2`h>H01`2`h>H2000001d0oooo00<000000?ooo`0000004@2`h>H00`00
0000oooo000000060?ooo`030000002`h>H0/>3V00L0/>3V00<000000?ooo`3oool06`3oool01000
0000oooo0?ooo`00000A0;3PiP030000003oool0000000D0oooo00<000000;3PiP2`h>H0202`h>H0
0`000000oooo0?ooo`0F0?ooo`00603oool2000000D0oooo00<000000?ooo`3oool01@3oool30000
00<0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP070;3PiP030000003oool0oooo
01d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`<000000`3oool00`00
0000oooo0?ooo`050?ooo`030000002`h>H0/>3V00H0/>3V0P00000O0?ooo`800000402`h>H00`00
0000oooo000000070?ooo`030000002`h>H0/>3V00H0/>3V0P00000N0?ooo`<00000402`h>H00`00
0000oooo000000060?ooo`030000002`h>H0/>3V00L0/>3V0P00000N0?ooo`800000402`h>H00`00
0000oooo000000070?ooo`030000002`h>H0/>3V00L0/>3V00<000000?ooo`3oool07@3oool20000
0100/>3V00<000000?ooo`0000001`3oool00`000000/>3V0;3PiP060;3PiP8000007P3oool30000
0100/>3V00<000000?ooo`0000001`3oool00`000000/>3V0;3PiP060;3PiP800000603oool001X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`800000203oool00`000000
/>3V0;3PiP050;3PiP800000803oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool00`000000/>3V0;3PiP050;3PiP030000003oool0oooo01l0
oooo0P00000?0;3PiP8000002@3oool00`000000/>3V0;3PiP050;3PiP030000003oool0oooo01l0
oooo0P00000?0;3PiP800000203oool00`000000/>3V0;3PiP060;3PiP030000003oool0oooo01h0
oooo0P00000?0;3PiP8000002@3oool00`000000/>3V0;3PiP050;3PiP030000003oool0oooo01l0
oooo0P00000?0;3PiP8000002@3oool00`000000/>3V0;3PiP050;3PiP030000003oool0oooo01l0
oooo0P00000?0;3PiP8000002@3oool00`000000/>3V0;3PiP050;3PiP030000003oool0oooo01L0
oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`8000000`2`h>H300000280oooo0P0000030?ooo`030000003oool0oooo00L0oooo
0P00000;0?ooo`8000000`2`h>H300000280oooo0P00000=0;3PiP8000002`3oool2000000<0/>3V
0`00000R0?ooo`8000003@2`h>H00`000000oooo0?ooo`090?ooo`8000000`2`h>H400000240oooo
0P00000=0;3PiP8000002`3oool2000000<0/>3V0`00000R0?ooo`8000003@2`h>H2000000/0oooo
0P0000030;3PiP<000008P3oool2000000d0/>3V0P00000;0?ooo`8000000`2`h>H3000001T0oooo
000L0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo1000
000W0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0<0?ooo`@00000
9P3oool2000000/0/>3V0P00000=0?ooo`@000009P3oool2000000/0/>3V00<000000?ooo`3oool0
303oool4000002H0oooo00<000000;3PiP2`h>H02@2`h>H2000000d0oooo1000000W0?ooo`030000
002`h>H0/>3V00T0/>3V0P00000=0?ooo`@000009P3oool2000000/0/>3V00<000000?ooo`3oool0
303oool4000001`0oooo000N0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0
203oool4000002`0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`080?ooo`D0
0000:`3oool3000000P0/>3V0P0000090?ooo`D00000:`3oool3000000P0/>3V00<000000?ooo`3o
ool0203oool5000002/0oooo0P0000080;3PiP8000002@3oool5000002`0oooo0P0000080;3PiP80
00002@3oool5000002/0oooo0`0000080;3PiP030000003oool0oooo00P0oooo1@00000P0?ooo`00
7`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo1@00000a0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool400000380oooo2@0000070?oo
o`@00000<P3oool9000000L0oooo1000000a0?ooo`X000001P3oool400000380oooo2@0000070?oo
o`@00000<P3oool9000000L0oooo1000000U0?ooo`00803oool300000080oooo0P0000030?ooo`@0
0000=`3oool300000080oooo0P0000030?ooo`D00000=`3oool2000000<0oooo0P0000030?ooo`D0
0000=`3oool2000000<0oooo0P0000030?ooo`D00000=P3oool2000000<0oooo0P0000030?ooo`D0
0000=`3oool2000000<0oooo0P0000030?ooo`D00000=`3oool2000000<0oooo0P0000030?ooo`D0
0000:@3oool00280oooo0`0000000`3oool0000000000002000003d0oooo0`0000000`3oool00000
00000002000003h0oooo00@000000?ooo`000000oooo1000000n0?ooo`040000003oool000000?oo
o`@00000?@3oool010000000oooo0000003oool4000003h0oooo00@000000?ooo`000000oooo1000
000n0?ooo`040000003oool000000?ooo`@00000;P3oool002<0oooo0`0000120?ooo`<00000@`3o
ool3000004<0oooo0`0000120?ooo`<00000@`3oool3000004<0oooo0`00000b0?ooo`00o`3ooook
0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook
0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`008`3oool300000480oooo0`00
00130?ooo`<00000@`3oool300000480oooo0`0000130?ooo`<00000@`3oool300000380oooo000R
0?ooo`8000000P3oool4000003d0oooo0P0000020?ooo`@00000?P3oool010000000/>3V0;3PiP2`
h>H4000003h0oooo0`0000000`3oool0000000000002000003d0oooo0P0000020?ooo`H00000?03o
ool010000000/>3V0;3PiP2`h>H4000003h0oooo0`0000000`3oool0000000000002000002h0oooo
000P0?ooo`80000000<0oooo0000003oool01@3oool6000003D0oooo100000060?ooo`H00000=P3o
ool2000000H0/>3V1`00000g0?ooo`80000000<0oooo0000003oool00P0000030?ooo`D00000=P3o
ool3000000030?ooo`0000000000008000000P2`h>H5000003L0oooo0P0000060;3PiPL00000=`3o
ool4000000030?ooo`000000000000<0oooo1@00000Y0?ooo`007`3oool01@000000oooo0?ooo`3o
ool0000000H0oooo2@00000a0?ooo`030000003oool0oooo008000001`3oool800000380oooo0P00
00080;3PiP030000003oool0oooo00<0oooo1000000b0?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`050?ooo`@00000<@3oool00`000000oooo0?ooo`02000000X0/>3V
1@00000b0?ooo`800000202`h>H00`000000oooo0?ooo`030?ooo`@00000<P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool4000002D0oooo000N0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000000P0/>3V1@00000/0?ooo`060000
003oool0oooo0000003oool000001@3oool2000000L0/>3V1P00000/0?ooo`8000002P2`h>H00`00
0000oooo0?ooo`060?ooo`D00000;03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool5000002/0oooo00@000000?ooo`3oool000003@2`h>H0
10000000oooo0?ooo`3oool5000002`0oooo0P00000:0;3PiP030000003oool0oooo00H0oooo1@00
000/0?ooo`060000003oool0oooo0000003oool00000103oool00`000000oooo0?ooo`080?ooo`D0
0000803oool001`0oooo0P0000050?ooo`030000003oool0oooo00800000302`h>H00`000000oooo
0?ooo`04000002L0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo0P00000;0;3P
iP8000000P3oool4000002L0oooo00<000000?ooo`0000002P2`h>H00`000000oooo0?ooo`0;0?oo
o`@000009P3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?oo
o`@000009P3oool01@000000oooo0?ooo`3oool0000000h0/>3V00<000000?ooo`3oool01@3oool4
000002L0oooo00<000000?ooo`0000002P2`h>H00`000000oooo0?ooo`0;0?ooo`@000009P3oool2
00000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0<0?ooo`@00000703o
ool001/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000?0;3PiP800000103oool3
00000280oooo0P0000030?ooo`040000003oool0oooo00000080oooo00<000000;3PiP2`h>H03@2`
h>H2000000@0oooo0`00000R0?ooo`8000000P3oool00`000000/>3V0;3PiP080;3PiP030000003o
ool0oooo00l0oooo0`00000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`090?ooo`8000000`2`h>H400000240oooo0P0000030?ooo`030000002`
h>H0/>3V00h0/>3V00<000000?ooo`3oool0203oool300000280oooo0P0000020?ooo`030000002`
h>H0/>3V00P0/>3V00<000000?ooo`3oool03`3oool300000280oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000060?ooo`8000002P3oool2000000<0/>3V1000000I0?ooo`006P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool000000100/>3V00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0P3oool00`000000/>3V0;3PiP0>0;3PiP030000003oool0oooo00@0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`020?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool0
2`3oool400000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo0P0000080?ooo`030000002`h>H0/>3V00D0/>3V0P00000P0?ooo`030000
003oool0oooo00<0oooo00<000000;3PiP2`h>H03P2`h>H00`000000oooo0?ooo`090?ooo`800000
8@3oool00`000000oooo0?ooo`020?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool0
2`3oool4000000030?ooo`00000000000240oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000P0oooo00<000000?ooo`3oool01P3oool00`000000/>3V0;3PiP050;3PiP80
00006@3oool001T0oooo00<000000?ooo`3oool01`3oool200000180/>3V00<000000?ooo`3oool0
0P3oool00`000000oooo0000000O0?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0
oooo0000003oool000000180/>3V00<000000?ooo`3oool00P3oool00`000000oooo0000000O0?oo
o`030000003oool0oooo00<0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`070?oo
o`@000001@3oool00`000000oooo0000000O0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000002`h>H0/>3V00H0/>3V0P00000N0?oo
o`030000003oool0oooo00<0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo0?ooo`060?oo
o`<0000000<0oooo0000003oool07P3oool00`000000oooo0?ooo`030?ooo`030000002`h>H0/>3V
00P0/>3V00<000000?ooo`3oool01`3oool4000000<0oooo0`0000000`3oool000000?ooo`0N0?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0
oooo00D0oooo00<000000;3PiP2`h>H01P2`h>H2000001P0oooo000G0?ooo`8000002P3oool20000
0180/>3V00<000000?ooo`3oool00P3oool00`000000oooo0000000N0?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool0oooo0P00000C0;3PiP030000003oool0oooo0080oooo00<00000
0?ooo`0000007P3oool00`000000oooo0?ooo`040?ooo`030000002`h>H0/>3V00L0/>3V00<00000
0?ooo`3oool00`3oool5000000T0oooo00<000000?ooo`0000007@3oool2000000X0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000002`h>H0/>3V00P0/>3V00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`030000002`h>H0/>3V0100/>3V00<00000
0?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo000001h0oooo00<000000?ooo`3oool0
103oool00`000000/>3V0;3PiP070;3PiP030000003oool0oooo00<0oooo1@0000060?ooo`060000
003oool0oooo0000003oool000007@3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000;3PiP2`h>H0202`h>H00`00
0000oooo0?ooo`0F0?ooo`005P3oool7000000H0oooo00<000000;3PiP2`h>H04P2`h>H010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`800000502`h>H010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool01P3oool00`000000/>3V0;3PiP050;3PiP030000003oool0
oooo00@000003@3oool01@000000oooo0?ooo`3oool0000001/0oooo1`0000060?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000/>3V0;3PiP080;3PiP8000006`3o
ool00`000000oooo0?ooo`040?ooo`8000004P2`h>H00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`030000
002`h>H0/>3V00D0/>3V00<000000?ooo`3oool01000000:0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool2000000<0oooo00<000000;3PiP2`h>H0202`h>H2000001L0
oooo000D0?ooo`8000001`2`h>H00`000000oooo0?ooo`030?ooo`030000002`h>H0/>3V0180/>3V
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0H0?ooo`8000001`3oool00`000000
oooo0?ooo`020?ooo`800000502`h>H010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
01P0oooo0P00000:0?ooo`X000004@3oool01@000000oooo0?ooo`3oool0000001T0oooo0P000007
0;3PiP800000103oool00`000000oooo0?ooo`0:0?ooo`8000000P3oool00`000000/>3V0;3PiP08
0;3PiP8000006@3oool2000000L0oooo0P00000B0;3PiP030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo01P0oooo0P00000:0?ooo`X000003@3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool010000000oooo
0?ooo`00000:0;3PiP8000005`3oool001<0oooo0P0000090;3PiP8000000`3oool00`000000/>3V
0;3PiP0C0;3PiP8000001@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000/>3V0;3PiP0C0;3PiP030000003oool0000000D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`L00000503oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01D0oooo0P00000:0;3PiP050000003oool0oooo0?ooo`00
00003P3oool00`000000oooo0000000:0;3PiP030000003oool0000001L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0000000B0;3PiP040000003oool0oooo0?ooo`8000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool50000
00l0oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool20000
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool00000
00X0/>3V00<000000?ooo`0000005P3oool00180oooo00<000000;3PiP2`h>H02`2`h>H010000000
oooo0?ooo`00000E0;3PiP8000001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3PiP0C0;3PiP030000003oool00000
00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`080?ooo`@00000102`h>H30000
0180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`030000002`h>H0/>3V
00/0/>3V00@000000?ooo`3oool000003`3oool2000000X0/>3V00<000000?ooo`0000005P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool000000180/>3V00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0203o
ool4000001<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00d0oooo0P00000:0;3PiP030000003oool0000001H0oooo000A0?ooo`030000002`h>H0
/>3V00`0/>3V00@000000?ooo`3oool000005@2`h>H00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01<0oooo1@0000050?ooo`030000003oool0oooo00@0oooo00<000000;3PiP2`h>H04`2`
h>H2000000L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`D000002`2`
h>H2000000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`8000003P2`
h>H00`000000oooo0000000@0?ooo`030000002`h>H0/>3V00L0/>3V00D000000?ooo`3oool0oooo
0000000D0?ooo`D000001@3oool01@000000oooo0?ooo`3oool000000140/>3V00<000000?ooo`00
00001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0103oool5000001H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0180oooo1P0000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03P3oool2000000P0/>3V00D000000?ooo`3oool0oooo0000000E0?ooo`003`3oool200000100
/>3V00<000000?ooo`000000502`h>H2000000L0oooo00<000000?ooo`3oool04@3oool2000000D0
/>3V00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000002`h>H0/>3V01<0
/>3V0P0000070?ooo`030000003oool0oooo0140oooo0P0000030?ooo`@0000000<0oooo00000000
00003`2`h>H00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0403oool300000100/>3V0P00000A0?ooo`030000002`h>H0/>3V00H0/>3V00D000000?ooo`3o
ool0oooo0000000B0?ooo`8000001@2`h>H00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000402`h>H00`000000oooo000000060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool04@3oool200000080oooo1`00000H0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`8000001@2`h>H00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`000000/>3V0;3PiP05
0;3PiP050000003oool0oooo0?ooo`0000005@3oool000h0oooo00<000000?ooo`000000402`h>H0
0`000000oooo0000000D0;3PiP030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool0
0`000000/>3V0;3PiP060;3PiP040000003oool0oooo000000L0oooo00<000000;3PiP2`h>H04`2`
h>H00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`0000000`00
00040?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000004@2`h>H2000000T0oooo4@00
00040?ooo`030000003oool0oooo00l0oooo00<000000;3PiP2`h>H01P2`h>H010000000oooo0?oo
o`0000050?ooo`030000002`h>H0/>3V00d0/>3V0P0000060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03`3oool00`000000oooo00000003000000H0/>3V0P00000D0?ooo`800000
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000;3PiP2`h>H0
1P2`h>H01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01`3ooolA000000D0
oooo00<000000?ooo`3oool04P3oool000d0oooo00@000000?ooo`3oool000004@2`h>H2000001@0
/>3V00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000002`h>H0/>3V00L0
/>3V00@000000?ooo`3oool000001`3oool2000001<0/>3V0P0000090?ooo`030000003oool0oooo
00h0oooo0`0000070?ooo`030000002`h>H0/>3V0180/>3V00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000004@2`h>H2
000000L0oooo0P00000:0;3PiP8000002P3oool00`000000oooo0?ooo`0=0?ooo`030000002`h>H0
/>3V00L0/>3V00@000000?ooo`3oool000001P3oool00`000000/>3V0;3PiP0;0;3PiP030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`@000002`2`
h>H00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`800000202`h>H010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00D0oooo0P00000:0;3PiP<000002@3oool00`000000oooo0?ooo`0B0?ooo`003@3o
ool010000000oooo0?ooo`00000A0;3PiP8000004`2`h>H2000000<0oooo0`0000040?ooo`030000
003oool0oooo00d0oooo00<000000;3PiP2`h>H0202`h>H2000000P0oooo0P00000C0;3PiP030000
003oool0oooo0080oooo0`0000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1P3oool00`000000/>3V0;3PiP0D0;3PiP030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0P3oool3000000@0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000A0;3PiP80
00001P3oool00`000000/>3V0;3PiP0<0;3PiP800000203oool00`000000oooo0?ooo`0=0?ooo`03
0000002`h>H0/>3V00P0/>3V0P0000080?ooo`030000002`h>H0/>3V00T0/>3V00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`<00000103oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0000000d0/>3V00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo0`0000040?ooo`030000003oool0oooo00`0oooo00<000000;3PiP2`
h>H0202`h>H00`000000oooo000000080?ooo`030000003oool0oooo00@0oooo00<000000;3PiP2`
h>H0302`h>H2000000T0oooo00<000000?ooo`3oool04@3oool000d0oooo0P0000000`3oool00000
0;3PiP0A0;3PiP8000004P2`h>H00`000000oooo0?ooo`02000000<0/>3V1@00000?0?ooo`030000
002`h>H0/>3V00P0/>3V0P0000080?ooo`030000003oool000000140/>3V0P0000020?ooo`800000
0`2`h>H5000000l0oooo0P0000070?ooo`030000002`h>H0/>3V01D0/>3V00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`02000000<0/>3V0`0000000`3oool000000?ooo`0=0?ooo`800000
00<0oooo0000002`h>H04@2`h>H00`000000oooo0?ooo`020?ooo`800000402`h>H2000000P0oooo
00<000000?ooo`3oool0303oool00`000000/>3V0;3PiP080;3PiP8000002@3oool2000000L0/>3V
0P0000090?ooo`030000003oool0oooo008000000`2`h>H5000000l0oooo00<000000?ooo`000000
3P2`h>H00`000000oooo0?ooo`0;0?ooo`8000002@3oool00`000000oooo0?ooo`02000000<0/>3V
0`0000000`3oool000000?ooo`0=0?ooo`030000002`h>H0/>3V00P0/>3V0P0000090?ooo`030000
003oool0oooo0080oooo0P00000A0;3PiP030000003oool0oooo00H0oooo00<000000?ooo`3oool0
4@3oool000d0oooo0P0000000`3oool000000;3PiP0A0;3PiP030000003oool000000100/>3V0P00
00000`3oool000000;3PiP080;3PiP8000003P3oool00`000000/>3V0;3PiP080;3PiP030000003o
ool0oooo00L0oooo00<000000?ooo`0000004@2`h>H010000000oooo0000000000090;3PiP800000
3P3oool2000000H0oooo00<000000;3PiP2`h>H05`2`h>H00`000000oooo0?ooo`040?ooo`040000
003oool00000000000P0/>3V00<000000?ooo`0000003@3oool2000000030?ooo`000000/>3V0140
/>3V00D000000?ooo`3oool0oooo0000000C0;3PiP8000001`3oool00`000000oooo0?ooo`0<0?oo
o`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool02P3oool8000000T0oooo00@000000?oo
o`00000000002@2`h>H2000000h0oooo0P00000@0;3PiP030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool010000000oooo0000000000080;3PiP030000003oool0000000d0oooo00<0
00000;3PiP2`h>H02@2`h>H00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000
502`h>H00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo000=0?ooo`040000003o
ool0000000000140/>3V0P0000020?ooo`030000002`h>H0/>3V00`0/>3V1000000;0;3PiP030000
003oool0oooo00`0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`070?ooo`040000
003oool0oooo000000l0/>3V0`00000<0;3PiP030000003oool0oooo00`0oooo00<000000?ooo`00
00001@3oool00`000000/>3V0;3PiP0G0;3PiP030000003oool0oooo00@0oooo0P00000;0;3PiP80
00003@3oool010000000oooo00000000000B0;3PiP050000003oool0oooo0?ooo`0000005@2`h>H0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000;3PiP2`h>H0202`h>H0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo0P00000<0;3PiP030000003oool0
oooo00`0oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo0P00000;0;3PiP8000003@3oool2000000T0/>3V00<000000?ooo`3oool0203oool0
1@000000oooo0?ooo`3oool0000001D0/>3V0P0000060?ooo`030000003oool0oooo0100oooo000=
0?ooo`040000003oool0000000000140/>3V0P0000030?ooo`030000002`h>H0/>3V00X0/>3V0`00
000>0;3PiP030000003oool0oooo00/0oooo00<000000;3PiP2`h>H01`2`h>H2000000T0oooo00@0
00000?ooo`3oool0oooo0P00000<0;3PiP<000003P2`h>H00`000000oooo0?ooo`0;0?ooo`030000
003oool0000000@0oooo00<000000;3PiP2`h>H06@2`h>H00`000000oooo0?ooo`020?ooo`800000
3@2`h>H2000000`0oooo00@000000?ooo`00000000004@2`h>H200000080oooo00<000000;3PiP2`
h>H05@2`h>H00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000;3PiP2`
h>H01`2`h>H200000100oooo00<000000?ooo`3oool02@3oool2000000h0/>3V00<000000?ooo`3o
ool02`3oool00`000000/>3V0;3PiP0?0;3PiP030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02@3oool2000000d0/>3V0P00000<0?ooo`8000002@2`h>H00`000000oooo0?ooo`080?ooo`04
0000003oool0oooo000001L0/>3V0P0000060?ooo`030000003oool0oooo00l0oooo000=0?ooo`04
0000003oool0oooo00000140/>3V0P0000040?ooo`8000002P2`h>H3000000h0/>3V0P00000<0?oo
o`800000202`h>H00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P0000090;3P
iP040000003oool00000000000h0/>3V0P00000<0?ooo`040000003oool0oooo000000<0oooo00<0
00000;3PiP2`h>H06@2`h>H00`000000oooo0?ooo`020?ooo`030000002`h>H0/>3V00d0/>3V00<0
00000?ooo`3oool02P3oool010000000oooo0?ooo`00000A0;3PiP80000000<0oooo0000002`h>H0
602`h>H00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo0P0000080;3PiP030000
003oool0oooo00d0oooo0P00000<0?ooo`8000003P2`h>H2000000`0oooo00<000000;3PiP2`h>H0
402`h>H00`000000oooo0?ooo`040?ooo`800000303oool00`000000/>3V0;3PiP0=0;3PiP030000
003oool0oooo00X0oooo00<000000?ooo`0000001`2`h>H00`000000oooo0?ooo`090?ooo`030000
003oool0000001T0/>3V0P0000050?ooo`030000003oool0oooo00l0oooo000=0?ooo`040000003o
ool0oooo00000100/>3V00<000000?ooo`0000001P3oool<00000100/>3V00<000000?ooo`3oool0
2P3oool00`000000oooo000000060;3PiP8000002P3oool00`000000oooo0?ooo`050?ooo`T00000
00<0oooo000000000000402`h>H00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000<0
oooo00<000000;3PiP2`h>H06@2`h>H01@000000oooo0?ooo`3oool000000100/>3V0P00000;0?oo
o`040000003oool0oooo00000100/>3V00@000000?ooo`00000000006P2`h>H3000000@0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo000000060;3PiP8000003P3oool00`000000oooo0?oo
o`0;0?ooo`800000402`h>H00`000000oooo0?ooo`0:0?ooo`030000002`h>H0/>3V0100/>3V00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000002`h>H0/>3V00h0/>3V0P00
000;0?ooo`040000003oool0oooo000000H0/>3V00<000000?ooo`3oool02@3oool2000001X0/>3V
00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0>0?ooo`003@3oool01@000000oooo0?oo
o`3oool0000000l0/>3V00<000000?ooo`000000403oool00`000000/>3V0;3PiP0?0;3PiP800000
2`3oool00`000000oooo0?ooo`07000000/0oooo00<000000?ooo`3oool03`3oool00`000000/>3V
0;3PiP0?0;3PiP030000003oool0oooo00X0oooo00L000000?ooo`3oool0oooo0000003oool00000
01d0/>3V00@000000?ooo`3oool000004@2`h>H00`000000oooo0?ooo`090?ooo`050000003oool0
oooo0?ooo`0000003`2`h>H010000000oooo00000000000K0;3PiP030000003oool0000000<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`07000000h0oooo00<000000?ooo`3oool0
303oool00`000000/>3V0;3PiP0?0;3PiP030000003oool0oooo00X0oooo00<000000;3PiP2`h>H0
402`h>H00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000;3PiP2`h>H0
3`2`h>H00`000000oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`H00000303oool2000001/0
/>3V00@000000?ooo`00000000000`3oool00`000000oooo0?ooo`0>0?ooo`003@3oool010000000
oooo0?ooo`3oool2000000d0/>3V00@000000?ooo`3oool00000403oool00`000000/>3V0;3PiP0@
0;3PiP030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00h0oooo0P00000A0;3PiP8000002`3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000007@2`h>H00`000000oooo0000000B0;3PiP8000002P3oool010000000oooo
0?ooo`3oool2000000d0/>3V00@000000?ooo`3oool00000702`h>H010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo0P00000A0;3PiP8000002`3oool00`000000/>3V0;3PiP0@
0;3PiP050000003oool0oooo0?ooo`0000003P3oool00`000000/>3V0;3PiP0@0;3PiP8000002P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000;3PiP2`h>H06P2`
h>H01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool03@3oool000d0oooo00<0
00000?ooo`3oool00P3oool2000000/0/>3V00D000000?ooo`3oool0oooo0000000?0?ooo`800000
4P2`h>H00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0>0?ooo`8000004P2`h>H00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo0P00000M0;3PiP030000003oool000000180/>3V0P00000:0?ooo`030000
003oool0oooo0080oooo0`00000:0;3PiP050000003oool0oooo0?ooo`000000702`h>H01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00X0oooo0P00000?0?ooo`8000004P2`h>H00`000000oooo0?ooo`090?oo
o`030000002`h>H0/>3V00l0/>3V00<000000?ooo`3oool00P00000?0?ooo`030000002`h>H0/>3V
0100/>3V0P00000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`00
0000/>3V0;3PiP0J0;3PiP030000003oool0oooo0080oooo00@000000?ooo`3oool000003`3oool0
00d0oooo00<000000?ooo`3oool00P3oool010000000oooo0000000000070;3PiP800000103oool0
0`000000oooo0?ooo`0=0?ooo`8000004P2`h>H2000000X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000004P2`h>H2
000000X0oooo00<000000?ooo`3oool00P3oool2000001d0/>3V0`00000B0;3PiP030000003oool0
000000T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070;3PiP800000103o
ool00`000000/>3V0;3PiP0J0;3PiP030000003oool0oooo0080oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0000000B0;3PiP8000002P3oool00`000000/>3V0;3PiP0?0;3PiP030000
003oool000000100oooo0P00000B0;3PiP<000002@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00/0oooo00<000000;3PiP2`h>H06P2`h>H00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000h0oooo000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`0000060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000004P2`h>H2000000X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`0000004P2`h>H2000000X0oooo00<000000?ooo`3oool00`3oool00`000000/>3V
0;3PiP0K0;3PiP<000004P2`h>H00`000000oooo000000090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`0000060?ooo`030000002`h>H0/>3V01X0/>3V00<000000?ooo`3oool0
0`3oool3000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`0000004P2`h>H2000000X0oooo0P00000?0;3PiP030000
003oool000000140oooo0P00000B0;3PiP030000003oool0000000T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0<0?ooo`030000002`h>H0/>3V01X0/>3V00<000000?ooo`3oool0
103oool3000000h0oooo000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool000000180/>3V00<000000?ooo`0000002@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303o
ool010000000oooo0?ooo`00000B0;3PiP030000003oool0000000T0oooo00<000000?ooo`3oool0
0`3oool00`000000/>3V0;3PiP0K0;3PiP030000003oool000000180/>3V00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000;3PiP2`
h>H06P2`h>H00`000000oooo0?ooo`050?ooo`8000002@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000B0;3P
iP030000003oool0000000T0oooo0P00000?0;3PiP8000004@3oool00`000000oooo0000000B0;3P
iP040000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<
0?ooo`030000002`h>H0/>3V01X0/>3V00<000000?ooo`3oool01P3oool2000000d0oooo000=0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?oo
o`040000003oool0oooo00000140/>3V00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool010000000oooo0?oo
o`00000A0;3PiP040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000
/>3V0;3PiP0J0;3PiP040000003oool0oooo00000140/>3V00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000;3PiP2`h>H06P2`h>H2
000000L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo0P00000B0?ooo`040000003oool0oooo00000140/>3V00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000=0;3PiP8000004P3oool010000000oooo0?ooo`00000A0;3PiP04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?oo
o`030000002`h>H0/>3V01X0/>3V0P0000080?ooo`030000003oool0oooo00/0oooo000=0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`04
0000003oool0oooo00000140/>3V00<000000?ooo`0000002P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo100000060?ooo`030000003oool0oooo00/0oooo00D000000?oo
o`3oool0oooo0000000A0;3PiP030000003oool0000000X0oooo00<000000?ooo`3oool0103oool0
0`000000/>3V0;3PiP0I0;3PiP050000003oool0oooo0?ooo`0000004@2`h>H00`000000oooo0000
00090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000/>3V0;3P
iP0J0;3PiP8000001P3oool2000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0140oooo00D000000?ooo`3oool0oooo0000000A0;3PiP030000
003oool0000000X0oooo00<000000?ooo`3oool00P0000090;3PiP8000004`3oool01@000000oooo
0?ooo`3oool000000140/>3V00<000000?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo1@0000060?ooo`030000002`h>H0/>3V01X0/>3V0P0000070?ooo`03
0000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000;3PiP2`h>H0
3@2`h>H4000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003000000@0/>3V
0P0000040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000/>3V
0;3PiP0=0;3PiP@000002P3oool00`000000oooo0?ooo`040?ooo`8000006P2`h>H00`000000oooo
0?ooo`020?ooo`030000002`h>H0/>3V00d0/>3V100000090?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02`3oool00`000000/>3V0;3PiP0J0;3PiP030000003oool0oooo00<0oooo
0`00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0000000200000100oooo00<000000?ooo`3oool00P3oool00`000000/>3V0;3PiP0=0;3PiP@00000
2P3oool00`000000oooo0?ooo`020?ooo`030000002`h>H0/>3V00D0/>3V0P000000103oool00000
00000000000@0?ooo`030000003oool0oooo0080oooo00<000000;3PiP2`h>H03@2`h>H4000000T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003000000D0/>3V0P0000040?ooo`03
0000002`h>H0/>3V01X0/>3V00<000000?ooo`3oool0103oool3000000h0oooo000=0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00<0oooo00<000000;3PiP2`h>H02`2`h>H2000000030?ooo`000000oooo00X0oooo
00<000000?ooo`3oool00P3oool2000000X0/>3V0P0000020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP0;0;3PiP80000000<0oooo0000003oool0
2P3oool00`000000oooo0?ooo`050?ooo`030000002`h>H0/>3V01L0/>3V00<000000?ooo`3oool0
103oool00`000000/>3V0;3PiP0;0;3PiP80000000<0oooo0000003oool02@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000;3PiP2`h>H06P2`h>H00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`<000000`2`h>H2000000d0oooo00<000000?ooo`3oool0103oool00`000000
/>3V0;3PiP0;0;3PiP80000000<0oooo0000003oool02P3oool00`000000oooo0?ooo`030?ooo`X0
00000`2`h>H2000000d0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP0;0;3PiP80
000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`020?ooo`8000002`2`h>H200000080
oooo00<000000;3PiP2`h>H06P2`h>H00`000000oooo0?ooo`030?ooo`030000003oool0000000l0
oooo000=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000;3PiP2`h>H02P2`h>H010000000oooo
0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`0000003P2`h>H00`000000oooo0000000<0?oo
o`030000003oool0oooo00D0oooo00<000000;3PiP2`h>H02P2`h>H010000000oooo0?ooo`00000;
0?ooo`030000003oool0oooo00D0oooo0P00000H0;3PiP030000003oool0oooo00@0oooo00<00000
0;3PiP2`h>H02`2`h>H010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02P3oool2000001X0/>3V00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000;0?ooo`050000003oool0oooo0?ooo`0000001P3oool3000000L0/>3V0P00000;0?ooo`03
0000003oool0oooo00D0oooo00<000000;3PiP2`h>H02P2`h>H010000000oooo0?ooo`00000;0?oo
o`030000003oool0oooo00P0oooo0`0000070;3PiP8000002`3oool00`000000oooo0?ooo`040?oo
o`030000002`h>H0/>3V00/0/>3V00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`3o
ool2000000h0/>3V00@000000?ooo`00000000006P2`h>H00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000l0oooo000=0?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000
/>3V0;3PiP080;3PiP040000003oool0oooo000000`0oooo00D000000?ooo`3oool0oooo0000000>
0;3PiP030000003oool0000000/0oooo00<000000?ooo`3oool01`3oool00`000000/>3V0;3PiP07
0;3PiP8000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@000000P3oool0
0`000000/>3V0;3PiP0E0;3PiP030000003oool0oooo00H0oooo00<000000;3PiP2`h>H0202`h>H2
00000080oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`3oool300000080oooo00<0
00000?ooo`3oool02P3oool2000001X0/>3V00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000050?ooo`8000002`2`h>H2000000P0
oooo00<000000?ooo`3oool01`3oool00`000000/>3V0;3PiP070;3PiP8000000P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo0P00000;0;3PiP800000203oool00`000000
oooo0?ooo`060?ooo`030000002`h>H0/>3V00P0/>3V0P0000020?ooo`030000003oool0oooo00T0
oooo00@000000?ooo`3oool0oooo0P00000>0;3PiP040000003oool00000000001X0/>3V00@00000
0?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo00h0oooo000=0?ooo`040000003oool0
0000000000<0/>3V0P0000000`3oool000000?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool:000000<0oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`00000@0;3PiP8000002`3oool00`000000oooo0?ooo`080?ooo`T00000103oool00`000000oooo
0?ooo`0:0?ooo`<00000102`h>H2000000030?ooo`000000/>3V01@0/>3V0P0000090?ooo`X00000
103oool00`000000oooo0?ooo`090?ooo`040000003oool00000000000<0/>3V0P0000000`3oool0
00000?ooo`0:0?ooo`8000006P2`h>H010000000oooo0000000000030?ooo`030000003oool0oooo
00X0oooo00@000000?ooo`3oool000001@3oool00`000000/>3V0;3PiP0=0;3PiP8000001P3oool0
0`000000oooo0?ooo`080?ooo`T00000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00H0oooo00<000000;3PiP2`h>H03@2`h>H2000000H0oooo00<000000?ooo`3oool01`3oool:
000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0200000100/>3V0`00000J
0;3PiP040000003oool0oooo000000@0oooo00<000000?ooo`3oool03P3oool000d0oooo0P000007
0;3PiP8000002`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0000000000100/>3V0P00
000:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0;0?ooo`030000002`h>H0/>3V00H0/>3V0`00000C0;3PiP8000004P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00X0oooo0P0000070;3PiP8000002`3oool00`000000oooo0000
000H0;3PiP030000003oool0000000D0oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`0000030?ooo`<00000402`h>H00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo
0P00000A0;3PiP030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000004@2`h>H200000003
0?ooo`000000/>3V01L0/>3V00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0?0?oo
o`003@3oool2000000P0/>3V0P00000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`00
00004P2`h>H00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo0P0000050?ooo`03
0000003oool0oooo00/0oooo00<000000;3PiP2`h>H01`2`h>H00`000000oooo0000000A0;3PiP03
0000003oool000000100oooo0P0000050?ooo`030000003oool0oooo00X0oooo0P0000080;3PiP80
00002P3oool010000000oooo0?ooo`00000G0;3PiP8000001@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000004P2`h>H00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00h0oooo0P0000050?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00`3oool2000001<0/>3V00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?oo
o`8000001@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0000000000140/>3V0P000002
0?ooo`030000002`h>H0/>3V01D0/>3V0`0000050?ooo`030000003oool0oooo00l0oooo000=0?oo
o`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo0P0000050?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`0000004P2`h>H00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000002`h>H0/>3V00P0/>3V00@000000?oo
o`00000000003@2`h>H2000000030?ooo`000000oooo00l0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0;0?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool0203oool0
10000000oooo0?ooo`00000F0;3PiP8000001P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool000000080oooo00@000000?ooo`3oool000004P2`h>H01@000000oooo0?ooo`3oool000000100
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000004`2`h>H01@000000oooo0?ooo`3oool000000100oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0;0?ooo`040000003oool0000000000140/>3V0P000002
0?ooo`030000002`h>H0/>3V01@0/>3V0P0000060?ooo`030000003oool0oooo0100oooo000=0?oo
o`030000002`h>H0/>3V00P0/>3V0P0000090?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo0`00000B0;3P
iP030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00`0oooo00<000000;3PiP2`h>H0202`h>H010000000oooo0?ooo`3oool2
000000T0/>3V0P0000030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0;0?ooo`030000002`h>H0/>3V00P0/>3V0P0000090?ooo`050000003oool0
oooo0?ooo`000000502`h>H00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo0P00
00020?ooo`040000003oool0oooo000001@0/>3V00@000000?ooo`3oool000003`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000002`h>H0/>3V0180/>3V00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00/0oooo0P0000000`3oool000000;3PiP0A0;3PiP050000003oool0
oooo0?ooo`000000502`h>H2000000L0oooo00<000000?ooo`3oool0403oool000d0oooo00<00000
0;3PiP2`h>H0202`h>H2000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool300000180/>3V00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool03@3oool00`000000/>3V0;3PiP080;3PiP800000103oool9000000@0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<00000
0;3PiP2`h>H0202`h>H2000000T0oooo00<000000?ooo`3oool00P3oool00`000000/>3V0;3PiP0@
0;3PiP030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool4000000<0oooo00<00000
0;3PiP2`h>H04P2`h>H00`000000oooo0000000?0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool03@3oool010000000oooo0000000000030?ooo`030000002`h>H0/>3V0180/>3V00<0
00000?ooo`0000003`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo0P00
00000`3oool000000;3PiP0A0;3PiP030000003oool0oooo0080oooo00<000000;3PiP2`h>H0402`
h>H2000000L0oooo00<000000?ooo`3oool04@3oool000d0oooo00<000000;3PiP2`h>H0202`h>H0
0`000000oooo000000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000004P2`h>H0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo0P0000080?ooo`030000003oool0
oooo00d0oooo00<000000;3PiP2`h>H01`2`h>H00`000000oooo0000000A0?ooo`030000003oool0
oooo00/0oooo0P0000080?ooo`030000003oool0oooo00`0oooo0P0000090;3PiP030000003oool0
000000P0oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3PiP0=0;3PiP800000203oool0
0`000000oooo0?ooo`0=0?ooo`8000001@3oool00`000000/>3V0;3PiP0B0;3PiP030000003oool0
000000d0oooo0P0000080?ooo`030000003oool0oooo00d0oooo0P0000040?ooo`030000002`h>H0
/>3V01<0/>3V00<000000?ooo`0000003@3oool2000000P0oooo00<000000?ooo`3oool0303oool0
10000000oooo0?ooo`00000B0;3PiP030000003oool0oooo00<0oooo0P00000>0;3PiP<00000203o
ool00`000000oooo0?ooo`0A0?ooo`003@3oool00`000000/>3V0;3PiP080;3PiP030000003oool0
000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`800000203oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool000000180/>3V00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000/>3V0;3PiP070;3PiP040000003oool0oooo000000l0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo0P0000090;3PiP030000003o
ool0000000P0oooo00<000000?ooo`3oool0103oool3000000T0/>3V100000090?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP0B0;3PiP8000003@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3o
ool00`000000/>3V0;3PiP0C0;3PiP8000003@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`3oool000004@2`h>H2000000L0oooo0P0000090;3PiP@00000
2@3oool00`000000oooo0?ooo`0B0?ooo`003P3oool2000000L0/>3V00D000000?ooo`3oool0oooo
000000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool6000000D0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0000000A0;3PiP030000003oool0oooo00D0oooo
00<000000?ooo`3oool02P3oool6000000D0oooo00<000000?ooo`3oool03`3oool00`000000/>3V
0;3PiP050;3PiP050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0:0?ooo`H0
00001@3oool00`000000oooo0?ooo`0>0?ooo`8000001`2`h>H01@000000oooo0?ooo`3oool00000
00L0oooo00<000000?ooo`3oool01`3oool9000000030?ooo`000000000000@000001P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000;3PiP2`h>H04P2`h>H20000
00`0oooo1P0000050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`00
0000/>3V0;3PiP0C0;3PiP800000303oool6000000D0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0000000A0;3PiP8000002@3oool900000080oooo1@0000060?ooo`030000003oool0oooo
0180oooo000?0?ooo`8000001P2`h>H01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`8000001@2`h>H01@000000oooo0?ooo`3oool0
000001<0oooo0P00000@0;3PiP8000001P3oool00`000000oooo0?ooo`090?ooo`8000001P2`h>H0
1@000000oooo0?ooo`3oool0000001<0oooo0P0000050;3PiP030000003oool0oooo0080oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`8000001@2`h>H00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo0P0000060;3PiP050000003oool0oooo0?ooo`000000
1`3oool00`000000oooo0?ooo`0@0?ooo`8000001@2`h>H00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo0P0000030?ooo`030000002`h>H0/>3V0180/>3V00<000000?ooo`3oool0
2@3oool3000000D0/>3V00D000000?ooo`3oool0oooo0000000C0?ooo`8000000P3oool00`000000
/>3V0;3PiP0C0;3PiP030000003oool0oooo00T0oooo0P0000050;3PiP030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool200000100/>3V00<000000?ooo`0000004P3oool2000000D0
/>3V00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`00403oool7000000D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo
00<000000;3PiP2`h>H01P2`h>H010000000oooo0?ooo`00000E0?ooo`030000002`h>H0/>3V00d0
/>3V0P0000060?ooo`030000003oool0oooo00P0oooo0P0000080;3PiP040000003oool0oooo0000
01@0oooo1P0000050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`00
0000/>3V0;3PiP060;3PiP050000003oool0oooo0?ooo`000000503oool6000000D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000002`h>H0/>3V00H0/>3V00D00000
0?ooo`3oool0oooo0000000D0?ooo`040000003oool0oooo000001@0/>3V00<000000?ooo`3oool0
203oool2000000P0/>3V00@000000?ooo`3oool000005@3oool00`000000oooo0000000E0;3PiP03
0000003oool0oooo00P0oooo00<000000;3PiP2`h>H01P2`h>H01@000000oooo0?ooo`3oool00000
01@0oooo00<000000;3PiP2`h>H03@2`h>H00`000000oooo0000000A0?ooo`030000002`h>H0/>3V
00H0/>3V00D000000?ooo`3oool0oooo0000000E0?ooo`004P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`8000002@2`h>H00`000000oooo0000000G0?ooo`030000002`h>H0/>3V00X0/>3V0P0000000`3o
ool000000?ooo`040?ooo`030000003oool0oooo00P0oooo0P0000090;3PiP030000003oool00000
01L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00P0oooo0P0000080;3PiP040000003oool0oooo000001H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo0`0000080;3PiP040000003oool0
oooo000001H0oooo00<000000?ooo`0000004`2`h>H2000000T0oooo0P0000090;3PiP030000003o
ool0000001L0oooo00<000000?ooo`0000004`2`h>H00`000000oooo0?ooo`080?ooo`800000202`
h>H010000000oooo0?ooo`00000F0?ooo`030000002`h>H0/>3V00/0/>3V00@000000?ooo`3oool0
0000403oool2000000P0/>3V00@000000?ooo`3oool000005P3oool001<0oooo0P0000080?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0000000X0/>3V0P00000H0?ooo`030000002`h>H0/>3V00P0/>3V00D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo00H0oooo0P0000000`3oool000000;3PiP090;3P
iP800000603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01P3oool3000000X0/>3V00<000000?ooo`0000005`3oool2000000P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000X0/>3V00<000000?oo
o`0000005`3oool2000001<0/>3V0P0000070?ooo`80000000<0oooo0000002`h>H02@2`h>H20000
01P0oooo0P00000C0;3PiP030000003oool0oooo00H0oooo0`00000:0;3PiP030000003oool00000
01L0oooo0P00000:0;3PiP050000003oool0oooo0?ooo`0000003P3oool3000000X0/>3V00<00000
0?ooo`0000005P3oool001D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000:
0;3PiP030000003oool0oooo01P0oooo0P0000080;3PiP050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002P2`h>H00`000000oooo
0?ooo`0H0?ooo`8000001`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00@000000?ooo`3oool000002P2`h>H2000001X0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000002P2`h>H20000
01T0oooo0P00000A0;3PiP8000001`3oool01@000000oooo0?ooo`3oool0000000X0/>3V00<00000
0?ooo`3oool0603oool200000140/>3V00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00
000:0;3PiP8000006P3oool00`000000/>3V0;3PiP060;3PiP030000003oool0oooo0080oooo00<0
00000?ooo`3oool02`3oool010000000oooo0?ooo`00000:0;3PiP8000005`3oool001H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000X0/>3V00<000000?ooo`3oool0
6P3oool8000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000002`2`h>H00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?oo
o`0000002P2`h>H2000001X0oooo0P00000@0;3PiP8000001P3oool00`000000oooo0?ooo`020?oo
o`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool06@3oool200000100/>3V00<000000?oo
o`3oool01@3oool01@000000oooo0?ooo`3oool0000000/0/>3V00<000000?ooo`3oool06@3oool8
000000D0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000X0/>3V0P00
000G0?ooo`005`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000060?ooo`800000103oool00`000000/>3V0;3PiP070;3PiP8000007@3o
ool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`030?ooo`030000002`h>H0/>3V00L0/>3V00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000002`h>H0/>3V00L0/>3V00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool2000000@0oooo
00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`0J0?ooo`8000003P2`h>H2000000H0oooo
00<000000?ooo`3oool00`3oool00`000000/>3V0;3PiP070;3PiP800000703oool2000000h0/>3V
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000002`h>H0/>3V00L0/>3V
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool00`000000/>3V0;3PiP080;3PiP030000003oool0oooo01H0oooo
000H0?ooo`8000001@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000002`h>H0/>3V00L0/>3V0P00000N0?ooo`030000
003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000050?ooo`8000001P3oool00`000000
/>3V0;3PiP070;3PiP030000003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000002`h>H0/>3V00L0
/>3V00<000000?ooo`3oool0703oool2000000D0oooo00D000000?ooo`3oool0oooo000000090?oo
o`030000003oool0oooo00@0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`0K0?oo
o`800000302`h>H2000000D0oooo0P0000060?ooo`030000002`h>H0/>3V00L0/>3V0P00000M0?oo
o`800000302`h>H2000000D0oooo0P0000060?ooo`030000002`h>H0/>3V00L0/>3V00<000000?oo
o`3oool0703oool2000000T0oooo00<000000?ooo`3oool01`3oool2000000H0oooo00<000000;3P
iP2`h>H01`2`h>H00`000000oooo0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00H0oooo00<000000;3PiP2`h>H01@2`h>H200000200oooo00<000000?ooo`3oool01P3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo00L0oooo00<000000;3PiP2`h>H01@2`h>H0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000;3PiP2`h>H01@2`h>H0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00080?ooo`030000003oool0oooo00H0oooo00<000000;3PiP2`h>H01P2`h>H00`000000oooo0?oo
o`0N0?ooo`8000002@2`h>H2000000D0oooo00<000000?ooo`3oool01`3oool00`000000/>3V0;3P
iP050;3PiP800000803oool2000000T0/>3V0P0000050?ooo`030000003oool0oooo00L0oooo00<0
00000;3PiP2`h>H01@2`h>H00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000002`h>H0/>3V00D0/>3V00<0
00000?ooo`3oool05`3oool001/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo0?ooo`8000002P3oool00`000000/>3V0;3PiP020;3PiP<00000
8P3oool2000000H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`090?ooo`03
0000002`h>H0/>3V0080/>3V0`00000R0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000/>3V0;3PiP020;3PiP<0
00008P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000H0oooo0P00000:0?oo
o`030000002`h>H0/>3V00<0/>3V0`00000Q0?ooo`X0000000<0oooo0000003oool00`3oool00`00
0000oooo0?ooo`090?ooo`030000002`h>H0/>3V0080/>3V0`00000R0?ooo`X0000000<0oooo0000
003oool00`3oool00`000000oooo0?ooo`090?ooo`030000002`h>H0/>3V0080/>3V0`00000R0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?oo
o`030000002`h>H0/>3V00<0/>3V0`00000I0?ooo`00703oool200000080oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`030000003oool0oooo00/0oooo1P00000U0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`0000000`3oool2000000d0oooo1@00000V0?ooo`050000003oool0
oooo0?ooo`0000000`3oool010000000oooo0?ooo`3oool2000000d0oooo1@00000U0?ooo`800000
0P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00/0oooo1P00000U0?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0P00000=0?ooo`D000009P3oool00`00
0000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`8000003@3oool5000002D0oooo0P000005
0?ooo`030000003oool0oooo00<0oooo0P00000<0?ooo`H000006`3oool001h0oooo00P000000?oo
o`3oool000000?ooo`000000oooo00000080oooo00<000000?ooo`3oool0203oool4000002`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000020?ooo`030000003oool0oooo00P0oooo
1@00000/0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000002P3oool50000
02`0oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`030000003oool0oooo00P0oooo1@00
000[0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000002P3oool5000002`0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000:0?ooo`D00000;03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool500000200
oooo000O0?ooo`040000003oool000000?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`D0
0000<@3oool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool01@3oool40000
0380oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo00D0oooo1000
000b0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`@00000
<@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo1000000b0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000001`3oool400000380oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00D0oooo1000000U0?ooo`00803oool70000
00<0oooo1000000g0?ooo`80000000<0oooo0000000000000P0000030?ooo`D00000=`3oool30000
00040?ooo`0000000000000000<0oooo1@00000g0?ooo`@0000000<0oooo0000000000000`3oool5
000003H0oooo0P0000020?ooo`<000000`3oool5000003L0oooo0P0000020?ooo`<000000`3oool5
000003L0oooo0P0000000`3oool000000?ooo`02000000<0oooo1@00000Y0?ooo`008P3oool30000
00030?ooo`000000000000800000?@3oool3000000030?ooo`000000000000800000?P3oool30000
00030?ooo`000000000000800000?P3oool3000000030?ooo`000000000000800000?@3oool30000
00030?ooo`000000000000800000?P3oool3000000030?ooo`000000000000800000?P3oool30000
00030?ooo`000000000000800000;P3oool002<0oooo0`0000120?ooo`<00000@`3oool3000004<0
oooo0`0000120?ooo`<00000@`3oool3000004<0oooo0`00000b0?ooo`00o`3ooook0?ooo`00o`3o
oook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3o
oook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`008`3oool300000480oooo0`0000130?ooo`<0
0000@`3oool300000480oooo0`0000130?ooo`<00000@`3oool300000380oooo000R0?ooo`P00000
?@3oool010000000oooo0000003oool4000003h0oooo0P0000020?ooo`@00000?P3oool8000003d0
oooo0`0000000`3oool0000000000002000003h0oooo2000000n0?ooo`040000003oool000000?oo
o`@00000;P3oool00200oooo0P0000050;3PiP030000003oool0oooo00@00000=`3oool2000000<0
oooo0P0000030?ooo`D00000=`3oool300000080oooo2P00000g0?ooo`8000001@2`h>H00`000000
oooo0?ooo`05000003H0oooo0`0000020?ooo`8000000`3oool5000003L0oooo0`0000050;3PiP03
0000003oool0000000@00000=`3oool2000000<0oooo0P0000030?ooo`D00000:@3oool001l0oooo
00<000000;3PiP2`h>H01P2`h>H00`000000oooo0?ooo`030?ooo`D00000<@3oool9000000L0oooo
1000000b0?ooo`060000003oool0oooo0000003oool000001`2`h>H2000000030?ooo`0000000000
00800000<P3oool00`000000/>3V0;3PiP060;3PiP030000003oool0oooo00@0oooo1000000a0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool400000380oooo0P000008
0;3PiP030000003oool0oooo00<0oooo1000000b0?ooo`L0000000<0oooo0000003oool01P3oool4
000002D0oooo000N0?ooo`800000202`h>H00`000000oooo0?ooo`080?ooo`@00000;03oool20000
00L0/>3V0P00000:0?ooo`D00000;03oool00`000000oooo0?ooo`03000000X0/>3V0P0000030?oo
o`D00000;03oool2000000T0/>3V00<000000?ooo`3oool01`3oool5000002/0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`080?ooo`D00000;03oool2000000T0/>3V00<00000
0?ooo`3oool01`3oool5000002`0oooo0P0000060;3PiP<000002P3oool500000200oooo000L0?oo
o`<000002P2`h>H00`000000oooo0?ooo`0;0?ooo`@000009`3oool2000000X0/>3V0P00000=0?oo
o`@000009`3oool01@000000oooo0?ooo`3oool0000000h0/>3V00<000000?ooo`3oool01@3oool4
000002H0oooo0`00000;0;3PiP030000003oool0oooo00/0oooo1000000V0?ooo`050000003oool0
oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0<0?ooo`@000009`3oool00`000000oooo0000
000:0;3PiP030000003oool0oooo00/0oooo1000000V0?ooo`8000002P2`h>H2000000h0oooo1000
000L0?ooo`006`3oool010000000oooo0?ooo`00000:0;3PiP800000403oool300000280oooo0P00
000=0;3PiP800000303oool200000080/>3V0`00000R0?ooo`8000000`3oool2000000h0/>3V00<0
00000?ooo`3oool02@3oool300000280oooo00@000000?ooo`3oool000002`2`h>H00`000000oooo
0?ooo`0?0?ooo`<000008@3oool2000000<0oooo00<000000?ooo`3oool01`3oool2000000d0oooo
0P000000102`h>H0000000000000000R0?ooo`8000000P3oool00`000000/>3V0;3PiP080;3PiP03
0000003oool0oooo00l0oooo0`00000R0?ooo`030000002`h>H0/>3V00`0/>3V0P00000<0?ooo`80
000000<0/>3V0000000000000P00000I0?ooo`006P3oool01@000000oooo0?ooo`3oool0000000X0
/>3V0P00000<0?ooo`@000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000h0
/>3V0P00000:0?ooo`030000002`h>H0/>3V00@0/>3V00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`030?ooo`030000002`h>H0/>3V00h0/>3V00<000000?ooo`3oool02@3oool200000240
oooo00D000000?ooo`3oool0oooo0000000:0;3PiP8000003@3oool4000000030?ooo`0000000000
0200oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00P0oooo0P0000050;3PiP030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool00`00
0000/>3V0;3PiP080;3PiP030000003oool0oooo00/0oooo100000020?ooo`030000003oool0oooo
01l0oooo0P00000>0;3PiP030000003oool0000000T0oooo0P0000050;3PiP8000006@3oool001T0
oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3PiP070;3PiP030000003oool0oooo00L0
oooo2@0000020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`000000402`h>H2000000P0
oooo00<000000;3PiP2`h>H01P2`h>H00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00<0
oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`070?ooo`8000000P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo00<000000;3PiP2`h>H01`2`h>H00`000000
oooo0?ooo`070?ooo`D000000`3oool200000080oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000
/>3V0;3PiP060;3PiP030000003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool00`000000
/>3V0;3PiP080;3PiP030000003oool0oooo00L0oooo200000030?ooo`030000003oool0oooo01d0
oooo0P00000@0;3PiP030000003oool0000000L0oooo00<000000;3PiP2`h>H01P2`h>H2000001P0
oooo000G0?ooo`8000001P3oool00`000000/>3V0;3PiP060;3PiP030000003oool0oooo00<0oooo
1`0000070;3PiP<000007P3oool00`000000oooo0000000A0;3PiP030000003oool0000000H0oooo
00<000000;3PiP2`h>H01`2`h>H2000001d0oooo00<000000?ooo`3oool0103oool00`000000/>3V
0;3PiP0?0;3PiP030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0K0?ooo`8000001P3oool00`000000/>3V0;3PiP060;3PiP030000003oool0oooo00@0oooo
100000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo0?ooo``000001P3oool00`000000/>3V0;3PiP070;3PiP80
00007@3oool00`000000oooo0?ooo`040?ooo`030000002`h>H0/>3V00L0/>3V00<000000?ooo`3o
ool00`3oool7000000H0/>3V0P0000000`3oool000000?ooo`0L0?ooo`<000004@2`h>H010000000
oooo0?ooo`0000060?ooo`030000002`h>H0/>3V00L0/>3V00<000000?ooo`3oool05P3oool001H0
oooo00<000000?ooo`3oool01`3oool00`000000/>3V0;3PiP050;3PiP030000003oool0000000<0
0000103oool00`000000/>3V0;3PiP090;3PiP800000703oool010000000oooo0?ooo`00000A0;3P
iP030000003oool0oooo00800000103oool00`000000/>3V0;3PiP080;3PiP030000003oool0oooo
01X0oooo00<000000?ooo`3oool0103oool200000180/>3V00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01`3oool00`00
0000/>3V0;3PiP050;3PiP030000003oool0000000@000002P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020000
00`0/>3V0P0000040?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`060?ooo`030000002`h>H0/>3V00D0/>3V00<000000?ooo`3oool0100000030?oo
o`8000002P2`h>H3000001/0oooo00@000000?ooo`3oool000004P2`h>H00`000000oooo0?ooo`02
000000<0oooo00<000000;3PiP2`h>H0202`h>H2000001L0oooo000E0?ooo`030000003oool0oooo
00T0oooo0P0000030;3PiP@000001`3oool00`000000/>3V0;3PiP0;0;3PiP8000006@3oool20000
00<0oooo00<000000;3PiP2`h>H0402`h>H01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0;3PiP2`h>H0202`h>H00`000000oooo0?ooo`0H0?ooo`8000001`3oool200000180/>3V00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool02@3oool2000000<0/>3V1000000>0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool05`3oool2000000L0oooo00<000000?ooo`000000402`h>H01@000000oooo0?ooo`3o
ool0000000X0/>3V00<000000?ooo`3oool0603oool2000000X0oooo0P0000030;3PiPD000001P3o
ool00`000000/>3V0;3PiP0<0;3PiP030000003oool0oooo01P0oooo00D000000?ooo`3oool0oooo
0000000B0;3PiP030000003oool0oooo0080oooo00@000000?ooo`3oool000002P2`h>H2000001L0
oooo000C0?ooo`800000303oool5000000/0oooo00<000000;3PiP2`h>H0302`h>H00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000T0/>3V0`00000H0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`0000004P2`h>H00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`0E0?ooo`8000003@3oool400000100oooo0P0000020?oo
o`8000001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`0000004P2`h>H010000000oooo0?ooo`00000:0;3PiP800000603oool00`000000oooo0?ooo`0;
0?ooo`D000002P3oool00`000000/>3V0;3PiP0<0;3PiP8000005`3oool2000000@0oooo00<00000
0;3PiP2`h>H0402`h>H00`000000oooo0?ooo`030?ooo`030000003oool0000000X0/>3V00<00000
0?ooo`0000005P3oool00180oooo00<000000?ooo`3oool0203oool4000000l0oooo00<000000;3P
iP2`h>H03@2`h>H2000001H0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP0@0;3P
iP030000003oool0oooo00<0oooo00<000000?ooo`0000002@2`h>H00`000000oooo0000000G0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`0000004P2`h>H00`000000oooo0?ooo`060000
00030;3PiP000000000000<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`080?oo
o`D000004`3oool500000080/>3V0P0000030?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01`3oool2000001@0/>3V00<000000?ooo`0000002P2`h>H2000001L0oooo00<000000?oo
o`3oool0203oool4000000h0oooo00<000000;3PiP2`h>H03P2`h>H00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00@0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo0?ooo`040?oo
o`8000002P2`h>H00`000000oooo0000000F0?ooo`004@3oool00`000000oooo0?ooo`040?ooo`D0
00004P3oool00`000000/>3V0;3PiP0?0;3PiP030000003oool0oooo01<0oooo00<000000?ooo`3o
ool01@3oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo00@0oooo0P0000080;3PiP05
0000003oool0oooo0?ooo`0000005@3oool3000000L0oooo00@000000?ooo`3oool000004@2`h>H0
0`000000oooo0?ooo`02000000P0/>3V0P0000020?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool01@3oool4000001L0oooo0P0000080;3PiP8000000P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0000000L0oooo0P00000F0;3PiP8000002@2`h>H010000000oooo0?ooo`00
000E0?ooo`030000003oool0oooo00@0oooo1@00000A0?ooo`030000002`h>H0/>3V0100/>3V00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000002`h>H0/>3V0100/>3V00<0
00000?ooo`3oool01@3oool2000000P0/>3V00D000000?ooo`3oool0oooo0000000E0?ooo`003`3o
ool2000000<0oooo1000000G0?ooo`030000002`h>H0/>3V00l0/>3V00<000000?ooo`3oool04@3o
ool2000000P0oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`070?ooo`030000002`
h>H0/>3V00D0/>3V00D000000?ooo`3oool0oooo0000000C0?ooo`<000000P2`h>H2000000D0oooo
00@000000?ooo`3oool000004@2`h>H00`000000oooo0000000<0;3PiP<000004P3oool2000000<0
oooo1@00000I0?ooo`800000302`h>H00`000000oooo0000000B0?ooo`@0000000<0/>3V00000000
00001@3oool00`000000/>3V0;3PiP0F0;3PiP8000001`2`h>H01@000000oooo0?ooo`3oool00000
01<0oooo0P0000030?ooo`@000005P3oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo
0100oooo0P0000080?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool01`3oool00`00
0000/>3V0;3PiP050;3PiP050000003oool0oooo0?ooo`0000005@3oool000h0oooo00<000000?oo
o`0000000`00000K0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`080?ooo`030000002`h>H0/>3V00l0/>3V00<000000?ooo`3oool0203oool20000
00<0/>3V0P0000050?ooo`030000003oool0oooo00l0oooo0P0000060;3PiP8000000`3oool01@00
0000oooo0?ooo`3oool0000000l0/>3V00<000000?ooo`0000003`2`h>H200000100oooo00<00000
0?ooo`0000001@0000020;3PiP@000005@3oool2000000h0/>3V0P00000A0?ooo`<000001@2`h>H2
000000<0oooo00<000000;3PiP2`h>H05`2`h>H3000000<0/>3V0P0000050?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`0000000`00000J0?ooo`030000002`h>H0/>3V0100/>3V0P00000@
0?ooo`030000003oool0oooo00T0oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`08
0?ooo`8000000`2`h>H2000000D0oooo00<000000?ooo`3oool04P3oool000d0oooo0`00000O0?oo
o`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool03P3oool3000000X0oooo00<000000;3P
iP2`h>H03@2`h>H00`000000oooo0?ooo`0:0?ooo`@000001`3oool00`000000oooo0?ooo`0>0?oo
o`030000002`h>H0/>3V00L0/>3V00@000000?ooo`3oool00000103oool00`000000/>3V0;3PiP0=
0;3PiP8000004@2`h>H00`000000oooo0?ooo`0=0?ooo`<000000P3oool2000000P0/>3V00<00000
0?ooo`3oool04@3oool200000100/>3V0P00000?0?ooo`800000202`h>H010000000oooo0?ooo`00
000J0;3PiP030000003oool0000000<000001`3oool00`000000oooo0?ooo`0>0?ooo`<000007P3o
ool00`000000/>3V0;3PiP0@0;3PiP8000003`3oool3000000/0oooo00<000000;3PiP2`h>H03@2`
h>H00`000000oooo0?ooo`0:0?ooo`@000001`3oool00`000000oooo0?ooo`0B0?ooo`003@3oool2
000000030?ooo`0000000000008000006`3oool00`000000/>3V0;3PiP0@0;3PiP8000003`3oool2
000000030?ooo`0000000000008000001P3oool00`000000/>3V0;3PiP0=0;3PiP030000003oool0
oooo00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000002`h>H0
/>3V00P0/>3V00<000000?ooo`0000001@3oool00`000000/>3V0;3PiP0;0;3PiP8000004`2`h>H0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo008000002`2`h>H00`000000oooo0?ooo`0?
0?ooo`8000004P2`h>H00`000000oooo0?ooo`0=0?ooo`030000002`h>H0/>3V00P0/>3V00<00000
0?ooo`0000006`2`h>H010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01000000J0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`0000003P3o
ool00`000000oooo0?ooo`04000000L0oooo00<000000;3PiP2`h>H03@2`h>H00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool000d0oooo10000003
0?ooo`@000005`3oool00`000000/>3V0;3PiP0@0;3PiP8000003`3oool4000000<0oooo10000003
0?ooo`030000002`h>H0/>3V00/0/>3V00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00d0oooo00<000000;3PiP2`h>H0202`h>H2000000L0oooo0P00000:
0;3PiP030000003oool0000001<0/>3V00<000000?ooo`3oool0303oool00`000000oooo0000000>
0;3PiP030000003oool0oooo00d0oooo00<000000?ooo`0000004P2`h>H2000000h0oooo00<00000
0;3PiP2`h>H0202`h>H2000001`0/>3V00D000000?ooo`3oool0oooo000000080?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0103oool4000001H0oooo00<000000;3PiP2`h>H0402`
h>H00`000000oooo0000000>0?ooo`030000003oool0oooo00@0oooo100000040?ooo`030000002`
h>H0/>3V00X0/>3V0P00000@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3o
ool000d0oooo0P0000020?ooo`030000003oool0oooo00@0oooo1000000C0?ooo`030000002`h>H0
/>3V00l0/>3V00@000000?ooo`3oool000003P3oool200000080oooo00<000000?ooo`3oool0103o
ool6000000X0/>3V00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00`0oooo00<000000;3PiP2`h>H0202`h>H2000000T0oooo0`0000050;3PiP80000000<0
oooo0000002`h>H04`2`h>H2000000d0oooo00<000000?ooo`0000003`2`h>H00`000000oooo0?oo
o`0:0?ooo`80000000<0oooo0000002`h>H04`2`h>H00`000000oooo0?ooo`0<0?ooo`030000002`
h>H0/>3V00P0/>3V0P00000L0;3PiP030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo1P00000B0?ooo`030000002`
h>H0/>3V00l0/>3V00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo00L0oooo
1`00000:0;3PiP030000003oool0oooo0140oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0@0?ooo`003@3oool00`000000oooo000000020?ooo`030000003oool0oooo00L0oooo1@00
000>0?ooo`030000002`h>H0/>3V00l0/>3V00@000000?ooo`3oool000003P3oool00`000000oooo
000000020?ooo`030000003oool0oooo00L0oooo1@0000050;3PiP800000503oool2000000H0oooo
00<000000?ooo`3oool0303oool00`000000/>3V0;3PiP070;3PiP8000003@3oool600000080oooo
00<000000;3PiP2`h>H04P2`h>H2000000d0oooo0P00000@0;3PiP030000003oool0oooo00T0oooo
00D000000?ooo`3oool0oooo0000000D0;3PiP8000003@3oool00`000000/>3V0;3PiP080;3PiP80
00007@2`h>H00`000000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00@0oooo0P0000060;3PiPD000003P3oool00`000000/>3V0;3PiP0>0;3PiP05
0000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`050?ooo`8000001@2`h>H50000
00D0/>3V0P00000E0?ooo`8000001P3oool00`000000oooo0?ooo`0@0?ooo`003@3oool00`000000
oooo000000030?ooo`030000003oool0oooo00/0oooo1000000;0?ooo`030000002`h>H0/>3V00d0
/>3V00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool02@3oool7000001P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0;0?ooo`030000002`h>H0/>3V00L0/>3V0P00000@0?ooo`030000003oool0oooo0080
oooo00<000000;3PiP2`h>H04`2`h>H2000000`0oooo00<000000;3PiP2`h>H0402`h>H00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000;3PiP2`h>H04`2`h>H00`000000
oooo0?ooo`0;0?ooo`030000002`h>H0/>3V00P0/>3V0P00000M0;3PiP030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo0P00000:0;3PiP030000003oool0oooo00@000002P3oool00`000000/>3V0;3PiP0>0;3PiP03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`80
00002@2`h>H8000001T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`00
3@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00h0oooo100000070?ooo`03
0000002`h>H0/>3V00d0/>3V00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool03P3oool4000001H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000002`h>H0/>3V00H0/>3V0P00000@0?oo
o`030000003oool0oooo00<0oooo00<000000;3PiP2`h>H04`2`h>H2000000`0oooo00<000000;3P
iP2`h>H0402`h>H00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000;3P
iP2`h>H04`2`h>H00`000000oooo0?ooo`0;0?ooo`030000002`h>H0/>3V00L0/>3V00<000000?oo
o`0000007@2`h>H00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`02000000d0/>3V00<000000?ooo`3oool00`3oool40000
00L0oooo00<000000;3PiP2`h>H03@2`h>H00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo00@000000?ooo`3oool0oooo0P00000=0;3PiP030000003oool0oooo0080oooo1@00000F
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool000d0oooo00@000000?oo
o`3oool00000103oool200000180oooo1@0000030?ooo`030000002`h>H0/>3V00/0/>3V00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000@0oooo0P00
000B0?ooo`D000004P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo0P00
00070;3PiP8000003`3oool00`000000oooo0?ooo`040?ooo`030000002`h>H0/>3V01<0/>3V00<0
00000?ooo`0000002`3oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo00@0oooo0P00
00060?ooo`030000002`h>H0/>3V01<0/>3V0P00000<0?ooo`8000001`2`h>H2000000030?ooo`00
0000/>3V01`0/>3V00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`000000402`h>H00`000000oooo0?ooo`060?ooo`D000000`3o
ool00`000000/>3V0;3PiP0:0;3PiP8000001P3oool00`000000oooo0?ooo`090?ooo`040000003o
ool0000000000100/>3V00<000000?ooo`3oool01P3oool4000001<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0>0?ooo`003@3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool0503oool6000000T0/>3V0P0000070?ooo`030000003oool0oooo00X0oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo01@0oooo1000000?0?ooo`80
00000`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool00000000000<0/>3V0`00000?0?oo
o`030000003oool0oooo00D0oooo00<000000;3PiP2`h>H04`2`h>H00`000000oooo0000000;0?oo
o`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`030000002`h>H0/>3V0180/>3V00<000000?ooo`000000303oool010000000oooo000000000003
0;3PiP<000000P3oool00`000000/>3V0;3PiP0J0;3PiP8000002@3oool2000000<0oooo00<00000
0?ooo`3oool02P3oool200000140/>3V00<000000?ooo`3oool02`3oool5000000X0/>3V00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`8000004P2`h>H00`000000oooo0?ooo`0:
0?ooo`D000003`3oool2000000<0oooo00<000000?ooo`3oool03P3oool000d0oooo00D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo01L0oooo100000060;3PiP030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`3oool05`3oool4000000d0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000
003oool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`0;0?ooo`800000203oool00`000000
/>3V0;3PiP0C0;3PiP040000003oool0oooo000000X0oooo00<000000;3PiP2`h>H0402`h>H00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000;3PiP2`h>H04P2`h>H01000
0000oooo0?ooo`00000;0?ooo`040000003oool0oooo0?ooo`<000000P3oool010000000oooo0?oo
o`00000L0;3PiP030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`80
00004P2`h>H00`000000oooo0?ooo`0>0?ooo`@000001@2`h>H2000000X0oooo00<000000?ooo`3o
ool0203oool2000001<0/>3V00<000000?ooo`3oool03P3oool4000000d0oooo00D000000?ooo`3o
ool0oooo0000000?0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool06@3oool7000000/0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool4000000X0
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02@3oool00`000000/>3V0;3PiP0A0;3PiP050000003oool0oooo
0?ooo`0000002P3oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo008000002P3oool0
0`000000/>3V0;3PiP0B0;3PiP040000003oool0oooo000000/0oooo00<000000?ooo`3oool01@3o
ool01@000000oooo0?ooo`3oool0000001`0/>3V00<000000?ooo`3oool02`3oool010000000oooo
0?ooo`00000;0?ooo`030000002`h>H0/>3V0140/>3V00<000000?ooo`3oool04@3oool6000000`0
oooo00<000000?ooo`3oool0203oool2000001<0/>3V00<000000?ooo`3oool04P3oool4000000X0
oooo00@000000?ooo`3oool000003`3oool000d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`8000006P3oool9000000T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P00000J0?ooo`T000001P3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000002`h>H0/>3V0140/>3V00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`8000004@2`h>H00`000000oooo0000000<0?ooo`030000002`h>H0/>3V
0180/>3V00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000000/>3V0;3PiP0H0;3PiP030000003oool0oooo00d0oooo00@00000
0?ooo`3oool000002P3oool00`000000/>3V0;3PiP0B0;3PiP030000003oool0oooo01D0oooo1@00
00090?ooo`030000003oool0oooo00L0oooo0P00000D0;3PiP030000003oool0oooo01D0oooo1@00
00060?ooo`040000003oool0oooo000000h0oooo000=0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`800000202`h>H5000000D0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool05@3oool2000000L0/>3V1P0000030?ooo`<000002P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool00`000000/>3V0;3P
iP0?0;3PiP030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool200000140/>3V0P00
000>0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3P
iP0H0;3PiP030000003oool0oooo00h0oooo0`00000:0?ooo`030000002`h>H0/>3V0180/>3V00<0
00000?ooo`3oool06P3oool4000000D0oooo00<000000?ooo`3oool01`3oool00`000000/>3V0;3P
iP0C0;3PiP030000003oool0oooo01X0oooo100000030?ooo`<000003P3oool000d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo0P00000<
0;3PiP030000003oool0oooo00@000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`8000002`2`h>H2
00000080oooo100000000`3oool00000000000090?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool2000000l0oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000003`2`h>H200000100oooo00<00000
0;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000002`h>H0/>3V01L0/>3V00<00000
0?ooo`3oool0403oool2000000T0oooo00<000000;3PiP2`h>H04P2`h>H00`000000oooo0?ooo`0N
0?ooo`@000000P3oool00`000000oooo0?ooo`060?ooo`030000002`h>H0/>3V01<0/>3V00<00000
0?ooo`3oool07P3oool4000000030?ooo`000000000000d0oooo000=0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`030000002`h>H0/>3V
00d0/>3V00<000000?ooo`3oool00`3oool3000000T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<000000;3PiP2`h>H03@2`h>H00`00
0000oooo0?ooo`030?ooo`<000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0403oool00`000000/>3V0;3PiP0=0;3PiP030000003oool0oooo
00<0oooo0`0000080?ooo`040000003oool0oooo000000d0/>3V0P00000B0?ooo`030000002`h>H0
/>3V00`0/>3V0P0000040?ooo`<000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000;3PiP2`h>H05P2`h>H00`000000oooo0?ooo`0@0?ooo`<000002@3oool0
0`000000/>3V0;3PiP0B0;3PiP8000008`3oool3000000P0oooo00<000000;3PiP2`h>H04`2`h>H0
0`000000oooo0?ooo`0R0?ooo`<000003@3oool000d0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`800000403oool00`000000/>3V0;3PiP0>0;3PiP030000003oool0oooo
00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00P0oooo0P00000@0?ooo`030000002`h>H0/>3V00h0/>3V00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0B0?ooo`800000302`h>H00`000000oooo0?ooo`0400000080oooo00<000000?oo
o`3oool01P3oool010000000oooo0?ooo`00000<0;3PiP030000003oool0oooo01<0oooo00<00000
0;3PiP2`h>H02P2`h>H00`000000oooo0?ooo`0400000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000;3PiP2`h>H05@2`h>H0
0`000000oooo0?ooo`0<0?ooo`@000000P3oool00`000000oooo0?ooo`070?ooo`030000002`h>H0
/>3V0180/>3V00<000000?ooo`3oool07P3oool400000080oooo00<000000?ooo`3oool01P3oool0
0`000000/>3V0;3PiP0C0;3PiP030000003oool0oooo01h0oooo100000020?ooo`030000003oool0
oooo00/0oooo000=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0<0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0<0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0E0?ooo`8000002@2`h>H4000000D0oooo00<000000?ooo`3oool01`3oool01@00
0000oooo0?ooo`3oool0000000X0/>3V00<000000?ooo`3oool05@3oool2000000T0/>3V10000005
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`030000002`h>H0/>3V01@0/>3V00<000000?ooo`3oool02@3oool4000000D0oooo00<00000
0?ooo`3oool0203oool00`000000/>3V0;3PiP0B0;3PiP030000003oool0oooo01X0oooo10000005
0?ooo`030000003oool0oooo00L0oooo00<000000;3PiP2`h>H04`2`h>H00`000000oooo0?ooo`0J
0?ooo`@000001@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000/>3V0;3PiP0@0;3P
iP030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000/>3V0;3PiP0A0;3P
iP030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo0P00000J0?ooo`T000002@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0080oooo2P00000J0?ooo`X00000203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000/>3V0;3PiP0B0;3P
iP030000003oool0oooo00H0oooo100000090?ooo`030000003oool0oooo00P0oooo00<000000;3P
iP2`h>H04P2`h>H00`000000oooo0?ooo`0F0?ooo`@000002@3oool00`000000oooo0?ooo`070?oo
o`030000002`h>H0/>3V0180/>3V00<000000?ooo`3oool05P3oool5000000T0oooo00<000000?oo
o`3oool0303oool000d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000;3PiP2`h>H04P2`h>H010000000oooo0?ooo`00000;0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?oo
o`030000002`h>H0/>3V0180/>3V00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool5000000`0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`8000006`3oool5000000`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo0P00000A
0;3PiP030000003oool0oooo0080oooo1@00000<0?ooo`030000003oool0oooo00T0oooo00<00000
0;3PiP2`h>H04P2`h>H00`000000oooo0?ooo`0A0?ooo`D00000303oool00`000000oooo0?ooo`08
0?ooo`8000004`2`h>H00`000000oooo0?ooo`0B0?ooo`@000003@3oool00`000000oooo0?ooo`0=
0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000d0oooo00<00000
0?ooo`3oool0203oool00`000000/>3V0;3PiP0B0;3PiP040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00P0oooo
00<000000;3PiP2`h>H04P2`h>H010000000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`0G0?ooo`@000000`2`h>H4000000X0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01L0oooo1@0000030;3P
iP@000002@3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000003P3oool2
000000d0/>3V0P0000000`3oool0000000000003000000<0/>3V0`00000:0?ooo`030000003oool0
oooo00T0oooo00<000000;3PiP2`h>H04@2`h>H00`000000oooo0?ooo`0>0?ooo`@000000`2`h>H4
000000X0oooo00<000000?ooo`3oool0203oool200000180/>3V00<000000?ooo`3oool03`3oool4
000000<0/>3V1000000:0?ooo`030000003oool0oooo00d0oooo000=0?ooo`040000003oool0oooo
0?ooo`80000000D0/>3V000000000000oooo0000000=0?ooo`800000203oool00`000000/>3V0;3P
iP0B0;3PiP030000003oool0000000`0oooo00@000000?ooo`3oool0oooo0P000000102`h>H00000
00000000000>0?ooo`8000001`3oool00`000000/>3V0;3PiP0C0;3PiP030000003oool0000000`0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo01@0oooo1@00000:0;3P
iP030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01@0oooo1@00000;0;3PiP030000003oool0oooo00D0oooo00<000000?oo
o`3oool02P3oool01@000000oooo0?ooo`3oool000000100oooo00<000000;3PiP2`h>H01`2`h>H7
000000X0/>3V00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`8000004P2`h>H0
0`000000oooo0?ooo`0:0?ooo`D000002P2`h>H00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`0000004@2`h>H00`000000oooo0?ooo`0:0?ooo`H000002P2`h>H0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo000=0?ooo`040000003oool00000
000000D0/>3V0P00000?0?ooo`030000003oool0oooo00D0oooo00<000000;3PiP2`h>H04P2`h>H0
0`000000oooo0000000<0?ooo`040000003oool00000000000D0/>3V0P00000?0?ooo`030000003o
ool0oooo00@0oooo00<000000;3PiP2`h>H04`2`h>H00`000000oooo0000000<0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0403oool5000000<0oooo00<000000;3PiP2`h>H0
2P2`h>H00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0@0?ooo`D00000103oool00`000000/>3V0;3PiP0:0;3PiP030000
003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000B0?ooo`/0
0000103oool00`000000/>3V0;3PiP090;3PiP030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02P3oool010000000oooo00000000000?0;3PiP030000003oool0oooo00H0oooo1@0000030?oo
o`030000002`h>H0/>3V00X0/>3V00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?oo
o`040000003oool0oooo000000l0/>3V00<000000?ooo`3oool01`3oool4000000@0oooo00<00000
0;3PiP2`h>H02P2`h>H00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo000=0?oo
o`800000202`h>H2000000l0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP0B0;3P
iP8000003@3oool2000000P0/>3V00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?oo
o`030000002`h>H0/>3V01<0/>3V0P00000=0?ooo`040000003oool0oooo000000<0oooo0P00000?
0?ooo`@000001`3oool00`000000/>3V0;3PiP0<0;3PiP030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`8000003`3oool4000000P0oooo00<00000
0;3PiP2`h>H0302`h>H00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00@00000
0?ooo`3oool00000503oool4000000P0oooo00<000000;3PiP2`h>H02`2`h>H00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000003P2`h>H00`000000oooo
0?ooo`030?ooo`@000001`3oool00`000000/>3V0;3PiP0<0;3PiP030000003oool0oooo00<0oooo
00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000h0/>3V00<000000?ooo`3o
ool00P3oool5000000L0oooo00<000000;3PiP2`h>H0302`h>H00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00l0oooo000=0?ooo`8000002@2`h>H00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00<0oooo00<000000;3PiP2`h>H04P2`h>H2000000d0oooo00<000000;3PiP2`h>H0
202`h>H00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000;3PiP2`h>H0
4`2`h>H2000000d0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0;0?ooo`@00000
2`3oool00`000000/>3V0;3PiP0=0;3PiP030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo1000000<0?ooo`030000
002`h>H0/>3V00d0/>3V00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool000000140
oooo1000000;0?ooo`030000002`h>H0/>3V00d0/>3V00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`000000302`h>H00`000000oooo0?ooo`040000
00/0oooo00<000000;3PiP2`h>H03@2`h>H00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00P3oool00`000000/>3V0;3PiP090;3PiP80000000<0oooo0000
000000000P00000<0?ooo`030000002`h>H0/>3V00d0/>3V00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0?0?ooo`003@3oool00`000000/>3V0;3PiP080;3PiP8000003@3oool5000000<0
oooo00<000000;3PiP2`h>H04P2`h>H00`000000oooo0?ooo`0<0?ooo`030000002`h>H0/>3V00P0
/>3V00<000000?ooo`3oool02`3oool3000000030?ooo`00000000000080oooo00<000000;3PiP2`
h>H04`2`h>H00`000000oooo0?ooo`0<0?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool0203oool4000000h0oooo00<000000;3PiP2`h>H03P2`h>H01@000000oooo0?ooo`3oool00000
00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`@000003`3oool00`00
0000/>3V0;3PiP0>0;3PiP050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0000000=
0?ooo`@000003P3oool00`000000/>3V0;3PiP0>0;3PiP050000003oool0oooo0?ooo`0000003P3o
ool00`000000oooo0?ooo`020?ooo`8000001`2`h>H6000000h0oooo00<000000;3PiP2`h>H03P2`
h>H01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool00`3oool2000000L0/>3V
1@00000?0?ooo`030000002`h>H0/>3V00h0/>3V00D000000?ooo`3oool0oooo0000000B0?ooo`00
3@3oool00`000000/>3V0;3PiP080;3PiP8000002`3oool2000000<0/>3V0`0000020?ooo`030000
002`h>H0/>3V0180/>3V00<000000?ooo`3oool0303oool00`000000/>3V0;3PiP080;3PiP800000
2`3oool010000000/>3V0;3PiP2`h>H400000080oooo00<000000;3PiP2`h>H04@2`h>H2000000h0
oooo0P0000020?ooo`030000003oool0oooo00@0oooo1@00000A0?ooo`030000002`h>H0/>3V0100
/>3V00@000000?ooo`3oool000003@3oool01@000000oooo0?ooo`3oool0000000H0oooo1@00000B
0?ooo`030000002`h>H0/>3V00l0/>3V00@000000?ooo`3oool000003P3oool2000000T0oooo1@00
000B0?ooo`030000002`h>H0/>3V00l0/>3V00@000000?ooo`3oool000003P3oool00`000000oooo
0?ooo`040?ooo`T000004@3oool00`000000/>3V0;3PiP0@0;3PiP040000003oool0oooo000000d0
oooo00<000000?ooo`3oool01@3oool800000180oooo00<000000;3PiP2`h>H03`2`h>H01@000000
oooo0?ooo`3oool000000180oooo000=0?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`00
0000203oool2000000P0/>3V00<000000?ooo`0000004`2`h>H2000000h0oooo00<000000;3PiP2`
h>H0202`h>H2000000T0oooo0P0000080;3PiP030000003oool0000001<0/>3V00<000000?ooo`3o
ool03@3oool4000000<0oooo1000000F0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`00
00003P3oool010000000oooo0000000000030?ooo`@000005`3oool00`000000/>3V0;3PiP0?0;3P
iP040000003oool0oooo000000h0oooo0P0000050?ooo`@000005P3oool00`000000/>3V0;3PiP0@
0;3PiP030000003oool0000000l0oooo00<000000?ooo`3oool0103oool4000001H0oooo00<00000
0;3PiP2`h>H0402`h>H00`000000oooo0000000>0?ooo`030000003oool0oooo00@0oooo1000000G
0?ooo`030000002`h>H0/>3V00l0/>3V00@000000?ooo`3oool000004`3oool000d0oooo00<00000
0;3PiP2`h>H0202`h>H00`000000oooo000000070?ooo`030000002`h>H0/>3V00T0/>3V00<00000
0?ooo`0000004P2`h>H00`000000oooo0?ooo`0=0?ooo`030000002`h>H0/>3V00P0/>3V00<00000
0?ooo`0000001P3oool2000000/0/>3V00<000000?ooo`0000004@2`h>H2000000l0oooo0P000000
0`3oool0000000000002000001X0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo0000000>
0?ooo`80000000<0oooo0000000000000P00000K0?ooo`030000002`h>H0/>3V0100/>3V0P00000?
0?ooo`030000003oool0oooo00@000006P3oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0
000000l0oooo00<000000?ooo`3oool01000000J0?ooo`030000002`h>H0/>3V0100/>3V00<00000
0?ooo`0000003P3oool00`000000oooo0?ooo`04000001/0oooo00<000000;3PiP2`h>H0402`h>H0
0`000000oooo0000000C0?ooo`003@3oool2000000P0/>3V00D000000?ooo`3oool0oooo00000005
0?ooo`030000002`h>H0/>3V00/0/>3V0`00000@0;3PiP8000003`3oool00`000000/>3V0;3PiP07
0;3PiP040000003oool0oooo000000D0oooo00<000000;3PiP2`h>H0302`h>H200000140/>3V00<0
00000?ooo`3oool03P3oool3000001h0oooo00<000000;3PiP2`h>H0402`h>H2000000l0oooo0`00
000O0?ooo`030000002`h>H0/>3V0100/>3V0P00000?0?ooo`<000007P3oool00`000000/>3V0;3P
iP0@0;3PiP800000403oool3000001h0oooo00<000000;3PiP2`h>H0402`h>H2000000l0oooo0`00
000O0?ooo`030000002`h>H0/>3V0100/>3V0P00000D0?ooo`003P3oool2000000L0/>3V00D00000
0?ooo`3oool0oooo000000040?ooo`030000002`h>H0/>3V00d0/>3V0`00000?0;3PiP030000003o
ool0oooo00l0oooo00<000000;3PiP2`h>H01@2`h>H00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000;3PiP2`h>H03@2`h>H2000000l0/>3V0P00000A0?ooo`030000003o
ool0000000<000006P3oool00`000000/>3V0;3PiP0@0;3PiP800000403oool00`000000oooo0000
0003000001/0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo0?ooo`0?0?ooo`030000003o
ool0000000<000006P3oool00`000000/>3V0;3PiP0@0;3PiP8000004@3oool00`000000oooo0000
0003000001X0oooo00<000000;3PiP2`h>H0402`h>H200000100oooo00<000000?ooo`0000000`00
000K0?ooo`030000002`h>H0/>3V0100/>3V0P00000D0?ooo`003`3oool3000000<0/>3V0P000005
0?ooo`040000003oool0oooo00000100/>3V00<000000?ooo`0000003P2`h>H00`000000oooo0?oo
o`0A0?ooo`8000000`2`h>H2000000D0oooo00D000000?ooo`3oool0oooo0000000@0;3PiP030000
003oool0000000h0/>3V00<000000?ooo`3oool04@3oool2000000<0oooo1000000F0?ooo`030000
002`h>H0/>3V0100/>3V00<000000?ooo`3oool0403oool2000000<0oooo1@00000F0?ooo`030000
002`h>H0/>3V0100/>3V00<000000?ooo`3oool0403oool2000000<0oooo1000000F0?ooo`030000
002`h>H0/>3V0100/>3V00<000000?ooo`3oool04@3oool2000000<0oooo1000000F0?ooo`030000
002`h>H0/>3V0100/>3V00<000000?ooo`3oool0403oool2000000<0oooo1@00000F0?ooo`030000
002`h>H0/>3V0100/>3V00<000000?ooo`3oool04`3oool00140oooo100000070?ooo`040000003o
ool0oooo00000140/>3V00<000000?ooo`000000302`h>H2000001D0oooo0`0000070?ooo`040000
003oool0oooo00000180/>3V00<000000?ooo`0000002`2`h>H3000001D0oooo00<000000?ooo`3o
ool0103oool500000180oooo00<000000;3PiP2`h>H03P2`h>H2000001@0oooo00<000000?ooo`3o
ool01@3oool400000180oooo00<000000;3PiP2`h>H03`2`h>H2000001@0oooo00<000000?ooo`3o
ool0103oool500000180oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00@0oooo1@00000B0?ooo`030000002`h>H0/>3V00h0/>3V0P00000D0?ooo`03
0000003oool0oooo00D0oooo1000000B0?ooo`030000002`h>H0/>3V00l0/>3V0P00000E0?ooo`00
4P3oool00`000000oooo0?ooo`080?ooo`030000003oool000000140/>3V00<000000?ooo`3oool0
100000030;3PiPH000005`3oool00`000000oooo0?ooo`070?ooo`030000003oool000000180/>3V
00<000000?ooo`3oool0100000030;3PiP@0000000<0oooo0000003oool05P3oool00`000000oooo
0?ooo`080?ooo`@000003P3oool00`000000/>3V0;3PiP0>0;3PiP030000003oool0oooo01@0oooo
00<000000?ooo`3oool0203oool5000000d0oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00P0oooo1000000>0?ooo`030000002`h>H0/>3V00h0/>3V
0P00000F0?ooo`030000003oool0oooo00P0oooo1000000>0?ooo`030000002`h>H0/>3V00h0/>3V
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`080?ooo`D000003@3oool00`000000/>3V
0;3PiP0?0;3PiP030000003oool0oooo01@0oooo000C0?ooo`800000203oool200000180/>3V00@0
00000?ooo`3oool0oooo0P000000103oool000000000000000050?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000B0;3PiP040000003oool0oooo0?oo
o`80000000@0oooo00000000000000001@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00/0oooo1000000:0?ooo`030000002`h>H0/>3V00d0/>3V0P00000G0?ooo`8000003@3oool4
000000X0oooo00<000000;3PiP2`h>H03@2`h>H2000001L0oooo00<000000?ooo`3oool02`3oool4
000000/0oooo00<000000;3PiP2`h>H03@2`h>H00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00/0oooo1000000:0?ooo`030000002`h>H0/>3V00h0/>3V00<000000?ooo`3oool05@3oool2
000000d0oooo1000000:0?ooo`030000002`h>H0/>3V00d0/>3V0P00000F0?ooo`005@3oool00`00
0000oooo0?ooo`060?ooo`030000002`h>H0/>3V0100/>3V0P0000040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0603oool2000000L0oooo0P00000B0;3PiP030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`8000002`3oool01000
0000/>3V0;3PiP2`h>H5000000H0oooo0P00000<0;3PiP8000006P3oool00`000000oooo0?ooo`09
0?ooo`030000002`h>H0/>3V0080/>3V100000070?ooo`030000002`h>H0/>3V00/0/>3V0P00000I
0?ooo`8000002`3oool010000000/>3V0;3PiP2`h>H5000000L0oooo00<000000;3PiP2`h>H02`2`
h>H00`000000oooo0?ooo`0H0?ooo`8000002`3oool010000000/>3V0;3PiP2`h>H5000000H0oooo
0P00000=0;3PiP030000003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool00`000000/>3V
0;3PiP020;3PiP@000001`3oool00`000000/>3V0;3PiP0;0;3PiP8000005`3oool001H0oooo00<0
00000?ooo`3oool01@3oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo0P00
000B0;3PiP030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo00L0oooo00<000000;3PiP2`h>H0102`h>H2000000030?ooo`00
00000000008000000`3oool00`000000/>3V0;3PiP0:0;3PiP8000006`3oool00`000000oooo0?oo
o`070?ooo`030000002`h>H0/>3V00D0/>3V00<000000?ooo`000000100000030?ooo`030000002`
h>H0/>3V00X0/>3V0P00000K0?ooo`030000003oool0oooo00L0oooo00<000000;3PiP2`h>H0102`
h>H2000000030?ooo`0000000000008000000`3oool00`000000/>3V0;3PiP0;0;3PiP030000003o
ool0oooo01X0oooo00<000000?ooo`3oool01`3oool00`000000/>3V0;3PiP040;3PiP80000000<0
oooo0000000000000P0000030?ooo`030000002`h>H0/>3V00X0/>3V0P00000K0?ooo`030000003o
ool0oooo00L0oooo00<000000;3PiP2`h>H01@2`h>H7000000<0oooo00<000000;3PiP2`h>H02P2`
h>H2000001L0oooo000G0?ooo`030000003oool0oooo00@0oooo0P00000A0;3PiP030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00@0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`040?ooo`800000202`h>H0
0`000000oooo0?ooo`030?ooo`D000002P2`h>H2000001d0oooo00<000000?ooo`3oool01@3oool0
0`000000/>3V0;3PiP070;3PiP030000003oool0oooo00<0oooo1@0000090;3PiP<000007@3oool0
0`000000oooo0?ooo`050?ooo`030000002`h>H0/>3V00H0/>3V00<000000?ooo`3oool00`3oool5
000000X0/>3V0P00000N0?ooo`030000003oool0oooo00@0oooo0P0000080;3PiP030000003oool0
oooo00<0oooo1@00000:0;3PiP8000007@3oool00`000000oooo0?ooo`050?ooo`030000002`h>H0
/>3V00L0/>3V00<000000?ooo`3oool00`3oool5000000T0/>3V0`00000H0?ooo`00603oool20000
00D0oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`060?ooo`8000000P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo0P00000@0;3PiP030000003oool0oooo
00L0oooo0P0000020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool00`00
0000/>3V0;3PiP080;3PiP030000003oool0oooo00L0oooo2P0000000`3oool000000?ooo`0M0?oo
o`8000001@3oool00`000000/>3V0;3PiP080;3PiP030000003oool0oooo00H0oooo2P0000020?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP070;3P
iP030000003oool0oooo00L0oooo2P0000000`3oool000000?ooo`0N0?ooo`030000003oool0oooo
00<0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`070?ooo`X0000000<0oooo0000
003oool07@3oool2000000D0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`060?oo
o`X000000P3oool00`000000oooo0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`020?ooo`80
0000402`h>H00`000000oooo0?ooo`080?ooo`8000008@3oool00`000000oooo0?ooo`030?ooo`03
0000002`h>H0/>3V00h0/>3V00<000000?ooo`3oool02@3oool200000240oooo00<000000?ooo`3o
ool00P3oool00`000000/>3V0;3PiP080;3PiP030000003oool0oooo00/0oooo100000020?ooo`03
0000003oool0oooo01l0oooo00D000000?ooo`3oool0oooo0000000;0;3PiP030000003oool0oooo
00/0oooo100000020?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`00
0000/>3V0;3PiP080;3PiP030000003oool0oooo00/0oooo100000020?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool00P3oool00`000000/>3V0;3PiP080;3PiP030000003oool0oooo
00/0oooo100000020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool00`00
0000/>3V0;3PiP080;3PiP030000003oool0oooo00/0oooo100000020?ooo`030000003oool0oooo
01L0oooo000K0?ooo`030000003oool0oooo0080oooo00<000000;3PiP2`h>H03@2`h>H00`000000
oooo0?ooo`080?ooo`<000008P3oool2000000<0oooo00<000000;3PiP2`h>H03P2`h>H00`000000
oooo0?ooo`080?ooo`<000008P3oool200000080oooo00<000000;3PiP2`h>H0202`h>H00`000000
oooo0?ooo`0?0?ooo`<000008P3oool010000000oooo0?ooo`00000;0;3PiP030000003oool0oooo
00l0oooo0`00000Q0?ooo`8000000P3oool00`000000/>3V0;3PiP080;3PiP030000003oool0oooo
00l0oooo0`00000R0?ooo`8000000P3oool00`000000/>3V0;3PiP080;3PiP030000003oool0oooo
00l0oooo0`00000R0?ooo`050000003oool0oooo0?ooo`0000002P2`h>H00`000000oooo0?ooo`0?
0?ooo`<000006@3oool001`0oooo0P0000030?ooo`030000002`h>H0/>3V00/0/>3V00<000000?oo
o`3oool01@3oool4000002L0oooo00@000000?ooo`3oool0oooo0P00000=0;3PiP030000003oool0
oooo00D0oooo1000000W0?ooo`030000003oool0000000X0/>3V00<000000?ooo`3oool02`3oool4
000002H0oooo0`00000:0;3PiP030000003oool0oooo00`0oooo1000000V0?ooo`030000003oool0
000000X0/>3V00<000000?ooo`3oool02`3oool4000002L0oooo00<000000?ooo`0000002P2`h>H0
0`000000oooo0?ooo`0;0?ooo`@000009P3oool2000000030?ooo`000000/>3V00P0/>3V00<00000
0?ooo`3oool0303oool4000001`0oooo000N0?ooo`040000003oool0oooo000000d0/>3V00@00000
0?ooo`3oool0oooo1000000/0?ooo`030000003oool0oooo00800000302`h>H010000000oooo0?oo
o`3oool5000002`0oooo0P00000:0;3PiP030000003oool0oooo00H0oooo1@00000/0?ooo`800000
2@2`h>H00`000000oooo0?ooo`070?ooo`D00000:`3oool2000000X0/>3V00<000000?ooo`3oool0
1P3oool5000002`0oooo0P00000:0;3PiP030000003oool0oooo00H0oooo1@00000/0?ooo`800000
2@2`h>H00`000000oooo0?ooo`070?ooo`D00000803oool001l0oooo00@000000?ooo`3oool00000
2P2`h>H600000340oooo00<000000?ooo`3oool00P00000:0;3PiPD00000<P3oool00`000000/>3V
0;3PiP070;3PiP030000003oool0oooo00<0oooo1000000b0?ooo`030000002`h>H0/>3V00H0/>3V
00<000000?ooo`3oool0103oool400000340oooo0P0000080;3PiP030000003oool0oooo00<0oooo
1000000b0?ooo`030000002`h>H0/>3V00L0/>3V00<000000?ooo`3oool00`3oool400000380oooo
00<000000;3PiP2`h>H01P2`h>H00`000000oooo0?ooo`040?ooo`@000009@3oool00200oooo3P00
000g0?ooo`<0000000<0oooo0000000000002@00000g0?ooo`8000001P2`h>H00`000000oooo0000
0004000003L0oooo0P0000060;3PiP030000003oool0000000@00000=P3oool2000000L0/>3V1P00
000g0?ooo`8000001P2`h>H00`000000oooo00000004000003L0oooo0P0000060;3PiP030000003o
ool0000000@00000:@3oool00280oooo0P0000020?ooo`@00000?@3oool200000080oooo1000000m
0?ooo`T00000?@3oool9000003d0oooo2000000m0?ooo`T00000?@3oool9000002h0oooo000S0?oo
o`<00000@P3oool3000004<0oooo0`0000130?ooo`<00000@P3oool3000004<0oooo0`0000130?oo
o`<00000<P3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool0
0?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool0
02<0oooo0`0000120?ooo`<00000@`3oool3000004<0oooo0`0000120?ooo`<00000@`3oool30000
04<0oooo0`00000b0?ooo`008P3oool200000080oooo1000000m0?ooo`8000000P3oool4000003d0
oooo0P0000030;3PiP@00000?P3oool3000000030?ooo`000000000000800000?@3oool200000080
oooo1P00000k0?ooo`8000000`2`h>H4000003h0oooo0`0000000`3oool0000000000002000002h0
oooo000P0?ooo`80000000<0oooo0000003oool01@3oool6000003D0oooo100000060?ooo`H00000
=P3oool2000000H0/>3V1`00000g0?ooo`80000000<0oooo0000000000000P0000030?ooo`D00000
=P3oool3000000030?ooo`0000000000008000000P2`h>H5000003L0oooo0P0000060;3PiPL00000
=`3oool7000000<0oooo1@00000Y0?ooo`007`3oool01@000000oooo0?ooo`3oool0000000H0oooo
0P0000020;3PiPD00000<@3oool00`000000oooo0?ooo`02000000L0oooo0P0000020;3PiP@00000
<P3oool00`000000/>3V0;3PiP070;3PiP030000003oool0oooo00<0oooo1000000b0?ooo`040000
003oool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`@00000<@3oool00`000000
oooo0?ooo`02000000X0/>3V1@00000b0?ooo`030000002`h>H0/>3V00L0/>3V00<000000?ooo`3o
ool00`3oool400000380oooo00@000000?ooo`000000oooo0P0000020?ooo`030000003oool0oooo
00D0oooo1000000U0?ooo`007P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo0P0000080;3PiPD00000;03oool01P000000oooo0?ooo`000000oooo000000D0oooo0P000007
0;3PiPH00000;03oool2000000X0/>3V00<000000?ooo`3oool01P3oool5000002`0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000020?ooo`030000003oool0oooo00P0oooo1@00000[
0?ooo`040000003oool0oooo000000h0/>3V00<000000?ooo`3oool01@00000/0?ooo`8000002P2`
h>H00`000000oooo0?ooo`060?ooo`D00000;03oool020000000oooo0?ooo`000000oooo0000003o
ool000000P3oool00`000000oooo0?ooo`080?ooo`D00000803oool001`0oooo0P0000050?ooo`03
0000003oool0oooo00800000302`h>H00`000000oooo0?ooo`04000002L0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo0P00000;0;3PiP8000000P3oool4000002L0oooo00<00000
0?ooo`0000002P2`h>H00`000000oooo0?ooo`0;0?ooo`@000009P3oool2000000D0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`@000009P3oool01@000000oooo0?ooo`3o
ool0000000h0/>3V00<000000?ooo`3oool01@3oool4000002L0oooo00<000000?ooo`0000002P2`
h>H00`000000oooo0?ooo`0;0?ooo`@000009P3oool200000080oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`8000003@3oool4000001`0oooo000K0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`0000003`2`h>H2000000@0oooo0`00000R0?ooo`8000000`3oool010000000oooo
0?ooo`0000020?ooo`030000002`h>H0/>3V00d0/>3V0P0000040?ooo`<000008P3oool200000080
oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`0?0?ooo`<000008P3oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo0P00000:0?ooo`8000000`2`h>H40000
0240oooo0P0000030?ooo`030000002`h>H0/>3V00h0/>3V00<000000?ooo`3oool0203oool30000
0280oooo0P0000020?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool03`3oool30000
0280oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool2000000<0/>3V1000000I0?ooo`006P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool000000100/>3V00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool0
0`000000/>3V0;3PiP0>0;3PiP030000003oool0oooo00@0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`020?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool02`3oool4
00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool01P3oool00`000000/>3V0;3PiP050;3PiP800000803o
ool00`000000oooo0?ooo`020?ooo`800000402`h>H00`000000oooo0?ooo`090?ooo`8000008@3o
ool00`000000oooo0?ooo`020?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool02`3o
ool4000000030?ooo`00000000000240oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
002`h>H0/>3V00D0/>3V0P00000I0?ooo`006@3oool00`000000oooo0?ooo`070?ooo`8000004P2`
h>H00`000000oooo0?ooo`020?ooo`<000007`3oool00`000000oooo0?ooo`030?ooo`070000003o
ool0oooo0?ooo`000000oooo0000000B0;3PiP030000003oool0oooo0080oooo0`00000O0?ooo`03
0000003oool0oooo00<0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`070?ooo`@0
00001@3oool3000001l0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool01@3oool00`000000/>3V0;3PiP060;3PiP8000007P3oool00`00
0000oooo0?ooo`030?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool01P3oool50000
01l0oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3PiP080;3PiP030000003oool0oooo
00L0oooo100000030?ooo`D000007`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`8000001P3oool00`000000/>3V0;3PiP06
0;3PiP800000603oool001L0oooo0P00000:0?ooo`8000004P2`h>H00`000000oooo0?ooo`020?oo
o`<000007P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000004`2`h>H0
0`000000oooo0?ooo`020?ooo`<000007P3oool00`000000oooo0?ooo`040?ooo`030000002`h>H0
/>3V00L0/>3V00<000000?ooo`3oool00`3oool5000000T0oooo0`00000M0?ooo`8000002P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo0P0000040?ooo`030000002`h>H0/>3V00P0/>3V00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`030000002`h>H0/>3V0100/>3V00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`03000001h0oooo00<000000?ooo`3oool0103o
ool00`000000/>3V0;3PiP070;3PiP030000003oool0oooo00<0oooo1@0000060?ooo`030000003o
ool0oooo00<000007@3oool2000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000/>3V0;3PiP080;3PiP030000
003oool0oooo01H0oooo000F0?ooo`L000001P3oool00`000000/>3V0;3PiP0B0;3PiP080000003o
ool0oooo0000003oool000000?ooo`00000L0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool2000001@0/>3V00P000000?ooo`3oool000000?ooo`000000oooo000001`0oooo
00<000000?ooo`3oool01P3oool00`000000/>3V0;3PiP050;3PiP030000003oool0oooo00@00000
3@3oool01@000000oooo0000003oool0000001/0oooo1`0000060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000X0/>3V0P00000K0?oo
o`030000003oool0oooo00@0oooo0P00000B0;3PiP030000003oool0oooo00@0oooo00P000000?oo
o`3oool000000?ooo`000000oooo000001`0oooo00<000000?ooo`3oool01P3oool00`000000/>3V
0;3PiP050;3PiP030000003oool0oooo00@000002P3oool020000000oooo0?ooo`000000oooo0000
003oool000006`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000002P2`
h>H2000001L0oooo000D0?ooo`8000001`2`h>H00`000000oooo0?ooo`030?ooo`030000002`h>H0
/>3V0180/>3V00P000000?ooo`3oool000000?ooo`000000oooo000001X0oooo0P0000070?ooo`03
0000003oool0oooo0080oooo0P00000D0;3PiP080000003oool0oooo0000003oool000000?ooo`00
000J0?ooo`8000002P3oool:00000140oooo00D000000?ooo`000000oooo0000000I0?ooo`800000
1`2`h>H2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo000000X0/>3V0P00000I0?ooo`8000001`3oool200000180/>3V00<000000?ooo`3o
ool00`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000000J0?ooo`8000002P3o
ool:000000d0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000006P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`040000003oool0oooo000000X0/>3V0P00000G0?ooo`004`3oool20000
00T0/>3V0P0000030?ooo`030000002`h>H0/>3V01<0/>3V0P0000020?ooo`040000003oool0oooo
000001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000002`h>H0
/>3V01<0/>3V00<000000?ooo`0000000P3oool010000000oooo0?ooo`00000H0?ooo`030000003o
ool0oooo00T0oooo1`00000D0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
5@3oool2000000X0/>3V00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`0000002P2`h>H00`000000oooo0000000G0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`0000004P2`h>H010000000oooo0?ooo`3oool2000000<0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00/0oooo1@00000?
0?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01D0oooo0P00
00080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`<000002P2`h>H00`000000oooo0000000F0?ooo`004P3oool00`000000/>3V0;3PiP0;
0;3PiP040000003oool0oooo000001D0/>3V0P0000020?ooo`040000003oool0oooo000001L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000002`h>H0/>3V01<0/>3V
00<000000?ooo`0000000P3oool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo00P0
oooo100000040;3PiP<000004P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
01@0oooo00<000000;3PiP2`h>H02`2`h>H010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo00L0oooo0P00000:0;3PiP030000003oool0000001H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0000000B0;3PiP040000003oool0oooo000000D0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00P0oooo1000000C0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0000000F0?ooo`00
4@3oool00`000000/>3V0;3PiP0<0;3PiP040000003oool0oooo000001D0/>3V00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo01<0oooo1@0000050?ooo`030000003oool0oooo
00@0oooo00<000000;3PiP2`h>H04`2`h>H2000000<0oooo00D000000?ooo`3oool0oooo0000000E
0?ooo`030000003oool0oooo00@0oooo1@00000;0;3PiP8000003`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool04P3oool2000000h0/>3V00<000000?ooo`0000001P3o
ool00`000000oooo0?ooo`080?ooo`030000002`h>H0/>3V00H0/>3V00D000000?ooo`3oool0oooo
0000000D0?ooo`D000001@3oool01@000000oooo0?ooo`3oool000000140/>3V00<000000?ooo`00
00001@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`040?ooo`D000005P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`0B0?ooo`H000001@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool2000000L0/>3V00D00000
0?ooo`3oool0oooo0000000E0?ooo`003`3oool200000100/>3V00<000000?ooo`000000502`h>H2
000000<0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`8000001@2`h>H00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000;3PiP2`h>H04`2`h>H2000000<0oooo00D0
00000?ooo`3oool0oooo0000000C0?ooo`8000000`3oool4000000030?ooo`000000000000l0/>3V
0P00000=0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0@0?ooo`<0
0000402`h>H2000000H0oooo00<000000?ooo`3oool02@3oool00`000000/>3V0;3PiP050;3PiP05
0000003oool0oooo0?ooo`0000004P3oool2000000D0/>3V00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool000000100/>3V00<000000?ooo`0000001P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool04@3oool200000080oooo1`00000H0?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0100oooo
0P0000050;3PiP030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00T0oooo0P0000060;3PiP050000003oool0oooo0?ooo`00
00005@3oool000h0oooo00<000000?ooo`000000402`h>H00`000000oooo0000000D0;3PiP030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000
002`h>H0/>3V00H0/>3V00@000000?ooo`3oool000001`3oool00`000000/>3V0;3PiP0C0;3PiP03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0000000<00000103oool00`000000/>3V0;3PiP0A0;3PiP030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`0000004@2`h>H2000000L0oooo00<000000?ooo`3oool02@3oool7000000D0
oooo00<000000?ooo`3oool03P3oool00`000000/>3V0;3PiP060;3PiP040000003oool0oooo0000
00D0oooo00<000000;3PiP2`h>H03@2`h>H2000000H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`0000000`0000060;3P
iP800000503oool2000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00h0oooo00<000000;3PiP2`h>H01P2`h>H01@000000oooo0?ooo`3oool0
000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`L000001@3oool0
0`000000oooo0?ooo`0B0?ooo`003@3oool010000000oooo0?ooo`00000A0;3PiP800000502`h>H0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool0
0`000000/>3V0;3PiP070;3PiP040000003oool0oooo000000L0oooo0P00000C0;3PiP800000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo0`0000070?ooo`030000002`
h>H0/>3V0180/>3V00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000A0;3PiP800000
1`3oool00`000000oooo0?ooo`0:0?ooo`8000002@3oool00`000000oooo0?ooo`0=0?ooo`030000
002`h>H0/>3V00L0/>3V00@000000?ooo`3oool000001P3oool00`000000/>3V0;3PiP0:0;3PiP80
0000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03P3oool4000000/0/>3V00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`80
0000202`h>H010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo000=0?ooo`04
0000003oool0oooo00000140/>3V0P00000C0;3PiP800000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00d0oooo00<000000;3PiP2`h>H0202`h>H2000000P0oooo0P00000C0;3P
iP030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00H0oooo00<000000;3PiP2`h>H0502`h>H00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?oo
o`040000003oool0oooo00000140/>3V0P0000080?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000002`h>H0/>3V00P0/>3V0P000008
0?ooo`030000002`h>H0/>3V00P0/>3V0P0000080?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000d0/>3V00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000002`h>H0/>3V00P0/>3V00<00000
0?ooo`000000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo0P000008
0?ooo`030000003oool0oooo0140oooo000=0?ooo`80000000<0oooo0000002`h>H04@2`h>H20000
0180/>3V00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00d0oooo00<000000;3PiP2`h>H0202`h>H2000000P0oooo00<000000?ooo`0000004@2`h>H20000
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`8000001`3oool00`00
0000/>3V0;3PiP0E0;3PiP030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo0P0000000`3oool000000;3PiP0A0;3P
iP030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00`0oooo00<000000;3PiP2`h>H0202`h>H2000000T0oooo0P0000070;3P
iP8000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0000000>0;3PiP030000003oool0oooo00/0oooo0P0000090?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?oo
o`030000002`h>H0/>3V00P0/>3V0P0000090?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo000=0?ooo`80
000000<0oooo0000002`h>H0402`h>H2000000030?ooo`000000/>3V00l0/>3V0P0000050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000/>3V0;3PiP080;3PiP03
0000003oool0oooo00L0oooo00<000000?ooo`0000004@2`h>H00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool2000000H0oooo00<000000;3PiP2`
h>H05`2`h>H00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0;0?ooo`80000000<0oooo0000002`h>H04@2`h>H00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0<0?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool02P3oool8000000T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0
oooo0P00000@0;3PiP030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000
/>3V0;3PiP090;3PiP030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool000d0oooo
00@000000?ooo`00000000004@2`h>H200000080oooo00<000000;3PiP2`h>H0302`h>H2000000H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000002`h>H0/>3V00P0
/>3V00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000?0;3PiP8000001P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000001@3oool00`00
0000/>3V0;3PiP0G0;3PiP030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00@000000?ooo`00000000004P2`h>H0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo0P0000060?ooo`030000003oool0
oooo00/0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00`0oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00/0oooo0P0000090;3PiP030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool0
00d0oooo00@000000?ooo`00000000004@2`h>H2000000<0oooo00<000000;3PiP2`h>H02P2`h>H2
000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000002`h>H0
/>3V00L0/>3V0P0000090?ooo`040000003oool0oooo0?ooo`800000302`h>H2000000L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000@0oooo00<0
00000;3PiP2`h>H06@2`h>H00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0000000000140/>3V
0P00000:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0;0?ooo`030000002`h>H0/>3V00L0/>3V0P00000@0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo
00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo
0P0000090;3PiP030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0>0?ooo`8000001@3oool00`000000oooo0?ooo`0?0?ooo`003@3oool010000000oooo0?oo
o`00000A0;3PiP800000103oool2000000X0/>3V0P0000070?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02`3oool2000000P0/>3V00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`030?ooo`8000002@2`h>H00`000000oooo000000070?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000030?ooo`030000002`h>H0/>3V01T0
/>3V00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000A0;3PiP8000002P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool20000
00P0/>3V00<000000?ooo`3oool03@3oool2000000`0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000;3PiP2`h>H0402`h>H00`00
0000oooo0?ooo`040?ooo`800000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo000000070;3PiP030000003oool0oooo
00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool00P00000?0;3PiP03
0000003oool0000000H0oooo2`0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo000000060;3PiP8000002P3oool00`000000oooo0?ooo`050?ooo`T0
000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0
oooo00@000000?ooo`3oool000000`3oool00`000000/>3V0;3PiP0I0;3PiP050000003oool0oooo
0?ooo`000000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00P00000?0;3PiP030000003oool0000000/0oooo00<000000?ooo`3oool02@3oool8
000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo000000060;3PiP8000003P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0:0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`090?ooo`040000003oool0oooo000000H0/>3V00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo1P0000000`3oool000000?oo
o`030?ooo`030000003oool0oooo00h0oooo000=0?ooo`050000003oool0oooo0?ooo`0000003`2`
h>H00`000000oooo0000000@0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0oooo
1P00000<0?ooo`030000003oool0oooo00L000002`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00H0oooo00@000000?ooo`3oool0oooo1P00000<0?ooo`070000003oool0oooo0?oo
o`000000oooo0000000M0;3PiP040000003oool0oooo000000P0oooo00@000000?ooo`3oool0oooo
1P00000;0?ooo`050000003oool0oooo0?ooo`0000003`2`h>H00`000000oooo0000000;0?ooo`03
0000003oool0oooo00L0oooo0P0000060;3PiP<000000`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00L000003P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0
oooo00@000000?ooo`3oool0oooo1P00000<0?ooo`030000002`h>H0/>3V0100/>3V00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00@000000?oo
o`3oool0oooo1P00000;0?ooo`040000003oool0oooo0?ooo`H00000303oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00L0oooo0P0000060;3PiP@000000P3oool00`000000oooo0?oo
o`0>0?ooo`003@3oool010000000oooo0?ooo`3oool2000000d0/>3V00@000000?ooo`3oool00000
403oool00`000000oooo0?ooo`060?ooo`040000003oool00000000000D0/>3V0P00000;0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`00000000001@2`h>H2000000/0oooo00L000000?oo
o`3oool0oooo0000003oool0000001d0/>3V00<000000?ooo`0000002@3oool010000000oooo0000
000000050;3PiP8000002P3oool010000000oooo0?ooo`3oool2000000d0/>3V00@000000?ooo`3o
ool00000303oool00`000000oooo0?ooo`040?ooo`8000002P2`h>H200000080oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000D0/>3V0P00000;
0?ooo`030000002`h>H0/>3V0100/>3V00D000000?ooo`3oool0oooo0000000>0?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`00000000001@2`h>H2000000X0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
103oool2000000X0/>3V0`0000020?ooo`030000003oool0oooo00d0oooo000=0?ooo`030000003o
ool0oooo0080oooo0P00000;0;3PiP050000003oool0oooo0?ooo`0000003`3oool00`000000oooo
0?ooo`070?ooo`800000202`h>H00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo
0P0000080;3PiP030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000001d0/>3V
00<000000?ooo`0000002@3oool2000000P0/>3V00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`<000002P2`h>H01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3o
ool00`3oool00`000000/>3V0;3PiP0<0;3PiP040000003oool0oooo000000X0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`8000003`3oool00`000000oooo0?ooo`070?oo
o`800000202`h>H00`000000oooo0?ooo`090?ooo`030000002`h>H0/>3V00l0/>3V00<000000?oo
o`3oool00P00000?0?ooo`030000003oool0oooo00L0oooo0P0000080;3PiP030000003oool0oooo
00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3PiP0<0;3PiP80000000<0oooo0000
003oool03P3oool000d0oooo00<000000?ooo`3oool00P3oool010000000oooo0000000000070;3P
iP800000103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo0P0000090;3P
iP030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool2000000P0/>3V0P00000:0?oo
o`030000003oool0oooo0080oooo0P00000M0;3PiP8000002P3oool00`000000/>3V0;3PiP070;3P
iP8000002@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0/>3V0P000004
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000/>3V0;3PiP0<
0;3PiP@000002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`800000202`h>H2000000X0oooo00<00000
0;3PiP2`h>H03`2`h>H00`000000oooo0000000@0?ooo`030000003oool0oooo00P0oooo00<00000
0;3PiP2`h>H01`2`h>H2000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000/>3V0;3PiP0<
0;3PiP030000003oool00000008000003P3oool000d0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`07000000H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?oo
o`030000002`h>H0/>3V00P0/>3V0P0000090?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000;3P
iP2`h>H0202`h>H00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000;3P
iP2`h>H06`2`h>H2000000X0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`0000060?ooo`030000003oool0oooo
00/0oooo00D000000?ooo`3oool0oooo0000000@0;3PiP040000003oool00000000000T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0203oool00`000000/>3V0;3PiP080;3PiP030000003oool0oooo00P0oooo0P00
000?0;3PiP030000003oool000000140oooo00<000000?ooo`3oool0203oool00`000000/>3V0;3P
iP080;3PiP030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000@0;3PiP040000
003oool0oooo000000h0oooo000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000;3PiP2`h>H0
2@2`h>H00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000;3PiP2`h>H0
202`h>H2000000T0oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3PiP0K0;3PiP030000
003oool0oooo00T0oooo00<000000;3PiP2`h>H0202`h>H2000000P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
4P2`h>H00`000000oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000;3PiP2`h>H0
202`h>H2000000T0oooo0P00000?0;3PiP8000004@3oool00`000000oooo0?ooo`090?ooo`030000
002`h>H0/>3V00P0/>3V0P0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool000000180/>3V00@000000?ooo`3oool0
00003@3oool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000/>3V0;3PiP090;3PiP030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000/>3V0;3PiP080;3PiP800000
2@3oool00`000000oooo0?ooo`040?ooo`030000002`h>H0/>3V01X0/>3V00<000000?ooo`3oool0
2@3oool00`000000/>3V0;3PiP080;3PiP800000203oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000B0;3PiP030000
003oool0000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`800000
4P3oool00`000000oooo0?ooo`090?ooo`030000002`h>H0/>3V00T0/>3V00<000000?ooo`3oool0
1`3oool00`000000oooo0000000=0;3PiP8000004P3oool00`000000oooo0?ooo`090?ooo`030000
002`h>H0/>3V00P0/>3V0P0000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool000000180/>3V00@000000?ooo`3oool0
00003@3oool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool2000000T0/>3V00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H000001P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00X0oooo0P0000090;3PiP030000003oool0oooo00P0oooo
00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP0I0;3PiP030000003oool0oooo00X0oooo
00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`8000004P2`h>H2000000X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool02P3oool2000000T0/>3V00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`02000000T0/>3V0P00000C0?ooo`030000003oool0oooo00X0oooo00<000000;3PiP2`h>H0
202`h>H00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`0000060?ooo`030000003oool0oooo00d0oooo0P00000B0;3PiP030000003oool0000000h0oooo
000=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo0P0000090;3PiP030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0000000000060;3PiP800000103oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00X0oooo0P0000090;3PiP030000003oool0oooo00P0oooo
00<000000?ooo`3oool0103oool2000001X0/>3V00<000000?ooo`3oool02P3oool00`000000/>3V
0;3PiP080;3PiP030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00d0oooo0P00000B0;3PiP8000002P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000P00000@0?ooo`030000
003oool0oooo00X0oooo0P0000090;3PiP030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool00`000000/>3V0;3PiP050;3PiP80000000@0oooo0000000000000000403oool00`000000
oooo0?ooo`0:0?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`020?ooo`040000003oool00000000000L0/>3V0P0000040?ooo`030000003oool0oooo
00d0oooo0P00000B0;3PiP030000003oool0000000h0oooo000=0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`0000001`2`h>H00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo0P00000:0;3PiP8000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`0000001`2`h>H00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0
oooo00<000000;3PiP2`h>H05`2`h>H00`000000oooo0?ooo`0;0?ooo`800000202`h>H00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0>0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0`0000030;3PiP@000002`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0000000L0/>3V00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`X000000`2`h>H4000000/0oooo00<000000?ooo`3oool02`3oool2000000P0
/>3V00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`8000002`2`h>H200000080
oooo00<000000?ooo`3oool03P3oool00`000000/>3V0;3PiP0@0;3PiP8000003`3oool000d0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000060;3PiP030000003oool0oooo00T0
oooo00D000000?ooo`3oool0oooo0000000>0;3PiP030000003oool0000000`0oooo00<000000?oo
o`3oool02`3oool010000000oooo0?ooo`0000060;3PiP030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01@3oool2000001L0/>3V0P00000=0?ooo`030000003oool0000000H0/>3V0P00000:
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>
0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3o
ool0000000H0oooo0`0000090;3PiP030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`0000060;3PiP030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool3000000T0/>3V00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0000000L0/>3V00<000000?ooo`3oool0203oool010000000oooo0?ooo`3oool2000000h0
/>3V00<000000?ooo`000000403oool00`000000/>3V0;3PiP0@0;3PiP8000003`3oool000d0oooo
00@000000?ooo`3oool0oooo1P00000<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02`3oool010000000oooo0?ooo`3oool6000000`0oooo00D000000?ooo`3oool0oooo0000000>
0;3PiP030000003oool0000000/0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`3o
ool6000000`0oooo00<000000?ooo`3oool01`00000F0;3PiP8000003P3oool00`000000oooo0?oo
o`07000000/0oooo00@000000?ooo`3oool0oooo1P00000<0?ooo`030000003oool0oooo00l0oooo
00<000000;3PiP2`h>H03P2`h>H00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`00
00001@3oool2000000`0/>3V00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`04
0000003oool0oooo0?ooo`H00000303oool00`000000oooo0?ooo`070?ooo`800000302`h>H00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`00000;0?oo
o`040000003oool0oooo0?ooo`8000003P2`h>H00`000000oooo0000000A0?ooo`030000002`h>H0
/>3V00h0/>3V0P00000@0?ooo`003@3oool010000000oooo0000000000050;3PiP8000002`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000100/>3V0P00000;0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`<000001P2`
h>H2000001D0/>3V0P00000>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3o
ool010000000oooo0000000000050;3PiP8000002`3oool00`000000oooo0?ooo`040?ooo`P00000
0`3oool00`000000/>3V0;3PiP0>0;3PiP030000003oool0oooo00X0oooo00@000000?ooo`3oool0
00001@3oool00`000000/>3V0;3PiP0=0;3PiP8000001P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`03
0000002`h>H0/>3V00d0/>3V0P0000060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00800000402`h>H2000000H0
oooo200000030?ooo`030000002`h>H0/>3V00h0/>3V0P00000@0?ooo`003@3oool2000000P0/>3V
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
1@0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool010000000oooo
00000000000@0;3PiP8000002P3oool00`000000oooo0?ooo`020?ooo`D000001P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000;3PiP2`h>H01`2`h>H2000001<0
/>3V0P0000040?ooo`D000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0
oooo0P0000080;3PiP030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000P0
/>3V0P0000000`3oool000000000000>0;3PiP030000003oool0oooo00/0oooo00@000000?ooo`3o
ool000000`3oool300000100/>3V00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`D000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0103oool200000140/>3V00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`D000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00@000000?oo
o`3oool000004@2`h>H2000000@0oooo0P0000080;3PiP80000000<0oooo0000000000003`2`h>H0
0`000000oooo0?ooo`0?0?ooo`003@3oool2000000P0/>3V0P00000:0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`0000000`0000050;3PiP030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool000000180/>3V00<000000?oo
o`3oool0203oool00`000000oooo00000002000000D0/>3V0P0000040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02`3oool00`000000/>3V0;3PiP070;3PiP030000003oool00000
0140/>3V00<000000?ooo`000000100000050;3PiP800000103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00X0oooo0P0000080;3PiP8000002P3oool00`000000oooo0?ooo`020000
00`0/>3V0`00000>0;3PiP030000003oool0oooo00/0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0000000B0;3PiP030000003oool0oooo0080oooo00<000000?ooo`0000000P0000050;3P
iP800000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00`3oool2000001<0/>3V00<000000?ooo`3oool00P3oool00`000000oooo000000020000
00D0/>3V0P0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool01000
0000oooo00000000000A0;3PiP8000000P3oool2000000`0/>3V0`00000?0;3PiP030000003oool0
oooo00l0oooo000=0?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`8000002P2`h>H01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0000000B0;3PiP030000003oool0oooo00L0oooo0`00000:
0;3PiP050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0<0?ooo`030000002`
h>H0/>3V00P0/>3V00@000000?ooo`00000000003@2`h>H2000000030?ooo`000000000000/0/>3V
00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00/0oooo00<000000;3PiP2`
h>H0202`h>H00`000000oooo0?ooo`080?ooo`030000003oool0000000l0/>3V00<000000?ooo`00
0000302`h>H2000000d0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`00000B0;3P
iP040000003oool0oooo0?ooo`<000002P2`h>H01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0000001<0/>3V00@0
00000?ooo`3oool0oooo0`00000:0;3PiP050000003oool0oooo0?ooo`0000001P3oool00`000000
oooo0?ooo`0;0?ooo`040000003oool0000000000140/>3V0P0000000`3oool000000;3PiP0>0;3P
iP030000003oool0000000`0/>3V0P00000B0?ooo`003@3oool00`000000/>3V0;3PiP080;3PiP80
00002@3oool00`000000oooo0?ooo`060?ooo`800000302`h>H010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo00`0oooo0`00000B0;3PiP030000003oool0oooo00L0oooo00<000000;3P
iP2`h>H02`2`h>H010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00`0oooo00<00000
0;3PiP2`h>H0202`h>H010000000oooo0?ooo`3oool2000000T0/>3V0P0000030?ooo`030000002`
h>H0/>3V00/0/>3V00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`0;0?ooo`030000
002`h>H0/>3V00P0/>3V0P0000090?ooo`030000003oool000000100/>3V0`00000:0;3PiP800000
3P3oool200000080oooo00@000000?ooo`3oool00000502`h>H010000000oooo0?ooo`00000=0;3P
iP040000003oool0oooo000000H0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000;3PiP2`h>H04P2`h>H010000000oooo0?ooo`00000=0;3PiP040000
003oool0oooo000000H0oooo00<000000?ooo`3oool02`3oool2000000030?ooo`000000/>3V0140
/>3V00<000000?ooo`000000402`h>H3000000X0/>3V00<000000?ooo`0000004P3oool000d0oooo
00<000000;3PiP2`h>H0202`h>H2000000T0oooo00<000000?ooo`3oool01P3oool00`000000/>3V
0;3PiP0<0;3PiP030000003oool0000000D0oooo00<000000?ooo`3oool03@3oool300000180/>3V
00<000000?ooo`3oool01P3oool2000000h0/>3V00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`0=0?ooo`030000002`h>H0/>3V00P0/>3V0P0000040?ooo`T00000103oool2000000h0/>3V
00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0<0?ooo`030000002`h>H0/>3V00P0/>3V
0P0000090?ooo`8000004P2`h>H4000000H0/>3V0P0000000`3oool000000?ooo`0=0?ooo`@00000
0`3oool00`000000/>3V0;3PiP0B0;3PiP040000003oool00000000000h0/>3V00<000000?ooo`00
00001@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool00000000000<0oooo00<000000;3P
iP2`h>H04P2`h>H010000000oooo00000000000>0;3PiP030000003oool0000000D0oooo00<00000
0?ooo`3oool0303oool2000000030?ooo`000000/>3V0140/>3V0P00000B0;3PiP@000001P2`h>H2
000000030?ooo`000000oooo0180oooo000=0?ooo`030000002`h>H0/>3V00P0/>3V00<000000?oo
o`000000203oool00`000000oooo0?ooo`060?ooo`030000002`h>H0/>3V00d0/>3V0P0000050?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`0000004P2`h>H00`000000oooo0?ooo`060?oo
o`030000002`h>H0/>3V00h0/>3V0P0000050?ooo`030000003oool0oooo00d0oooo00<000000;3P
iP2`h>H01`2`h>H00`000000oooo0000000A0?ooo`030000002`h>H0/>3V00h0/>3V0P0000050?oo
o`030000003oool0oooo00`0oooo0P0000090;3PiP030000003oool0000000P0oooo0P00000B0;3P
iP8000000P3oool600000080oooo00<000000?ooo`3oool03@3oool2000000D0oooo00<000000;3P
iP2`h>H04P2`h>H00`000000oooo0000000@0;3PiP8000001@3oool00`000000oooo0?ooo`0=0?oo
o`800000103oool00`000000/>3V0;3PiP0C0;3PiP030000003oool000000100/>3V0P0000050?oo
o`030000003oool0oooo00`0oooo00@000000?ooo`3oool000004P2`h>H200000180/>3V0P000002
0?ooo`H000000`3oool00`000000oooo0?ooo`0A0?ooo`003@3oool2000000T0/>3V00<000000?oo
o`000000203oool00`000000oooo0?ooo`050?ooo`030000002`h>H0/>3V00h0/>3V0P0000040?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`0000004P2`h>H00`000000oooo0?ooo`050?oo
o`800000402`h>H2000000@0oooo00<000000?ooo`3oool03P3oool00`000000/>3V0;3PiP070;3P
iP040000003oool0oooo000000l0oooo0P00000@0;3PiP800000103oool00`000000oooo0?ooo`0=
0?ooo`8000002@2`h>H00`000000oooo000000080?ooo`030000002`h>H0/>3V0180/>3V0P000009
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP0B
0;3PiP<00000402`h>H2000000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03
0?ooo`030000002`h>H0/>3V01<0/>3V0`00000@0;3PiP800000103oool00`000000oooo0?ooo`0=
0?ooo`040000003oool0oooo00000140/>3V0P00000D0;3PiP8000002@3oool00`000000oooo0?oo
o`0B0?ooo`003P3oool2000000L0/>3V00D000000?ooo`3oool0oooo000000070?ooo`030000003o
ool0oooo00D0oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`0000004@2`h>H00`000000oooo0?ooo`050?ooo`030000002`
h>H0/>3V0100/>3V00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000002`
h>H0/>3V00D0/>3V00D000000?ooo`3oool0oooo0000000?0?ooo`030000002`h>H0/>3V00l0/>3V
0P0000040?ooo`030000003oool0oooo00h0oooo0P0000070;3PiP050000003oool0oooo0?ooo`00
00001`3oool00`000000/>3V0;3PiP0B0;3PiP800000203oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00<0oooo00<000000;3PiP2`h>H04P2`h>H200000180/>3V00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000;3PiP2`
h>H04`2`h>H200000180/>3V00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool000000140/>3V0P00000D0;3PiP8000002@3oool00`000000oooo0?ooo`0B0?ooo`00
3`3oool2000000H0/>3V00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00@0
oooo00<000000;3PiP2`h>H0402`h>H01@000000oooo0?ooo`3oool0000001<0oooo0P00000@0;3P
iP8000001P3oool200000180/>3V00D000000?ooo`3oool0oooo0000000C0?ooo`8000001@2`h>H0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo0P00000A0;3PiP8000000`3oool0
0`000000oooo0?ooo`0@0?ooo`8000001P2`h>H01@000000oooo0?ooo`3oool0000000L0oooo00<0
00000;3PiP2`h>H04`2`h>H2000000L0oooo00<000000?ooo`3oool0403oool2000000<0oooo00<0
00000;3PiP2`h>H04P2`h>H200000180/>3V00D000000?ooo`3oool0oooo0000000C0?ooo`800000
0P3oool00`000000/>3V0;3PiP0C0;3PiP8000004P2`h>H01@000000oooo0?ooo`3oool000000180
oooo0P00000@0;3PiP030000003oool0000001D0/>3V0P0000070?ooo`030000003oool0oooo01<0
oooo000@0?ooo`L000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000;3PiP2`h>H0402`h>H01@000000oooo0?ooo`3oool0000001D0oooo00<000000;3PiP2`
h>H03@2`h>H2000000H0oooo0P00000B0;3PiP050000003oool0oooo0?ooo`000000503oool60000
00D0oooo00<000000?ooo`3oool02`3oool200000180/>3V00D000000?ooo`3oool0oooo0000000D
0?ooo`H000001@3oool00`000000oooo0?ooo`040?ooo`030000002`h>H0/>3V01<0/>3V0P000007
0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000502`h>H200000180/>3V00D0
00000?ooo`3oool0oooo0000000E0?ooo`030000003oool0000001D0/>3V0P00000B0;3PiP050000
003oool0oooo0?ooo`000000503oool00`000000/>3V0;3PiP0=0;3PiP030000003oool0000001D0
/>3V0P0000070?ooo`030000003oool0oooo01<0oooo000B0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`8000004P2`h>H010000000oooo
0?ooo`00000G0?ooo`030000002`h>H0/>3V00X0/>3V0P0000000`3oool000000?ooo`040?ooo`03
0000003oool000000180/>3V00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`0000004P2`h>H010000000oooo0?ooo`00000F
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP0C
0;3PiP030000003oool0000000D0oooo00<000000?ooo`3oool0503oool00`000000oooo0000000C
0;3PiP<000004P2`h>H010000000oooo0?ooo`00000G0?ooo`030000003oool0000001<0/>3V00<0
00000?ooo`0000004P2`h>H010000000oooo0?ooo`00000F0?ooo`030000002`h>H0/>3V00/0/>3V
00@000000?ooo`3oool000005@2`h>H00`000000oooo000000050?ooo`030000003oool0oooo01@0
oooo000C0?ooo`800000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
0P00000B0;3PiP040000003oool0oooo000001P0oooo00<000000;3PiP2`h>H0202`h>H01@000000
oooo0?ooo`3oool0000000D0oooo00<000000?ooo`0000004P2`h>H010000000oooo0?ooo`00000H
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000B
0;3PiP040000003oool0oooo000001L0oooo0P0000080?ooo`030000003oool0oooo00<0oooo00<0
00000;3PiP2`h>H04P2`h>H2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05@3o
ool2000001<0/>3V0`00000B0;3PiP040000003oool0oooo000001P0oooo0P00000C0;3PiP030000
003oool000000180/>3V00@000000?ooo`3oool000005`3oool2000000X0/>3V00D000000?ooo`3o
ool0oooo0000000E0;3PiP030000003oool0000000D0oooo00<000000?ooo`3oool0503oool001D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000004P2`h>H00`000000oooo0000000J0?ooo`8000001P2`h>H3000000<0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000B0;3PiP030000003oool00000
01X0oooo0P0000070?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000004P2`h>H0
0`000000oooo0000000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool0
0`000000/>3V0;3PiP0B0;3PiP050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`0G0?ooo`8000004@2`h>H2000000030?ooo`000000/>3V0140/>3V00<000000?ooo`0000006P3o
ool200000140/>3V00@000000?ooo`3oool000004P2`h>H00`000000oooo0000000J0?ooo`030000
002`h>H0/>3V00D0/>3V0P0000040?ooo`030000002`h>H0/>3V01<0/>3V00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`0E0?ooo`005P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000A0;3PiP03
0000003oool0000001`0oooo1P0000060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000@0;3PiP80000000<0oooo0000003oool06`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`3oool000004@2`h>H2000000030?ooo`000000
oooo01X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000002`h>H0
/>3V0180/>3V00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo01P0oooo0P00
000@0;3PiP050000003oool0oooo0?ooo`000000402`h>H2000000030?ooo`000000oooo01X0oooo
0P00000?0;3PiP8000000P3oool00`000000/>3V0;3PiP0?0;3PiP80000000<0oooo0000003oool0
6P3oool7000000H0oooo00<000000;3PiP2`h>H04P2`h>H01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool05@3oool001L0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000/>3V0;3PiP0>0;3PiP<0
00007P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000/>3V0;3PiP0>0;3PiP<000007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00D000000?ooo`3oool0oooo0000000@0;3PiP040000003oool00000000001d0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000002`h>H0/>3V0180/>3V00<0
00000?ooo`3oool00P3oool00`000000oooo0000000L0?ooo`8000003P2`h>H00`000000oooo0?oo
o`020?ooo`030000002`h>H0/>3V00h0/>3V0`00000M0?ooo`8000003P2`h>H01@000000oooo0?oo
o`3oool000000100/>3V00@000000?ooo`00000000007@3oool00`000000oooo0?ooo`090?ooo`03
0000002`h>H0/>3V0180/>3V00<000000?ooo`3oool00P3oool00`000000oooo0000000H0?ooo`00
603oool2000000D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080
oooo00<000000;3PiP2`h>H03@2`h>H3000001l0oooo00<000000?ooo`3oool01`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000;3PiP2`h>H03P2`h>H3000001l0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000;3P
iP2`h>H03@2`h>H010000000oooo00000000000N0?ooo`8000001@3oool010000000oooo0?ooo`3o
ool200000180/>3V00<000000?ooo`3oool00`3oool00`000000oooo0000000M0?ooo`8000002`2`
h>H3000000@0oooo00<000000;3PiP2`h>H03P2`h>H3000001h0oooo0P00000;0;3PiP<00000103o
ool00`000000/>3V0;3PiP0=0;3PiP040000003oool00000000001h0oooo0P0000090?ooo`800000
4P2`h>H00`000000oooo0?ooo`030?ooo`030000003oool0000001P0oooo000J0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo
00<000000;3PiP2`h>H02`2`h>H00`000000oooo0000000Q0?ooo`030000003oool0oooo00H0oooo
00@000000?ooo`3oool000001P3oool2000000d0/>3V00<000000?ooo`0000008@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
/>3V0;3PiP0;0;3PiP040000003oool0oooo00000240oooo00<000000?ooo`3oool00P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000004@2`h>H00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo01h0oooo0P0000070;3PiP80000000<0oooo0000003oool01@3oool2000000d0/>3V00<0
00000?ooo`0000008@3oool2000000L0/>3V0P0000000`3oool000000?ooo`050?ooo`030000002`
h>H0/>3V00/0/>3V00@000000?ooo`3oool000008@3oool00`000000oooo0?ooo`060?ooo`030000
003oool000000140/>3V00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`006`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
1@3oool00`000000/>3V0;3PiP0:0;3PiP<000008P3oool2000000H0oooo00@000000?ooo`3oool0
0000203oool00`000000/>3V0;3PiP090;3PiP@000008P3oool2000000<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`8000002`2`h>H400000280oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`030000002`h>H0/>3V00d0/>3V00<000000?oo
o`3oool00`3oool300000240oooo200000030?ooo`030000003oool0oooo00H0oooo00<000000;3P
iP2`h>H02@2`h>H400000280oooo200000030?ooo`030000003oool0oooo00D0oooo0P00000;0;3P
iP@000008P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000l0/>3V00<00000
0?ooo`3oool00`3oool3000001T0oooo000L0?ooo`8000000P3oool01P000000oooo0?ooo`000000
oooo000000T0oooo0P0000060;3PiP@000009`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000X0oooo0P0000060;3PiP@000009`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool0203oool00`000000/>3V0;3PiP050;3PiP@000009P3oool200000080oooo
00@000000?ooo`3oool000000P3oool00`000000/>3V0;3PiP0<0;3PiP030000003oool0oooo00@0
00009P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0P0000060;3PiP@0
00009`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000;3PiP2`
h>H01@2`h>H4000002H0oooo0P0000050?ooo`040000003oool0oooo000000h0/>3V00<000000?oo
o`3oool01000000L0?ooo`007P3oool020000000oooo0?ooo`000000oooo0000003oool000002`3o
ool8000002X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000<0?ooo`P00000:P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00T0oooo2000000[0?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000/>3V0;3PiP090;3PiPD00000:`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo2000000Z0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02@3oool9000002X0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000/0/>3V1@00000P0?ooo`007`3oool010000000oooo0000003oool2
000000T0oooo1@00000a0?ooo`040000003oool0oooo0?ooo`8000002P3oool400000380oooo00H0
00000?ooo`3oool000000?ooo`00000:0?ooo`@00000<P3oool01@000000oooo0000003oool00000
00@0oooo100000030;3PiPD00000<03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo1000000b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool40000
0380oooo00D000000?ooo`3oool0oooo000000040?ooo`@000000`2`h>H5000002@0oooo000P0?oo
o`D000001@3oool4000003L0oooo0P0000000`3oool00000000000050?ooo`D00000=`3oool30000
00030?ooo`000000oooo00@0oooo1@00000g0?ooo`@000001P3oool5000003H0oooo0P0000020?oo
o`030000003oool0oooo00<0oooo1@00000g0?ooo`8000000P3oool00`000000oooo0?ooo`030?oo
o`D00000=`3oool2000000030?ooo`000000oooo00D0oooo1@00000Y0?ooo`008P3oool200000080
oooo1000000m0?ooo`8000000P3oool4000003h0oooo0P0000020?ooo`@00000?P3oool200000080
oooo1000000m0?ooo`8000000P3oool4000003h0oooo0P0000020?ooo`@00000?P3oool200000080
oooo1000000^0?ooo`008`3oool300000480oooo0`0000130?ooo`<00000@`3oool300000480oooo
0`0000130?ooo`<00000@`3oool300000380oooo003o0?oooo/0oooo003o0?oooo/0oooo003o0?oo
oo/0oooo003o0?oooo/0oooo003o0?oooo/0oooo003o0?oooo/0oooo003o0?oooo/0oooo003o0?oo
oo/0oooo003o0?oooo/0oooo000S0?ooo`<00000@P3oool3000004<0oooo0`0000130?ooo`<00000
@P3oool3000004<0oooo0`0000130?ooo`<00000<P3oool00280oooo2000000m0?ooo`<0000000<0
oooo0000000000000P00000n0?ooo`8000000P3oool4000003h0oooo2000000m0?ooo`<0000000<0
oooo0000000000000P00000n0?ooo`P00000?P3oool010000000oooo0000003oool4000002h0oooo
000P0?ooo`8000001@2`h>H00`000000oooo0?ooo`04000003L0oooo0P0000020?ooo`<000000`3o
ool5000003L0oooo0`0000020?ooo`X00000=`3oool2000000D0/>3V00<000000?ooo`3oool01@00
000f0?ooo`<0000000@0oooo00000000000000000`3oool5000003L0oooo0`0000050;3PiP030000
003oool0000000@00000=`3oool2000000<0oooo0P0000030?ooo`D00000:@3oool001l0oooo00<0
00000;3PiP2`h>H01P2`h>H00`000000oooo0?ooo`030?ooo`D00000<@3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000L0oooo1000000b0?ooo`060000003oool0oooo0000003o
ool000001`2`h>H2000000030?ooo`000000000000800000<P3oool00`000000/>3V0;3PiP060;3P
iP030000003oool0oooo00@0oooo1000000a0?ooo`060000003oool0oooo0000003oool000000P3o
ool00`000000oooo0?ooo`050?ooo`@00000<P3oool2000000P0/>3V00<000000?ooo`3oool00`3o
ool400000380oooo1`0000000`3oool000000?ooo`060?ooo`@000009@3oool001h0oooo0P000008
0;3PiP030000003oool0oooo00P0oooo1000000/0?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool000002P3oool5000002`0oooo00<000000?ooo`3oool00`00000:0;3PiP8000000`3o
ool5000002`0oooo0P0000090;3PiP030000003oool0oooo00L0oooo1@00000[0?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool000002P3oool5000002`0oooo0P0000090;3PiP03
0000003oool0oooo00L0oooo1@00000/0?ooo`8000001P2`h>H3000000X0oooo1@00000P0?ooo`00
703oool3000000X0/>3V00<000000?ooo`3oool02`3oool4000002L0oooo00<000000?ooo`3oool0
1@3oool01@000000oooo0?ooo`3oool0000000h0oooo1000000W0?ooo`050000003oool0oooo0?oo
o`0000003P2`h>H00`000000oooo0?ooo`050?ooo`@000009P3oool3000000/0/>3V00<000000?oo
o`3oool02`3oool4000002H0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000003P3oool4000002L0oooo00<000000?ooo`0000002P2`h>H00`000000oooo0?oo
o`0;0?ooo`@000009P3oool2000000X0/>3V0P00000>0?ooo`@00000703oool001/0oooo00@00000
0?ooo`3oool000002P2`h>H200000100oooo0`00000R0?ooo`80000000@0oooo0000000000000000
1@3oool010000000oooo0?ooo`3oool2000000`0oooo0P0000020;3PiP<000008P3oool2000000<0
oooo0P00000>0;3PiP030000003oool0oooo00T0oooo0`00000R0?ooo`040000003oool0oooo0000
00/0/>3V00<000000?ooo`3oool03`3oool300000240oooo0P0000030?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool0oooo0P00000=0?ooo`80000000@0/>3V00000000000000008P3o
ool200000080oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`0?0?ooo`<000008P3o
ool00`000000/>3V0;3PiP0<0;3PiP800000303oool2000000030;3PiP0000000000008000006@3o
ool001X0oooo00D000000?ooo`3oool0oooo0000000:0;3PiP800000303oool400000080oooo00<0
00000?ooo`3oool07`3oool010000000oooo0000000000030;3PiP@0000000<0oooo0000003oool0
103oool00`000000oooo0?ooo`080?ooo`030000002`h>H0/>3V00@0/>3V0P00000P0?ooo`030000
003oool0oooo00<0oooo00<000000;3PiP2`h>H03P2`h>H00`000000oooo0?ooo`090?ooo`800000
8@3oool01@000000oooo0?ooo`3oool0000000X0/>3V0P00000=0?ooo`@0000000<0oooo00000000
0000803oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`080?ooo`8000001@2`h>H200000200oooo00<000000?ooo`3o
ool00P3oool00`000000/>3V0;3PiP080;3PiP030000003oool0oooo00/0oooo100000020?ooo`03
0000003oool0oooo01l0oooo0P00000>0;3PiP030000003oool0000000T0oooo0P0000050;3PiP80
00006@3oool001T0oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3PiP070;3PiP030000
003oool0oooo00L0oooo100000060?ooo`8000007`3oool3000000T0/>3V00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`060?ooo`030000002`h>H0/>3V00H0/>3V00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`030?ooo`030000002`h>H0/>3V00l0/>3V00<000000?ooo`3oool0
1`3oool2000000030?ooo`000000000001l0oooo00<000000?ooo`3oool00`3oool00`000000/>3V
0;3PiP070;3PiP030000003oool0oooo00L0oooo1@0000030?ooo`80000000<0oooo000000000000
7P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000002`h>H0/>3V00H0/>3V00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`030?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool0
1`3oool8000000<0oooo00<000000?ooo`3oool07@3oool200000100/>3V00<000000?ooo`000000
1`3oool00`000000/>3V0;3PiP060;3PiP800000603oool001L0oooo0P0000060?ooo`030000002`
h>H0/>3V00H0/>3V00<000000?ooo`3oool00`3oool5000000X0oooo0P00000N0?ooo`800000302`
h>H2000000H0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP070;3PiP8000007@3o
ool00`000000oooo0?ooo`040?ooo`030000002`h>H0/>3V00l0/>3V00<000000?ooo`3oool01P3o
ool010000000oooo0?ooo`3oool2000001d0oooo0P0000060?ooo`030000002`h>H0/>3V00H0/>3V
00<000000?ooo`3oool0103oool4000000L0oooo00@000000?ooo`3oool0oooo0P00000M0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000;3PiP2`h>H01`2`h>H2000001d0oooo00<000000?ooo`3o
ool0103oool00`000000/>3V0;3PiP070;3PiP030000003oool0oooo00<0oooo1`0000060;3PiP80
000000<0oooo0000003oool0703oool300000140/>3V00@000000?ooo`3oool000001P3oool00`00
0000/>3V0;3PiP070;3PiP030000003oool0oooo01H0oooo000F0?ooo`030000003oool0oooo00L0
oooo00<000000;3PiP2`h>H01@2`h>H00`000000oooo00000007000000/0oooo00<000000?ooo`00
0000703oool00`000000/>3V0;3PiP0=0;3PiP8000001P3oool2000000@0oooo00<000000;3PiP2`
h>H0202`h>H00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo0P00000B0;3PiP03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000K0?ooo`03
0000003oool0oooo00L0oooo00<000000;3PiP2`h>H01@2`h>H00`000000oooo00000004000000X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000K0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`800000103oool00`000000
/>3V0;3PiP080;3PiP030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool00`000000
/>3V0;3PiP050;3PiP030000003oool0oooo00@000000`3oool2000000X0/>3V0`00000K0?ooo`04
0000003oool0oooo00000180/>3V00<000000?ooo`3oool00P0000030?ooo`030000002`h>H0/>3V
00P0/>3V0P00000G0?ooo`005@3oool00`000000oooo0?ooo`090?ooo`8000000`2`h>H6000000H0
/>3V0P0000090?ooo`030000003oool0000001X0oooo0`00000@0;3PiP030000003oool0oooo00H0
oooo00D000000?ooo`3oool0oooo0000000:0;3PiP030000003oool0oooo01P0oooo0P0000070?oo
o`8000004P2`h>H00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000006P3oool00`000000oooo0?ooo`090?ooo`8000000`2`h>H4000000h0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0000000I0?ooo`8000001`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000000:0;3PiP030000003oool0
oooo01P0oooo0P00000:0?ooo`8000000`2`h>H5000000H0oooo00<000000;3PiP2`h>H0302`h>H0
0`000000oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`0000004P2`h>H00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000X0/>3V0P00000G0?ooo`004`3oool2000000`0oooo1@00
00000`3oool000000000000;0;3PiP<000001P3oool010000000oooo0?ooo`00000H0?ooo`030000
003oool000000180/>3V00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000090;3PiP<0
0000603oool00`000000oooo0?ooo`060?ooo`030000003oool000000180/>3V00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000001L0oooo0P00000=0?oo
o`@00000403oool2000000H0oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00
000:0;3PiP800000603oool00`000000oooo0?ooo`0;0?ooo`D000002P3oool00`000000/>3V0;3P
iP0<0;3PiP8000005`3oool2000000@0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo0?oo
o`030?ooo`030000003oool0000000X0/>3V00<000000?ooo`0000005P3oool00180oooo00<00000
0?ooo`3oool0203oool4000000D0oooo00<000000;3PiP2`h>H03P2`h>H2000000@0oooo00@00000
0?ooo`3oool000005`3oool010000000oooo0?ooo`00000B0;3PiP030000003oool0oooo00L0oooo
00<000000?ooo`0000002@2`h>H00`000000oooo0000000G0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`0000004P2`h>H00`000000oooo0?ooo`02000000L0oooo00@000000?ooo`3oool0
00005P3oool00`000000oooo0?ooo`080?ooo`D000004`3oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo000001H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`0000002P2`h>H2000001L0oooo00<000000?oo
o`3oool0203oool4000000h0oooo00<000000;3PiP2`h>H03P2`h>H00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00@0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo0?ooo`040?oo
o`8000002P2`h>H00`000000oooo0000000F0?ooo`004@3oool00`000000oooo0?ooo`040?ooo`D0
0000203oool00`000000/>3V0;3PiP0A0;3PiP050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0C0?ooo`040000003oool0oooo000001@0/>3V00<000000?ooo`3oool01`3oool2
000000P0/>3V00D000000?ooo`3oool0oooo0000000E0?ooo`<000001`3oool010000000oooo0?oo
o`00000A0;3PiP040000003oool0oooo000000T0oooo00D000000?ooo`3oool0oooo0000000D0?oo
o`030000003oool0oooo00D0oooo1000000G0?ooo`030000003oool0oooo00L0oooo00D000000?oo
o`3oool0oooo0000000D0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`070?ooo`8000002@2`h>H010000000oooo0?ooo`00000E0?ooo`030000003o
ool0oooo00@0oooo1@00000A0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`050?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool01@3o
ool2000000P0/>3V00D000000?ooo`3oool0oooo0000000E0?ooo`003`3oool2000000<0oooo1000
000<0?ooo`030000002`h>H0/>3V01<0/>3V00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0A0?ooo`8000000`3oool00`000000/>3V0;3PiP0B0;3PiP030000003oool0oooo00T0oooo
00<000000;3PiP2`h>H01@2`h>H01@000000oooo0?ooo`3oool0000001<0oooo0`0000020;3PiP80
00001@3oool010000000oooo0?ooo`00000A0;3PiP030000003oool0000000X0oooo00D000000?oo
o`3oool0oooo0000000B0?ooo`8000000`3oool5000001X0oooo00<000000?ooo`3oool0203oool0
1@000000oooo0?ooo`3oool000000180oooo100000000`2`h>H00000000000050?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000/>3V0;3PiP050;3PiP050000003o
ool0oooo0?ooo`0000004`3oool2000000<0oooo1000000F0?ooo`030000002`h>H0/>3V0100/>3V
00<000000?ooo`3oool0403oool2000000P0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo
0?ooo`070?ooo`030000002`h>H0/>3V00D0/>3V00D000000?ooo`3oool0oooo0000000E0?ooo`00
3P3oool00`000000oooo00000003000000l0oooo00<000000;3PiP2`h>H05@2`h>H00`000000oooo
000000040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000/>3V
0;3PiP0C0;3PiP8000002`3oool2000000<0/>3V0P0000050?ooo`030000003oool0oooo00l0oooo
0P0000060;3PiP8000000`3oool01@000000oooo0?ooo`3oool0000000l0/>3V00<000000?ooo`00
00002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`00
00001@0000020;3PiP@000005@3oool2000000/0oooo00D000000?ooo`3oool0oooo0000000A0?oo
o`<000001@2`h>H2000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?oo
o`8000000`2`h>H2000000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo000000030000
01X0oooo00<000000;3PiP2`h>H0402`h>H200000100oooo00<000000?ooo`3oool02@3oool00`00
0000/>3V0;3PiP0?0;3PiP030000003oool0oooo00P0oooo0P0000030;3PiP8000001@3oool00`00
0000oooo0?ooo`0B0?ooo`003@3oool300000180oooo00<000000;3PiP2`h>H05P2`h>H00`000000
oooo000000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000
/>3V0;3PiP0C0;3PiP800000303oool4000000L0oooo00<000000?ooo`3oool03P3oool00`000000
/>3V0;3PiP070;3PiP040000003oool0oooo000000@0oooo00<000000;3PiP2`h>H03@2`h>H20000
00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`<000000P3oool20000
00P0/>3V00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03@3oool2000000P0/>3V00@000000?ooo`3oool000003`3oool0
0`000000oooo0?ooo`0:0?ooo`@000001`3oool00`000000oooo0?ooo`0>0?ooo`<000007P3oool0
0`000000/>3V0;3PiP0@0;3PiP8000003`3oool3000000/0oooo00<000000;3PiP2`h>H03@2`h>H0
0`000000oooo0?ooo`0:0?ooo`@000001`3oool00`000000oooo0?ooo`0B0?ooo`003@3oool20000
0180oooo00<000000;3PiP2`h>H0602`h>H2000000D0oooo00<000000?ooo`3oool03@3oool20000
00@0oooo00<000000;3PiP2`h>H04`2`h>H00`000000oooo0000000=0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03@3oool00`000000/>3V0;3PiP080;3PiP030000003oool00000
00D0oooo00<000000;3PiP2`h>H02`2`h>H00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`02000000/0/>3V00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool00`000000/>3V0;3PiP080;3PiP030000003oool000000100oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo0P0000000`3o
ool0000000000002000001X0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo0000000>0?oo
o`80000000<0oooo0000000000000P0000070?ooo`030000002`h>H0/>3V00d0/>3V00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo000=0?ooo`@0
0000403oool00`000000/>3V0;3PiP0H0;3PiP8000001@3oool00`000000oooo0?ooo`0=0?ooo`@0
00000`3oool00`000000/>3V0;3PiP0B0;3PiP030000003oool0000000h0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0=0?ooo`030000002`h>H0/>3V00P0/>3V0P0000070?ooo`80
00002P2`h>H00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0000000>0;3PiP030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000;3PiP2`
h>H0202`h>H200000140oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00d0oooo00@000000?ooo`00000000000`3oool4000001H0oooo00<000000;3P
iP2`h>H0402`h>H00`000000oooo0000000>0?ooo`040000003oool00000000000<0oooo10000004
0?ooo`030000002`h>H0/>3V00X0/>3V0P00000@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool04@3oool000d0oooo0P0000020?ooo`030000003oool0oooo00`0oooo00<000000;3P
iP2`h>H06P2`h>H00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo0P0000020?oo
o`040000003oool0oooo000001@0/>3V00@000000?ooo`3oool000003P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00`0oooo00<000000;3PiP2`h>H0202`h>H2000000T0oooo0`00
00050;3PiP800000403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`0000003`2`h>H00`000000oooo0?ooo`0:0?ooo`800000403oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00`0oooo00<000000;3PiP2`h>H0202`h>H2000000<0oooo2`00
00040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0<0?ooo`050000003oool0oooo0?ooo`0000001P3oool400000180oooo00<000000;3PiP2`h>H0
3`2`h>H01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo000000060?oo
o`H000002P2`h>H00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0403oool000d0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`03
0000002`h>H0/>3V01X0/>3V00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool000000080oooo00<000000?ooo`000000502`h>H010000000oooo0?ooo`00000?0?oo
o`8000001P3oool00`000000oooo0?ooo`0<0?ooo`030000002`h>H0/>3V00L0/>3V0P00000=0?oo
o`H000004@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo0P00000@0;3P
iP030000003oool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00/0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`020000
00/0/>3V0P0000020?ooo`030000003oool0oooo00d0oooo0P0000060?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`D000003P3oool00`00
0000/>3V0;3PiP0>0;3PiP050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo100000050;3PiP8000005@3oool2000000H0oooo00<00000
0?ooo`3oool0403oool000d0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0:0?oo
o`030000002`h>H0/>3V01X0/>3V00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0000000<0oooo0P00000C0;3PiP030000003oool0oooo0080oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000;3P
iP2`h>H01`2`h>H200000100oooo00<000000?ooo`0000001@00000<0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02P3oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo
00L0oooo00<000000?ooo`0000001@00000<0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02`3oool00`000000/>3V0;3PiP080;3PiP030000003oool0000000l0/>3V0P0000000`3o
ool000000?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo1000000:0?ooo`030000002`h>H0/>3V
00h0/>3V00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02P3oool6000001T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0?0?ooo`003@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00T0oooo00<000000;3PiP2`h>H06P2`h>H00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00/0oooo00@000000?ooo`3oool000000`3oool200000140/>3V00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool0
0`000000/>3V0;3PiP060;3PiP800000403oool3000000H0/>3V0`0000090?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0
oooo00H0oooo0`0000060;3PiP8000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00/0oooo00<000000;3PiP2`h>H01`2`h>H00`000000oooo0000000B0;3PiP8000004@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0>0?ooo`@000001`3oool00`000000/>3V0;3PiP0=0;3PiP030000003oool0
oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`8000003`3oool5
000001H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`003@3oool01000
0000oooo0?ooo`0000040?ooo`8000002@3oool00`000000/>3V0;3PiP0J0;3PiP030000003oool0
oooo00H0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000040?ooo`8000003`2`
h>H00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo0`0000000`3oool000000?oo
o`040?ooo`030000003oool0oooo00X0oooo0P0000070;3PiP8000003`3oool2000000/0/>3V0P00
00070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000/>3V0;3P
iP0@0;3PiP030000003oool0oooo00@0oooo0P00000;0;3PiP<000001`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00X0oooo0P0000070;3PiP<00000502`h>H2000000d0oooo0`00
00000`3oool000000?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3o
ool200000180oooo1@0000030?ooo`030000002`h>H0/>3V00X0/>3V0P0000060?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`@000004`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo000=0?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`030000002`h>H0/>3V01X0/>3V00<0
00000?ooo`3oool00`3oool2000000030?ooo`000000oooo00/0oooo00D000000?ooo`3oool0oooo
000000040?ooo`8000003P2`h>H00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
100000030;3PiP@000000`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool00000000000<0
/>3V0`00000>0?ooo`8000003`2`h>H2000000D0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`00000;0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool00`3oool00`00
0000/>3V0;3PiP0>0;3PiP8000001@3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000
003oool02`3oool010000000oooo0000000000030;3PiP@000005P2`h>H00`000000oooo0?ooo`07
0?ooo`@000000`2`h>H4000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01@0oooo1@00000:0;3PiP030000003oool0oooo00H0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo1@00000?
0?ooo`8000000`3oool00`000000oooo0?ooo`0>0?ooo`003@3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`3oool01@3oool00`000000/>3V0;3PiP0J0;3PiP040000003oool0
oooo0?ooo`8000000P2`h>H3000000/0oooo00D000000?ooo`3oool0oooo000000050?ooo`800000
2`2`h>H2000000T0oooo00<000000?ooo`3oool01@3oool00`000000/>3V0;3PiP090;3PiP050000
003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`3oool300000080oooo00<000000?oo
o`3oool02`3oool200000180/>3V00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2
000000050;3PiP00000000000?ooo`0000002P3oool00`000000/>3V0;3PiP0@0;3PiP030000003o
ool0oooo0080oooo00<000000;3PiP2`h>H04@2`h>H00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo008000000P2`h>H3000000/0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000
002`h>H0/>3V01D0/>3V0P0000070?ooo`030000002`h>H0/>3V00T0/>3V00D000000?ooo`3oool0
oooo0000000;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05`3oool4000000D0
/>3V0P00000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0H0?ooo`@000003@3oool01@000000oooo0?ooo`3oool0000000l0oooo000=0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000002`h>H0/>3V01X0/>3V00@000000?ooo`00000000001P2`h>H00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000000L0/>3V0P00000;0?oo
o`030000003oool0oooo00D0oooo00<000000;3PiP2`h>H02P2`h>H010000000oooo0?ooo`00000;
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000/>3V0;3PiP0B
0;3PiP030000003oool0oooo0080oooo00@000000?ooo`00000000001@2`h>H2000000X0oooo00<0
00000;3PiP2`h>H0402`h>H00`000000oooo0?ooo`02000001@0/>3V00<000000?ooo`3oool00P3o
ool3000000H0/>3V0P00000:0?ooo`030000003oool0oooo00D0oooo0P00000H0;3PiP030000003o
ool0oooo00D0oooo00<000000;3PiP2`h>H02P2`h>H010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool6000000`0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`800000703oool4000000X0oooo00@000000?ooo`3oool0
00003`3oool000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`800000
103oool00`000000/>3V0;3PiP0J0;3PiP8000002@2`h>H00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01@3oool8000000d0oooo00<000000?ooo`3oool0
103oool00`000000/>3V0;3PiP0<0;3PiP040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0:0?ooo`030000002`h>H0/>3V01@0/>3V00@000000?ooo`3o
ool0oooo0P0000080;3PiP8000002@3oool200000140/>3V00@000000?ooo`00000000005P2`h>H0
1@000000oooo0?ooo`3oool0000000T0/>3V00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`050?ooo`030000002`h>H0/>3V01L0/>3V0P0000050?ooo`030000002`h>H0/>3V00`0/>3V00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`T000006P3oool9000000T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`H0000000<0oooo0000003oool0
6@3oool:000000H0oooo00@000000?ooo`3oool000003P3oool000d0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000;3PiP2`h>H0
6@2`h>H2000000T0/>3V0P0000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00<000000;3PiP2`h>H0
3@2`h>H3000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000
5`2`h>H010000000oooo0?ooo`00000:0;3PiP030000003oool0oooo00L0oooo0P00000A0;3PiP<0
0000602`h>H010000000oooo0?ooo`0000090;3PiP8000002@3oool00`000000oooo0?ooo`040?oo
o`8000006P2`h>H00`000000oooo0?ooo`030?ooo`030000002`h>H0/>3V00d0/>3V0`00000:0?oo
o`040000003oool0oooo0?ooo`8000001`2`h>H3000001L0oooo0P0000070;3PiPH000001@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo0P0000060;3PiP<000005`3oool2
000000P0/>3V1P0000030?ooo`<000003P3oool000d0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000006P2`h>H2000000/0/>3V00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000002`h>H0/>3V00h0/>3V00@00000
0?ooo`00000000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo0`00
000I0;3PiP030000003oool0000000X0/>3V0P0000080?ooo`030000003oool0000000l0/>3V0P00
00000`3oool000000;3PiP0H0;3PiP030000003oool0000000X0/>3V00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`040?ooo`030000002`h>H0/>3V01T0/>3V0P0000030?ooo`030000002`
h>H0/>3V00h0/>3V00@000000?ooo`00000000002@3oool010000000oooo0?ooo`00000;0;3PiP80
0000503oool2000000/0/>3V0P0000020?ooo`@000000P3oool00`000000oooo0?ooo`060?ooo`05
0000003oool0oooo0?ooo`0000002P2`h>H2000001@0oooo0P00000<0;3PiP8000000P3oool40000
00030?ooo`000000000000d0oooo000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01`3oool010000000oooo0?ooo`00000J0;3PiP8000002`2`h>H00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?oo
o`040000003oool0oooo00000140/>3V00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000006@2`h>H00`000000oooo
0000000:0;3PiP800000203oool010000000oooo0?ooo`00000=0;3PiP80000000<0oooo0000002`
h>H06@2`h>H00`000000oooo0000000:0;3PiP030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0103oool00`000000/>3V0;3PiP0J0;3PiP040000003oool0oooo00000140/>3V00@000000?oo
o`3oool000002@3oool00`000000oooo0000000=0;3PiP8000004P3oool00`000000/>3V0;3PiP0<
0;3PiP030000003oool0oooo00@0oooo0`0000080?ooo`040000003oool0oooo000000d0/>3V0P00
000A0?ooo`030000002`h>H0/>3V00d0/>3V00<000000?ooo`3oool0103oool3000000d0oooo000=
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000
/>3V01L0/>3V00<000000?ooo`0000002P2`h>H2000000T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`080?ooo`800000403oool010000000oooo0?ooo`00000A0;3PiP040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000
003oool0oooo000001/0/>3V0P00000:0;3PiP800000203oool010000000oooo0?ooo`00000<0;3P
iP040000003oool0oooo000001`0/>3V0P0000090;3PiP8000002@3oool00`000000oooo0?ooo`03
0?ooo`800000702`h>H010000000oooo0?ooo`00000A0;3PiP040000003oool0oooo000000T0oooo
00<000000?ooo`0000003P2`h>H3000000l0oooo00<000000;3PiP2`h>H03P2`h>H00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000003P2`h>H00`000000oooo
0000000@0?ooo`030000002`h>H0/>3V00h0/>3V00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo0P00
000H0;3PiP040000003oool00000000000T0/>3V00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0000000B0;3PiP8000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo
00D000000?ooo`3oool0oooo0000000K0;3PiP8000002P2`h>H00`000000oooo0?ooo`070?ooo`05
0000003oool0oooo0?ooo`0000002P2`h>H01@000000oooo0?ooo`3oool0000001`0/>3V0P000009
0;3PiP030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool2000001`0/>3V0P000000
0`3oool000000;3PiP0A0;3PiP8000002P3oool200000100/>3V00<000000?ooo`0000003@3oool0
0`000000/>3V0;3PiP0@0;3PiP800000103oool00`000000oooo0?ooo`070?ooo`800000402`h>H0
0`000000oooo0000000>0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00X0oooo0P00000F0;3PiP030000003oool0oooo00800000202`h>H2000000X0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`0000004P2`h>H2000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`800000103oool00`000000/>3V0;3PiP0I0;3PiP8000002@2`h>H2000000T0oooo00<000000?oo
o`3oool00P3oool:000000@0oooo00<000000;3PiP2`h>H06P2`h>H2000000P0/>3V0P00000:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`000000702`h>H2000000030?ooo`000000/>3V
0140/>3V0P00000:0?ooo`030000002`h>H0/>3V00l0/>3V00@000000?ooo`3oool00000303oool0
0`000000/>3V0;3PiP0A0;3PiP030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool2
00000140/>3V00<000000?ooo`0000003@3oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0
oooo00<0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0:0?ooo`8000005@2`h>H01P000000oooo0?ooo`000000oooo000000L0/>3V00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03@3oool200000180/>3V00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3P
iP0K0;3PiP8000001`2`h>H2000000X0oooo00<000000?ooo`3oool02@3oool2000000D0oooo00<0
00000;3PiP2`h>H06P2`h>H3000000L0/>3V00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000001`0/>3V00@000000?ooo`00000000004P2`h>H00`000000oooo
0?ooo`090?ooo`030000002`h>H0/>3V00l0/>3V00D000000?ooo`3oool0oooo0000000:0?ooo`03
0000002`h>H0/>3V0180/>3V00D000000?ooo`3oool0oooo0000000:0?ooo`8000004@2`h>H00`00
0000oooo0?ooo`02000000X0oooo00<000000;3PiP2`h>H04P2`h>H01@000000oooo0?ooo`3oool0
000000l0oooo000=0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000003@3oool2
000001<0/>3V00D000000?ooo`3oool0oooo000000020?ooo`8000000`2`h>H3000000/0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00`0oooo
0P00000B0;3PiP030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0oooo00@0oooo00<000000;3PiP2`h>H06`2`h>H010000000oooo0000000000030;3P
iP80000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo00<000000;3PiP2`h>H06P2`h>H2000000030?ooo`000000000000<0/>3V0`00000;0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000/>3V0;3PiP0J0;3PiP040000003oool0
000000000180/>3V00<000000?ooo`3oool02@3oool00`000000/>3V0;3PiP0@0;3PiP050000003o
ool0oooo0?ooo`0000002@3oool00`000000/>3V0;3PiP0B0;3PiP050000003oool0oooo0?ooo`00
00002P3oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo0080oooo00<000000?ooo`3o
ool01`3oool00`000000/>3V0;3PiP0B0;3PiP050000003oool0oooo0?ooo`0000003`3oool000d0
oooo00@000000?ooo`3oool0oooo0P0000001@2`h>H000000000003oool0000000d0oooo0P00000@
0;3PiP800000103oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo0000003oool02`3oool0
10000000oooo0?ooo`3oool2000000040;3PiP0000000000000000h0oooo0P00000=0?ooo`030000
002`h>H0/>3V00l0/>3V00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`3oool01@3oool00`000000/>3V0;3PiP0K0;3PiP040000003oool0oooo0?oo
o`<000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000/>3V0;3PiP0J0;3PiP8000000`3oool3000000030?ooo`000000oooo
00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000002`h>H0/>3V01X0/>3V00@00000
0?ooo`3oool000004@2`h>H00`000000oooo0?ooo`0:0?ooo`030000002`h>H0/>3V0100/>3V00<0
00000?ooo`3oool00P3oool2000000L0oooo00<000000;3PiP2`h>H04`2`h>H00`000000oooo0000
000;0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`030000002`h>H0/>3V01<0/>3V00<000000?ooo`000000403oool000d0oooo00@00000
0?ooo`00000000001@2`h>H2000000l0oooo0`00000;0;3PiP8000001P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00X0oooo00@000000?ooo`00000000001@2`h>H2000000l0oooo
00<000000?ooo`3oool02P3oool00`000000/>3V0;3PiP0>0;3PiP800000303oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo00H0oooo00<000000;3PiP2`h>H06`2`h>H00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000002`h>H0/>3V01X0/>3V0P0000070?ooo`030000003oool0oooo00X0
oooo00@000000?ooo`3oool000000`3oool00`000000/>3V0;3PiP0J0;3PiP040000003oool0oooo
00000100/>3V0P00000<0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000002`h>H0/>3V01<0/>3V00<000000?ooo`0000002`3oool0
0`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo00@0oooo0P0000060?ooo`030000002`h>H0
/>3V01<0/>3V00<000000?ooo`000000403oool000d0oooo0P0000080;3PiP8000003`3oool00`00
0000oooo00000002000000H0/>3V0P0000080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02`3oool2000000P0/>3V00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?oo
o`030000002`h>H0/>3V00d0/>3V00<000000?ooo`3oool02`3oool010000000oooo0?ooo`000003
0?ooo`8000002@3oool00`000000/>3V0;3PiP0K0;3PiP030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`8000002P3oool00`000000/>3V0;3PiP0J
0;3PiP8000001P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000<0oooo00<0
00000;3PiP2`h>H06@2`h>H00`000000oooo0?ooo`020?ooo`030000002`h>H0/>3V00d0/>3V00<0
00000?ooo`3oool02`3oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool00`000000/>3V0;3PiP0C0;3PiP800000303oool00`000000/>3V0;3P
iP0@0;3PiP030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3P
iP0C0;3PiP8000004@3oool000d0oooo0P0000090;3PiP030000003oool0oooo00h0oooo00@00000
0?ooo`3oool0oooo1P00000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3o
ool00`000000/>3V0;3PiP080;3PiP030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3o
ool2000000d0/>3V0P00000=0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool02@3o
ool00`000000/>3V0;3PiP0K0;3PiP030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000;3PiP2`h>H06P2`
h>H2000000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo000000050?ooo`030000002`
h>H0/>3V01P0/>3V00<000000?ooo`3oool00P3oool2000000d0/>3V0P00000=0?ooo`030000002`
h>H0/>3V00l0/>3V00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000002`
h>H0/>3V01<0/>3V0P00000<0?ooo`8000004@2`h>H00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo00<000000;3PiP2`h>H04P2`h>H300000140oooo000=0?ooo`030000002`h>H0
/>3V00P0/>3V0P00000=0?ooo`D000004@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00`0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`0;0?ooo`<0000000<0oooo
0000000000002P3oool3000000/0/>3V00<000000?ooo`3oool0303oool00`000000oooo00000002
0?ooo`030000003oool0oooo00/0oooo00<000000;3PiP2`h>H06P2`h>H00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<
0?ooo`030000002`h>H0/>3V01T0/>3V0P0000060?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`0000001@3oool00`000000/>3V0;3PiP0H0;3PiP030000003oool0oooo00<0oooo0`00000;
0;3PiP030000003oool0oooo00`0oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`08
0?ooo`8000000P3oool00`000000/>3V0;3PiP0C0;3PiP030000003oool0oooo00/0oooo0P00000A
0;3PiP030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000D0;3PiP8000004P3o
ool000d0oooo00<000000;3PiP2`h>H0202`h>H2000000/0oooo0P0000030;3PiP<00000403oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000;3PiP2`h>H0202`h>H2
000000/0oooo00@000000;3PiP2`h>H0/>3V100000090?ooo`040000003oool0oooo000000P0/>3V
0`00000>0?ooo`8000000P3oool00`000000oooo0?ooo`0<0?ooo`030000002`h>H0/>3V01T0/>3V
0P0000060?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`03
0000002`h>H0/>3V01P0/>3V00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0<0?ooo`80
00001`3oool00`000000/>3V0;3PiP0F0;3PiP030000003oool0oooo00@0oooo00@000000?ooo`3o
ool00000202`h>H3000000h0oooo0P00000?0;3PiP030000003oool0oooo00/0oooo00@000000?oo
o`3oool000004`2`h>H2000000d0oooo00<000000?ooo`0000003`2`h>H00`000000oooo0?ooo`0:
0?ooo`80000000<0oooo0000002`h>H04`2`h>H200000180oooo000=0?ooo`030000002`h>H0/>3V
00P0/>3V00<000000?ooo`000000203oool2000000P0/>3V00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000;3PiP2`h>H0202`h>H20000
00T0oooo0P0000080;3PiP030000003oool0oooo00L0oooo00<000000?ooo`3oool0200000000`3o
ool000000?ooo`0>0?ooo`@000003`3oool00`000000/>3V0;3PiP0I0;3PiP8000001@3oool00`00
0000oooo0?ooo`0<0?ooo`040000003oool0000000000100oooo00<000000;3PiP2`h>H0602`h>H0
0`000000oooo000000050?ooo`030000003oool0oooo00`0oooo0P0000070?ooo`030000002`h>H0
/>3V01H0/>3V00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`08000000030?ooo`000000
oooo00h0oooo0P00000?0;3PiP030000003oool0oooo00`0oooo00<000000?ooo`0000004`2`h>H0
0`000000oooo0?ooo`0<0?ooo`030000003oool0000000l0/>3V00<000000?ooo`3oool0303oool2
000001@0/>3V00<000000?ooo`3oool04@3oool000d0oooo00<000000;3PiP2`h>H0202`h>H00`00
0000oooo000000070?ooo`030000002`h>H0/>3V00T0/>3V00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000;3PiP2`h>H0202`h>H00`00
0000oooo000000060?ooo`8000002`2`h>H00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool03@3oool200000180oooo00<000000;3PiP2`h>H05`2`h>H00`00
0000oooo000000050?ooo`030000003oool0oooo00`0oooo0P00000C0?ooo`030000002`h>H0/>3V
01L0/>3V00<000000?ooo`000000103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00L0oooo00<000000;3PiP2`h>H0502`h>H00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000=0;3PiP030000003oool0oooo
00h0oooo00<000000?ooo`0000004@2`h>H2000000h0oooo00@000000?ooo`3oool000003@2`h>H0
0`000000oooo0?ooo`0>0?ooo`8000004P2`h>H2000001<0oooo000=0?ooo`800000202`h>H01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000;3PiP2`h>H02`2`h>H2000000`0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000002`h>H0/>3V00L0/>3V00@00000
0?ooo`3oool000001@3oool00`000000/>3V0;3PiP0<0;3PiP8000001`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00h0oooo0`00000A0?ooo`030000002`h>H0/>3V01L0/>3V00<0
00000?ooo`000000103oool00`000000oooo0?ooo`0=0?ooo`<000004P3oool00`000000/>3V0;3P
iP0F0;3PiP040000003oool0oooo000000@0oooo00<000000?ooo`3oool03@3oool3000000L0oooo
0P00000D0;3PiP030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0>0?ooo`D000002@2`h>H200000180oooo0P00000A0;3PiP030000003oool0oooo00d0oooo
0`0000000`3oool000000;3PiP090;3PiP8000004P3oool200000140/>3V00<000000?ooo`3oool0
4P3oool000h0oooo0P0000070;3PiP050000003oool0oooo0?ooo`000000103oool00`000000/>3V
0;3PiP0=0;3PiP8000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo
00<000000;3PiP2`h>H01@2`h>H00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000;3PiP2`h>H03@2`h>H2000000H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0000000<000003P3oool00`000000/>3V0;3PiP0E0;3PiP040000
003oool0oooo000000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo00000003000000l0
oooo00<000000;3PiP2`h>H05@2`h>H010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`0000000`0000050?ooo`800000402`h>H2000000/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000000@000001@2`h>H00`00
0000oooo0?ooo`0D0?ooo`030000002`h>H0/>3V00d0/>3V0P00000@0?ooo`030000003oool00000
00D00000102`h>H2000001D0oooo0P00000>0;3PiP<00000503oool000l0oooo0`0000030;3PiP80
00001@3oool010000000oooo0?ooo`00000@0;3PiP030000003oool0000000X0oooo00D000000?oo
o`3oool0oooo0000000C0?ooo`8000000`2`h>H2000000D0oooo00D000000?ooo`3oool0oooo0000
000@0;3PiP030000003oool0000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0A0?ooo`8000000`3oool4000000/0oooo00<000000;3PiP2`h>H04`2`h>H01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool0403oool2000000<0oooo1@00000;0?ooo`030000
002`h>H0/>3V01<0/>3V00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0100
oooo0P0000030?ooo`@000000`3oool00`000000/>3V0;3PiP0<0;3PiP030000003oool0oooo00`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`8000000`3oool6000001P0
oooo00<000000;3PiP2`h>H02`2`h>H200000180oooo0P0000030?ooo`H00000603oool2000000`0
/>3V00<000000?ooo`0000005@3oool00140oooo100000070?ooo`040000003oool0oooo00000140
/>3V00<000000?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000001D0oooo0`0000070?oo
o`040000003oool0oooo00000180/>3V00<000000?ooo`0000001@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool5000000L0oooo00<00000
0;3PiP2`h>H04@2`h>H00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000503o
ool00`000000oooo0?ooo`050?ooo`@00000203oool00`000000/>3V0;3PiP0A0;3PiP030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo0000000D0?ooo`030000003oool0oooo00@0oooo
1P0000090;3PiP<000003`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0103oool5000001H0oooo00<000000;3PiP2`h>H02@2`h>H00`000000oooo
0000000D0?ooo`030000003oool0oooo00D0oooo1000000F0?ooo`8000002`2`h>H00`000000oooo
0000000E0?ooo`004P3oool00`000000oooo0?ooo`080?ooo`030000003oool000000140/>3V00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`0000004P2`h>H010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`080?ooo`@00000103oool00`00
0000/>3V0;3PiP0?0;3PiP030000003oool0oooo00<0oooo00@000000?ooo`3oool000005P3oool0
0`000000oooo0?ooo`080?ooo`D00000103oool00`000000/>3V0;3PiP0?0;3PiP030000003oool0
oooo00<0oooo00@000000?ooo`3oool000005P3oool00`000000oooo0?ooo`080?ooo`X000004`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0203o
ool4000001<0oooo100000030;3PiP@0000000<0oooo0000003oool05@3oool00`000000oooo0?oo
o`080?ooo`D000004P3oool4000000<0/>3V1@0000000`3oool000000?ooo`0E0?ooo`004`3oool2
000000P0oooo0P00000B0;3PiP040000003oool0oooo0?ooo`8000001P3oool010000000oooo0?oo
o`00000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000004P2`h>H010000000oooo
0?ooo`3oool2000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00/0oooo100000000`3oool000000000000=0;3PiP8000001P3oool010000000
oooo0?ooo`00000G0?ooo`8000003@3oool4000000030?ooo`000000000000d0/>3V0P0000060?oo
o`040000003oool0oooo000001L0oooo00<000000?ooo`3oool02`3oool4000001D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00/0oooo1000000@
0?ooo`80000000@0oooo00000000000000001@3oool00`000000oooo0?ooo`0E0?ooo`8000003@3o
ool400000100oooo1@0000060?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0
oooo00H0oooo00<000000;3PiP2`h>H0402`h>H2000000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0000000J0?ooo`8000001`3oool200000180/>3V00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0603oool2000000/0oooo00@0
00000;3PiP2`h>H0/>3V1@0000090;3PiP800000203oool00`000000oooo0000000J0?ooo`030000
003oool0oooo00T0oooo00<000000;3PiP2`h>H00P2`h>H4000000T0/>3V0`0000080?ooo`030000
003oool0000001T0oooo0P00000;0?ooo`040000002`h>H0/>3V0;3PiPD000004@3oool01@000000
oooo0?ooo`3oool0000001X0oooo0P00000;0?ooo`040000002`h>H0/>3V0;3PiPD000003@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool0
0`000000/>3V0;3PiP020;3PiP@000003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01D0oooo000F0?ooo`030000003oool0oooo00D0oooo00<000000;3PiP2`h>H0402`h>H00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000703oool00`00
0000oooo0?ooo`040?ooo`8000004P2`h>H00`000000oooo0?ooo`040?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`070?ooo`030000002`h>H0
/>3V00@0/>3V0P0000000`3oool0000000000007000000X0oooo00<000000?ooo`0000006`3oool0
0`000000oooo0?ooo`070?ooo`030000002`h>H0/>3V00D0/>3V00<000000?ooo`0000002000000;
0?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool01`3oool00`000000/>3V0;3PiP04
0;3PiP80000000<0oooo0000000000000P00000=0?ooo`050000003oool0oooo0?ooo`000000703o
ool00`000000oooo0?ooo`070?ooo`030000002`h>H0/>3V00@0/>3V0P0000000`3oool000000000
0002000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00L0oooo00<000000;3PiP2`h>H01@2`h>H7000000X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0E0?ooo`005`3oool00`000000oooo0?ooo`040?ooo`8000004@2`h>H0
0`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`8000007P3oool00`000000oooo0?oo
o`040?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool01@3oool01P000000oooo0?oo
o`000000oooo000001h0oooo00<000000?ooo`3oool0103oool2000000P0/>3V00<000000?ooo`3o
ool00`3oool5000000X0oooo0P00000M0?ooo`030000003oool0oooo00D0oooo00<000000;3PiP2`
h>H01`2`h>H00`000000oooo0?ooo`030?ooo`@000002`3oool2000001d0oooo00<000000?ooo`3o
ool01@3oool00`000000/>3V0;3PiP060;3PiP030000003oool0oooo00<0oooo1@0000090?ooo`03
0000003oool0000001h0oooo00<000000?ooo`3oool0103oool2000000P0/>3V00<000000?ooo`3o
ool00`3oool5000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo00<000000;3PiP2`h>H01`2`h>H00`000000oooo0?ooo`030?ooo`@0
00001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo000H0?ooo`800000
1@3oool00`000000/>3V0;3PiP0?0;3PiP030000003oool0oooo00H0oooo0P0000000`3oool00000
0000000O0?ooo`030000003oool0oooo00<0oooo0P00000@0;3PiP030000003oool0oooo00L0oooo
0`0000000`3oool000000?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<000000;3PiP2`h>H0
202`h>H00`000000oooo0?ooo`070?ooo`@000001P3oool2000001h0oooo0P0000050?ooo`030000
002`h>H0/>3V00P0/>3V00<000000?ooo`3oool01P3oool5000000H0oooo0P00000N0?ooo`030000
003oool0oooo00@0oooo00<000000;3PiP2`h>H01`2`h>H00`000000oooo0?ooo`070?ooo`@00000
1@3oool00`000000oooo0000000O0?ooo`030000003oool0oooo00<0oooo00<000000;3PiP2`h>H0
202`h>H00`000000oooo0?ooo`070?ooo`@000000`3oool200000080oooo00<000000?ooo`3oool0
703oool2000000D0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`060?ooo`D00000
0`3oool200000080oooo00<000000?ooo`3oool05P3oool001X0oooo00<000000?ooo`3oool00P3o
ool200000100/>3V00<000000?ooo`3oool0203oool200000240oooo00<000000?ooo`3oool00`3o
ool00`000000/>3V0;3PiP0>0;3PiP030000003oool0oooo00T0oooo0P00000Q0?ooo`030000003o
ool0oooo0080oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`0;0?ooo`@000000P3o
ool00`000000oooo0?ooo`0O0?ooo`050000003oool0oooo0?ooo`0000002`2`h>H00`000000oooo
0?ooo`0;0?ooo`@000000P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo
00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`0;0?ooo`@000000P3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo0080oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo
0?ooo`0;0?ooo`@0000000<0oooo0000000000008@3oool00`000000oooo0?ooo`020?ooo`030000
002`h>H0/>3V00P0/>3V00<000000?ooo`3oool02`3oool4000000030?ooo`000000000001T0oooo
000K0?ooo`030000003oool0oooo0080oooo00<000000;3PiP2`h>H03@2`h>H00`000000oooo0?oo
o`080?ooo`<000008P3oool2000000<0oooo00<000000;3PiP2`h>H03P2`h>H00`000000oooo0?oo
o`080?ooo`<000008P3oool200000080oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?oo
o`0?0?ooo`<000008P3oool010000000oooo0?ooo`00000;0;3PiP030000003oool0oooo00l0oooo
0`00000Q0?ooo`8000000P3oool00`000000/>3V0;3PiP080;3PiP030000003oool0oooo00l0oooo
0`00000R0?ooo`8000000P3oool00`000000/>3V0;3PiP080;3PiP030000003oool0oooo00l0oooo
0`00000R0?ooo`050000003oool0oooo0?ooo`0000002P2`h>H00`000000oooo0?ooo`0?0?ooo`<0
00006@3oool001`0oooo0P0000030?ooo`030000002`h>H0/>3V00/0/>3V00<000000?ooo`3oool0
1@3oool4000002L0oooo00@000000?ooo`3oool0oooo0P00000=0;3PiP030000003oool0oooo00D0
oooo1000000W0?ooo`030000003oool0000000X0/>3V00<000000?ooo`3oool02`3oool4000002H0
oooo0`00000:0;3PiP030000003oool0oooo00`0oooo1000000V0?ooo`030000003oool0000000X0
/>3V00<000000?ooo`3oool02`3oool4000002L0oooo00<000000?ooo`0000002P2`h>H00`000000
oooo0?ooo`0;0?ooo`@000009P3oool2000000030?ooo`000000/>3V00P0/>3V00<000000?ooo`3o
ool0303oool4000001`0oooo000N0?ooo`040000003oool0oooo000000d0/>3V00@000000?ooo`3o
ool0oooo1000000/0?ooo`030000003oool0oooo00800000302`h>H010000000oooo0?ooo`3oool5
000002`0oooo0P00000:0;3PiP030000003oool0oooo00H0oooo1@00000/0?ooo`8000002@2`h>H0
0`000000oooo0?ooo`070?ooo`D00000:`3oool2000000X0/>3V00<000000?ooo`3oool01P3oool5
000002`0oooo0P00000:0;3PiP030000003oool0oooo00H0oooo1@00000/0?ooo`8000002@2`h>H0
0`000000oooo0?ooo`070?ooo`D00000803oool001l0oooo00@000000?ooo`3oool000002P2`h>H6
00000340oooo00<000000?ooo`3oool00P00000:0;3PiPD00000<P3oool00`000000/>3V0;3PiP07
0;3PiP030000003oool0oooo00<0oooo1000000b0?ooo`030000002`h>H0/>3V00H0/>3V00<00000
0?ooo`3oool0103oool400000340oooo0P0000080;3PiP030000003oool0oooo00<0oooo1000000b
0?ooo`030000002`h>H0/>3V00L0/>3V00<000000?ooo`3oool00`3oool400000380oooo00<00000
0;3PiP2`h>H01P2`h>H00`000000oooo0?ooo`040?ooo`@000009@3oool00200oooo3P00000g0?oo
o`<0000000<0oooo0000000000002@00000g0?ooo`8000001P2`h>H00`000000oooo000000040000
03L0oooo0P0000060;3PiP030000003oool0000000@00000=P3oool2000000L0/>3V1P00000g0?oo
o`8000001P2`h>H00`000000oooo00000004000003L0oooo0P0000060;3PiP030000003oool00000
00@00000:@3oool00280oooo0P0000020?ooo`@00000?@3oool200000080oooo1000000m0?ooo`T0
0000?@3oool9000003d0oooo2000000m0?ooo`T00000?@3oool9000002h0oooo000S0?ooo`<00000
@P3oool3000004<0oooo0`0000130?ooo`<00000@P3oool3000004<0oooo0`0000130?ooo`<00000
<P3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooo
n`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool002<0oooo
0`0000120?ooo`<00000@`3oool300000480oooo100000120?ooo`<00000@`3oool3000004<0oooo
0`00000b0?ooo`008P3oool200000080oooo1000000m0?ooo`8000000P3oool4000003h0oooo0P00
00020?ooo`@00000?03oool3000000<0/>3V1000000m0?ooo`<0000000<0oooo0000000000000P00
000n0?ooo`8000000P3oool4000003h0oooo0P0000020?ooo`@00000;P3oool00200oooo0P000002
0?ooo`030000003oool0oooo00<0oooo1000000g0?ooo`8000000P3oool00`000000oooo0?ooo`03
0?ooo`D00000=`3oool3000000030?ooo`000000oooo00@0oooo1@00000f0?ooo`<000001P2`h>H0
0`000000oooo00000004000003H0oooo0P0000020?ooo`<000000`3oool5000003L0oooo0P000000
0`3oool00000000000050?ooo`D00000=`3oool5000000D0oooo1@00000Y0?ooo`007`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo1@00000a0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool400000380oooo00H000000?ooo`3oool000000?ooo`00
000:0?ooo`@00000<P3oool00`000000/>3V0;3PiP070;3PiP030000003oool0oooo00<0oooo1000
000a0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001`3oool400000380oooo
00@000000?ooo`3oool0oooo0P00000:0?ooo`@00000<P3oool010000000oooo0000003oool20000
00X0oooo1000000U0?ooo`007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0
oooo1`00000[0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool6000002`0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`090?ooo`L00000;03oool00`00
0000/>3V0;3PiP090;3PiP030000003oool0oooo00H0oooo1@00000[0?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000002P3oool5000002`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0000000;0?ooo`L00000;03oool020000000oooo0?ooo`000000oooo0000003oool0
00002`3oool700000200oooo000L0?ooo`8000001`3oool00`000000oooo0?ooo`070?ooo`800000
1P2`h>H4000002L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`800000
1P2`h>H4000002L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00L0
oooo0P0000070;3PiP@000009P3oool3000000/0/>3V00<000000?ooo`3oool02`3oool4000002H0
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3oool2000000d0oooo1000000W0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000002P3oool00`000000/>3V0;3PiP050;3P
iP@000009P3oool200000080oooo00H000000?ooo`3oool000000?ooo`0000090?ooo`8000001`2`
h>H4000001`0oooo000K0?ooo`P000000`3oool00`000000oooo0?ooo`050?ooo`030000002`h>H0
/>3V00P0/>3V1@00000R0?ooo`P000000`3oool00`000000oooo0?ooo`050?ooo`8000002P2`h>H5
00000280oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000/>3V0;3PiP090;3PiPD000008P3oool010000000oooo0?ooo`00000;0;3PiP030000003o
ool0oooo00l0oooo0`00000Q0?ooo`P000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00T0oooo0P0000030;3PiP<000008P3oool2000000H0oooo00@000000?ooo`3oool00000
1`3oool2000000X0/>3V1@00000R0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`050?ooo`030000002`h>H0/>3V00P0/>3V0P000000103oool0
000000000000000I0?ooo`006@3oool2000000P0/>3V0P0000000`3oool000000?ooo`050?ooo`03
0000002`h>H0/>3V00/0/>3V00<000000?ooo`0000008@3oool2000000L0/>3V0P0000000`3oool0
00000?ooo`050?ooo`030000002`h>H0/>3V00`0/>3V00<000000?ooo`0000008@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
/>3V0;3PiP0<0;3PiP030000003oool000000240oooo00<000000?ooo`3oool00P3oool00`000000
/>3V0;3PiP070;3PiP030000003oool0oooo00`0oooo100000020?ooo`030000003oool0oooo01h0
oooo0P0000070;3PiP80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`070?ooo`03
0000002`h>H0/>3V00D0/>3V0P00000P0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3o
ool000001P3oool00`000000/>3V0;3PiP0<0;3PiP030000003oool000000240oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool0
0`000000/>3V0;3PiP0;0;3PiP040000003oool0oooo000001T0oooo000G0?ooo`<000002`2`h>H3
000000@0oooo00<000000;3PiP2`h>H0302`h>H010000000oooo00000000000N0?ooo`8000002`2`
h>H3000000D0oooo00<000000;3PiP2`h>H0302`h>H010000000oooo00000000000O0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000
002`h>H0/>3V00`0/>3V00@000000?ooo`00000000007`3oool00`000000oooo0?ooo`030?ooo`03
0000002`h>H0/>3V00L0/>3V00<000000?ooo`3oool01`3oool5000000H0oooo0P00000M0?ooo`80
00002`2`h>H3000000D0oooo0P0000060?ooo`030000002`h>H0/>3V00L0/>3V00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000/>3V0;3PiP0<0;3PiP040000003oool00000000001l0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000/>3V0;3P
iP0<0;3PiP030000003oool0oooo00800000603oool001H0oooo0`00000=0;3PiP8000000`3oool0
0`000000/>3V0;3PiP0>0;3PiP<000007@3oool2000000h0/>3V00<000000?ooo`3oool00P3oool0
0`000000/>3V0;3PiP0>0;3PiP<000007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000/>3V0;3PiP0>0;3PiP<000007@3oool2
000000H0oooo00<000000;3PiP2`h>H01P2`h>H00`000000oooo0?ooo`040?ooo`@000002`3oool2
000001`0oooo0P00000>0;3PiP030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool0
0`000000/>3V0;3PiP070;3PiP8000007@3oool00`000000oooo0?ooo`080?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000/>3V0;3PiP0>0;3PiP<000007@3oool2000000D0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000;3PiP2`h>H0
3P2`h>H010000000oooo00000000000H0?ooo`005P3oool00`000000/>3V0;3PiP0>0;3PiP800000
0P3oool00`000000/>3V0;3PiP0?0;3PiP030000003oool0000001`0oooo00<000000;3PiP2`h>H0
3P2`h>H010000000oooo0?ooo`00000B0;3PiP030000003oool0000001`0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo00000140/>3V0P0000000`3o
ool000000?ooo`0J0?ooo`030000003oool0oooo00L0oooo00<000000;3PiP2`h>H01@2`h>H70000
00<0/>3V0P00000:0?ooo`030000003oool0000001/0oooo00<000000;3PiP2`h>H03P2`h>H00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000;3PiP2`h>H0202`h>H00`00
0000oooo0?ooo`0I0?ooo`L000001P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000180/>3V00<000000?ooo`0000006`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000A0;3PiP80000000<0
oooo0000003oool05P3oool001D0oooo00<000000;3PiP2`h>H0402`h>H010000000oooo0?ooo`00
000A0;3PiP030000003oool0000001X0oooo0P00000A0;3PiP80000000<0oooo0000002`h>H04@2`
h>H00`000000oooo0000000J0?ooo`8000001`3oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo00000140/>3V0P0000000`3oool000000?ooo`0I0?ooo`030000003oool0oooo00T0oooo
2@00000:0;3PiP800000203oool00`000000oooo0000000I0?ooo`8000004@2`h>H2000000L0oooo
00D000000?ooo`3oool0oooo0000000:0;3PiP030000003oool0oooo01P0oooo0P0000060;3PiP80
0000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000180/>3V00<000000?oo
o`0000006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`00000A0;3PiP80000000<0oooo0000003oool05P3oool0
01<0oooo0`00000B0;3PiP<000004P2`h>H010000000oooo0?ooo`00000H0?ooo`030000003oool0
00000180/>3V00<000000?ooo`0000004P2`h>H010000000oooo0?ooo`00000H0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000B0;3PiP040000003o
ool0oooo000001L0oooo0P00000=0?ooo`D000003`2`h>H2000000H0oooo00@000000?ooo`3oool0
00005`3oool00`000000oooo0000000B0;3PiP030000003oool0oooo00H0oooo0P0000000`3oool0
00000;3PiP090;3PiP8000005`3oool2000000X0/>3V0P0000020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000004P2`h>H010000000oooo0?ooo`00000G0?ooo`800000203oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P00000C0;3PiP040000003oool0oooo
000001H0oooo000B0?ooo`030000003oool0000001@0/>3V0P00000B0;3PiP040000003oool0oooo
000001L0oooo00<000000?ooo`0000004`2`h>H300000180/>3V00@000000?ooo`3oool000005`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000004P2`
h>H010000000oooo0?ooo`00000F0?ooo`030000003oool0oooo00P0oooo1@0000030?ooo`030000
002`h>H0/>3V0100/>3V00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000F0?ooo`03
0000003oool0000001<0/>3V0P0000090?ooo`8000002P2`h>H2000001H0oooo0P00000=0;3PiP03
0000003oool0000000D0oooo00<000000?ooo`0000004P2`h>H010000000oooo0?ooo`00000F0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`8000004`2`h>H010000000oooo0?ooo`00000F0?ooo`004@3oool010000000oooo0?ooo`00000D
0;3PiP8000004P2`h>H01@000000oooo0?ooo`3oool0000001D0oooo00@000000?ooo`3oool00000
502`h>H200000180/>3V00D000000?ooo`3oool0oooo0000000D0?ooo`H000001@3oool00`000000
oooo0?ooo`0;0?ooo`8000004P2`h>H01@000000oooo0?ooo`3oool0000001@0oooo00<000000?oo
o`3oool01@3oool4000000L0oooo00<000000;3PiP2`h>H04P2`h>H00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000503oool010000000oooo0?ooo`00000D0;3PiP030000003o
ool0oooo00P0oooo0P0000080;3PiP040000003oool0oooo000001D0oooo00<000000;3PiP2`h>H0
302`h>H00`000000oooo000000060?ooo`8000004P2`h>H01@000000oooo0?ooo`3oool0000001@0
oooo1P0000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
/>3V0;3PiP0@0;3PiP8000000`3oool00`000000oooo0?ooo`0C0?ooo`003`3oool2000000<0oooo
00<000000;3PiP2`h>H04`2`h>H00`000000/>3V0;3PiP0@0;3PiP050000003oool0oooo0?ooo`00
00004`3oool200000080oooo00<000000;3PiP2`h>H04`2`h>H200000180/>3V00D000000?ooo`3o
ool0oooo0000000B0?ooo`<000001@2`h>H00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo0P00000B0;3PiP050000003oool0oooo0?ooo`0000004P3oool2000000<0oooo1@00000:
0?ooo`030000002`h>H0/>3V01@0/>3V00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo0100oooo0P0000030?ooo`030000002`h>H0/>3V0180/>3V00<000000?ooo`3oool02@3o
ool2000000H0/>3V00D000000?ooo`3oool0oooo0000000C0?ooo`800000402`h>H2000000H0oooo
0P00000B0;3PiP050000003oool0oooo0?ooo`0000004P3oool2000000D0/>3V00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0P00000A0;3PiP80
00000`3oool00`000000oooo0?ooo`0C0?ooo`003P3oool00`000000oooo0?ooo`030?ooo`030000
002`h>H0/>3V01<0/>3V0P00000A0;3PiP030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`020?ooo`030000002`h>H0/>3V01<0/>3V0P00000A0;3PiP800000
103oool00`000000oooo0?ooo`0>0?ooo`800000202`h>H010000000oooo0?ooo`00000?0?ooo`03
0000002`h>H0/>3V00l0/>3V0P0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`00
00000`00000>0?ooo`030000002`h>H0/>3V01H0/>3V00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000;3PiP2`h>H04P2`h>H20000
00`0oooo1P0000050?ooo`030000003oool0oooo00l0oooo0P00000A0;3PiP8000001`3oool00`00
0000/>3V0;3PiP0?0;3PiP800000103oool00`000000oooo0?ooo`0>0?ooo`030000002`h>H0/>3V
00H0/>3V00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00D0oooo00<00000
0;3PiP2`h>H03`2`h>H2000000@0oooo00<000000?ooo`3oool04P3oool000d0oooo00<000000?oo
o`3oool0103oool00`000000/>3V0;3PiP0C0;3PiP8000004@2`h>H00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3PiP0C0;3P
iP<00000402`h>H2000000@0oooo00<000000?ooo`3oool03P3oool00`000000/>3V0;3PiP070;3P
iP040000003oool0oooo000000l0oooo00<000000;3PiP2`h>H03`2`h>H2000000@0oooo00<00000
0?ooo`3oool03@3oool300000180oooo00<000000;3PiP2`h>H05`2`h>H00`000000oooo00000004
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP0B
0;3PiP8000003@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`0000004P2`h>H00`000000oooo0?ooo`050?ooo`030000002`h>H0/>3V00l0/>3V0P000004
0?ooo`030000003oool0oooo00d0oooo0P0000080;3PiP040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool01@3oool00`000000/>3V0;3PiP0?0;3PiP800000103oool00`000000oooo0?oo
o`0B0?ooo`003@3oool2000000D0oooo00<000000;3PiP2`h>H04P2`h>H2000000030?ooo`000000
/>3V00h0/>3V0P0000050?ooo`030000003oool0oooo00d0oooo0P0000050?ooo`030000002`h>H0
/>3V0180/>3V00<000000?ooo`000000402`h>H2000000D0oooo00<000000?ooo`3oool03@3oool0
0`000000/>3V0;3PiP080;3PiP8000004@3oool00`000000/>3V0;3PiP0=0;3PiP030000003oool0
000000D0oooo00<000000?ooo`3oool0303oool200000180oooo00<000000;3PiP2`h>H0602`h>H0
0`000000oooo000000040?ooo`030000003oool0oooo00d0oooo0P0000050?ooo`030000002`h>H0
/>3V0180/>3V00<000000?ooo`0000003@3oool2000000P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0000000B0;3PiP030000003oool0oooo00H0oooo00<000000;3PiP2`h>H03@2`h>H0
0`000000oooo000000050?ooo`030000003oool0oooo00`0oooo00<000000;3PiP2`h>H0202`h>H0
0`000000oooo000000080?ooo`030000003oool0oooo00H0oooo00<000000;3PiP2`h>H03@2`h>H0
0`000000oooo000000050?ooo`030000003oool0oooo0140oooo000=0?ooo`040000003oool00000
000000<0oooo00<000000;3PiP2`h>H04P2`h>H010000000oooo0?ooo`00000?0;3PiP8000001@3o
ool00`000000oooo0?ooo`0=0?ooo`@000000`3oool00`000000/>3V0;3PiP0B0;3PiP040000003o
ool00000000000l0/>3V0P0000050?ooo`030000003oool0oooo00d0oooo00<000000;3PiP2`h>H0
202`h>H2000000D0oooo1P0000060?ooo`030000002`h>H0/>3V00d0/>3V00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0000000000100oooo00<000000;3PiP2`
h>H06@2`h>H2000000D0oooo00<000000?ooo`3oool0303oool010000000oooo0000000000030?oo
o`030000002`h>H0/>3V0180/>3V00<000000?ooo`0000003`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00d0oooo0`00000B0;3PiP030000003oool0oooo00H0oooo00<000000;3P
iP2`h>H03@2`h>H00`000000oooo000000050?ooo`030000003oool0oooo00`0oooo00<000000;3P
iP2`h>H0202`h>H2000000T0oooo00<000000?ooo`3oool01P3oool00`000000/>3V0;3PiP0=0;3P
iP030000003oool0000000D0oooo00<000000?ooo`3oool04@3oool000d0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000002`h>H0/>3V0180/>3V00<000000?ooo`3oool00P00000=0;3P
iP030000003oool0000000H0oooo00<000000?ooo`3oool0303oool200000080oooo00@000000?oo
o`3oool00000502`h>H00`000000oooo0?ooo`02000000`0/>3V0P0000000`3oool000000?ooo`05
0?ooo`030000003oool0oooo00`0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`02
0?ooo`8000001P2`h>H3000000@0oooo00<000000;3PiP2`h>H02`2`h>H010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000
002`h>H0/>3V01X0/>3V0P0000050?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000002`h>H0/>3V0180/>3V00@000000?ooo`3oool000003`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo0`00000B0;3PiP030000003oool0oooo
00L0oooo00<000000;3PiP2`h>H02`2`h>H010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo00/0oooo00<000000;3PiP2`h>H02@2`h>H00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000;3PiP2`h>H02`2`h>H010000000oooo0?ooo`0000060?ooo`030000003o
ool0oooo0100oooo000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000502`h>H0
10000000oooo0?ooo`3oool2000000X0/>3V0P0000020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0303oool00`000000oooo000000020?ooo`030000003oool0000001@0/>3V00H0
00000?ooo`3oool000000?ooo`00000:0;3PiP050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`0<0?ooo`030000002`h>H0/>3V00L0/>3V0P0000020?ooo`8000002`2`h>H20000
0080oooo0`0000090;3PiP8000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000002`h>H0/>3V
01X0/>3V0P0000060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0000000D0;3PiP040000003oool0oooo00000100oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool000000180/>3V00<000000?ooo`3oool01`3oool3
000000X0/>3V00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00/0oooo0P00
00090;3PiP030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool2000000X0/>3V0P00
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool000d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0000000B0;3PiP030000003oool0oooo0080oooo00@00000
0?ooo`00000000001P2`h>H2000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000004P2`h>H00`000000oooo0?oo
o`020?ooo`040000003oool00000000000H0/>3V0P0000040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02`3oool00`000000/>3V0;3PiP070;3PiP040000003oool00000000000l0
/>3V0P000000103oool000000?ooo`0000070;3PiP030000003oool0oooo00<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo0P00000;0?oo
o`030000002`h>H0/>3V01X0/>3V0P0000060?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0000000B0;3PiP030000003oool0oooo0080oooo00<000000?oo
o`3oool03P3oool2000000D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0000000A0;3P
iP8000002P3oool00`000000oooo000000070;3PiP800000103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00X0oooo0P0000090;3PiP030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool3000000L0/>3V00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00l0oooo000=0?ooo`030000003oool0oooo00@0oooo0`00000A0;3PiP03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01P0000060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000030?ooo`8000004@2`h>H00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`H000001P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00/0oooo0P0000070;3PiP<000004`2`h>H200000080oooo1`000006
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00P0oooo00<000000;3PiP2`h>H06P2`h>H2000000L0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`8000004P2`h>H00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;
0?ooo`040000003oool0oooo00000100/>3V0P00000:0?ooo`030000003oool0oooo00L000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000001`2`
h>H00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`00
00060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool000d0oooo00<00000
0?ooo`3oool01P3oool2000000l0/>3V00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00
00050?ooo`030000002`h>H0/>3V00d0/>3V00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000
00050;3PiP030000003oool0000001D0/>3V0P00000>0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000;3PiP2`h>H06P2`h>H2000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`060?ooo`030000002`h>H0/>3V00h0/>3V00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`090?ooo`P00000103oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000l0/>3V
00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000050;3PiP8000002`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0>0?ooo`003@3oool00`000000oooo0?ooo`070?ooo`030000002`h>H0/>3V00`0/>3V
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo0?ooo`H0
0000303oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000;3PiP2`h>H0302`h>H00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool0oooo1P00000<
0?ooo`030000003oool0oooo00D0000000<0oooo0000002`h>H05P2`h>H00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo0?ooo`H000002`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000;3PiP2`h>H06P2`h>H200000080oooo1`00000;0?ooo`030000003o
ool0oooo00L0oooo00<000000;3PiP2`h>H0302`h>H00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo0P0000070;3PiP<000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo008000003P2`h>H00`000000oooo0000000;0?ooo`030000003oool0oooo00`0oooo00@0
00000?ooo`3oool0oooo1P00000;0?ooo`040000003oool0oooo0?ooo`H00000303oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`00000@0?ooo`00
3@3oool00`000000oooo0?ooo`080?ooo`030000002`h>H0/>3V00X0/>3V00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool00000000000D0/>3V0P00000;0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool00`000000/>3V0;3PiP090;3PiP8000002@3oool00`00
0000oooo0?ooo`0;0?ooo`040000003oool00000000000D0/>3V0P00000;0?ooo`030000003oool0
oooo00D0oooo0P00000G0;3PiP8000003@3oool010000000oooo0000000000050;3PiP8000002P3o
ool00`000000oooo0?ooo`080?ooo`8000001P3oool00`000000/>3V0;3PiP0J0;3PiP@000001P2`
h>H00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000;3PiP2`h>H02@2`
h>H2000000T0oooo00<000000?ooo`3oool01@3oool00`000000/>3V0;3PiP090;3PiP8000000P3o
ool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000003@2`h>H010000000oooo
0?ooo`00000<0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`00000000001@2`h>H20000
00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo000000060;3PiP8000003`3oool000d0
oooo00<000000?ooo`3oool01P3oool7000000H0/>3V0P00000;0?ooo`030000003oool0oooo00X0
oooo0P0000080;3PiP030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`@000001@2`h>H2000000/0oooo00<000000?ooo`3oool02`3oool2000000P0
/>3V00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000002`h>H0/>3V01L0
/>3V00<000000?ooo`3oool02`3oool2000000P0/>3V00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`060?ooo`D000001@3oool00`000000/>3V0;3PiP0J0;3PiP8000002@2`h>H00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo200000050;3PiP8000002`3oool00`000000
oooo0?ooo`040?ooo`030000002`h>H0/>3V00`0/>3V00<000000?ooo`0000002`3oool00`000000
oooo0?ooo`020?ooo`8000002P2`h>H01@000000oooo0?ooo`3oool0000000`0oooo00<000000?oo
o`3oool02`3oool2000000P0/>3V00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?oo
o`800000202`h>H00`000000oooo0?ooo`0=0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`@0
0000102`h>H2000000030?ooo`000000000000@000003@3oool00`000000oooo0?ooo`0:0?ooo`80
00002@2`h>H00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo00000004000000h0oooo00<000000?ooo`3oool02P3oool2000000P0
/>3V0P00000:0?ooo`030000003oool0oooo00D0oooo00<000000;3PiP2`h>H05`2`h>H2000000`0
oooo00<000000;3PiP2`h>H01`2`h>H2000000T0oooo00<000000?ooo`3oool00P3oool4000000@0
/>3V0P0000040?ooo`030000002`h>H0/>3V01X0/>3V0P0000090;3PiP030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool3000000D0/>3V0P0000000`3oool0000000000003000000h0
oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3PiP0<0;3PiP@000002P3oool00`000000
oooo0?ooo`020?ooo`040000003oool00000000000H0/>3V0P0000040?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02P3oool00`000000/>3V0;3PiP070;3PiP8000002@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0:0?ooo`030000002`h>H0/>3V00L0/>3V0P00000>0?ooo`003@3oool00`000000
oooo0?ooo`02000000X0/>3V0P00000C0?ooo`030000003oool0oooo00T0oooo00<000000;3PiP2`
h>H0202`h>H2000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool02P3oool00`000000/>3V0;3PiP080;3PiP03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP0I0;3PiP03
0000003oool0oooo00X0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo008000002P2`h>H2000000<0oooo00<000000;3PiP2`h>H0602`h>H00`000000
oooo0000000:0;3PiP030000003oool0oooo00L0oooo00<000000?ooo`3oool00P00000:0;3PiP80
00004P3oool00`000000oooo0?ooo`020?ooo`030000002`h>H0/>3V00h0/>3V00<000000?ooo`00
00002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H000001P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000;3PiP2`h>H0202`h>H00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000;3PiP2`h>H0202`h>H00`000000
oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0000000=0;3PiP8000004P3oool00`000000oooo
0?ooo`090?ooo`030000002`h>H0/>3V00T0/>3V00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo0P00000B0?ooo`030000003oool0oooo00T0oooo
00<000000;3PiP2`h>H0202`h>H2000000T0oooo00<000000?ooo`3oool0103oool00`000000/>3V
0;3PiP0I0;3PiP8000002`3oool00`000000/>3V0;3PiP080;3PiP800000203oool00`000000oooo
0000000>0;3PiP040000003oool0oooo000001X0/>3V00<000000?ooo`0000002P2`h>H00`000000
oooo0?ooo`070?ooo`030000003oool0000000d0/>3V0P00000B0?ooo`040000003oool0oooo0000
0140/>3V00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000002`h>H0
/>3V00P0/>3V0P0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000;3PiP2`h>H0202`h>H2
000000d0oooo000=0?ooo`030000003oool0000000h0/>3V0P00000B0?ooo`030000003oool0oooo
00P0oooo00<000000;3PiP2`h>H02@2`h>H00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00T0oooo00<000000;3PiP2`h>H0202`h>H2000000T0oooo00<000000?ooo`3oool00`3oool20000
01`0/>3V00<000000?ooo`3oool02@3oool00`000000/>3V0;3PiP080;3PiP800000203oool00`00
0000oooo0000000>0;3PiP8000000P3oool00`000000/>3V0;3PiP0G0;3PiP030000003oool00000
00X0/>3V00<000000?ooo`3oool01`3oool00`000000oooo0000000>0;3PiP8000004@3oool01000
0000oooo0?ooo`00000A0;3PiP040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3o
ool00`000000/>3V0;3PiP080;3PiP800000203oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000002`
h>H0/>3V00P0/>3V0P00000=0?ooo`003@3oool200000100/>3V0P00000A0?ooo`030000003oool0
oooo00P0oooo0P0000090;3PiP030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool2
000000T0/>3V00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000002`h>H0
/>3V01/0/>3V0P00000:0?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool01`3oool2
00000100/>3V0P0000000`3oool000000;3PiP0G0;3PiP040000003oool0oooo000000T0/>3V00<0
00000?ooo`3oool0203oool200000100/>3V0P00000A0?ooo`030000003oool000000180/>3V0P00
000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00P0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`0000060?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000/>3V0;3PiP070;3PiP8000003P3o
ool000d0oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo0000000A0?ooo`030000003oool0
oooo00L0oooo0P0000090;3PiP030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool2
000000T0/>3V00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`8000007@2`h>H2
000000X0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?ooo`070?ooo`030000002`h>H0
/>3V00l0/>3V00<000000?ooo`0000000P00000G0;3PiP040000003oool0oooo000000T0/>3V00<0
00000?ooo`3oool0203oool00`000000/>3V0;3PiP0?0;3PiP030000003oool000000100oooo00<0
00000?ooo`0000004P2`h>H2000000X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000/>3V0;3P
iP080;3PiP030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0000
000000070;3PiP800000103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo
00<000000;3PiP2`h>H01`2`h>H2000000h0oooo000=0?ooo`030000002`h>H0/>3V0100/>3V00@0
00000?ooo`00000000003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000L0/>3V
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo
0P00000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000001`2`h>H00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0080oooo0P00000M0;3PiP030000003oool0000000T0oooo
0P0000080;3PiP030000003oool0oooo00P0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo
0?ooo`02000001D0/>3V00@000000?ooo`3oool0oooo0P0000070;3PiP030000003oool0oooo00T0
oooo00<000000;3PiP2`h>H0402`h>H010000000oooo00000000000?0?ooo`8000004P2`h>H00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo0P0000080;3PiP030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool2000000/0/>3V0P0000020?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool01`3oool2000000L0/>3V0P00000?0?ooo`003@3oool00`000000
/>3V0;3PiP0@0;3PiP050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`060?oo
o`040000003oool0oooo000000H0/>3V00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo000000H0/>3V00<000000?ooo`3oool02@3oool01`000000oooo0?oo
o`3oool000000?ooo`0000007@2`h>H00`000000oooo000000090?ooo`030000003oool0000000H0
/>3V0P00000:0?ooo`030000002`h>H0/>3V0100/>3V00@000000?ooo`3oool0oooo0P00000C0;3P
iP030000003oool0oooo0080oooo00<000000?ooo`0000001P2`h>H00`000000oooo0?ooo`090?oo
o`030000002`h>H0/>3V0100/>3V00D000000?ooo`3oool0oooo0000000>0?ooo`8000004P2`h>H0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000001`2`h>H0
0`000000oooo0?ooo`080?ooo`040000003oool0oooo0?ooo`8000003P2`h>H00`000000oooo0000
000@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000001P2`h>H2000000l0oooo000=
0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0oooo1P00000<0?ooo`040000003o
ool0oooo0?ooo`H000003P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo
00@000000?ooo`3oool0oooo1P00000<0?ooo`070000003oool0oooo0?ooo`000000oooo0000000M
0;3PiP040000003oool0oooo000000P0oooo00<000000?ooo`3oool01`00000;0?ooo`030000002`
h>H0/>3V0100/>3V00<000000?ooo`3oool00P3oool200000140/>3V00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`06000000`0oooo00<000000;3PiP2`h>H0402`h>H00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00`0oooo00<000000;3PiP2`h>H03`2`h>H00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00L000002`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`00000;0?ooo`040000003oool0oooo0?ooo`800000
3P2`h>H00`000000oooo0000000A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`00000@0?ooo`003@3oool00`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02P3oool010000000oooo0000000000050;3PiP8000003P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0:0?ooo`040000003oool0oooo00000080oooo00<000000;3PiP2`h>H06`2`h>H010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`00
0000/>3V0;3PiP0@0;3PiP030000003oool0oooo00@0oooo0P00000=0;3PiP8000001P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000;3PiP2`h>H0402`h>H00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000;3PiP2`h>H03`2`h>H00`00
0000oooo0?ooo`0:0?ooo`<000001P2`h>H2000000X0oooo00<000000?ooo`3oool01@3oool70000
00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P00000@0;3PiP8000001P3oool8000000<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo000=0?ooo`03
0000002`h>H0/>3V0100/>3V00<000000?ooo`3oool0103oool2000000`0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo0P0000080;3PiP03
0000003oool0oooo00d0oooo0P00000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000<0oooo00<000000;3P
iP2`h>H06P2`h>H01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0:0?ooo`030000002`h>H0/>3V0100/>3V00<000000?ooo`3oool01@3oool2
000000T0/>3V0`0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool0
0`000000/>3V0;3PiP0@0;3PiP030000003oool0oooo00@0oooo0P00000<0?ooo`030000002`h>H0
/>3V00d0/>3V00<000000?ooo`3oool02`3oool00`000000/>3V0;3PiP070;3PiP030000003oool0
oooo00P0oooo00<000000?ooo`3oool00`3oool2000000L0/>3V0P0000020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0
oooo00000140/>3V0P0000040?ooo`800000202`h>H200000080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000002`h>H0
/>3V0100/>3V00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000002`h>H0
/>3V00L0/>3V00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
000000@0oooo00<000000;3PiP2`h>H06@2`h>H00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000002`h>H0
/>3V0100/>3V00<000000?ooo`3oool01P3oool:000000/0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0;0?ooo`030000002`h>H0/>3V00l0/>3V00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`090?ooo`030000002`h>H0/>3V00d0/>3V00<000000?ooo`3oool02`3oool0
0`000000/>3V0;3PiP070;3PiP030000003oool0oooo00P0oooo00@000000?ooo`3oool0oooo0P00
000;0;3PiP<000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00@0
00000?ooo`00000000004@2`h>H200000080oooo0P00000<0;3PiP<000001`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00l0oooo000=0?ooo`8000004@2`h>H00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00`0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000103oool00`000000/>3V0;3P
iP0I0;3PiP030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00/0oooo0P00000A0;3PiP030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<0
00000;3PiP2`h>H03`2`h>H00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000;3PiP2`h>H02`2`h>H00`000000oooo0?ooo`0<0?ooo`030000002`h>H0/>3V00P0/>3V00<0
00000?ooo`3oool01`3oool010000000oooo0?ooo`00000>0;3PiP030000003oool0000000H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`040000003oool0000000000140
/>3V0P0000000`3oool000000;3PiP0>0;3PiP030000003oool0000000H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0@0?ooo`003@3oool200000100/>3V00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0<0?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool0
2P3oool7000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00`0oooo0P0000060?ooo`030000002`h>H0/>3V01L0/>3V00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2`3oool200000100/>3V00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000/>3V0;3PiP0>0;3PiP030000
003oool0oooo00X0oooo00<000000?ooo`3oool0203oool3000000T0/>3V0`00000>0?ooo`030000
002`h>H0/>3V00P0/>3V00<000000?ooo`3oool01`3oool00`000000oooo0000000@0;3PiP800000
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo0P0000000`3oool00000
0;3PiP0A0;3PiP030000003oool000000100/>3V0P0000060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0403oool000d0oooo00<000000?ooo`0000003`2`h>H00`000000oooo0?oo
o`0:0?ooo`8000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03@3oool00`000000/>3V0;3PiP080;3PiP8000002@3oool2000000H0/>3V0`00
00090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0=0?ooo`8000001P3oool00`000000/>3V0;3PiP0F0;3PiP030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`0000003`2`h>H00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`8000003`2`h>H00`000000oooo0?oo
o`0;0?ooo`8000002@3oool00`000000oooo000000070;3PiP030000003oool0000000l0oooo00<0
00000;3PiP2`h>H0202`h>H2000000P0oooo0P00000B0;3PiP8000001@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00`0oooo0P0000000`3oool000000;3PiP0A0;3PiP8000004P2`
h>H2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`003@3oool0
10000000oooo0?ooo`00000<0;3PiP8000003`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000002`
h>H0/>3V00P0/>3V0P0000070?ooo`8000002P2`h>H2000000P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3o
ool00`000000/>3V0;3PiP0D0;3PiP030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000
302`h>H2000000l0oooo0P00000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0000000=0;3PiP030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0700000080oooo00<000000?ooo`3oool03@3oool00`000000/>3V
0;3PiP070;3PiP030000003oool0000000P0oooo0P00000C0;3PiP030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo00000180
/>3V0P00000B0;3PiP8000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140
oooo000=0?ooo`<0000000<0oooo0000002`h>H02@2`h>H00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00h0oooo00<000000;3PiP2`h>H0202`h>H00`000000oooo000000050?ooo`030000
002`h>H0/>3V00`0/>3V00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03P3oool3000000L0oooo00<000000;3PiP2`h>H0
4`2`h>H00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0=0?ooo`<0000000<0oooo0000002`h>H02@2`h>H00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0=0?ooo`D000002P2`h>H00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000002`h>H0/>3V00L0/>3V
00@000000?ooo`3oool000001`3oool00`000000/>3V0;3PiP0C0;3PiP030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0000
0140/>3V0P00000D0;3PiP800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0180oooo000>0?ooo`030000003oool0000000<00000202`h>H00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00l0oooo00<000000;3PiP2`h>H01P2`h>H010000000oooo0?ooo`0000050?oo
o`030000002`h>H0/>3V00`0/>3V0P0000070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000000<00000103oool00`00
0000/>3V0;3PiP0A0;3PiP030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000000`0000080;3P
iP030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0
00000140oooo00<000000?ooo`0000000`0000080;3PiP030000003oool0oooo0140oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo00<00000
0;3PiP2`h>H01@2`h>H01@000000oooo0?ooo`3oool0000000L0oooo00<000000;3PiP2`h>H04`2`
h>H00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0000000A0;3PiP800000502`h>H2000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`003`3oool2000000<0oooo2000000E0?ooo`8000001P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool04@3oool2000000D0/>3V00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000100/>3V0`0000060?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0A0?ooo`8000000`3oool400000003
0?ooo`000000000000l0/>3V0P00000=0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0@0?ooo`8000000`3oool8000001H0oooo0P00000:0?ooo`050000003oool0oooo
0?ooo`0000004P3oool2000000<0oooo2000000E0?ooo`8000001P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0140oooo0P0000050;3PiP030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000/>3V0;3PiP0C0;3PiP8000000`3oool01@000000oooo0?ooo`3o
ool000000180oooo0`00000?0;3PiP030000003oool0000001D0/>3V0P0000030?ooo`050000003o
ool0oooo0?ooo`0000005@3oool00140oooo00<000000?ooo`3oool0103oool5000001H0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
4P3oool6000000D0oooo00@000000?ooo`3oool000004@2`h>H010000000oooo0?ooo`0000050?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00@0oooo1P00000:0;3PiP8000003`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`@000005`3oool00`000000oooo0?oo
o`070?ooo`050000003oool0oooo0?ooo`000000503oool00`000000oooo0?ooo`040?ooo`D00000
5P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4P3oool6000000D0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP0C0;3PiP800000
0`3oool01@000000oooo0?ooo`3oool0000001@0oooo00<000000;3PiP2`h>H03@2`h>H00`000000
oooo0000000E0;3PiP8000000`3oool01@000000oooo0?ooo`3oool0000001D0oooo000B0?ooo`03
0000003oool0oooo00P0oooo1000000C0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`0000004P2`h>H010000000oooo0?ooo`0000050?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`080?ooo`@000001P2`h>H00`000000oooo0?oo
o`0@0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`080?ooo`D000004`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000001H0
oooo00<000000?ooo`3oool0203oool4000001<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000002`h>H0/>3V01<0/>3V00<000000?ooo`0000000P3oool010000000
oooo0?ooo`00000F0?ooo`030000002`h>H0/>3V00/0/>3V00@000000?ooo`3oool000005@2`h>H0
0`000000oooo000000020?ooo`040000003oool0oooo000001H0oooo000C0?ooo`800000303oool4
00000100oooo0P0000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool000000180/>3V00@000000?ooo`3oool0oooo
0P0000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0;0?ooo`H000004`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
01D0oooo0P00000=0?ooo`@00000403oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo
000001L0oooo00<000000?ooo`3oool02`3oool400000100oooo0P0000030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00<0oooo00<000000;3PiP2`h>H04`2`h>H00`000000oooo000000020?ooo`040000003oool0
oooo000001L0oooo0P00000:0;3PiP050000003oool0oooo0?ooo`0000005@2`h>H00`000000oooo
000000020?ooo`040000003oool0oooo000001H0oooo000E0?ooo`030000003oool0oooo00X0oooo
2000000=0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000001X0oooo0P000007
0?ooo`8000004P2`h>H00`000000oooo0?ooo`030?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000001X0oooo0P00000<0?ooo`P000004@3oool01@000000oooo0000003oool00000
01X0oooo00<000000?ooo`3oool02P3oool8000000d0oooo0P0000050?ooo`030000003oool00000
01T0oooo0P00000<0?ooo`P000003@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0603oool2000000L0oooo00<000000?ooo`3oool00P3oool00`000000/>3V0;3PiP0C
0;3PiP080000003oool0oooo0000003oool000000?ooo`00000J0?ooo`030000002`h>H0/>3V00D0
/>3V0P0000040?ooo`030000002`h>H0/>3V01<0/>3V00P000000?ooo`3oool000000?ooo`000000
oooo000001L0oooo000F0?ooo`030000003oool0oooo00L0oooo0P0000050;3PiP030000003oool0
oooo00@000002P3oool020000000oooo0?ooo`000000oooo0000003oool00000703oool00`000000
oooo0?ooo`040?ooo`8000004P2`h>H00`000000oooo0?ooo`040?ooo`080000003oool0oooo0000
003oool000000?ooo`00000L0?ooo`030000003oool0oooo00L0oooo0P0000050;3PiP030000003o
ool0oooo00@000003@3oool01@000000oooo0000003oool0000001/0oooo00<000000?ooo`3oool0
1`3oool2000000D0/>3V00<000000?ooo`3oool01@00000:0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000006`3oool00`000000oooo0?ooo`070?ooo`8000001@2`h>H00`000000oooo
0?ooo`04000000X0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool2000001<0/>3V00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000006`3oool7000000H0oooo00<000000;3PiP2`h>H04P2`
h>H02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000000G0?ooo`005`3oool00`000000
oooo0?ooo`050?ooo`030000002`h>H0/>3V00H0/>3V00<000000?ooo`3oool00`3oool5000000H0
oooo00<000000?ooo`3oool00`00000N0?ooo`030000003oool0oooo00@0oooo00<000000;3PiP2`
h>H0402`h>H00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<000007P3oool00`000000
oooo0?ooo`050?ooo`030000002`h>H0/>3V00H0/>3V00<000000?ooo`3oool00`3oool5000000T0
oooo0`00000M0?ooo`030000003oool0oooo00D0oooo00<000000;3PiP2`h>H01P2`h>H00`000000
oooo0?ooo`040?ooo`@000001`3oool010000000oooo0?ooo`3oool2000001d0oooo00<000000?oo
o`3oool01@3oool00`000000/>3V0;3PiP060;3PiP030000003oool0oooo00<0oooo1@0000060?oo
o`060000003oool0oooo0000003oool000007P3oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo0?ooo`8000004`2`h>H00`000000oooo0?ooo`020?ooo`<000007@3oool00`000000oooo
0?ooo`090?ooo`030000002`h>H0/>3V0180/>3V00<000000?ooo`3oool00P3oool3000001P0oooo
000H0?ooo`8000001@3oool00`000000/>3V0;3PiP060;3PiP030000003oool0oooo00P0oooo1000
00030?ooo`D000007`3oool00`000000oooo0?ooo`030?ooo`030000002`h>H0/>3V00l0/>3V00<0
00000?ooo`3oool01`3oool5000001l0oooo00<000000?ooo`3oool00`3oool00`000000/>3V0;3P
iP070;3PiP030000003oool0oooo00P0oooo100000050?ooo`<000007P3oool2000000D0oooo00<0
00000;3PiP2`h>H01`2`h>H00`000000oooo0?ooo`070?ooo`D000000`3oool2000000030?ooo`00
0000000001h0oooo00<000000?ooo`3oool0103oool00`000000/>3V0;3PiP060;3PiP030000003o
ool0oooo00P0oooo100000030?ooo`<0000000<0oooo0000003oool07P3oool00`000000oooo0?oo
o`030?ooo`070000003oool0oooo0?ooo`000000oooo0000000A0;3PiP030000003oool0oooo00<0
oooo0`00000N0?ooo`8000002@3oool200000180/>3V00<000000?ooo`3oool00`3oool3000001P0
oooo000J0?ooo`050000003oool0oooo0?ooo`0000002P2`h>H00`000000oooo0?ooo`0;0?ooo`@0
000000<0oooo0000000000008@3oool00`000000oooo0?ooo`030?ooo`030000002`h>H0/>3V00h0
/>3V00<000000?ooo`3oool02@3oool200000240oooo00<000000?ooo`3oool00P3oool00`000000
/>3V0;3PiP080;3PiP030000003oool0oooo00/0oooo100000020?ooo`030000003oool0oooo01l0
oooo00D000000?ooo`3oool0oooo0000000;0;3PiP030000003oool0oooo00/0oooo100000000`3o
ool000000000000P0?ooo`030000003oool0oooo0080oooo00<000000;3PiP2`h>H0202`h>H00`00
0000oooo0?ooo`0;0?ooo`@0000000<0oooo0000000000008@3oool00`000000oooo0?ooo`030?oo
o`060000003oool0oooo0000003oool000004@2`h>H00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000A0;3PiP030000003o
ool0oooo00@0oooo00<000000?ooo`3oool05`3oool001/0oooo00@000000?ooo`3oool000002P2`
h>H200000100oooo0`00000R0?ooo`8000000`3oool00`000000/>3V0;3PiP0>0;3PiP030000003o
ool0oooo00P0oooo0`00000R0?ooo`8000000P3oool00`000000/>3V0;3PiP080;3PiP030000003o
ool0oooo00l0oooo0`00000R0?ooo`040000003oool0oooo000000/0/>3V00<000000?ooo`3oool0
3`3oool300000240oooo0P0000020?ooo`030000002`h>H0/>3V00P0/>3V00<000000?ooo`3oool0
3`3oool300000280oooo0P0000030?ooo`040000003oool0oooo00000080oooo00<000000;3PiP2`
h>H03@2`h>H00`000000oooo0?ooo`030?ooo`<000008P3oool00`000000oooo0?ooo`050?ooo`04
0000003oool0oooo000000h0/>3V0P0000050?ooo`<000006@3oool001`0oooo0`00000:0;3PiP80
0000303oool4000002L0oooo00D000000?ooo`3oool0oooo0000000?0;3PiP030000003oool0oooo
00@0oooo1000000W0?ooo`030000003oool0000000X0/>3V00<000000?ooo`3oool02`3oool40000
02H0oooo0`00000:0;3PiP8000003@3oool4000002H0oooo00<000000?ooo`0000002P2`h>H00`00
0000oooo0?ooo`0;0?ooo`@000009`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3o
ool00`000000/>3V0;3PiP0;0;3PiP030000003oool0oooo00@000009P3oool2000000D0oooo00@0
00000?ooo`3oool000003@2`h>H010000000oooo0?ooo`3oool4000001`0oooo000N0?ooo`800000
2@2`h>H00`000000oooo0?ooo`070?ooo`@00000;03oool00`000000oooo0?ooo`02000000`0/>3V
0P0000020?ooo`D00000;03oool2000000X0/>3V00<000000?ooo`3oool01P3oool5000002`0oooo
0P0000090;3PiP030000003oool0oooo00L0oooo1@00000[0?ooo`8000002P2`h>H00`000000oooo
0?ooo`060?ooo`D00000;03oool01P000000oooo0?ooo`000000oooo000000@0oooo00<000000;3P
iP2`h>H0202`h>H5000002`0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000/0/>3V1@00000P0?ooo`007`3oool00`000000/>3V0;3PiP060;3PiP030000003oool0oooo
00<0oooo1@00000a0?ooo`030000003oool0oooo008000002P2`h>H500000380oooo00<000000;3P
iP2`h>H01`2`h>H00`000000oooo0?ooo`030?ooo`@00000<P3oool00`000000/>3V0;3PiP060;3P
iP030000003oool0oooo00@0oooo1000000a0?ooo`800000202`h>H00`000000oooo0?ooo`030?oo
o`@00000<P3oool00`000000oooo0?ooo`02000000D0oooo100000020;3PiPD00000<@3oool01@00
0000oooo0?ooo`3oool0000000@0oooo100000030;3PiPD00000903oool00200oooo0P0000060;3P
iP030000003oool0000000<00000=`3oool3000000030?ooo`000000000000@0/>3V1@00000g0?oo
o`8000001P2`h>H00`000000oooo00000004000003L0oooo0P0000060;3PiP030000003oool00000
00@00000=P3oool2000000L0/>3V1P00000g0?ooo`@000001P3oool6000003H0oooo0P0000000`3o
ool000000?ooo`050?ooo`D00000:@3oool00240oooo0P0000030;3PiP@00000?@3oool200000080
oooo1P00000k0?ooo`8000000`2`h>H4000003d0oooo0P0000030;3PiP@00000?@3oool200000080
/>3V1000000n0?ooo`8000000P3oool4000003h0oooo0P0000020?ooo`@00000;P3oool002<0oooo
100000110?ooo`<00000@`3oool400000480oooo100000110?ooo`D00000@@3oool3000004<0oooo
0`00000b0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00
o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00
o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 505.75}, {443.5, 0}} -> {-0.176481, -0.153553, \
0.0145388, 0.0145388}, {{12.125, 75.4375}, {432.938, 367.938}} -> {-1.33076, \
-1.35762, 0.0315267, 0.0315267}, {{81.8125, 145.125}, {432.938, 367.938}} -> \
{-3.52778, -1.35762, 0.0315267, 0.0315267}, {{151.5, 214.813}, {432.938, \
367.938}} -> {-5.7248, -1.35762, 0.0315267, 0.0315267}, {{221.188, 284.5}, \
{432.938, 367.938}} -> {-7.92182, -1.35762, 0.0315267, 0.0315267}, {{290.875, \
354.188}, {432.938, 367.938}} -> {-10.1188, -1.35762, 0.0315267, 0.0315267}, \
{{360.563, 423.875}, {432.938, 367.938}} -> {-12.3159, -1.35762, 0.0315267, \
0.0315267}, {{430.25, 493.563}, {432.938, 367.938}} -> {-14.5129, -1.35762, \
0.0315267, 0.0315267}, {{12.125, 75.4375}, {361.438, 296.438}} -> {-1.33076, \
-3.61178, 0.0315267, 0.0315267}, {{81.8125, 145.125}, {361.438, 296.438}} -> \
{-3.52778, -3.61178, 0.0315267, 0.0315267}, {{151.5, 214.813}, {361.438, \
296.438}} -> {-5.7248, -3.61178, 0.0315267, 0.0315267}, {{221.188, 284.5}, \
{361.438, 296.438}} -> {-7.92182, -3.61178, 0.0315267, 0.0315267}, {{290.875, \
354.188}, {361.438, 296.438}} -> {-10.1188, -3.61178, 0.0315267, 0.0315267}, \
{{360.563, 423.875}, {361.438, 296.438}} -> {-12.3159, -3.61178, 0.0315267, \
0.0315267}, {{430.25, 493.563}, {361.438, 296.438}} -> {-14.5129, -3.61178, \
0.0315267, 0.0315267}, {{12.125, 75.4375}, {289.938, 225}} -> {-1.33084, \
-5.86526, 0.0315284, 0.0315284}, {{81.8125, 145.125}, {289.938, 225}} -> \
{-3.52797, -5.86526, 0.0315284, 0.0315284}, {{151.5, 214.813}, {289.938, \
225}} -> {-5.7251, -5.86526, 0.0315284, 0.0315284}, {{221.188, 284.5}, \
{289.938, 225}} -> {-7.92224, -5.86526, 0.0315284, 0.0315284}, {{290.875, \
354.188}, {289.938, 225}} -> {-10.1194, -5.86526, 0.0315284, 0.0315284}, \
{{360.563, 423.875}, {289.938, 225}} -> {-12.3165, -5.86526, 0.0315284, \
0.0315284}, {{430.25, 493.563}, {289.938, 225}} -> {-14.5136, -5.86526, \
0.0315284, 0.0315284}, {{12.125, 75.4375}, {218.5, 153.5}} -> {-1.33076, \
-8.11813, 0.0315267, 0.0315267}, {{81.8125, 145.125}, {218.5, 153.5}} -> \
{-3.52778, -8.11813, 0.0315267, 0.0315267}, {{151.5, 214.813}, {218.5, \
153.5}} -> {-5.7248, -8.11813, 0.0315267, 0.0315267}, {{221.188, 284.5}, \
{218.5, 153.5}} -> {-7.92182, -8.11813, 0.0315267, 0.0315267}, {{290.875, \
354.188}, {218.5, 153.5}} -> {-10.1188, -8.11813, 0.0315267, 0.0315267}, \
{{360.563, 423.875}, {218.5, 153.5}} -> {-12.3159, -8.11813, 0.0315267, \
0.0315267}, {{430.25, 493.563}, {218.5, 153.5}} -> {-14.5129, -8.11813, \
0.0315267, 0.0315267}, {{12.125, 75.4375}, {147, 82}} -> {-1.33076, -10.3723, \
0.0315267, 0.0315267}, {{81.8125, 145.125}, {147, 82}} -> {-3.52778, \
-10.3723, 0.0315267, 0.0315267}, {{151.5, 214.813}, {147, 82}} -> {-5.7248, \
-10.3723, 0.0315267, 0.0315267}, {{221.188, 284.5}, {147, 82}} -> {-7.92182, \
-10.3723, 0.0315267, 0.0315267}, {{290.875, 354.188}, {147, 82}} -> \
{-10.1188, -10.3723, 0.0315267, 0.0315267}, {{360.563, 423.875}, {147, 82}} -> \
{-12.3159, -10.3723, 0.0315267, 0.0315267}, {{430.25, 493.563}, {147, 82}} -> \
{-14.5129, -10.3723, 0.0315267, 0.0315267}, {{12.125, 75.4375}, {75.5, \
10.5625}} -> {-1.33084, -12.6261, 0.0315284, 0.0315284}, {{81.8125, 145.125}, \
{75.5, 10.5625}} -> {-3.52797, -12.6261, 0.0315284, 0.0315284}, {{151.5, \
214.813}, {75.5, 10.5625}} -> {-5.7251, -12.6261, 0.0315284, 0.0315284}, \
{{221.188, 284.5}, {75.5, 10.5625}} -> {-7.92224, -12.6261, 0.0315284, \
0.0315284}, {{290.875, 354.188}, {75.5, 10.5625}} -> {-10.1194, -12.6261, \
0.0315284, 0.0315284}, {{360.563, 423.875}, {75.5, 10.5625}} -> {-12.3165, \
-12.6261, 0.0315284, 0.0315284}, {{430.25, 493.563}, {75.5, 10.5625}} -> \
{-14.5136, -12.6261, 0.0315284, 0.0315284}}]
}, Open  ]],

Cell["\<\
The sum of the radius of all circles in any of the above triangulations is a \
constant approximately equal to 1.30678. In general:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      s = First[
          brackets[
            Take[CharacterRange["\<a\>", "\<z\>"], 
              n - 1]]]; \[IndentingNewLine]v = \({Cos[\(\(\ \)\(2\ \[Pi]\ #\)\
\)\/n], Sin[\(\(\ \)\(2\ \[Pi]\ #\)\)\/n]} &\) /@ 
          Range[n]; \[IndentingNewLine]Plus\  @@ \((\(Last[
                decorateT[#]] &\)\  /@ \ tri[functional[s], v])\), {n, 3, 
        7}]\)], "Input",
  CellLabel->"In[272]:="],

Cell[BoxData[
    \({0.5`, 0.8284271247461901`, 1.0450849718747368`, 1.1961524227066302`, 
      1.306782075316928`}\)], "Output",
  CellLabel->"Out[272]="]
}, Open  ]],

Cell[TextData[{
  "Exact expressions for these are: ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  ", 2(",
  Cell[BoxData[
      \(TraditionalForm\`\@2 - 1\)]],
  "), ",
  Cell[BoxData[
      \(TraditionalForm\`1\/4\)]],
  "(5",
  Cell[BoxData[
      \(TraditionalForm\`\@5\)]],
  "-7), 3",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  "-4, ... and can be obtained as follows:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(radius[{A_, B_, C_}]\), ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({d, P, x, y, Px, Py, h, k, u, v}\), ",", 
          "\[IndentingNewLine]", 
          
          RowBox[{\(d = \@\(\((C - A)\) . \((C - A)\)\)\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{\({{x, y}}\), "=", 
              RowBox[{"(", 
                RowBox[{\({x, y}\), " ", "/.", 
                  RowBox[{"Solve", "[", 
                    RowBox[{
                      RowBox[{
                        RowBox[{
                          RowBox[{"(", GridBox[{
                                {"x", \(-y\)},
                                {"y", "x"}
                                }], ")"}], ".", \((C - A)\)}], 
                        "\[Equal]", \({d, 0}\)}], ",", \({x, y}\)}], "]"}]}], 
                ")"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"P", "=", 
              RowBox[{\({Px, Py}\), "=", 
                RowBox[{
                  RowBox[{"(", GridBox[{
                        {"x", \(-y\)},
                        {"y", "x"}
                        }], ")"}], ".", \((B - A)\)}]}]}], ";", 
            "\[IndentingNewLine]", \(h = \@\(P . P\)\), ";", 
            "\[IndentingNewLine]", \(u = Py\/\(h + Px\)\), ";", 
            "\[IndentingNewLine]", \(k = \@\(\((d - Px)\)\^2 + Py\^2\)\), ";",
             "\[IndentingNewLine]", \(v = Py\/\(k + d - Px\)\), ";", 
            "\[IndentingNewLine]", \(Abs[
              FullSimplify[\(d\ u\ v\)\/\(u + v\)]]\)}]}], "]"}]}]], "Input",
  CellLabel->"In[105]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[h = \(2  \[Pi]\)\/n; \n
      FullSimplify[
        Plus\  @@ \((radius\  /@ \ 
              Table[{{Cos[h], Sin[h]}, {Cos[i\ h], 
                    Sin[i\ h]}, {Cos[\((i + 1)\)\ h], 
                    Sin[\((i + 1)\)\ h]}}, {i, 2, n - 1}])\)], {n, 3, 
        10}]\)], "Input",
  CellLabel->"In[208]:="],

Cell[BoxData[
    \({1\/2, 2\ \((\(-1\) + \@2)\), 
      1\/4\ \((\(-7\) + 5\ \@5)\), \(-4\) + 3\ \@3, 
      Root[\(-337\) + 124\ #1 + 92\ #1\^2 + 8\ #1\^3 &, 3], \(-6\) + 
        4\ \@\(2 + \@2\), 
      Root[\(-1\) + 12\ #1\^2 + 8\ #1\^3 &, 3] + 
        Root[3 - 18\ #1 + 24\ #1\^2 + 8\ #1\^3 &, 2] + 
        Root[\(-1\) + 6\ #1 + 24\ #1\^2 + 8\ #1\^3 &, 3] + 
        Root[\(-9\) + 36\ #1 + 36\ #1\^2 + 8\ #1\^3 &, 3] - 
        1\/2\ Root[\(-1\) + 72\ #1\^2 - 1296\ #1\^4 + 1728\ #1\^6 &, 
            5]\ \((2\ \@3\ Cos[\(2\ \[Pi]\)\/9] + 
              Root[\(-192\) + 144\ #1\^2 - 24\ #1\^4 + #1\^6 &, 2] - 
              2\ Sin[\(2\ \[Pi]\)\/9])\) + \(\@3\ \((\(-1\) + Cos[\(2\ \
\[Pi]\)\/9] - Cos[\(8\ \[Pi]\)\/9])\) + Sin[\(2\ \[Pi]\)\/9] - Sin[\(8\ \[Pi]\
\)\/9]\)\/\(2\ \((\@3 + \@\(2 + Cos[\(2\ \[Pi]\)\/9] - \@3\ Sin[\(2\ \
\[Pi]\)\/9]\) + \@\(2 + Cos[\(8\ \[Pi]\)\/9] - \@3\ Sin[\(8\ \[Pi]\)\/9]\))\)\
\) + Root[\(-15552\) + 2592\ #1\^2 - 108\ #1\^4 + #1\^6 &, 5]\/\(4\ \((\@3 + \
\@\(2 + Cos[\(2\ \[Pi]\)\/9] + \@3\ Sin[\(2\ \[Pi]\)\/9]\) + \@\(2 + Cos[\(14\
\ \[Pi]\)\/9] + \@3\ Sin[\(14\ \[Pi]\)\/9]\))\)\), \(-8\) + 
        5\ \@\(1\/2\ \((5 + \@5)\)\)}\)], "Output",
  CellLabel->"Out[208]="]
}, Open  ]],

Cell[BoxData[
    \(triangulation3[s_String] := 
      Module[{u = functional[s], n, v, A, B, C}, \[IndentingNewLine]n = 
          numVar[u] + 
            1; \[IndentingNewLine]v = \(N[{Cos[\(\(\ \)\(2\ \[Pi]\ #\)\)\/n], 
                  Sin[\(\(\ \)\(2\ \[Pi]\ #\)\)\/n]}] &\) /@ 
            Range[n]; \[IndentingNewLine]Graphics[\(\(({A, B, 
                    C} = #; \[IndentingNewLine]\ {{Coral, 
                    Polygon[\(1\/2\) {A + B, B + C, A + C, A + B}]}, 
                  Line[\(1\/2\) {A + B, B + C, A + C, A + B}]})\) &\) /@ \ 
            tri[u, v], AspectRatio \[Rule] Automatic]]\)], "Input",
  CellLabel->"In[273]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[
          Partition[triangulation3\  /@ \ sweep["\<abcdefgh\>"], 
            9]]];\)\)], "Input",
  CellLabel->"In[274]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33157 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.00789447 0.10582 [
[ 0 0 0 0 ]
[ 1 .33157 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .33157 L
0 .33157 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00789447 0.120991 0.106575 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.13868 .19211 m
.42954 .02418 L
.31467 .16107 L
.13868 .19211 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.13868 .19211 m
.42954 .02418 L
.31467 .16107 L
.13868 .19211 L
s
1 .498 .314 r
.31467 .85435 m
.02381 .50771 L
.31467 .67564 L
.31467 .85435 L
F
0 g
.31467 .85435 m
.02381 .50771 L
.31467 .67564 L
.31467 .85435 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.46944 .58629 m
.31467 .16107 L
.7603 .41836 L
.46944 .58629 L
F
0 g
.46944 .58629 m
.31467 .16107 L
.7603 .41836 L
.46944 .58629 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.31467 .67564 L
.46944 .58629 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.31467 .67564 L
.46944 .58629 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.130709 0.00789447 0.227891 0.106575 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.42954 .02418 m
.7603 .0825 L
.58431 .11353 L
.42954 .02418 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.42954 .02418 m
.7603 .0825 L
.58431 .11353 L
.42954 .02418 L
s
1 .498 .314 r
.31467 .85435 m
.02381 .50771 L
.31467 .67564 L
.31467 .85435 L
F
0 g
.31467 .85435 m
.02381 .50771 L
.31467 .67564 L
.31467 .85435 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
F
0 g
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
s
1 .498 .314 r
.58431 .44939 m
.58431 .11353 L
.91507 .50771 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.58431 .11353 L
.91507 .50771 L
.58431 .44939 L
s
1 .498 .314 r
.7603 .93293 m
.31467 .67564 L
.46944 .58629 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.31467 .67564 L
.46944 .58629 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.237609 0.00789447 0.334791 0.106575 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.7603 .0825 m
.97619 .33978 L
.82142 .25043 L
.7603 .0825 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.7603 .0825 m
.97619 .33978 L
.82142 .25043 L
.7603 .0825 L
s
1 .498 .314 r
.31467 .85435 m
.02381 .50771 L
.31467 .67564 L
.31467 .85435 L
F
0 g
.31467 .85435 m
.02381 .50771 L
.31467 .67564 L
.31467 .85435 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
F
0 g
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.7603 .41836 m
.82142 .25043 L
.97619 .67564 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.82142 .25043 L
.97619 .67564 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.31467 .67564 L
.46944 .58629 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.31467 .67564 L
.46944 .58629 L
.7603 .93293 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.344509 0.00789447 0.441691 0.106575 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.13868 .64461 m
.13868 .19211 L
.25355 .50771 L
.13868 .64461 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.13868 .64461 m
.13868 .19211 L
.25355 .50771 L
.13868 .64461 L
s
1 .498 .314 r
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
F
0 g
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
s
1 .498 .314 r
.42954 .99125 m
.25355 .50771 L
.42954 .53875 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.25355 .50771 L
.42954 .53875 L
.42954 .99125 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.42954 .53875 L
.58431 .44939 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.42954 .53875 L
.58431 .44939 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.451409 0.00789447 0.548591 0.106575 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.13868 .19211 m
.42954 .02418 L
.31467 .16107 L
.13868 .19211 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.13868 .19211 m
.42954 .02418 L
.31467 .16107 L
.13868 .19211 L
s
1 .498 .314 r
.02381 .50771 m
.31467 .16107 L
.31467 .33978 L
.02381 .50771 L
F
0 g
.02381 .50771 m
.31467 .16107 L
.31467 .33978 L
.02381 .50771 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.46944 .765 m
.31467 .33978 L
.7603 .41836 L
.46944 .765 L
F
0 g
.46944 .765 m
.31467 .33978 L
.7603 .41836 L
.46944 .765 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.558309 0.00789447 0.655491 0.106575 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.02381 .50771 m
.13868 .19211 L
.13868 .37082 L
.02381 .50771 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .50771 m
.13868 .19211 L
.13868 .37082 L
.02381 .50771 L
s
1 .498 .314 r
.42954 .02418 m
.7603 .0825 L
.58431 .11353 L
.42954 .02418 L
F
0 g
.42954 .02418 m
.7603 .0825 L
.58431 .11353 L
.42954 .02418 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.46944 .765 m
.13868 .37082 L
.58431 .44939 L
.46944 .765 L
F
0 g
.46944 .765 m
.13868 .37082 L
.58431 .44939 L
.46944 .765 L
s
1 .498 .314 r
.58431 .44939 m
.58431 .11353 L
.91507 .50771 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.58431 .11353 L
.91507 .50771 L
.58431 .44939 L
s
1 .498 .314 r
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.665209 0.00789447 0.762391 0.106575 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.02381 .50771 m
.13868 .19211 L
.13868 .37082 L
.02381 .50771 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .50771 m
.13868 .19211 L
.13868 .37082 L
.02381 .50771 L
s
1 .498 .314 r
.7603 .0825 m
.97619 .33978 L
.82142 .25043 L
.7603 .0825 L
F
0 g
.7603 .0825 m
.97619 .33978 L
.82142 .25043 L
.7603 .0825 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.46944 .765 m
.13868 .37082 L
.58431 .44939 L
.46944 .765 L
F
0 g
.46944 .765 m
.13868 .37082 L
.58431 .44939 L
.46944 .765 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.7603 .41836 m
.82142 .25043 L
.97619 .67564 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.82142 .25043 L
.97619 .67564 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.772109 0.00789447 0.869291 0.106575 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.13868 .19211 m
.58431 .11353 L
.46944 .25043 L
.13868 .19211 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.13868 .19211 m
.58431 .11353 L
.46944 .25043 L
.13868 .19211 L
s
1 .498 .314 r
.42954 .02418 m
.7603 .0825 L
.58431 .11353 L
.42954 .02418 L
F
0 g
.42954 .02418 m
.7603 .0825 L
.58431 .11353 L
.42954 .02418 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.46944 .58629 m
.46944 .25043 L
.91507 .50771 L
.46944 .58629 L
F
0 g
.46944 .58629 m
.46944 .25043 L
.91507 .50771 L
.46944 .58629 L
s
1 .498 .314 r
.46944 .765 m
.02381 .50771 L
.46944 .58629 L
.46944 .765 L
F
0 g
.46944 .765 m
.02381 .50771 L
.46944 .58629 L
.46944 .765 L
s
1 .498 .314 r
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.879009 0.00789447 0.97619 0.106575 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.13868 .64461 m
.13868 .19211 L
.25355 .50771 L
.13868 .64461 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.13868 .64461 m
.13868 .19211 L
.25355 .50771 L
.13868 .64461 L
s
1 .498 .314 r
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
F
0 g
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
s
1 .498 .314 r
.42954 .53875 m
.42954 .02418 L
.60554 .50771 L
.42954 .53875 L
F
0 g
.42954 .53875 m
.42954 .02418 L
.60554 .50771 L
.42954 .53875 L
s
1 .498 .314 r
.42954 .99125 m
.25355 .50771 L
.42954 .53875 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.25355 .50771 L
.42954 .53875 L
.42954 .99125 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.60554 .50771 L
.7603 .41836 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.60554 .50771 L
.7603 .41836 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.116443 0.120991 0.215124 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.7603 .0825 m
.97619 .33978 L
.82142 .25043 L
.7603 .0825 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.7603 .0825 m
.97619 .33978 L
.82142 .25043 L
.7603 .0825 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
F
0 g
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
s
1 .498 .314 r
.46944 .765 m
.02381 .50771 L
.46944 .58629 L
.46944 .765 L
F
0 g
.46944 .765 m
.02381 .50771 L
.46944 .58629 L
.46944 .765 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.7603 .41836 m
.82142 .25043 L
.97619 .67564 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.82142 .25043 L
.97619 .67564 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.130709 0.116443 0.227891 0.215124 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.13868 .64461 m
.13868 .19211 L
.25355 .50771 L
.13868 .64461 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.13868 .64461 m
.13868 .19211 L
.25355 .50771 L
.13868 .64461 L
s
1 .498 .314 r
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
F
0 g
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.58431 .9019 m
.25355 .50771 L
.58431 .44939 L
.58431 .9019 L
F
0 g
.58431 .9019 m
.25355 .50771 L
.58431 .44939 L
.58431 .9019 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.237609 0.116443 0.334791 0.215124 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.02381 .50771 m
.13868 .19211 L
.13868 .37082 L
.02381 .50771 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .50771 m
.13868 .19211 L
.13868 .37082 L
.02381 .50771 L
s
1 .498 .314 r
.13868 .82332 m
.13868 .37082 L
.25355 .50771 L
.13868 .82332 L
F
0 g
.13868 .82332 m
.13868 .37082 L
.25355 .50771 L
.13868 .82332 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.58431 .9019 m
.25355 .50771 L
.58431 .44939 L
.58431 .9019 L
F
0 g
.58431 .9019 m
.25355 .50771 L
.58431 .44939 L
.58431 .9019 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.344509 0.116443 0.441691 0.215124 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.13868 .19211 m
.42954 .02418 L
.31467 .16107 L
.13868 .19211 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.13868 .19211 m
.42954 .02418 L
.31467 .16107 L
.13868 .19211 L
s
1 .498 .314 r
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
F
0 g
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
s
1 .498 .314 r
.46944 .58629 m
.31467 .16107 L
.7603 .41836 L
.46944 .58629 L
F
0 g
.46944 .58629 m
.31467 .16107 L
.7603 .41836 L
.46944 .58629 L
s
1 .498 .314 r
.58431 .9019 m
.13868 .64461 L
.46944 .58629 L
.58431 .9019 L
F
0 g
.58431 .9019 m
.13868 .64461 L
.46944 .58629 L
.58431 .9019 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.451409 0.116443 0.548591 0.215124 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.42954 .02418 m
.7603 .0825 L
.58431 .11353 L
.42954 .02418 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.42954 .02418 m
.7603 .0825 L
.58431 .11353 L
.42954 .02418 L
s
1 .498 .314 r
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
F
0 g
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
s
1 .498 .314 r
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
F
0 g
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
s
1 .498 .314 r
.58431 .44939 m
.58431 .11353 L
.91507 .50771 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.58431 .11353 L
.91507 .50771 L
.58431 .44939 L
s
1 .498 .314 r
.58431 .9019 m
.13868 .64461 L
.46944 .58629 L
.58431 .9019 L
F
0 g
.58431 .9019 m
.13868 .64461 L
.46944 .58629 L
.58431 .9019 L
s
1 .498 .314 r
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.558309 0.116443 0.655491 0.215124 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.02381 .50771 m
.13868 .19211 L
.13868 .37082 L
.02381 .50771 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .50771 m
.13868 .19211 L
.13868 .37082 L
.02381 .50771 L
s
1 .498 .314 r
.13868 .37082 m
.42954 .02418 L
.31467 .33978 L
.13868 .37082 L
F
0 g
.13868 .37082 m
.42954 .02418 L
.31467 .33978 L
.13868 .37082 L
s
1 .498 .314 r
.46944 .765 m
.31467 .33978 L
.7603 .41836 L
.46944 .765 L
F
0 g
.46944 .765 m
.31467 .33978 L
.7603 .41836 L
.46944 .765 L
s
1 .498 .314 r
.58431 .9019 m
.13868 .82332 L
.46944 .765 L
.58431 .9019 L
F
0 g
.58431 .9019 m
.13868 .82332 L
.46944 .765 L
.58431 .9019 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.665209 0.116443 0.762391 0.215124 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.31467 .67564 m
.13868 .19211 L
.42954 .53875 L
.31467 .67564 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.31467 .67564 m
.13868 .19211 L
.42954 .53875 L
.31467 .67564 L
s
1 .498 .314 r
.31467 .85435 m
.02381 .50771 L
.31467 .67564 L
.31467 .85435 L
F
0 g
.31467 .85435 m
.02381 .50771 L
.31467 .67564 L
.31467 .85435 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.42954 .53875 L
.58431 .44939 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.42954 .53875 L
.58431 .44939 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.772109 0.116443 0.869291 0.215124 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
s
1 .498 .314 r
.31467 .67564 m
.13868 .19211 L
.42954 .53875 L
.31467 .67564 L
F
0 g
.31467 .67564 m
.13868 .19211 L
.42954 .53875 L
.31467 .67564 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .64461 L
.31467 .67564 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .64461 L
.31467 .67564 L
.42954 .99125 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.42954 .53875 L
.58431 .44939 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.42954 .53875 L
.58431 .44939 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.879009 0.116443 0.97619 0.215124 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.02381 .50771 m
.13868 .19211 L
.13868 .37082 L
.02381 .50771 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .50771 m
.13868 .19211 L
.13868 .37082 L
.02381 .50771 L
s
1 .498 .314 r
.31467 .85435 m
.13868 .37082 L
.42954 .53875 L
.31467 .85435 L
F
0 g
.31467 .85435 m
.13868 .37082 L
.42954 .53875 L
.31467 .85435 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.42954 .53875 L
.58431 .44939 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.42954 .53875 L
.58431 .44939 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.224992 0.120991 0.323673 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
s
1 .498 .314 r
.46944 .765 m
.02381 .50771 L
.46944 .58629 L
.46944 .765 L
F
0 g
.46944 .765 m
.02381 .50771 L
.46944 .58629 L
.46944 .765 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.58431 .9019 m
.13868 .82332 L
.46944 .765 L
.58431 .9019 L
F
0 g
.58431 .9019 m
.13868 .82332 L
.46944 .765 L
.58431 .9019 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.130709 0.224992 0.227891 0.323673 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
F
0 g
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
s
1 .498 .314 r
.46944 .765 m
.02381 .50771 L
.46944 .58629 L
.46944 .765 L
F
0 g
.46944 .765 m
.02381 .50771 L
.46944 .58629 L
.46944 .765 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.237609 0.224992 0.334791 0.323673 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
s
1 .498 .314 r
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
F
0 g
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.58431 .9019 m
.13868 .64461 L
.46944 .58629 L
.58431 .9019 L
F
0 g
.58431 .9019 m
.13868 .64461 L
.46944 .58629 L
.58431 .9019 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.344509 0.224992 0.441691 0.323673 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.02381 .50771 m
.13868 .19211 L
.13868 .37082 L
.02381 .50771 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .50771 m
.13868 .19211 L
.13868 .37082 L
.02381 .50771 L
s
1 .498 .314 r
.46944 .765 m
.13868 .37082 L
.58431 .44939 L
.46944 .765 L
F
0 g
.46944 .765 m
.13868 .37082 L
.58431 .44939 L
.46944 .765 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.58431 .9019 m
.13868 .82332 L
.46944 .765 L
.58431 .9019 L
F
0 g
.58431 .9019 m
.13868 .82332 L
.46944 .765 L
.58431 .9019 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.42954 .99125 L
.58431 .9019 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.451409 0.224992 0.548591 0.323673 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.31467 .85435 m
.02381 .50771 L
.31467 .67564 L
.31467 .85435 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.31467 .85435 m
.02381 .50771 L
.31467 .67564 L
.31467 .85435 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
F
0 g
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.31467 .67564 L
.46944 .58629 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.31467 .67564 L
.46944 .58629 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.558309 0.224992 0.655491 0.323673 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.13868 .82332 m
.02381 .50771 L
.13868 .64461 L
.13868 .82332 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .64461 L
.31467 .67564 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .64461 L
.31467 .67564 L
.42954 .99125 L
s
1 .498 .314 r
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
F
0 g
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.31467 .67564 L
.46944 .58629 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.31467 .67564 L
.46944 .58629 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.665209 0.224992 0.762391 0.323673 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.02381 .50771 m
.13868 .19211 L
.13868 .37082 L
.02381 .50771 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .50771 m
.13868 .19211 L
.13868 .37082 L
.02381 .50771 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.46944 .765 m
.13868 .37082 L
.58431 .44939 L
.46944 .765 L
F
0 g
.46944 .765 m
.13868 .37082 L
.58431 .44939 L
.46944 .765 L
s
1 .498 .314 r
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.42954 .02418 L
.7603 .41836 L
.58431 .44939 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.772109 0.224992 0.869291 0.323673 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.13868 .19211 m
.42954 .02418 L
.31467 .16107 L
.13868 .19211 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.13868 .19211 m
.42954 .02418 L
.31467 .16107 L
.13868 .19211 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.46944 .58629 m
.31467 .16107 L
.7603 .41836 L
.46944 .58629 L
F
0 g
.46944 .58629 m
.31467 .16107 L
.7603 .41836 L
.46944 .58629 L
s
1 .498 .314 r
.46944 .765 m
.02381 .50771 L
.46944 .58629 L
.46944 .765 L
F
0 g
.46944 .765 m
.02381 .50771 L
.46944 .58629 L
.46944 .765 L
s
1 .498 .314 r
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
F
0 g
.7603 .41836 m
.7603 .0825 L
.91507 .50771 L
.7603 .41836 L
s
1 .498 .314 r
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.879009 0.224992 0.97619 0.323673 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.514805 0.522507 0.507713 0.522507 [
[ 0 0 0 0 ]
[ 1 1.01543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 .498 .314 r
.42954 .02418 m
.7603 .0825 L
.58431 .11353 L
.42954 .02418 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.42954 .02418 m
.7603 .0825 L
.58431 .11353 L
.42954 .02418 L
s
1 .498 .314 r
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
F
0 g
.42954 .99125 m
.13868 .82332 L
.31467 .85435 L
.42954 .99125 L
s
1 .498 .314 r
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
F
0 g
.46944 .58629 m
.13868 .19211 L
.58431 .44939 L
.46944 .58629 L
s
1 .498 .314 r
.46944 .765 m
.02381 .50771 L
.46944 .58629 L
.46944 .765 L
F
0 g
.46944 .765 m
.02381 .50771 L
.46944 .58629 L
.46944 .765 L
s
1 .498 .314 r
.58431 .44939 m
.58431 .11353 L
.91507 .50771 L
.58431 .44939 L
F
0 g
.58431 .44939 m
.58431 .11353 L
.91507 .50771 L
.58431 .44939 L
s
1 .498 .314 r
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
F
0 g
.7603 .93293 m
.31467 .85435 L
.46944 .765 L
.7603 .93293 L
s
1 .498 .314 r
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
F
0 g
.91507 .50771 m
.97619 .33978 L
.97619 .67564 L
.91507 .50771 L
s
0 0 m
1 0 L
1 1.01543 L
0 1.01543 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[274]:=",
  ImageSize->{493.813, 163.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007]0000Xb000`400?l00000o`00003oo`3oooo^
0?ooo`00o`3oooo^0?ooo`00o`3oooo^0?ooo`00o`3oooo^0?ooo`00o`3oooo^0?ooo`008@3oool0
0`000000oooo0?ooo`0a0?ooo`<00000<P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0<@3oool300000340oooo00<000000?ooo`3oool0<P3oool3
00000340oooo00<000000?ooo`3oool09P3oool001l0oooo0P00000e0?ooo`L00000;@3oool20000
0380oooo0P00000a0?ooo`800000=@3oool7000002`0oooo0P00000d0?ooo`L00000;03oool00`00
0000oooo0?ooo`0V0?ooo`007@3oool3000003P0oooo0P0000030?moD0H00000:03oool200000380
oooo0P00000^0?ooo`<00000>03oool2000000<0ogm@1P00000W0?ooo`800000=@3oool2000000<0
ogm@1P00000V0?ooo`8000009`3oool001/0oooo0P0000000`3oOe0000000?ooo`0@0?ooo`030000
003oool0oooo02L0oooo0P0000050?moD0D000009@3oool2000000`0oooo00<000000?ooo`3oool0
8`3oool00`000000ogm@0000000<0?ooo`030000003oool0oooo01`0oooo0P0000000`3oOe000000
0?ooo`0@0?ooo`030000003oool0oooo02L0oooo0P0000050?moD0D00000903oool00`000000ogm@
0000000<0?ooo`030000003oool0oooo02L0oooo0P0000050?moD0D000008`3oool2000000h0oooo
00<000000?ooo`3oool05P3oool001X0oooo00@000000?moD03oOe0000004P3oool00`000000oooo
0?ooo`0Y0?ooo`D00000:P3oool00`000000ogm@0000000;0?ooo`800000903oool00`000000ogm@
0000000<0?ooo`030000003oool0oooo01/0oooo00@000000?moD03oOe0000004P3oool00`000000
oooo0?ooo`0Y0?ooo`D00000:P3oool2000000`0oooo0P00000X0?ooo`L00000:03oool00`000000
ogm@0000000=0?ooo`030000003oool0oooo01H0oooo000H0?ooo`8000000P3oOe000`000000oooo
0?ooo`0A0?ooo`800000:P3oool2000002h0oooo00<000000?moD00000002`3oool2000002@0oooo
00<000000?moD00000002`3oool2000001X0oooo0P0000020?moD0030000003oool0oooo0140oooo
0P00000Z0?ooo`800000;@3oool00`000000ogm@0000000<0?ooo`8000008P3oool5000000030?mo
D0000000oooo02`0oooo00<000000?moD00000003@3oool2000001L0oooo000F0?ooo`8000000P3o
Oe02000001@0oooo0P00000Z0?ooo`030000003oOe00000002d0oooo00@000000?moD03oOe000000
2P3oool00`000000ogm@0000000S0?ooo`040000003oOe00ogm@000000X0oooo0P00000H0?ooo`80
00000P3oOe02000001@0oooo0P00000Z0?ooo`030000003oOe00000002`0oooo00@000000?moD03o
Oe0000002`3oool00`000000ogm@0000000K0?ooo`H000001P3oOe000`000000oooo0?ooo`0[0?oo
o`030000003oOe00000000d0oooo0P00000G0?ooo`00503oool6000000040?ooo`00000000000000
0180oooo00<000000?moD0000000:@3oool010000000ogm@0?moD000000/0?ooo`050000003oOe00
ogm@0?moD00000002@3oool010000000ogm@0?moD000000R0?ooo`050000003oOe00ogm@0?moD000
00002@3oool2000001H0oooo2000000D0?ooo`030000003oOe00000002T0oooo00@000000?moD03o
Oe000000;03oool010000000ogm@0?moD000000:0?ooo`040000003oOe00ogm@000001D0oooo1@00
000;0?moD0030000003oool0oooo02`0oooo00@000000?moD03oOe000000303oool00`000000ogm@
0000000F0?ooo`004`3oool3000000H0oooo00@000000?moD00000000000403oool00`000000ogm@
0000000D0?ooo`030000003oool0oooo0180oooo00@000000?moD03oOe000000703oool00`000000
oooo0?ooo`0>0?ooo`040000003oOe00ogm@000000X0oooo00@000000?moD03oOe0000004@3oool0
0`000000oooo0?ooo`0>0?ooo`050000003oOe00ogm@0?moD0000000203oool00`000000ogm@0000
000D0?ooo`<000000`3oool00`000000ogm@0000000D0?ooo`030000003oOe00000001@0oooo00<0
00000?ooo`3oool04P3oool010000000ogm@0?moD000000L0?ooo`030000003oool0oooo00d0oooo
00D000000?moD03oOe00ogm@0000000:0?ooo`040000003oOe00ogm@00000140oooo0`00000?0?mo
D0030000003oool0oooo0200oooo00<000000?ooo`3oool02P3oool010000000ogm@0?moD000000<
0?ooo`030000003oOe00000001H0oooo000L0?ooo`050000003oOe00ogm@0?moD00000003`3oool0
0`000000ogm@0000000E0?ooo`8000004P3oool01@000000ogm@0?moD03oOe00000001`0oooo0P00
000>0?ooo`050000003oOe00ogm@0?moD00000002@3oool010000000ogm@0?moD000000A0?ooo`03
0000003oool0oooo00h0oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`050?ooo`03
0000003oOe00000001X0oooo00<000000?moD0000000503oool00`000000ogm@0000000D0?ooo`03
0000003oool0oooo0180oooo00D000000?moD03oOe00ogm@0000000K0?ooo`030000003oool0oooo
00h0oooo00D000000?moD03oOe00ogm@000000090?ooo`040000003oOe00ogm@000001@0oooo1@00
00090?moD0030000003oool0oooo0240oooo00<000000?ooo`3oool02P3oool01@000000ogm@0?mo
D03oOe00000000/0oooo00<000000?moD00000005P3oool001d0oooo00@000000?moD03oOe00ogm@
0P00000=0?ooo`040000003oOe00ogm@000001D0oooo0`00000@0?ooo`030000003oOe00ogm@0080
ogm@00<000000?ooo`3oool06P3oool3000000`0oooo00<000000?moD03oOe000P3oOe000`000000
oooo0?ooo`070?ooo`040000003oOe00ogm@00000100oooo0P00000?0?ooo`030000003oOe00ogm@
0080ogm@00<000000?ooo`3oool01@3oool00`000000ogm@0000000I0?ooo`040000003oOe00ogm@
000001@0oooo00@000000?moD03oOe0000004P3oool2000001@0oooo00<000000?moD03oOe000P3o
Oe000`000000oooo0?ooo`0G0?ooo`800000403oool01@000000ogm@0?moD03oOe00000000X0oooo
00@000000?moD03oOe000000603oool6000000<0ogm@00<000000?ooo`3oool08@3oool2000000/0
oooo00D000000?moD03oOe00ogm@0000000;0?ooo`040000003oOe00ogm@000001D0oooo000M0?oo
o`030000003oOe00ogm@00<0ogm@00<000000?ooo`3oool02P3oool010000000ogm@0?moD000000F
0?ooo`040000003oOe000000000000h0oooo00<000000?moD03oOe000`3oOe000`000000oooo0?oo
o`0I0?ooo`030000003oOe00ogm@008000002`3oool00`000000ogm@0?moD0020?moD0030000003o
ool0oooo00H0oooo00D000000?moD03oOe00ogm@0000000?0?ooo`800000403oool00`000000ogm@
0?moD0020?moD0030000003oool0oooo00@0oooo00@000000?moD03oOe0000005`3oool01@000000
ogm@0?moD03oOe00000001@0oooo00@000000?moD03oOe0000004P3oool2000001@0oooo00<00000
0?moD03oOe000`3oOe000`000000oooo0?ooo`0F0?ooo`800000403oool00`000000ogm@0?moD002
0?moD0030000003oool0oooo00L0oooo00D000000?moD03oOe00ogm@0000000M0?ooo`<00000903o
ool2000000/0oooo00D000000?moD03oOe00ogm@0000000;0?ooo`040000003oOe00ogm@000001D0
oooo000M0?ooo`030000003oOe00ogm@00@0ogm@0P00000:0?ooo`050000003oOe00ogm@0?moD000
00005@3oool01@000000ogm@0?moD03oOe00000000d0oooo00<000000?moD03oOe00103oOe000`00
0000oooo0?ooo`0I0?ooo`050000003oOe00ogm@0?moD00000002P3oool00`000000ogm@0?moD002
0?moD0030000003oool0oooo00H0oooo0`0000020?moD0030000003oool0oooo00`0oooo00<00000
0?moD00000003`3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo00<0oooo00@00000
0?moD03oOe0000005P3oool00`000000ogm@0?moD0020?moD0030000003oool0oooo0180oooo00D0
00000?moD03oOe00ogm@0000000A0?ooo`800000503oool00`000000ogm@0?moD0040?moD0030000
003oool0oooo01@0oooo00<000000?moD00000004@3oool00`000000ogm@0?moD0020?moD0030000
003oool0oooo00H0oooo0`0000020?moD0030000003oool0oooo01`0oooo0`00000R0?ooo`800000
2`3oool00`000000ogm@0?moD0020?moD0030000003oool0oooo00P0oooo00D000000?moD03oOe00
ogm@0000000D0?ooo`007P3oool00`000000ogm@0?moD0050?moD0800000203oool01@000000ogm@
0?moD03oOe00000001H0oooo00@000000?moD03oOe00ogm@0P00000;0?ooo`030000003oOe00ogm@
00D0ogm@00<000000?ooo`3oool06@3oool010000000ogm@0?moD03oOe02000000T0oooo00<00000
0?moD03oOe000P3oOe000`000000oooo0?ooo`040?ooo`040000003oOe0000000?ooo`80000000<0
ogm@0000003oool0303oool00`000000ogm@0000000@0?ooo`030000003oOe00ogm@00<0ogm@00<0
00000?ooo`3oool00P3oool010000000ogm@0?moD000000E0?ooo`030000003oOe00ogm@00<0ogm@
00<000000?ooo`3oool04P3oool01@000000ogm@0?moD03oOe0000000100oooo00<000000?moD000
0000503oool00`000000ogm@0?moD0050?moD0030000003oool0oooo01<0oooo00<000000?moD000
00004@3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo00@0oooo00@000000?moD000
0000oooo0P0000000`3oOe0000000?ooo`0L0?ooo`030000003oOe00ogm@00800000803oool00`00
0000ogm@0000000:0?ooo`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool0203oool01@00
0000ogm@0?moD03oOe00000001@0oooo000N0?ooo`030000003oOe00ogm@00L0ogm@00<000000?oo
o`3oool01@3oool01@000000ogm@0?moD03oOe00000001L0oooo00<000000?moD03oOe000P3oOe02
000000T0oooo00<000000?moD03oOe001@3oOe000`000000oooo0?ooo`0J0?ooo`030000003oOe00
ogm@0080ogm@0P0000070?ooo`030000003oOe00ogm@00<0ogm@00<000000?ooo`3oool00`3oool0
0`000000ogm@000000030?ooo`<00000303oool00`000000ogm@0000000@0?ooo`030000003oOe00
ogm@00@0ogm@00D000000?ooo`3oool0oooo000000030?moD0030000003oool0oooo0140oooo00<0
00000?moD03oOe00103oOe000`000000oooo0?ooo`0B0?ooo`050000003oOe00ogm@0?moD0000000
403oool00`000000ogm@0000000D0?ooo`030000003oOe00ogm@00D0ogm@00<000000?ooo`3oool0
4`3oool00`000000ogm@0000000B0?ooo`030000003oOe00ogm@00<0ogm@00<000000?ooo`3oool0
0`3oool00`000000ogm@000000030?ooo`<00000703oool00`000000ogm@0?moD0020?moD0800000
7P3oool00`000000ogm@0000000:0?ooo`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool0
203oool01@000000ogm@0?moD03oOe00000001@0oooo000N0?ooo`030000003oOe00ogm@00P0ogm@
0P0000050?ooo`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oOe00ogm@00<0ogm@0P0000070?ooo`030000003oOe00ogm@00H0ogm@
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`030000003oOe00ogm@00<0ogm@
0P0000050?ooo`030000003oOe00ogm@00@0ogm@00D000000?ooo`3oool0oooo000000030?moD003
0000003oool0oooo0080oooo0P00000;0?ooo`040000003oOe00ogm@000000l0oooo00<000000?mo
D03oOe001@3oOe0010000000oooo0?ooo`0000030?moD0030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02`3oool00`000000ogm@0?moD0040?moD0<000004P3oool00`000000ogm@0?moD002
0?moD0030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000ogm@0000000D
0?ooo`030000003oOe00ogm@00H0ogm@00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`040000003oOe00ogm@00000180oooo00<000000?moD03oOe00103oOe001@000000oooo0?oo
o`3oool0000000<0ogm@00<000000?ooo`3oool00P3oool2000001/0oooo00<000000?moD03oOe00
103oOe000`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<000000?moD0000000
2P3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo00L0oooo00<000000?moD03oOe00
0P3oOe000`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo000O0?ooo`030000003o
Oe00ogm@00T0ogm@00<000000?ooo`3oool00P3oool00`000000ogm@0?moD0020?moD0030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000ogm@0?moD0040?moD0030000003o
ool0oooo00@0oooo00<000000?moD03oOe001`3oOe000`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0100oooo00<000000?moD03oOe001@3oOe000`000000oooo0?ooo`030?ooo`030000003o
Oe00ogm@00@0ogm@00@000000?ooo`3oool000000`3oOe000`000000oooo0?ooo`0?0?ooo`040000
003oOe00ogm@00000100oooo00<000000?moD03oOe00103oOe0010000000oooo0?ooo`0000040?mo
D0030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000ogm@0?moD0030?mo
D0<000000P3oOe05000000d0oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`030?oo
o`030000003oool0oooo00H0oooo00<000000?moD03oOe000`00000B0?ooo`030000003oOe00ogm@
00L0ogm@00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oOe00ogm@
00<00000403oool00`000000ogm@0?moD0040?moD0050000003oool0oooo0?ooo`0000000`3oOe00
0`000000oooo0?ooo`0O0?ooo`030000003oOe00ogm@00D0ogm@0P00000>0?ooo`030000003oool0
oooo00X0oooo00@000000?moD03oOe0000002@3oool00`000000ogm@0?moD0030?moD0030000003o
ool0oooo00L0oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00`0oooo000O0?ooo`030000003oOe00ogm@00X0ogm@0P0000020?ooo`030000003oOe00
ogm@00<0ogm@00@000000?ooo`3oool0oooo0P00000C0?ooo`030000003oOe00ogm@00@0ogm@0P00
00040?ooo`030000003oOe00ogm@00P0ogm@00<000000?ooo`3oool0103oool2000001<0oooo00<0
00000?moD03oOe001@3oOe02000000<0oooo00<000000?moD03oOe00103oOe0010000000oooo0?oo
o`0000030?moD0030000003oool0oooo00l0oooo00D000000?moD03oOe00ogm@0000000?0?ooo`03
0000003oOe00ogm@00D0ogm@00<000000?ooo`000000103oOe0010000000oooo0?ooo`3oool20000
00/0oooo00<000000?moD03oOe000P3oOe02000000<0oooo00<000000?moD03oOe00103oOe060000
00L0oooo00<000000?moD03oOe000`3oOe0010000000oooo0?ooo`3oool2000000P0oooo00H00000
0?moD0000000oooo0000003oOe05000000d0oooo00<000000?moD03oOe00203oOe000`000000oooo
0?ooo`040?ooo`800000203oool01`000000ogm@0?moD0000000oooo0000003oOe001@00000<0?oo
o`030000003oOe00ogm@00@0ogm@00@000000?ooo`3oool000000`3oOe000`000000oooo0?ooo`0O
0?ooo`030000003oOe00ogm@00L0ogm@0P00000;0?ooo`800000303oool010000000ogm@0?moD000
00090?ooo`030000003oOe00ogm@00@0ogm@00<000000?ooo`3oool01P3oool00`000000ogm@0?mo
D0030?moD0030000003oool0oooo008000003P3oool00200oooo00<000000?moD03oOe002`3oOe03
000000D0ogm@00@000000?ooo`3oool0oooo0P00000C0?ooo`030000003oOe00ogm@00H0ogm@0P00
00020?ooo`030000003oOe00ogm@00T0ogm@00<000000?ooo`3oool00`3oool2000001@0oooo00<0
00000?moD03oOe001P3oOe02000000030?ooo`000000ogm@00H0ogm@0P0000050?moD0030000003o
ool0oooo00h0oooo00D000000?moD03oOe00ogm@0000000?0?ooo`030000003oOe00ogm@00H0ogm@
0P0000040?moD0040000003oool0oooo0?ooo`8000002P3oool010000000ogm@0?moD03oOe020000
00D0oooo00<000000?moD03oOe002P3oOe0500000080oooo00<000000?moD03oOe000`3oOe001000
0000oooo0?ooo`3oool2000000P0oooo00<000000?moD00000000P3oool00`000000ogm@0?moD003
0?moD0H000001`3oool00`000000ogm@0?moD0090?moD0030000003oool0oooo00<0oooo0P000008
0?ooo`030000003oOe00000000<0oooo00<000000?moD03oOe000`3oOe06000000H0oooo00<00000
0?moD03oOe001@3oOe02000000D0ogm@00<000000?ooo`3oool07P3oool00`000000ogm@0?moD009
0?moD08000002@3oool2000000`0oooo00@000000?moD03oOe0000002@3oool00`000000ogm@0?mo
D0040?moD0030000003oool0oooo00H0oooo00<000000?moD03oOe000`3oOe000`000000oooo0?oo
o`02000000h0oooo000P0?ooo`030000003oOe00ogm@00d0ogm@00<000000?moD03oOe000`3oOe00
1P000000oooo0?ooo`000000ogm@000001@0oooo00<000000?moD03oOe001`3oOe03000000`0ogm@
00L000000?ooo`3oool0oooo0000003oOe00000001D0oooo00<000000?moD03oOe001`3oOe030000
00@0ogm@100000050?moD0030000003oool0oooo00h0oooo00D000000?moD03oOe00ogm@0000000@
0?ooo`030000003oOe00ogm@0080ogm@1@0000050?moD0050000003oool000000?moD00000002@3o
ool01@000000ogm@0?moD03oOe00000000L0oooo00<000000?moD03oOe003`3oOe03000000D0ogm@
00H000000?ooo`3oool000000?moD00000070?ooo`030000003oOe00000000@0oooo00<000000?mo
D03oOe00203oOe0500000080oooo00<000000?moD03oOe002P3oOe001`000000oooo0?ooo`3oool0
00000?moD0000000203oool2000000@0oooo00<000000?moD03oOe002@3oOe0500000080oooo00<0
00000?moD03oOe000P3oOe04000000D0ogm@00<000000?ooo`3oool07P3oool00`000000ogm@0?mo
D00;0?moD0030000003oool0oooo00D0oooo00<000000?moD0000000303oool01@000000ogm@0?mo
D03oOe00000000P0oooo00<000000?moD03oOe00103oOe000`000000oooo0?ooo`060?ooo`030000
003oOe00ogm@00<0ogm@00<000000?ooo`3oool00P00000>0?ooo`00803oool00`000000ogm@0?mo
D00;0?moD080000000<0oooo000000000000103oOe001@000000oooo0000003oOe00000001D0oooo
00<000000?moD03oOe00203oOe03000000X0ogm@00L000000?ooo`3oool0oooo0000003oOe000000
01D0oooo00<000000?moD03oOe002@3oOe05000000@0oooo00<000000?moD03oOe000`3oOe000`00
0000oooo0?ooo`0=0?ooo`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool03@3oool50000
00D0oooo0P0000030?moD0050000003oool000000?moD0000000203oool00`000000ogm@0?moD002
000000T0oooo00<000000?moD03oOe003`3oOe0010000000oooo0000000000040?moD0050000003o
ool000000?moD00000001`3oool2000000D0oooo00<000000?moD03oOe003@3oOe05000000X0ogm@
00L000000?ooo`3oool0oooo0000003oOe00000000L0oooo00<000000?moD00000001@3oool00`00
0000ogm@0?moD00=0?moD0L00000103oool00`000000ogm@0?moD0030?moD0030000003oool0oooo
01d0oooo00<000000?moD03oOe00303oOe02000000D0oooo00<000000?moD0000000303oool01@00
0000ogm@0?moD03oOe00000000P0oooo00<000000?moD03oOe001@3oOe000`000000oooo0?ooo`03
0?ooo`D00000103oOe0010000000oooo00000000000>0?ooo`008@3oool00`000000ogm@0?moD008
0?moD08000001@3oool200000080ogm@00D000000?ooo`000000ogm@0000000F0?ooo`030000003o
Oe00ogm@00H0ogm@00@000000?ooo`3oool0oooo1@0000060?moD0060000003oool0oooo0000003o
Oe0000005P3oool00`000000ogm@0?moD0070?moD0030000003oool0oooo00P0oooo00<000000?mo
D03oOe000P3oOe000`000000oooo0?ooo`0=0?ooo`030000003oOe00ogm@0080ogm@00<000000?oo
o`3oool02`3oool3000000/0oooo0P0000001P3oOe0000000?ooo`000000ogm@000000P0oooo0`00
000;0?ooo`030000003oOe00ogm@00h0ogm@00<000000?ooo`3oool00P3oool200000080ogm@00D0
00000?ooo`000000ogm@000000070?ooo`030000003oool0oooo00D0oooo00<000000?moD03oOe00
3P3oOe000`000000oooo0?ooo`05000000H0ogm@00H000000?ooo`3oool000000?moD00000070?oo
o`8000001`3oool00`000000ogm@0?moD00>0?moD0030000003oool0oooo00L0oooo00<000000?mo
D03oOe000P3oOe000`000000oooo0?ooo`0M0?ooo`030000003oOe00ogm@00h0ogm@0P0000030?oo
o`030000003oOe00000000`0oooo00D000000?moD03oOe00ogm@000000080?ooo`030000003oOe00
ogm@00D0ogm@00@000000?ooo`3oool0oooo0P0000020?moD0030000003oool0oooo008000000P3o
Oe02000000030?moD0000000oooo00d0oooo000Q0?ooo`030000003oOe00ogm@00L0ogm@00<00000
0?ooo`3oool01`3oool2000000050?moD0000000ogm@0?moD00000005`3oool00`000000ogm@0?mo
D0050?moD0030000003oool0oooo00H0oooo1P0000000`3oOe000000000000020?moD0030000003o
ool0oooo01D0oooo00<000000?moD03oOe001@3oOe000`000000oooo0?ooo`0:0?ooo`050000003o
Oe00ogm@0?moD00000003`3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo00P0oooo
0P0000030?moD0030000003oool0oooo00X0oooo0`0000020?moD0030000003oool0oooo00D0oooo
0P00000=0?ooo`030000003oOe00ogm@00d0ogm@00<000000?ooo`3oool01@3oool2000000050?mo
D0000000ogm@0?moD00000001P3oool2000000P0oooo00<000000?moD03oOe00303oOe000`000000
oooo0?ooo`060?ooo`H0000000<0ogm@0000000000000P3oOe000`000000oooo0?ooo`040?ooo`80
00002@3oool00`000000ogm@0?moD00<0?moD0030000003oool0oooo00T0oooo00D000000?moD03o
Oe00ogm@0000000O0?ooo`030000003oOe00ogm@0100ogm@0`0000020?moD0030000003oool0oooo
00X0oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`050?ooo`030000003oOe00ogm@
00H0ogm@0`0000040?moD0030000003oool0oooo0080oooo0P000000103oOe0000000?moD000000>
0?ooo`003@3oool00`000000oooo0?ooo`0A0?ooo`030000003oOe00ogm@00D0ogm@0P00000<0?oo
o`8000000P3oOe000`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?mo
D03oOe000`3oOe000`000000oooo0?ooo`0=0?ooo`<000000P3oOe000`000000oooo0?ooo`040?oo
o`030000003oool0oooo00l0oooo00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`0<0?oo
o`050000003oOe00ogm@0?moD00000002@3oool00`000000oooo0?ooo`020?ooo`030000003oOe00
ogm@00<0ogm@100000050?ooo`8000001@3oOe000`000000oooo0?ooo`0<0?ooo`040000003oOe00
ogm@000000H0oooo00<000000?ooo`3oool03P3oool00`000000ogm@0?moD00;0?moD0030000003o
ool0oooo00P0oooo0P0000020?moD0030000003oool0oooo00@0oooo00<000000?ooo`3oool0203o
ool00`000000ogm@0?moD00;0?moD0030000003oool0oooo00`0oooo0`0000020?moD0030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000ogm@0?moD00;0?moD0030000003o
ool0oooo00X0oooo00D000000?moD03oOe00ogm@000000090?ooo`<000004P3oool00`000000ogm@
0?moD00@0?moD0<000000P3oOe000`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?moD03oOe000P3oOe04000000@0oooo00<000000?moD03oOe000P3oOe05000000H0ogm@
00<000000?ooo`3oool0103oool2000000030?moD0000000oooo00d0oooo000>0?ooo`8000004P3o
ool00`000000ogm@0?moD0030?moD0030000003oool0oooo00d0oooo00@000000?moD03oOe000000
1`3oool2000000l0oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`0@0?ooo`040000
003oOe00ogm@000000L0oooo0P00000@0?ooo`030000003oOe00ogm@0080ogm@00<000000?ooo`3o
ool03@3oool010000000ogm@0?moD00000090?ooo`8000000`3oool00`000000ogm@0?moD0020?mo
D08000000`3oOe05000000P0ogm@00<000000?ooo`3oool02`3oool010000000ogm@0?moD000000G
0?ooo`030000003oOe00ogm@00/0ogm@00<000000?ooo`3oool02@3oool010000000ogm@0?moD000
000B0?ooo`030000003oOe00ogm@00X0ogm@00<000000?ooo`3oool03P3oool010000000ogm@0?mo
D000000B0?ooo`030000003oOe00ogm@00X0ogm@00<000000?ooo`3oool0303oool010000000ogm@
0?moD000000:0?ooo`L000003@3oool00`000000ogm@0?moD00;0?moD0D000000P3oool010000000
ogm@0?moD00000060?ooo`800000103oool010000000ogm@0?moD03oOe02000000<0ogm@2@000004
0?ooo`030000003oOe00ogm@00@0ogm@00<000000?ooo`3oool01@3oool00`000000ogm@0000000>
0?ooo`003`3oool300000100oooo00@000000?moD03oOe00ogm@0P00000A0?ooo`030000003oOe00
000000P0oooo0`00000>0?ooo`040000003oOe00ogm@000001@0oooo00<000000?moD0000000203o
ool3000000h0oooo00D000000?moD03oOe00ogm@0000000@0?ooo`050000003oOe00ogm@0?moD000
00002@3oool200000080oooo00D000000?moD03oOe00ogm@000000020?ooo`030000003oOe00ogm@
00@0ogm@0P0000070?moD0030000003oool0oooo00`0oooo00<000000?moD00000005`3oool00`00
0000ogm@0?moD00:0?moD0030000003oool0oooo00/0oooo00<000000?moD00000004`3oool00`00
0000ogm@0?moD0080?moD0030000003oool0oooo0100oooo00<000000?moD00000004`3oool00`00
0000ogm@0?moD0090?moD0030000003oool0oooo00`0oooo00D000000?moD03oOe00ogm@0000000;
0?ooo`8000000`3oOe06000000L0oooo00<000000?moD03oOe001@3oOe06000000P0oooo00<00000
0?moD00000001`3oool2000000<0oooo00@000000?moD03oOe0000000P3oool00`000000ogm@0?mo
D0040?moD0030000003oool0oooo00L0oooo00<000000?moD03oOe000`3oOe000`000000oooo0?oo
o`050?ooo`030000003oOe00000000h0oooo000@0?ooo`040000003oOe000000000000l0oooo0`00
000C0?ooo`030000003oOe00000000T0oooo00@000000?moD000000000003@3oool00`000000ogm@
0000000D0?ooo`030000003oOe00000000T0oooo00@000000?moD000000000003@3oool00`000000
ogm@0000000B0?ooo`040000003oOe00ogm@000000T0oooo0P0000020?ooo`040000003oOe00ogm@
000000<0oooo00<000000?moD03oOe00103oOe000`000000oooo000000060?moD0030000003oool0
oooo00`0oooo00<000000?moD0000000603oool00`000000ogm@0?moD0080?moD0030000003oool0
oooo00`0oooo00<000000?moD00000004`3oool00`000000ogm@0?moD0080?moD0030000003oool0
oooo0100oooo00<000000?moD0000000503oool00`000000ogm@0?moD0080?moD0030000003oool0
oooo00d0oooo00@000000?moD03oOe0000003@3oool2000000L0ogm@1@0000020?ooo`030000003o
Oe00ogm@00D000003P3oool00`000000ogm@000000070?ooo`030000003oOe0000000080oooo00<0
00000?moD00000000`3oool00`000000ogm@0?moD0040?moD0030000003oool0oooo00L0oooo00<0
00000?moD03oOe000`3oOe000`000000oooo0?ooo`060?ooo`8000003P3oool00100oooo00D00000
0?moD03oOe00ogm@0000000>0?ooo`030000003oool0oooo01<0oooo00<000000?moD00000002@3o
ool01@000000ogm@0?moD03oOe00000000d0oooo00<000000?ooo`3oool04`3oool00`000000ogm@
000000090?ooo`050000003oOe00ogm@0?moD00000003@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oOe00000000T0oooo00L000000?moD0000000oooo0000003oOe00000000@0oooo00<00000
0?moD03oOe00103oOe0010000000oooo0?ooo`0000060?moD0030000003oool0oooo00/0oooo00<0
00000?moD0000000603oool00`000000ogm@0?moD0070?moD0030000003oool0oooo00d0oooo00<0
00000?moD0000000503oool00`000000ogm@0?moD0070?moD0030000003oool0oooo0100oooo00<0
00000?moD00000005@3oool00`000000ogm@0?moD0060?moD0030000003oool0oooo00l0oooo00<0
00000?moD00000003`3oool00`000000ogm@0?moD0090?moD0D000004`3oool00`000000ogm@0000
00080?ooo`070000003oOe0000000?ooo`000000ogm@000000030?ooo`030000003oOe00ogm@00@0
ogm@00<000000?ooo`3oool01`3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo00H0
oooo0P00000>0?ooo`004@3oool010000000ogm@0?moD03oOe02000000X0oooo0P0000000`3oOe00
00000?ooo`0D0?ooo`8000002P3oool010000000ogm@0?moD03oOe02000000T0oooo0P0000000`3o
Oe0000000?ooo`0D0?ooo`8000002P3oool010000000ogm@0?moD03oOe02000000T0oooo0P000000
0`3oOe0000000?ooo`0C0?ooo`030000003oOe00000000T0oooo00<000000?moD00000000P000006
0?ooo`030000003oOe00ogm@00<0ogm@00@000000?ooo`3oool000001P3oOe000`000000oooo0?oo
o`0<0?ooo`8000006@3oool00`000000ogm@0?moD0050?moD0030000003oool0oooo00l0oooo0P00
000E0?ooo`030000003oOe00ogm@00D0ogm@00<000000?ooo`3oool04P3oool2000001D0oooo00<0
00000?moD03oOe001P3oOe000`000000oooo0?ooo`0@0?ooo`030000003oOe00000000l0oooo0P00
000;0?moD0030000003oool0oooo01@0oooo0P0000080?ooo`030000003oOe00ogm@00<000001@3o
ool00`000000ogm@0?moD0030?moD0030000003oool0oooo00P0oooo00<000000?moD03oOe000P3o
Oe000`000000oooo0?ooo`060?ooo`8000003P3oool00180oooo00<000000?moD03oOe000P3oOe02
000000H0oooo0P0000040?moD0030000003oool0oooo0180oooo0P00000;0?ooo`030000003oOe00
ogm@0080ogm@0P0000050?ooo`800000103oOe000`000000oooo0?ooo`0B0?ooo`8000002`3oool0
0`000000ogm@0?moD0020?moD08000001@3oool2000000@0ogm@00<000000?ooo`3oool04P3oool2
000000T0oooo00@000000?moD03oOe0000001`3oool00`000000ogm@0?moD0030?moD0050000003o
ool0oooo0?ooo`0000001P3oOe000`000000oooo0?ooo`0;0?ooo`8000006@3oool00`000000ogm@
0?moD0040?moD0030000003oool0oooo0100oooo0P00000F0?ooo`030000003oOe00ogm@00@0ogm@
00<000000?ooo`3oool04P3oool2000001H0oooo00<000000?moD03oOe00103oOe000`000000oooo
0?ooo`0B0?ooo`8000004@3oool2000000T0ogm@00<000000?ooo`3oool0503oool2000000P0oooo
00D000000?moD03oOe00ogm@000000060?ooo`030000003oOe00ogm@00<0ogm@00<000000?ooo`3o
ool0203oool00`000000ogm@0?moD0020?moD0030000003oool0oooo00H0oooo0P00000>0?ooo`00
4`3oool00`000000ogm@0?moD0030?moD08000000P3oool2000000H0ogm@00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0:0?ooo`030000003oOe00ogm@00<0ogm@0P0000000`3oool00000
000000070?moD0030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000ogm@
0?moD0030?moD080000000<0oooo0000000000001`3oOe000`000000oooo0?ooo`0B0?ooo`800000
203oool010000000ogm@0?moD00000070?ooo`030000003oOe00ogm@00<0ogm@00<000000?ooo`3o
ool00P3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo00`0oooo00<000000?ooo`3o
ool05`3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo0180oooo00<000000?ooo`3o
ool05@3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo01<0oooo00<000000?ooo`3o
ool05@3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo01<0oooo0P00000B0?ooo`80
00001`3oOe000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo00@000000?moD03o
Oe0000001P3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo00P0oooo00<000000?mo
D03oOe000P3oOe000`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo000D0?ooo`03
0000003oOe00ogm@00@0ogm@0P0000090?moD0030000003oool0oooo0180oooo00<000000?ooo`3o
ool02`3oool00`000000ogm@0?moD0040?moD0030000003oOe00ogm@00L0ogm@00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0;0?ooo`030000003oOe00ogm@00@0ogm@00<000000?moD03o
Oe001`3oOe000`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?moD000
0000203oool00`000000ogm@0?moD0020?moD0030000003oool0oooo00<0oooo00<000000?moD03o
Oe000P3oOe000`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01P0oooo00D000000?moD03o
Oe00ogm@0000000E0?ooo`030000003oool0oooo01H0oooo00D000000?moD03oOe00ogm@0000000F
0?ooo`030000003oool0oooo01H0oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0180oooo00<000000?moD03oOe00103oOe000`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00L0oooo00@000000?moD03oOe0000001`3oool00`000000ogm@0?mo
D0020?moD0030000003oool0oooo00T0oooo00D000000?moD03oOe00ogm@000000090?ooo`030000
003oool0oooo00`0oooo000E0?ooo`030000003oOe00ogm@00<0ogm@0`0000090?moD0030000003o
ool0oooo0200oooo00<000000?moD03oOe000`3oOe03000000P0ogm@00<000000?ooo`3oool0803o
ool00`000000ogm@0?moD0030?moD0<00000203oOe000`000000oooo0?ooo`0L0?ooo`030000003o
Oe00000000P0oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`040?ooo`030000003o
Oe00ogm@0080ogm@00<000000?ooo`3oool09P3oool01@000000ogm@0?moD03oOe00000002h0oooo
00D000000?moD03oOe00ogm@0000000`0?ooo`040000003oOe00ogm@000002d0oooo0P0000040?mo
D0030000003oool0oooo0200oooo00<000000?moD00000001`3oool00`000000ogm@0?moD0020?mo
D0030000003oool0oooo00T0oooo00D000000?moD03oOe00ogm@0000000H0?ooo`005P3oool00`00
0000ogm@0?moD0020?moD0030000003oool0oooo00800000203oOe000`000000oooo0?ooo`0P0?oo
o`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool00P0000070?moD0030000003oool0oooo
0200oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`02000000L0ogm@00<000000?oo
o`3oool06`3oool00`000000ogm@000000080?ooo`030000003oOe00ogm@0080ogm@00<000000?oo
o`3oool01@3oool01@000000ogm@0?moD03oOe00000002P0oooo00@000000?moD03oOe000000<03o
ool010000000ogm@0?moD000000`0?ooo`040000003oOe00ogm@000002l0oooo0P0000020?moD003
0000003oool0oooo0200oooo00<000000?moD00000001`3oool00`000000ogm@0?moD0020?moD003
0000003oool0oooo00T0oooo00D000000?moD03oOe00ogm@0000000H0?ooo`005`3oool01@000000
ogm@0?moD03oOe00000000@0oooo0P0000070?moD0030000003oool0oooo0200oooo00D000000?mo
D03oOe00ogm@000000040?ooo`8000001P3oOe000`000000oooo0?ooo`0P0?ooo`050000003oOe00
ogm@0?moD0000000103oool2000000H0ogm@00<000000?ooo`3oool06`3oool2000000T0oooo00D0
00000?moD03oOe00ogm@000000070?ooo`050000003oOe00ogm@0?moD0000000:@3oool200000380
oooo0P00000b0?ooo`800000<P3oool300000280oooo00<000000?moD0000000203oool01@000000
ogm@0?moD03oOe00000000`0oooo00@000000?moD03oOe000000603oool001L0oooo00D000000?mo
D03oOe00ogm@000000060?ooo`030000003oOe00ogm@00@0ogm@00<000000?ooo`3oool0803oool0
1@000000ogm@0?moD03oOe00000000H0oooo00<000000?moD03oOe00103oOe000`000000oooo0?oo
o`0O0?ooo`050000003oOe00ogm@0?moD00000001P3oool00`000000ogm@0?moD0040?moD0030000
003oool0oooo01X0oooo0P0000090?ooo`050000003oOe00ogm@0?moD0000000203oool01@000000
ogm@0?moD03oOe00000002P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool08@3oool2000000P0oooo00D000000?mo
D03oOe00ogm@0000000<0?ooo`040000003oOe00ogm@000001P0oooo000H0?ooo`040000003oOe00
ogm@000000L0oooo0P0000050?moD0030000003oool0oooo0200oooo00@000000?moD03oOe000000
1`3oool2000000D0ogm@00<000000?ooo`3oool07`3oool010000000ogm@0?moD00000070?ooo`80
00001@3oOe000`000000oooo0?ooo`0I0?ooo`8000002P3oool010000000ogm@0?moD00000090?oo
o`040000003oOe00ogm@000002H0oooo0P0000000`3oOe0000000000000`0?ooo`80000000<0ogm@
000000000000;`3oool2000000030?moD000000000000300oooo0P0000000`3oOe0000000000000Q
0?ooo`8000002@3oool010000000ogm@0?moD000000=0?ooo`030000003oOe00000001P0oooo000I
0?ooo`030000003oOe00000000T0oooo0P0000040?moD0030000003oool0oooo0200oooo00<00000
0?moD00000002@3oool2000000@0ogm@00<000000?ooo`3oool07`3oool00`000000ogm@00000009
0?ooo`800000103oOe000`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo00@00000
0?moD03oOe0000002P3oool010000000ogm@0?moD000000S0?ooo`8000001@3oOe02000002`0oooo
0P0000050?moD0800000:`3oool2000000D0ogm@0P00000/0?ooo`8000001@3oOe0200000200oooo
00<000000?ooo`3oool01`3oool010000000ogm@0?moD000000=0?ooo`030000003oOe00000001P0
oooo000C0?ooo`@000000`3oool2000000/0oooo0P0000030?moD0030000003oool0oooo01P0oooo
1@0000030?ooo`8000002`3oool2000000<0ogm@00<000000?ooo`3oool0603oool4000000<0oooo
0P00000;0?ooo`8000000`3oOe000`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo
00@000000?moD03oOe0000002`3oool00`000000ogm@0000000H0?ooo`@000001@3oool2000000T0
ogm@0P00000N0?ooo`D000001@3oool2000000T0ogm@0P00000N0?ooo`@000001@3oool2000000T0
ogm@0P00000N0?ooo`@000001P3oool2000000T0ogm@0P00000N0?ooo`030000003oool0oooo00L0
oooo00@000000?moD03oOe0000003@3oool00`000000ogm@0000000H0?ooo`00503oool200000003
0?moD0000000000000<000003@3oool01@000000ogm@0?moD03oOe00000001X0oooo0P0000020?mo
D0D000003@3oool010000000ogm@0?moD000000K0?ooo`80000000<0ogm@0000000000000`00000=
0?ooo`040000003oOe00ogm@000002H0oooo00<000000?moD0000000303oool2000001T0oooo0P00
00000`3oOe00000000000005000000/0ogm@00<000000?ooo`3oool0703oool200000080ogm@1`00
000;0?moD0030000003oool0oooo01`0oooo0P0000000`3oOe00000000000005000000/0ogm@00<0
00000?ooo`3oool0703oool2000000030?moD0000000000000D00000303oOe000`000000oooo0?oo
o`0V0?ooo`030000003oOe00000000h0oooo0P00000H0?ooo`005P3oool2000000@0ogm@00<00000
0?ooo`3oool02`3oool200000080ogm@00<000000?ooo`3oool06@3oool2000000D0ogm@00<00000
0?ooo`3oool02`3oool2000000030?moD0000000oooo01/0oooo0P0000040?moD0030000003oool0
oooo00/0oooo0P0000000`3oOe0000000?ooo`0T0?ooo`030000003oOe00000000`0oooo00<00000
0?moD00000006P3oool2000000@0ogm@00<000000?ooo`000000100000070?moD08000007P3oool2
000000D0ogm@00<000000?ooo`000000100000070?moD08000007P3oool2000000@0ogm@00<00000
0?ooo`000000100000070?moD08000007P3oool2000000@0ogm@00<000000?ooo`0000001@000007
0?moD08000009P3oool00`000000ogm@0000000>0?ooo`800000603oool001P0oooo0P0000030?mo
D0030000003oool0oooo00`0oooo0`00000M0?ooo`8000000`3oOe000`000000oooo0?ooo`0=0?oo
o`<000007@3oool2000000<0ogm@00<000000?ooo`3oool0303oool3000002@0oooo00<000000?mo
D00000003@3oool2000001`0oooo0P0000030?moD0030000003oool0oooo00<0oooo1P0000030?mo
D08000007P3oool2000000<0ogm@00<000000?ooo`3oool0103oool6000000<0ogm@0P00000N0?oo
o`050000003oOe00ogm@0?moD00000001P3oool6000000<0ogm@0P00000N0?ooo`8000000`3oOe00
0`000000oooo0?ooo`040?ooo`D00000103oOe02000002@0oooo00<000000?moD00000003P3oool2
000001P0oooo000J0?ooo`050000003oOe00ogm@0?moD00000003`3oool2000001h0oooo00D00000
0?moD03oOe00ogm@0000000@0?ooo`8000007P3oool01@000000ogm@0?moD03oOe00000000l0oooo
0P00000T0?ooo`8000003P3oool2000001d0oooo00D000000?moD03oOe00ogm@0000000:0?ooo`L0
00007P3oool01@000000ogm@0?moD03oOe00000000/0oooo1`00000M0?ooo`8000000P3oOe000`00
0000oooo0?ooo`090?ooo`L000007P3oool01@000000ogm@0?moD03oOe00000000X0oooo2000000S
0?ooo`8000003`3oool00`000000oooo0?ooo`0F0?ooo`006`3oool2000000030?moD0000000oooo
0100oooo00<000000?ooo`3oool0703oool200000080ogm@00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0L0?ooo`80000000<0ogm@0000003oool0403oool00`000000oooo0?ooo`0Q0?oo
o`8000003`3oool00`000000oooo0?ooo`0L0?ooo`80000000<0ogm@0000003oool03P3oool30000
01h0oooo0P0000020?moD0030000003oool0oooo00d0oooo0`00000N0?ooo`040000003oOe00ogm@
000000l0oooo0`00000N0?ooo`80000000<0ogm@0000003oool03`3oool300000280oooo0P00000?
0?ooo`030000003oool0oooo01H0oooo000M0?ooo`<00000<@3oool2000000030?moD0000000oooo
0300oooo0`00000d0?ooo`800000<03oool300000340oooo0P0000000`3oOe0000000?ooo`0_0?oo
o`80000000<0ogm@0000003oool0<03oool3000003@0oooo0P00000X0?ooo`007`3oool200000380
oooo0P00000c0?ooo`800000=03oool00`000000oooo0?ooo`0`0?ooo`800000<P3oool200000380
oooo0P00000c0?ooo`800000=03oool00`000000oooo0?ooo`0V0?ooo`008@3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool09P3oool00?l0ooookP3o
ool00?l0ooookP3oool00?l0ooookP3oool00?l0ooookP3oool00?l0ooookP3oool00?l0ooookP3o
ool00240oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0<P3oool300000340oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool09P3oool0
0240oooo0P00000b0?ooo`800000<`3oool200000300oooo0P00000f0?ooo`L00000:`3oool20000
03<0oooo0P00000c0?ooo`800000<P3oool2000002L0oooo000R0?ooo`800000<P3oool2000003<0
oooo0P00000]0?ooo`80000000<0ogm@0000003oool0=`3oool2000000<0ogm@1@00000U0?ooo`80
0000=@3oool2000003<0oooo0P00000b0?ooo`8000009P3oool00280oooo0P00000<0?ooo`030000
003oool0oooo02<0oooo00<000000?moD0000000303oool00`000000oooo0?ooo`0S0?ooo`800000
303oool00`000000oooo0?ooo`0L0?ooo`8000000P3oOe000`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo02L0oooo0P0000050?moD0@000008P3oool200000100oooo00<000000?ooo`3oool0
8P3oool00`000000ogm@0000000<0?ooo`030000003oool0oooo02<0oooo00<000000?moD0000000
303oool00`000000oooo0?ooo`0R0?ooo`030000003oOe00000000`0oooo00<000000?ooo`3oool0
5P3oool00280oooo00<000000?moD00000002`3oool2000002@0oooo00<000000?moD0000000303o
ool00`000000oooo0?ooo`0S0?ooo`030000003oOe00000000/0oooo00<000000?ooo`3oool06`3o
ool01@000000ogm@0?moD03oOe0000000180oooo00<000000?ooo`3oool0:@3oool5000002D0oooo
00<000000?moD0000000403oool00`000000oooo0?ooo`0S0?ooo`800000303oool00`000000oooo
0?ooo`0S0?ooo`030000003oOe00000000`0oooo00<000000?ooo`3oool08`3oool2000000`0oooo
00<000000?ooo`3oool05P3oool002<0oooo00<000000?moD00000002`3oool2000002@0oooo00<0
00000?moD00000002`3oool2000002D0oooo00<000000?moD00000002P3oool2000001X0oooo0P00
00030?moD0030000003oool0oooo0140oooo0P00000Z0?ooo`8000009`3oool00`000000ogm@0000
000A0?ooo`800000903oool00`000000ogm@0000000;0?ooo`8000009@3oool00`000000ogm@0000
000;0?ooo`800000903oool00`000000ogm@0000000;0?ooo`8000005`3oool002<0oooo00@00000
0?moD03oOe0000002P3oool00`000000ogm@0000000S0?ooo`040000003oOe00ogm@000000X0oooo
0P00000U0?ooo`040000003oOe00ogm@000000T0oooo0P00000H0?ooo`8000001@3oOe000`000000
oooo0?ooo`0A0?ooo`800000:P3oool00`000000ogm@0000000U0?ooo`040000003oOe00ogm@0000
0140oooo0P00000T0?ooo`040000003oOe00ogm@000000X0oooo0P00000U0?ooo`040000003oOe00
ogm@000000X0oooo0P00000T0?ooo`040000003oOe00ogm@000000X0oooo0P00000G0?ooo`008`3o
ool01@000000ogm@0?moD03oOe00000000T0oooo00@000000?moD03oOe0000008P3oool01@000000
ogm@0?moD03oOe00000000T0oooo0P00000U0?ooo`050000003oOe00ogm@0?moD0000000203oool0
0`000000ogm@0000000E0?ooo`8000000P3oOe05000001@0oooo0P00000Z0?ooo`040000003oOe00
ogm@000002<0oooo00D000000?moD03oOe00ogm@0000000A0?ooo`8000009@3oool010000000ogm@
0?moD00000090?ooo`030000003oOe00000002@0oooo00D000000?moD03oOe00ogm@000000090?oo
o`8000009@3oool010000000ogm@0?moD00000090?ooo`030000003oOe00000001H0oooo000C0?oo
o`030000003oool0oooo00h0oooo00@000000?moD03oOe0000002P3oool010000000ogm@0?moD000
000A0?ooo`030000003oool0oooo00h0oooo00D000000?moD03oOe00ogm@000000080?ooo`030000
003oOe00000001@0oooo00<000000?ooo`3oool03P3oool010000000ogm@0?moD00000080?ooo`03
0000003oOe00000001@0oooo1@0000040?ooo`<000004P3oool00`000000ogm@0000000D0?ooo`03
0000003oool0oooo0180oooo00@000000?moD03oOe0000006`3oool00`000000oooo0?ooo`040?oo
o`050000003oOe00ogm@0?moD00000004P3oool00`000000ogm@0000000D0?ooo`030000003oool0
oooo00d0oooo00D000000?moD03oOe00ogm@000000080?ooo`030000003oOe00000001@0oooo00<0
00000?ooo`3oool03P3oool01@000000ogm@0?moD03oOe00000000P0oooo00<000000?moD0000000
503oool00`000000oooo0?ooo`0=0?ooo`050000003oOe00ogm@0?moD0000000203oool00`000000
ogm@0000000F0?ooo`00503oool2000000h0oooo00D000000?moD03oOe00ogm@000000090?ooo`04
0000003oOe00ogm@00000140oooo00<000000?ooo`3oool03P3oool00`000000ogm@0?moD0020?mo
D0030000003oool0oooo00D0oooo00<000000?moD0000000503oool00`000000oooo0?ooo`0>0?oo
o`050000003oOe00ogm@0?moD00000001`3oool00`000000ogm@0000000N0?ooo`040000003oOe00
000000000100oooo00<000000?moD00000005@3oool200000180oooo00D000000?moD03oOe00ogm@
0000000J0?ooo`030000003oool0oooo00@0oooo00D000000?moD03oOe00ogm@0000000B0?ooo`03
0000003oOe00000001@0oooo0P00000?0?ooo`050000003oOe00ogm@0?moD00000001`3oool00`00
0000ogm@0000000D0?ooo`8000003`3oool00`000000ogm@0?moD0020?moD0030000003oool0oooo
00D0oooo00<000000?moD0000000503oool00`000000oooo0?ooo`0>0?ooo`050000003oOe00ogm@
0?moD00000001`3oool00`000000ogm@0000000F0?ooo`005@3oool3000000`0oooo00<000000?mo
D03oOe000P3oOe000`000000oooo0?ooo`070?ooo`040000003oOe00ogm@00000100oooo0P00000?
0?ooo`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool01@3oool00`000000ogm@0000000C
0?ooo`800000403oool00`000000ogm@0?moD0020?moD0030000003oool0oooo00@0oooo00@00000
0?moD03oOe0000007@3oool010000000ogm@0?moD03oOe02000000h0oooo00<000000?moD0000000
5P3oool300000100oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`0F0?ooo`800000
1@3oool00`000000ogm@0?moD0020?moD0030000003oool0oooo0100oooo00<000000?moD0000000
5@3oool2000000h0oooo00D000000?moD03oOe00ogm@000000070?ooo`040000003oOe00ogm@0000
01@0oooo0P00000>0?ooo`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool01@3oool00`00
0000ogm@0000000C0?ooo`800000403oool01@000000ogm@0?moD03oOe00000000L0oooo00@00000
0?moD03oOe0000005@3oool001H0oooo00@000000?moD000000000002`3oool00`000000ogm@0?mo
D0020?moD0030000003oool0oooo00H0oooo00D000000?moD03oOe00ogm@0000000?0?ooo`800000
403oool00`000000ogm@0?moD0020?moD0030000003oool0oooo00@0oooo00@000000?moD03oOe00
00004P3oool200000140oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`030?ooo`04
0000003oOe00ogm@000001d0oooo00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`0;0?oo
o`040000003oOe00ogm@000001D0oooo00<000000?moD03oOe000P00000>0?ooo`030000003oOe00
ogm@00<0ogm@00<000000?ooo`3oool05@3oool2000000@0oooo00<000000?moD03oOe000P3oOe00
0`000000oooo0?ooo`0A0?ooo`040000003oOe00ogm@000001@0oooo0P00000>0?ooo`030000003o
Oe00ogm@0080ogm@00<000000?ooo`3oool0103oool010000000ogm@0?moD000000D0?ooo`800000
3`3oool00`000000ogm@0?moD0020?moD0030000003oool0oooo00@0oooo00@000000?moD03oOe00
00004P3oool200000100oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`040?ooo`04
0000003oOe00ogm@000001D0oooo000F0?ooo`050000003oOe00ogm@0?moD00000002P3oool00`00
0000ogm@0?moD0020?moD0030000003oool0oooo00H0oooo0`0000020?moD0030000003oool0oooo
00`0oooo00<000000?moD00000003`3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo
00<0oooo00@000000?moD03oOe0000004@3oool00`000000ogm@0000000A0?ooo`030000003oOe00
ogm@0080ogm@00<000000?ooo`3oool00`3oool01@000000ogm@0?moD03oOe00000001d0oooo00<0
00000?moD03oOe000`3oOe02000000/0oooo00@000000?moD03oOe0000005P3oool01@000000ogm@
0?moD03oOe00000000d0oooo00<000000?moD03oOe00103oOe000`000000oooo0?ooo`0D0?ooo`80
00000`3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo0140oooo00@000000?moD03o
Oe000000503oool00`000000ogm@0000000>0?ooo`030000003oOe00ogm@0080ogm@00<000000?oo
o`3oool00`3oool01@000000ogm@0?moD03oOe00000001<0oooo00<000000?moD00000003P3oool0
0`000000ogm@0?moD0030?moD0030000003oool0oooo00<0oooo00@000000?moD03oOe0000004@3o
ool00`000000ogm@0000000A0?ooo`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool00`3o
ool01@000000ogm@0?moD03oOe00000001@0oooo000G0?ooo`040000003oOe00ogm@0?moD0800000
2@3oool00`000000ogm@0?moD0020?moD0030000003oool0oooo00@0oooo00@000000?moD0000000
oooo0P0000000`3oOe0000000?ooo`0<0?ooo`030000003oOe0000000100oooo00<000000?moD03o
Oe000`3oOe000`000000oooo0?ooo`020?ooo`040000003oOe00ogm@00000140oooo00<000000?mo
D00000004P3oool00`000000ogm@0?moD0020?moD0030000003oool0oooo0080oooo00D000000?mo
D03oOe00ogm@0000000M0?ooo`030000003oOe00ogm@00D0ogm@0P0000090?ooo`040000003oOe00
ogm@000001L0oooo00@000000?moD03oOe00ogm@0P00000;0?ooo`030000003oOe00ogm@00D0ogm@
00<000000?ooo`3oool04P3oool00`000000ogm@000000020?ooo`030000003oOe00ogm@00@0ogm@
00<000000?ooo`3oool04@3oool010000000ogm@0?moD000000E0?ooo`030000003oOe00000000d0
oooo00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`020?ooo`050000003oOe00ogm@0?mo
D0000000503oool00`000000ogm@0000000>0?ooo`030000003oOe00ogm@00<0ogm@00<000000?oo
o`3oool00P3oool010000000ogm@0?moD000000A0?ooo`030000003oOe0000000140oooo00<00000
0?moD03oOe000`3oOe000`000000oooo0?ooo`020?ooo`050000003oOe00ogm@0?moD0000000503o
ool001P0oooo00<000000?moD03oOe000P3oOe02000000L0oooo00<000000?moD03oOe000`3oOe00
0`000000oooo0?ooo`030?ooo`030000003oOe00000000<0oooo0`00000<0?ooo`030000003oOe00
00000100oooo00<000000?moD03oOe00103oOe001@000000oooo0?ooo`3oool0000000<0ogm@00<0
00000?ooo`3oool03P3oool00`000000ogm@0000000B0?ooo`030000003oOe00ogm@00<0ogm@00D0
00000?ooo`3oool0oooo000000030?moD0030000003oool0oooo01/0oooo00<000000?moD03oOe00
1`3oOe02000000L0oooo00D000000?moD03oOe00ogm@0000000G0?ooo`030000003oOe00ogm@0080
ogm@0P0000090?ooo`030000003oOe00ogm@00D0ogm@00<000000?ooo`3oool04P3oool01@000000
ogm@0000003oool0000000H0ogm@00<000000?ooo`3oool04P3oool01@000000ogm@0?moD03oOe00
000001@0oooo00@000000?moD03oOe0000003@3oool00`000000ogm@0?moD0030?moD0050000003o
ool0oooo0?ooo`0000000`3oOe000`000000oooo0?ooo`0B0?ooo`040000003oOe00ogm@000000d0
oooo00<000000?moD03oOe00103oOe001@000000oooo0?ooo`3oool0000000<0ogm@00<000000?oo
o`3oool03P3oool00`000000ogm@0000000B0?ooo`030000003oOe00ogm@00<0ogm@00D000000?oo
o`3oool0oooo000000030?moD0030000003oool0oooo0180oooo000I0?ooo`030000003oOe00ogm@
00<0ogm@0P0000050?ooo`030000003oOe00ogm@00@0ogm@00D000000?ooo`3oool0oooo00000003
0?moD0030000003oool0oooo0080oooo0P00000;0?ooo`040000003oOe00ogm@000000l0oooo00<0
00000?moD03oOe001@3oOe0010000000oooo0?ooo`0000030?moD0030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool010000000ogm@0?moD000000B0?ooo`030000003oOe00ogm@00@0
ogm@00@000000?ooo`3oool00000103oOe000`000000oooo0?ooo`030?ooo`030000003oool0oooo
01D0oooo00<000000?moD03oOe00203oOe000`000000oooo0?ooo`040?ooo`050000003oOe00ogm@
0?moD00000001@3oool00`000000oooo0?ooo`0@0?ooo`030000003oOe00ogm@00<0ogm@0P000007
0?ooo`030000003oOe00ogm@00H0ogm@00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`050000003oOe0000000?ooo`000000103oOe0500000180oooo00D000000?moD03oOe00ogm@
000000050?ooo`030000003oool0oooo00`0oooo00@000000?moD03oOe0000003@3oool00`000000
ogm@0?moD0040?moD0040000003oool0oooo000000@0ogm@00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0;0?ooo`050000003oOe00ogm@0?moD0000000303oool00`000000ogm@0?moD005
0?moD0040000003oool0oooo000000<0ogm@00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`040000003oOe00ogm@00000180oooo00<000000?moD03oOe00103oOe0010000000oooo
0?ooo`0000040?moD0030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool001X0oooo
00<000000?moD03oOe00103oOe000`000000oooo0?ooo`030?ooo`030000003oOe00ogm@00@0ogm@
00@000000?ooo`3oool000000`3oOe000`000000oooo0?ooo`0?0?ooo`040000003oOe00ogm@0000
0100oooo00<000000?moD03oOe00103oOe0010000000oooo0?ooo`0000040?moD0030000003oool0
oooo0080oooo00<000000?ooo`3oool01`3oool010000000ogm@0?moD000000C0?ooo`030000003o
Oe00ogm@00@0ogm@00<000000?ooo`000000103oOe000`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01D0oooo00<000000?moD03oOe002@3oOe02000000@0oooo00<000000?moD03oOe000P3o
Oe000`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?moD03oOe001@3o
Oe000`000000oooo0?ooo`040?ooo`030000003oOe00ogm@00L0ogm@00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oOe00ogm@0080000000<0ogm@0000000000000P00
00020?ooo`030000003oOe00ogm@00D000003@3oool00`000000ogm@0?moD0020?moD0030000003o
ool0oooo0080oooo00<000000?ooo`3oool03@3oool010000000ogm@0?moD000000<0?ooo`030000
003oOe00ogm@00@0ogm@00@000000?ooo`3oool00000103oOe000`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00`0oooo00D000000?moD03oOe00ogm@0000000<0?ooo`030000003oOe00ogm@
00@0ogm@00@000000?ooo`3oool00000103oOe000`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00@000000?moD03oOe0000004P3oool00`000000ogm@0?moD0040?moD0040000003o
ool0oooo000000@0ogm@00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`006`3o
ool00`000000ogm@0?moD0040?moD08000000`3oool00`000000ogm@0?moD0040?moD0040000003o
ool0oooo000000<0ogm@00<000000?ooo`3oool03`3oool01@000000ogm@0?moD03oOe00000000l0
oooo00<000000?moD03oOe001@3oOe000`000000oooo000000040?moD0040000003oool0oooo0?oo
o`800000203oool01@000000ogm@0?moD03oOe00000001<0oooo00<000000?moD03oOe00103oOe00
0`000000oooo000000050?moD0040000003oool0oooo0?ooo`8000005`3oool00`000000ogm@0?mo
D00;0?moD08000000P3oool00`000000ogm@0?moD0020?moD0040000003oool0oooo0?ooo`800000
4`3oool00`000000ogm@0?moD0050?moD0800000103oool00`000000ogm@0?moD0080?moD0030000
003oool0oooo00@0oooo0P0000080?ooo`030000003oOe00ogm@00<000001`3oool00`000000ogm@
0?moD0040?moD0H000001`3oool00`000000ogm@0?moD0020?moD0040000003oool0oooo0?ooo`80
00003`3oool01@000000ogm@0?moD03oOe00000000`0oooo00<000000?moD03oOe00103oOe000`00
0000oooo000000050?moD0040000003oool0oooo0?ooo`8000003P3oool01@000000ogm@0?moD03o
Oe00000000`0oooo00<000000?moD03oOe001@3oOe000`000000oooo000000040?moD0040000003o
ool0oooo0?ooo`800000203oool01@000000ogm@0?moD03oOe00000001<0oooo00<000000?moD03o
Oe00103oOe000`000000oooo000000050?moD0030000003oool0oooo008000003P3oool001/0oooo
00<000000?moD03oOe001P3oOe02000000030?ooo`000000ogm@00H0ogm@0P0000050?moD0030000
003oool0oooo00h0oooo00D000000?moD03oOe00ogm@0000000?0?ooo`030000003oOe00ogm@00H0
ogm@0P0000040?moD0040000003oool0oooo0?ooo`800000203oool00`000000ogm@0?moD0030000
0180oooo00<000000?moD03oOe001@3oOe02000000D0ogm@00@000000?ooo`3oool0oooo0P00000H
0?ooo`030000003oOe00ogm@00`0ogm@0`0000040?moD0040000003oool0oooo0?ooo`800000503o
ool00`000000ogm@0?moD0060?moD08000000P3oool00`000000ogm@0?moD0090?moD0030000003o
ool0oooo00<0oooo0P0000080?ooo`030000003oOe00000000X0oooo00<000000?moD03oOe002P3o
Oe0500000080oooo00<000000?moD03oOe000P3oOe0010000000oooo0?ooo`3oool2000000l0oooo
00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`090?ooo`030000003oOe00ogm@00D0ogm@
0P0000050?moD0040000003oool0oooo0?ooo`8000003P3oool00`000000ogm@0?moD0020?moD003
0000003oool0oooo00T0oooo00<000000?moD03oOe001P3oOe02000000@0ogm@00@000000?ooo`3o
ool0oooo0P0000080?ooo`030000003oOe00ogm@00@000004@3oool00`000000ogm@0?moD0050?mo
D08000001@3oOe000`000000oooo0?ooo`02000000h0oooo000L0?ooo`030000003oOe00ogm@00L0
ogm@0`0000040?moD0@000001@3oOe000`000000oooo0?ooo`0>0?ooo`050000003oOe00ogm@0?mo
D0000000403oool00`000000ogm@0?moD0020?moD0D000001@3oOe001@000000oooo0000003oOe00
000000P0oooo00L000000?moD0000000oooo0000003oOe0000000180oooo00<000000?moD03oOe00
0P3oOe04000000D0ogm@00H000000?ooo`3oool000000?moD000000H0?ooo`030000003oOe00ogm@
00h0ogm@00<000000?moD03oOe000`3oOe001@000000oooo0000003oOe00000001D0oooo00<00000
0?moD03oOe001`3oOe03000000`0ogm@00L000000?ooo`3oool0oooo0000003oOe00000000L0oooo
00<000000?moD00000002`3oool00`000000ogm@0?moD00?0?moD0<000001@3oOe001@000000oooo
0000003oOe0000000100oooo00D000000?moD03oOe00ogm@0000000<0?ooo`030000003oOe00ogm@
0080ogm@100000050?moD0060000003oool0oooo0000003oOe0000003`3oool00`000000ogm@0?mo
D0020?moD0030000003oool0oooo00T0oooo00<000000?moD03oOe000P3oOe05000000D0ogm@00D0
00000?ooo`000000ogm@000000080?ooo`030000003oOe0000000080oooo00@000000?moD0000000
0000403oool00`000000ogm@0?moD0020?moD0@000001@3oOe000`000000oooo0?ooo`02000000h0
oooo000M0?ooo`030000003oOe00ogm@00P0ogm@1@0000040?ooo`030000003oOe00ogm@00<0ogm@
00<000000?ooo`3oool03@3oool00`000000ogm@0?moD0020?moD0030000003oool0oooo00/0oooo
1`0000050?ooo`8000000`3oOe001@000000oooo0000003oOe00000000L0oooo00<000000?moD000
00000P3oool00`000000ogm@0000000@0?ooo`L00000103oool2000000@0ogm@00D000000?ooo`00
0000ogm@0000000I0?ooo`030000003oOe00ogm@00/0ogm@0P0000000`3oool00000000000030?mo
D0050000003oool000000?moD00000005@3oool00`000000ogm@0?moD0090?moD0<000002P3oOe00
1`000000oooo0?ooo`3oool000000?moD00000001`3oool2000000d0oooo00<000000?moD03oOe00
3`3oOe0010000000oooo0000000000030?moD0050000003oool000000?moD0000000403oool00`00
0000ogm@0?moD0020?moD0030000003oool0oooo00T0oooo1@0000040?ooo`800000103oOe001@00
0000oooo0000003oOe00000000l0oooo00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`08
0?ooo`D000001@3oool2000000<0ogm@00D000000?ooo`000000ogm@000000070?ooo`030000003o
Oe00000000<0oooo00D000000?moD03oOe00ogm@0000000?0?ooo`D00000103oool2000000@0ogm@
00@000000?ooo`00000000003P3oool001h0oooo00<000000?moD03oOe001P3oOe000`000000oooo
0?ooo`080?ooo`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool03@3oool00`000000ogm@
0?moD0020?moD0030000003oool0oooo00H0oooo1@0000020?moD0030000003oool0oooo00T0oooo
0P0000001P3oOe0000000?ooo`000000ogm@000000L0oooo0P0000030?ooo`040000003oOe00ogm@
000000X0oooo1@0000020?moD0030000003oool0oooo00P0oooo0P0000020?moD0050000003oool0
00000?moD00000006@3oool00`000000ogm@0?moD0090?moD08000001@3oool2000000060?moD000
0000oooo0000003oOe0000005P3oool00`000000ogm@0?moD0070?moD0040000003oool0oooo0?oo
o`D000001P3oOe001P000000oooo0?ooo`000000ogm@000000L0oooo0P00000=0?ooo`030000003o
Oe00ogm@00h0ogm@00<000000?ooo`3oool00P3oool2000000060?moD0000000oooo0000003oOe00
00004@3oool00`000000ogm@0?moD0020?moD0030000003oool0oooo00H0oooo0`00000:0?ooo`80
00000P3oOe001@000000oooo0000003oOe0000000100oooo00<000000?moD03oOe000`3oOe000`00
0000oooo0?ooo`050?ooo`<000002`3oool2000000060?moD0000000oooo0000003oOe0000001`3o
ool2000000@0oooo00<000000?moD03oOe000P3oOe02000000/0oooo0`00000:0?ooo`8000000P3o
Oe02000000030?moD0000000oooo00d0oooo000O0?ooo`030000003oOe00ogm@00D0ogm@00<00000
0?ooo`3oool02@3oool01@000000ogm@0?moD03oOe00000000l0oooo00<000000?moD03oOe000`3o
Oe000`000000oooo0?ooo`05000000L0ogm@00<000000?ooo`3oool02`3oool300000080ogm@00<0
00000?ooo`3oool0103oool2000000@0oooo00D000000?moD03oOe00ogm@000000030?ooo`H00000
1`3oOe000`000000oooo0?ooo`0:0?ooo`80000000D0ogm@0000003oOe00ogm@0000000I0?ooo`03
0000003oOe00ogm@00L0ogm@0P0000090?ooo`<000000P3oOe000`000000oooo0?ooo`0E0?ooo`03
0000003oOe00ogm@00D0ogm@00<000000?ooo`3oool01`3oool6000000030?moD000000000000080
ogm@00<000000?ooo`3oool0103oool2000000h0oooo00<000000?moD03oOe003@3oOe000`000000
oooo0?ooo`050?ooo`<000000P3oOe000`000000oooo0?ooo`0?0?ooo`030000003oOe00ogm@00<0
ogm@00<000000?ooo`3oool0103oool01@000000ogm@0?moD03oOe00000000/0oooo0P0000001@3o
Oe0000000?moD03oOe0000000100oooo00<000000?moD03oOe00103oOe000`000000oooo0?ooo`03
0?ooo`050000003oOe00ogm@0?moD0000000303oool300000080ogm@00<000000?ooo`3oool0103o
ool2000000H0oooo00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`070?ooo`050000003o
Oe00ogm@0?moD00000002`3oool2000000040?moD0000000ogm@000000h0oooo000=0?ooo`<00000
403oool00`000000ogm@0?moD0030?moD0030000003oool0oooo00/0oooo00D000000?moD03oOe00
ogm@000000090?ooo`030000003oool0oooo0080oooo00<000000?moD03oOe000`3oOe03000000`0
ogm@00<000000?ooo`3oool03@3oool010000000ogm@0?moD00000060?ooo`030000003oool0oooo
00<0oooo00<000000?moD03oOe000P3oOe03000000d0ogm@00<000000?ooo`3oool0303oool20000
0080ogm@00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`030000003oOe00ogm@
00D0ogm@00<000000?ooo`3oool02`3oool010000000ogm@0?moD00000060?ooo`030000003oool0
oooo00l0oooo00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`0>0?ooo`<000000P3oOe00
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?moD03oOe002`3oOe00
0`000000oooo0?ooo`080?ooo`040000003oOe00ogm@000000H0oooo00<000000?ooo`3oool0203o
ool00`000000ogm@0?moD0030?moD0030000003oool0oooo0080oooo0P0000040?moD0030000003o
ool0oooo00/0oooo0P0000020?moD0030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool00`000000ogm@0?moD0040?moD0030000003oool0oooo0080oooo00<000000?moD03oOe000P3o
Oe000`000000oooo0?ooo`0<0?ooo`040000003oOe00ogm@000000H0oooo00<000000?ooo`3oool0
1@3oool00`000000ogm@0?moD0040?moD08000001@3oool2000000@0ogm@00<000000?ooo`3oool0
2`3oool2000000030?moD0000000oooo00d0oooo000>0?ooo`P000002P3oool00`000000ogm@0?mo
D0020?moD0030000003oool0oooo00d0oooo00@000000?moD03oOe0000002@3oool2000000<0oooo
00<000000?moD03oOe000P3oOe000`000000oooo0000000=0?moD0030000003oool0oooo00d0oooo
00@000000?moD03oOe000000303oool00`000000ogm@0?moD0020?moD08000003P3oOe000`000000
oooo0?ooo`0=0?ooo`040000003oOe00ogm@000000H0oooo0P00000B0?ooo`030000003oOe00ogm@
00<0ogm@0P00000>0?ooo`040000003oOe00ogm@000000H0oooo0P00000A0?ooo`030000003oOe00
ogm@0080ogm@00<000000?ooo`3oool0403oool010000000ogm@0?moD000000G0?ooo`030000003o
Oe00ogm@00/0ogm@00<000000?ooo`3oool0203oool010000000ogm@0?moD00000070?ooo`800000
2@3oool00`000000ogm@0?moD0030?moD0040000003oool00000000000H0ogm@00<000000?ooo`3o
ool0303oool010000000ogm@0?moD00000060?ooo`8000002@3oool00`000000ogm@0?moD0040?mo
D0040000003oool00000000000H0ogm@00<000000?ooo`3oool02`3oool010000000ogm@0?moD000
000>0?ooo`030000003oOe00ogm@00H0ogm@0P0000000`3oool00000000000060?moD0030000003o
ool0oooo00`0oooo00<000000?moD00000003P3oool00100oooo0P0000040?moD0D000001P3oool0
10000000ogm@0?moD000000@0?ooo`050000003oOe00ogm@0?moD00000002@3oool01@000000oooo
0?ooo`3oool0000000<0ogm@00D000000?ooo`3oool0oooo0000000<0?moD0030000003oool0oooo
00h0oooo00<000000?moD0000000303oool01@000000ogm@0?moD03oOe0000000080oooo00<00000
0?moD03oOe002`3oOe000`000000oooo0?ooo`0>0?ooo`030000003oOe00000000L0oooo00<00000
0?ooo`3oool0403oool010000000ogm@0?moD03oOe0200000140oooo00<000000?moD00000001`3o
ool200000100oooo00D000000?moD03oOe00ogm@0000000D0?ooo`030000003oOe00000001L0oooo
00<000000?moD03oOe002P3oOe000`000000oooo0?ooo`0:0?ooo`030000003oOe00000000P0oooo
0`0000070?ooo`030000003oOe00ogm@00@0ogm@00<000000?moD03oOe001`3oOe000`000000oooo
0?ooo`0<0?ooo`030000003oOe00000000L0oooo00<000000?ooo`3oool01`3oool00`000000ogm@
0?moD0050?moD0030000003oOe00ogm@00H0ogm@00<000000?ooo`3oool0303oool00`000000ogm@
0000000?0?ooo`030000003oOe00ogm@00L0ogm@00<000000?moD03oOe001`3oOe000`000000oooo
0?ooo`0;0?ooo`030000003oOe00000000h0oooo000B0?ooo`8000001`3oOe06000000040?ooo`00
0000ogm@00000140oooo00@000000?moD03oOe0000002@3oool200000080oooo00@000000?moD03o
Oe000000103oool00`000000ogm@0?moD00:0?moD0030000003oool0oooo00h0oooo00<000000?mo
D0000000303oool01@000000ogm@0?moD03oOe00000000<0oooo00<000000?moD03oOe002P3oOe00
0`000000oooo0?ooo`0>0?ooo`030000003oOe00000000L0oooo0P00000B0?ooo`<000004`3oool0
0`000000ogm@000000070?ooo`030000003oOe0000000100oooo00<000000?moD00000005@3oool0
0`000000ogm@0000000H0?ooo`030000003oOe00ogm@00P0ogm@00<000000?ooo`3oool02`3oool0
0`000000ogm@000000080?ooo`030000003oOe00ogm@008000001@3oool00`000000ogm@0?moD003
0?moD0030000003oool0000000P0ogm@00<000000?ooo`3oool0303oool00`000000ogm@00000007
0?ooo`800000203oool00`000000ogm@0?moD0040?moD0030000003oool0000000L0ogm@00<00000
0?ooo`3oool0303oool00`000000ogm@0000000?0?ooo`030000003oOe00ogm@00L0ogm@0P000008
0?moD0030000003oool0oooo00`0oooo0P00000>0?ooo`00503oool2000000/0ogm@0`00000C0?oo
o`030000003oOe00000000T0oooo00D000000?moD0000000oooo000000020?moD0030000003oool0
oooo00<0oooo00<000000?moD03oOe002@3oOe000`000000oooo0?ooo`0>0?ooo`030000003oOe00
000000`0oooo00D000000?moD03oOe00ogm@000000030?ooo`030000003oOe00ogm@00X0ogm@00<0
00000?ooo`3oool03P3oool00`000000ogm@000000070?ooo`030000003oOe00000000l0oooo0`00
000E0?ooo`030000003oOe00000000P0oooo0P00000?0?ooo`<000005P3oool00`000000ogm@0000
000H0?ooo`030000003oOe00ogm@00L0ogm@00<000000?ooo`3oool0303oool00`000000ogm@0000
00090?ooo`050000003oOe00ogm@0?moD00000001@3oool01@000000ogm@0?moD03oOe00000000<0
oooo00<000000?moD03oOe001@3oOe000`000000oooo0?ooo`0<0?ooo`030000003oOe00000000L0
oooo00<000000?moD0000000203oool00`000000ogm@0?moD0020?moD0050000003oool0oooo0?oo
o`0000001`3oOe000`000000oooo0?ooo`0;0?ooo`030000003oOe00000000l0oooo00<000000?mo
D03oOe001P3oOe0010000000oooo0?ooo`0000070?moD0030000003oool0oooo00`0oooo0P00000>
0?ooo`005P3oool2000000/0ogm@00<000000?ooo`3oool04P3oool00`000000ogm@000000090?oo
o`060000003oOe0000000000003oOe0000001`3oool00`000000ogm@0?moD0080?moD0030000003o
ool0oooo00l0oooo0P00000<0?ooo`040000003oOe00ogm@000000D0oooo00<000000?moD03oOe00
2@3oOe000`000000oooo0?ooo`0?0?ooo`800000203oool00`000000ogm@000000090?ooo`D00000
0P3oOe000`000000oooo0?ooo`0D0?ooo`800000203oool00`000000ogm@000000090?ooo`D00000
0P3oOe000`000000oooo0?ooo`0E0?ooo`8000006@3oool00`000000ogm@0?moD0050?moD0030000
003oool0oooo00h0oooo0P00000:0?ooo`040000003oOe00ogm@0?moD08000000`3oool010000000
ogm@0?moD00000050?ooo`030000003oOe00ogm@00D0ogm@00<000000?ooo`3oool0303oool20000
00P0oooo00<000000?moD00000001`3oool01@000000ogm@0?moD03oOe00000000D0oooo00<00000
0?moD03oOe00103oOe000`000000oooo0?ooo`0<0?ooo`800000403oool00`000000ogm@0?moD005
0?moD0050000003oool0oooo0?ooo`0000001`3oOe000`000000oooo0?ooo`0;0?ooo`8000003P3o
ool001P0oooo00<000000?moD03oOe00203oOe000`000000oooo0?ooo`0C0?ooo`8000002@3oool0
0`000000ogm@00000002000000T0oooo00<000000?moD03oOe001`3oOe000`000000oooo0?ooo`0?
0?ooo`800000303oool010000000ogm@0?moD00000060?ooo`030000003oOe00ogm@00P0ogm@00<0
00000?ooo`3oool03`3oool2000000P0oooo00<000000?moD00000000`3oool6000000P0ogm@00<0
00000?ooo`3oool04`3oool2000000P0oooo00@000000?moD03oOe0000000`3oool5000000P0ogm@
00<000000?ooo`3oool0503oool2000001T0oooo00<000000?moD03oOe00103oOe000`000000oooo
0?ooo`0?0?ooo`8000002`3oool00`000000ogm@0?moD0020?moD080000000D0oooo0000003oOe00
ogm@000000060?ooo`030000003oOe00ogm@00@0ogm@00<000000?ooo`3oool0303oool2000000P0
oooo00<000000?moD00000001`3oool010000000ogm@0?moD00000070?ooo`030000003oOe00ogm@
00@0ogm@00<000000?ooo`3oool02`3oool200000100oooo00<000000?moD03oOe001@3oOe000`00
0000oooo0?ooo`020?ooo`030000003oOe00ogm@00@0ogm@00<000000?ooo`3oool02`3oool20000
00h0oooo000I0?ooo`800000203oOe000`000000oooo0?ooo`0D0?ooo`800000203oool010000000
ogm@0?moD000000;0?ooo`030000003oOe00ogm@00H0ogm@00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0:0?ooo`040000003oOe00ogm@000000L0oooo00<000000?moD03oOe001`3oOe00
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<000000?moD03oOe000`00000>
0?moD0030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool00`000000ogm@0?moD003
000000d0ogm@00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`030000003oOe00
ogm@00<0ogm@00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oOe00
ogm@00<0ogm@100000070?ooo`030000003oOe00ogm@00@0ogm@00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`060?ooo`030000003oOe00ogm@00@00000103oool2000000P0oooo00<00000
0?moD03oOe00103oOe000`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<00000
0?moD03oOe000`3oOe000`000000oooo0?ooo`030?ooo`030000003oOe00ogm@00@0ogm@00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`006`3oool2000000H0ogm@00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`070?ooo`030000003oOe00000000/0oooo00<000000?mo
D03oOe001P3oOe000`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo00<000000?mo
D00000002@3oool00`000000ogm@0?moD0060?moD0030000003oool0oooo0100oooo00<000000?oo
o`3oool01`3oool00`000000ogm@00000002000000h0ogm@00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`070?ooo`030000003oOe00ogm@00<000003P3oOe000`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01P0oooo00D000000?moD03oOe00ogm@0000000D0?ooo`030000003oool0
oooo00/0oooo00<000000?moD03oOe00103oOe000`000000oooo0?ooo`070?ooo`030000003oOe00
ogm@00@0ogm@00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`040000003oOe00
000000000080ogm@1@00000:0?ooo`030000003oOe00ogm@00<0ogm@00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0?0?ooo`030000003oOe00ogm@00<0ogm@00<000000?ooo`3oool0103o
ool00`000000ogm@0?moD0040?moD0030000003oool0oooo00/0oooo00<000000?ooo`3oool0303o
ool001d0oooo0P0000040?moD0030000003oool0oooo01l0oooo00<000000?moD0000000303oool0
0`000000ogm@0?moD0050?moD0030000003oool0oooo01d0oooo00<000000?moD00000002P3oool0
0`000000ogm@0?moD0050?moD0030000003oool0oooo01X0oooo00<000000?moD00000000P3oool2
000000d0ogm@00<000000?ooo`3oool07P3oool00`000000ogm@000000020?ooo`800000303oOe00
0`000000oooo0?ooo`0_0?ooo`050000003oOe00ogm@0?moD00000008P3oool00`000000ogm@0?mo
D0040?moD0030000003oool0oooo00P0oooo00<000000?moD03oOe000`3oOe000`000000oooo0?oo
o`0F0?ooo`050000003oOe0000000?ooo`0000001@3oOe000`000000oooo0?ooo`090?ooo`030000
003oOe00ogm@00<0ogm@00<000000?ooo`3oool07@3oool00`000000ogm@0?moD0030?moD0030000
003oool0oooo00D0oooo00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`0J0?ooo`007`3o
ool200000080ogm@00<000000?ooo`3oool07`3oool00`000000ogm@0000000=0?ooo`030000003o
Oe00ogm@00@0ogm@00<000000?ooo`3oool07@3oool00`000000ogm@0000000:0?ooo`030000003o
Oe00ogm@00D0ogm@00<000000?ooo`3oool06P3oool00`000000ogm@000000040?ooo`8000002`3o
Oe000`000000oooo0?ooo`0N0?ooo`030000003oOe00000000@0oooo0P00000:0?moD0030000003o
ool0oooo02l0oooo00@000000?moD03oOe000000903oool00`000000ogm@0?moD0030?moD0030000
003oool0oooo00T0oooo00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`0E0?ooo`030000
003oOe0000000080oooo00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`090?ooo`030000
003oOe00ogm@0080ogm@00<000000?ooo`3oool07P3oool01@000000ogm@0?moD03oOe00000000T0
oooo00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`0I0?ooo`008@3oool300000280oooo
0P00000>0?ooo`030000003oOe00ogm@00<0ogm@00<000000?ooo`3oool07@3oool2000000`0oooo
00<000000?moD03oOe00103oOe000`000000oooo0?ooo`0K0?ooo`8000001P3oool00`000000ogm@
0?moD0080?moD0030000003oool0oooo01h0oooo00<000000?moD00000001P3oool00`000000ogm@
0?moD0080?moD0030000003oool0oooo02l0oooo0P00000V0?ooo`030000003oOe00ogm@0080ogm@
00<000000?ooo`3oool02P3oool00`000000ogm@0?moD0020?moD0030000003oool0oooo01H0oooo
0P0000020?ooo`030000003oOe00ogm@00<0ogm@00<000000?ooo`3oool02P3oool01@000000ogm@
0?moD03oOe0000000200oooo00D000000?moD03oOe00ogm@0000000:0?ooo`030000003oOe00ogm@
0080ogm@00<000000?ooo`3oool06@3oool002<0oooo00<000000?ooo`3oool0803oool2000000h0
oooo00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`0M0?ooo`8000003@3oool00`000000
ogm@0?moD0030?moD0030000003oool0oooo01/0oooo0P0000070?ooo`8000002@3oOe000`000000
oooo0?ooo`0N0?ooo`8000001`3oool2000000P0ogm@00<000000?ooo`3oool0;@3oool3000002P0
oooo00D000000?moD03oOe00ogm@0000000=0?ooo`050000003oOe00ogm@0?moD0000000603oool2
000000<0oooo00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`0:0?ooo`050000003oOe00
ogm@0?moD00000007`3oool01@000000ogm@0?moD03oOe00000000/0oooo00D000000?moD03oOe00
ogm@0000000K0?ooo`008@3oool2000000030?moD000000000000200oooo0P00000?0?ooo`030000
003oOe00ogm@0080ogm@00<000000?ooo`3oool07@3oool2000000h0oooo00<000000?moD03oOe00
0P3oOe000`000000oooo0?ooo`0K0?ooo`8000002@3oool2000000L0ogm@00<000000?ooo`3oool0
7P3oool2000000T0oooo0P0000070?moD0030000003oool0oooo02L0oooo1@0000030?moD0030000
003oool0oooo02H0oooo00@000000?moD03oOe0000003P3oool01@000000ogm@0?moD03oOe000000
01L0oooo0P0000040?ooo`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool02`3oool01000
0000ogm@0?moD000000P0?ooo`030000003oOe00000000d0oooo00D000000?moD03oOe00ogm@0000
000J0?ooo`00803oool00`000000ogm@0?moD0030?moD08000007`3oool00`000000oooo0?ooo`0>
0?ooo`050000003oOe00ogm@0?moD00000007`3oool00`000000oooo0?ooo`0>0?ooo`050000003o
Oe00ogm@0?moD00000007P3oool00`000000oooo0?ooo`090?ooo`8000001@3oOe000`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00T0oooo0P0000050?moD0030000003oool0oooo0240oooo
1P0000080?moD0030000003oool0oooo02L0oooo00<000000?moD00000003`3oool010000000ogm@
0?moD000000H0?ooo`030000003oool0oooo00<0oooo00D000000?moD03oOe00ogm@0000000>0?oo
o`040000003oOe00ogm@000001l0oooo00<000000?moD00000003P3oool010000000ogm@0?moD000
000J0?ooo`004`3oool2000000T0oooo0P0000080?moD0030000003oool0oooo01`0oooo00<00000
0?ooo`3oool03`3oool010000000ogm@0?moD000000O0?ooo`030000003oool0oooo00l0oooo00@0
00000?moD03oOe0000007P3oool00`000000oooo0?ooo`0;0?ooo`030000003oOe00ogm@00<0ogm@
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0;0?ooo`030000003oOe00ogm@0080ogm@
00<000000?ooo`3oool07P3oool3000000l0ogm@00<000000?ooo`3oool0803oool2000000@0oooo
00<000000?moD0000000403oool00`000000ogm@0000000H0?ooo`030000003oool0oooo00@0oooo
00D000000?moD03oOe00ogm@0000000>0?ooo`030000003oOe00000001P0oooo0P0000050?ooo`03
0000003oOe00000000l0oooo00<000000?moD00000006P3oool001@0oooo1@0000030?ooo`800000
2`3oOe02000002l0oooo00<000000?moD0000000<@3oool010000000ogm@0?moD000000]0?ooo`80
00000`3oOe000`000000oooo0?ooo`0]0?ooo`8000000`3oOe000`000000oooo0?ooo`0P0?ooo`D0
00002`3oOe000`000000oooo0?ooo`0P0?ooo`D0000000<0oooo000000000000403oool010000000
ogm@0?moD000000O0?ooo`040000003oOe00ogm@000000h0oooo00<000000?moD00000006@3oool5
00000080oooo00<000000?ooo`3oool03P3oool010000000ogm@0?moD000000I0?ooo`005P3oool2
000000030?moD0000000000000@00000303oOe000`000000oooo0?ooo`0/0?ooo`030000003oOe00
00000380oooo00<000000?moD0000000;`3oool2000000030?moD0000000oooo0300oooo0P000000
0`3oOe0000000?ooo`0V0?ooo`H000001P3oOe000`000000oooo0?ooo`0Q0?ooo`80000000@0ogm@
00000000000000004@3oool00`000000ogm@0000000P0?ooo`040000003oOe00ogm@000000h0oooo
00<000000?moD00000006P3oool2000000040?moD0000000000000000140oooo00<000000?moD000
00006@3oool001P0oooo0P0000020?moD0030000003oool0oooo00L000001P3oOe02000002d0oooo
0P00000c0?ooo`800000<@3oool300000380oooo0`00000/0?ooo`D0000000<0ogm@0000003oool0
903oool01@000000ogm@0?moD03oOe0000000140oooo0P00000Q0?ooo`030000003oOe00000000l0
oooo0P00000L0?ooo`050000003oOe00ogm@0?moD00000004@3oool2000001T0oooo000J0?ooo`04
0000003oOe00ogm@000000P0oooo1`0000000`3oOe0000000000000/0?ooo`D00000<03oool40000
0300oooo1@00000`0?ooo`@00000;P3oool700000240oooo0P0000020?moD0030000003oool0oooo
00l0oooo0P00000P0?ooo`030000003oOe0000000100oooo0P00000L0?ooo`8000000P3oOe000`00
0000oooo0?ooo`0?0?ooo`800000603oool001/0oooo0P0000000`3oOe0000000?ooo`0=0?ooo`@0
0000:@3oool2000000D0ogm@1@00000Y0?ooo`800000103oOe05000002T0oooo0P0000050?moD0D0
0000:@3oool2000000@0ogm@1@00000Y0?ooo`8000001@3oOe05000001h0oooo00<000000?moD000
00004P3oool00`000000oooo0?ooo`0O0?ooo`030000003oOe0000000100oooo00<000000?ooo`3o
ool0703oool00`000000ogm@0000000B0?ooo`030000003oool0oooo01H0oooo000M0?ooo`<00000
>03oool2000000@0ogm@1@00000Z0?ooo`8000000`3oOe05000002X0oooo0P0000040?moD0D00000
:P3oool2000000<0ogm@1@00000Z0?ooo`800000103oOe0500000280oooo0`00000d0?ooo`800000
<03oool3000002X0oooo000O0?ooo`800000=@3oool8000002d0oooo1`00000]0?ooo`P00000;@3o
ool7000002d0oooo2000000Y0?ooo`800000=03oool200000340oooo0P00000Y0?ooo`008@3oool0
0`000000oooo0?ooo`0a0?ooo`<00000<P3oool300000340oooo0`00000b0?ooo`<00000<@3oool3
00000340oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo02H0oooo003o0?ooonh0oooo003o0?ooonh0oooo003o0?ooonh0oooo003o0?ooonh0oooo003o
0?ooonh0oooo003o0?ooonh0oooo000Q0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0<@3oool3000002H0oooo000Q0?ooo`800000<P3oool2000003<0oooo0P00000b0?ooo`800000
<`3oool200000380oooo0P00000b0?ooo`800000<@3oool2000003D0oooo1`00000Q0?ooo`008P3o
ool200000380oooo0P00000c0?ooo`800000<P3oool2000003<0oooo0P00000b0?ooo`800000<P3o
ool2000002h0oooo0`00000h0?ooo`030000003oOe00ogm@0080ogm@1P00000K0?ooo`008P3oool2
000000`0oooo00<000000?ooo`3oool08`3oool00`000000ogm@0000000<0?ooo`030000003oool0
oooo02<0oooo0P00000<0?ooo`030000003oool0oooo02<0oooo00<000000?moD0000000303oool0
0`000000oooo0?ooo`0S0?ooo`800000303oool00`000000oooo0?ooo`0S0?ooo`030000003oOe00
000000`0oooo00<000000?ooo`3oool08P3oool00`000000ogm@0000000<0?ooo`030000003oool0
oooo01`0oooo0P0000000`3oOe0000000?ooo`0A0?ooo`030000003oool0oooo02D0oooo0P000008
0?moD0<00000603oool00280oooo00<000000?moD00000002`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oOe00000000`0oooo00<000000?ooo`3oool08`3oool00`000000ogm@0000000;0?oo
o`030000003oool0oooo02<0oooo00<000000?moD0000000303oool00`000000oooo0?ooo`0S0?oo
o`030000003oOe00000000/0oooo00<000000?ooo`3oool08`3oool00`000000ogm@0000000<0?oo
o`030000003oool0oooo02<0oooo0P00000<0?ooo`030000003oool0oooo01/0oooo00D000000?mo
D03oOe00ogm@0000000B0?ooo`030000003oool0oooo02L0oooo0P0000030?moD0@000006P3oool0
02<0oooo00<000000?moD00000002P3oool2000002D0oooo00<000000?moD00000002`3oool20000
02D0oooo00<000000?moD00000002P3oool2000002D0oooo00<000000?moD00000002`3oool20000
02D0oooo00<000000?moD00000002P3oool2000002D0oooo00<000000?moD00000002`3oool20000
02@0oooo00<000000?moD00000002`3oool2000001X0oooo0P0000030?moD0030000003oool0oooo
0140oooo0P00000Z0?ooo`<000007P3oool002<0oooo00@000000?moD03oOe0000002@3oool20000
02D0oooo00@000000?moD03oOe0000002P3oool2000002D0oooo00@000000?moD03oOe0000002@3o
ool2000002D0oooo00@000000?moD03oOe0000002P3oool2000002D0oooo00@000000?moD03oOe00
00002@3oool2000002D0oooo00@000000?moD03oOe0000002P3oool2000002@0oooo00@000000?mo
D03oOe0000002P3oool2000001P0oooo0P0000040?moD0030000003oool0oooo0180oooo0P00000Z
0?ooo`8000007`3oool002<0oooo00D000000?moD03oOe00ogm@000000080?ooo`030000003oOe00
000002@0oooo00D000000?moD03oOe00ogm@000000090?ooo`8000009@3oool01@000000ogm@0?mo
D03oOe00000000P0oooo00<000000?moD0000000903oool01@000000ogm@0?moD03oOe00000000T0
oooo0P00000U0?ooo`050000003oOe00ogm@0?moD0000000203oool00`000000ogm@0000000T0?oo
o`050000003oOe00ogm@0?moD00000002@3oool2000002D0oooo00@000000?moD03oOe0000002@3o
ool00`000000ogm@0000000E0?ooo`8000000P3oOe04000001D0oooo0P00000Z0?ooo`030000003o
Oe00000001h0oooo000C0?ooo`030000003oool0oooo00h0oooo00@000000?moD03oOe000000203o
ool00`000000ogm@0000000D0?ooo`030000003oool0oooo00h0oooo00D000000?moD03oOe00ogm@
000000080?ooo`030000003oOe00000001@0oooo00<000000?ooo`3oool03P3oool010000000ogm@
0?moD00000080?ooo`030000003oOe00000001@0oooo00<000000?ooo`3oool03P3oool01@000000
ogm@0?moD03oOe00000000P0oooo00<000000?moD0000000503oool00`000000oooo0?ooo`0>0?oo
o`040000003oOe00ogm@000000P0oooo00<000000?moD0000000503oool00`000000oooo0?ooo`0>
0?ooo`050000003oOe00ogm@0?moD0000000203oool00`000000ogm@0000000D0?ooo`030000003o
ool0oooo00d0oooo00D000000?moD03oOe00ogm@000000080?ooo`030000003oOe00000001@0oooo
1@0000030?ooo`<000004`3oool00`000000ogm@0000000D0?ooo`030000003oool0oooo0180oooo
00@000000?moD03oOe0000007@3oool001@0oooo0P00000>0?ooo`050000003oOe00ogm@0?moD000
00001`3oool00`000000ogm@0000000E0?ooo`8000003P3oool00`000000ogm@0?moD0020?moD003
0000003oool0oooo00D0oooo00<000000?moD00000005@3oool2000000h0oooo00D000000?moD03o
Oe00ogm@000000070?ooo`030000003oOe00000001@0oooo00<000000?ooo`3oool03P3oool00`00
0000ogm@0?moD0020?moD0030000003oool0oooo00D0oooo00<000000?moD00000005@3oool20000
00h0oooo00D000000?moD03oOe00ogm@000000070?ooo`030000003oOe00000001D0oooo0P00000>
0?ooo`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool01@3oool00`000000ogm@0000000D
0?ooo`030000003oool0oooo00d0oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`05
0?ooo`030000003oOe00000001d0oooo00@000000?moD000000000004@3oool00`000000ogm@0000
000E0?ooo`8000004P3oool01@000000ogm@0?moD03oOe00000001`0oooo000E0?ooo`<00000303o
ool00`000000ogm@0?moD0020?moD0030000003oool0oooo00@0oooo00@000000?moD03oOe000000
5@3oool3000000`0oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`050?ooo`030000
003oOe00000001H0oooo0`00000<0?ooo`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool0
103oool010000000ogm@0?moD000000B0?ooo`800000403oool00`000000ogm@0?moD0020?moD003
0000003oool0oooo00D0oooo00<000000?moD00000005P3oool3000000`0oooo00<000000?moD03o
Oe000P3oOe000`000000oooo0?ooo`040?ooo`040000003oOe00ogm@000001D0oooo0`00000<0?oo
o`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool01@3oool00`000000ogm@0000000C0?oo
o`800000403oool01@000000ogm@0?moD03oOe00000000L0oooo00@000000?moD03oOe000000703o
ool010000000ogm@0?moD03oOe02000000l0oooo00<000000?moD00000005P3oool300000100oooo
00D000000?moD03oOe00ogm@0000000L0?ooo`005P3oool00`000000ogm@0000000<0?ooo`030000
003oOe00ogm@0080ogm@00<000000?ooo`3oool00`3oool010000000ogm@0?moD000000F0?ooo`03
0000003oOe00000000`0oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`040?ooo`04
0000003oOe00ogm@000001D0oooo00@000000?moD03oOe000000303oool00`000000ogm@0?moD002
0?moD0030000003oool0oooo00<0oooo00@000000?moD03oOe0000004P3oool200000140oooo00<0
00000?moD03oOe000P3oOe000`000000oooo0?ooo`040?ooo`040000003oOe00ogm@000001D0oooo
00@000000?moD03oOe000000303oool00`000000ogm@0?moD0020?moD0030000003oool0oooo00<0
oooo00@000000?moD03oOe0000005P3oool00`000000ogm@0000000<0?ooo`030000003oOe00ogm@
0080ogm@00<000000?ooo`3oool0103oool010000000ogm@0?moD000000B0?ooo`800000403oool0
0`000000ogm@0?moD0020?moD0030000003oool0oooo00@0oooo00@000000?moD03oOe0000007@3o
ool00`000000ogm@0?moD0020?moD08000003@3oool010000000ogm@0?moD000000E0?ooo`040000
003oOe00ogm@000000l0oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`0I0?ooo`00
5P3oool00`000000ogm@0?moD002000000X0oooo00<000000?moD03oOe000P3oOe000`000000oooo
0?ooo`030?ooo`050000003oOe00ogm@0?moD00000005@3oool00`000000ogm@0?moD002000000X0
oooo00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`030?ooo`040000003oOe00ogm@0000
01H0oooo00<000000?moD03oOe000P00000:0?ooo`030000003oOe00ogm@0080ogm@00<000000?oo
o`3oool00`3oool01@000000ogm@0?moD03oOe0000000140oooo0P00000A0?ooo`030000003oOe00
ogm@00<0ogm@00<000000?ooo`3oool00`3oool010000000ogm@0?moD000000F0?ooo`030000003o
Oe00ogm@008000002P3oool00`000000ogm@0?moD0020?moD0030000003oool0oooo00<0oooo00D0
00000?moD03oOe00ogm@0000000E0?ooo`030000003oOe00ogm@008000002P3oool00`000000ogm@
0?moD0030?moD0030000003oool0oooo00<0oooo00@000000?moD03oOe0000004@3oool00`000000
ogm@0000000A0?ooo`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool00`3oool01@000000
ogm@0?moD03oOe00000001`0oooo00<000000?moD03oOe00103oOe02000000/0oooo00@000000?mo
D03oOe0000005P3oool00`000000ogm@0?moD002000000d0oooo00<000000?moD03oOe000`3oOe00
0`000000oooo0?ooo`0H0?ooo`005`3oool01@000000ogm@0?moD03oOe00000000T0oooo00<00000
0?moD03oOe000`3oOe000`000000oooo0?ooo`020?ooo`050000003oOe00ogm@0?moD00000005P3o
ool01@000000ogm@0?moD03oOe00000000T0oooo00<000000?moD03oOe00103oOe000`000000oooo
0?ooo`020?ooo`040000003oOe00ogm@000001L0oooo00D000000?moD03oOe00ogm@000000090?oo
o`030000003oOe00ogm@00<0ogm@00<000000?ooo`3oool00P3oool01@000000ogm@0?moD03oOe00
00000100oooo00<000000?moD00000004@3oool00`000000ogm@0?moD0040?moD0030000003oool0
oooo0080oooo00@000000?moD03oOe0000005`3oool01@000000ogm@0?moD03oOe00000000T0oooo
00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`020?ooo`050000003oOe00ogm@0?moD000
00005P3oool01@000000ogm@0?moD03oOe00000000T0oooo00<000000?moD03oOe00103oOe000`00
0000oooo0?ooo`020?ooo`040000003oOe00ogm@00000140oooo00<000000?moD00000004@3oool0
0`000000ogm@0?moD0030?moD0030000003oool0oooo0080oooo00D000000?moD03oOe00ogm@0000
000L0?ooo`030000003oOe00ogm@00H0ogm@00<000000?ooo`3oool0203oool010000000ogm@0?mo
D000000G0?ooo`050000003oOe00ogm@0?moD0000000303oool00`000000ogm@0?moD0040?moD003
0000003oool0oooo01L0oooo000H0?ooo`040000003oOe00ogm@0?moD0800000203oool00`000000
ogm@0?moD0030?moD0050000003oool0oooo0?ooo`0000000`3oOe000`000000oooo0?ooo`0E0?oo
o`040000003oOe00ogm@0?moD0800000203oool00`000000ogm@0?moD0040?moD0050000003oool0
oooo0?ooo`0000000`3oOe000`000000oooo0?ooo`0E0?ooo`040000003oOe00ogm@0?moD0800000
203oool00`000000ogm@0?moD0030?moD0050000003oool0oooo0?ooo`0000000`3oOe000`000000
oooo0?ooo`0>0?ooo`030000003oOe0000000180oooo00<000000?moD03oOe00103oOe001@000000
oooo0?ooo`3oool0000000<0ogm@00<000000?ooo`3oool05@3oool010000000ogm@0?moD03oOe02
000000P0oooo00<000000?moD03oOe000`3oOe001@000000oooo0?ooo`3oool0000000<0ogm@00<0
00000?ooo`3oool05@3oool010000000ogm@0?moD03oOe02000000P0oooo00<000000?moD03oOe00
103oOe001@000000oooo0?ooo`3oool0000000<0ogm@00<000000?ooo`3oool03P3oool00`000000
ogm@0000000A0?ooo`030000003oOe00ogm@00@0ogm@00D000000?ooo`3oool0oooo000000030?mo
D0030000003oool0oooo01/0oooo00<000000?moD03oOe001P3oOe02000000P0oooo00D000000?mo
D03oOe00ogm@0000000G0?ooo`040000003oOe00ogm@0?moD08000002P3oool00`000000ogm@0?mo
D0050?moD0030000003oool0oooo01H0oooo000I0?ooo`030000003oOe00ogm@0080ogm@0P000006
0?ooo`030000003oOe00ogm@00@0ogm@00@000000?ooo`3oool00000103oOe000`000000oooo0?oo
o`030?ooo`030000003oool0oooo00l0oooo00<000000?moD03oOe000P3oOe02000000H0oooo00<0
00000?moD03oOe001@3oOe0010000000oooo0?ooo`0000030?moD0030000003oool0oooo00<0oooo
00<000000?ooo`3oool0403oool00`000000ogm@0?moD0020?moD08000001P3oool00`000000ogm@
0?moD0040?moD0040000003oool0oooo000000@0ogm@00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oOe0000000180oooo00<000000?moD03oOe001@3oOe0010000000
oooo0?ooo`0000030?moD0030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`00
0000ogm@0?moD0020?moD08000001P3oool00`000000ogm@0?moD0040?moD0040000003oool0oooo
000000@0ogm@00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003oOe00
ogm@0080ogm@0P0000060?ooo`030000003oOe00ogm@00D0ogm@00@000000?ooo`3oool000000`3o
Oe000`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?moD03oOe000000
4P3oool00`000000ogm@0?moD0040?moD0040000003oool0oooo000000@0ogm@00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0D0?ooo`030000003oOe00ogm@00P0ogm@0P0000060?ooo`05
0000003oOe00ogm@0?moD00000001@3oool00`000000oooo0?ooo`0@0?ooo`030000003oOe00ogm@
0080ogm@0P0000080?ooo`030000003oOe00ogm@00H0ogm@00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0<0?ooo`006P3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo00<0
oooo00<000000?moD03oOe001@3oOe000`000000oooo000000040?moD0030000003oool0oooo00<0
oooo00<000000?ooo`3oool0403oool00`000000ogm@0?moD0030?moD0030000003oool0oooo00<0
oooo00<000000?moD03oOe001@3oOe0010000000oooo0?ooo`0000040?moD0030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool00`000000ogm@0?moD0040?moD0030000003oool0oooo
00<0oooo00<000000?moD03oOe001@3oOe000`000000oooo000000040?moD0030000003oool0oooo
00<0oooo00<000000?ooo`3oool01P3oool010000000ogm@0?moD000000B0?ooo`030000003oOe00
ogm@00D0ogm@00@000000?ooo`3oool00000103oOe000`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0100oooo00<000000?moD03oOe00103oOe000`000000oooo0?ooo`030?ooo`030000003o
Oe00ogm@00D0ogm@00<000000?ooo`000000103oOe000`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0100oooo00<000000?moD03oOe000`3oOe000`000000oooo0?ooo`030?ooo`030000003o
Oe00ogm@00D0ogm@00@000000?ooo`3oool00000103oOe000`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00@000000?moD03oOe0000004P3oool00`000000ogm@0?moD0040?moD004
0000003oool0oooo000000@0ogm@00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oOe00ogm@00T0ogm@0P0000040?ooo`030000003oOe00ogm@0080ogm@00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oOe00ogm@00@0ogm@00<000000?oo
o`3oool01@3oool00`000000ogm@0?moD0070?moD0030000003oool0oooo00D0oooo00<000000?oo
o`3oool0303oool001/0oooo00<000000?moD03oOe000`3oOe02000000@0oooo00<000000?moD03o
Oe00103oOe000`000000oooo000000050?moD0040000003oool0oooo0?ooo`8000004`3oool00`00
0000ogm@0?moD0030?moD0800000103oool00`000000ogm@0?moD0050?moD0030000003oool00000
00@0ogm@00@000000?ooo`3oool0oooo0P00000C0?ooo`030000003oOe00ogm@00@0ogm@0P000004
0?ooo`030000003oOe00ogm@00@0ogm@00<000000?ooo`0000001@3oOe0010000000oooo0?ooo`3o
ool2000000P0oooo00<000000?moD03oOe000`00000A0?ooo`030000003oOe00ogm@00D0ogm@00<0
00000?ooo`000000103oOe0010000000oooo0?ooo`3oool2000001<0oooo00<000000?moD03oOe00
103oOe02000000@0oooo00<000000?moD03oOe00103oOe000`000000oooo000000050?moD0040000
003oool0oooo0?ooo`8000004`3oool00`000000ogm@0?moD0030?moD0800000103oool00`000000
ogm@0?moD0050?moD0030000003oool0000000@0ogm@00@000000?ooo`3oool0oooo0P0000080?oo
o`040000003oOe00ogm@0?moD0<00000403oool00`000000ogm@0?moD0050?moD0030000003oool0
000000D0ogm@00@000000?ooo`3oool0oooo0P00000G0?ooo`030000003oOe00ogm@00/0ogm@0P00
00020?ooo`030000003oOe00ogm@0080ogm@00@000000?ooo`3oool0oooo0P00000C0?ooo`030000
003oOe00ogm@00@0ogm@0P0000050?ooo`030000003oOe00ogm@00P0ogm@00<000000?ooo`3oool0
0`3oool2000000h0oooo000K0?ooo`030000003oOe00ogm@00D0ogm@00D000000?ooo`3oool0oooo
000000070?moD08000001@3oOe0010000000oooo0?ooo`3oool2000001<0oooo00<000000?moD03o
Oe001@3oOe001@000000oooo0?ooo`3oool0000000P0ogm@0P0000040?moD0040000003oool0oooo
0?ooo`800000503oool00`000000ogm@0?moD0050?moD0050000003oool0oooo0?ooo`0000001`3o
Oe02000000D0ogm@00@000000?ooo`3oool0oooo0P0000080?ooo`060000003oOe0000000?ooo`00
0000ogm@1@00000<0?ooo`030000003oOe00ogm@00H0ogm@0P0000040?moD0040000003oool0oooo
0?ooo`800000503oool00`000000ogm@0?moD0050?moD0050000003oool0oooo0?ooo`0000001`3o
Oe02000000D0ogm@00@000000?ooo`3oool0oooo0P00000C0?ooo`030000003oOe00ogm@00D0ogm@
00D000000?ooo`3oool0oooo000000080?moD0800000103oOe0010000000oooo0?ooo`3oool20000
00P0oooo00L000000?moD03oOe0000000?ooo`000000ogm@00D00000303oool00`000000ogm@0?mo
D0050?moD08000001@3oOe0010000000oooo0?ooo`3oool2000001L0oooo00<000000?moD03oOe00
3@3oOe03000000@0ogm@00@000000?ooo`3oool0oooo0P00000D0?ooo`030000003oOe00ogm@00D0
ogm@00<000000?ooo`3oool00P3oool00`000000ogm@0?moD0090?moD0030000003oool0oooo0080
oooo0P00000>0?ooo`00703oool00`000000ogm@0?moD0050?moD080000000<0oooo0000003oOe00
1P3oOe02000000D0ogm@00H000000?ooo`3oool000000?moD000000D0?ooo`030000003oOe00ogm@
00D0ogm@0P0000000`3oool000000?moD0060?moD0<000001@3oOe001@000000oooo0000003oOe00
000001D0oooo00<000000?moD03oOe001@3oOe02000000030?ooo`000000ogm@00H0ogm@0P000005
0?moD0060000003oool0oooo0000003oOe0000001`3oool00`000000ogm@000000030?ooo`030000
003oOe00ogm@00<0ogm@1P0000060?ooo`030000003oOe00ogm@00D0ogm@0`0000050?moD0050000
003oool000000?moD00000005@3oool00`000000ogm@0?moD0050?moD080000000<0oooo0000003o
Oe001P3oOe02000000D0ogm@00H000000?ooo`3oool000000?moD000000D0?ooo`030000003oOe00
ogm@00D0ogm@0P0000000`3oool000000?moD0060?moD0<000001@3oOe001@000000oooo0000003o
Oe00000000P0oooo00<000000?moD00000000`3oool00`000000ogm@0?moD0030?moD0H000001P3o
ool00`000000ogm@0?moD0050?moD08000001@3oOe001P000000oooo0?ooo`000000ogm@000001P0
oooo00<000000?moD03oOe003P3oOe000`000000ogm@0?moD0030?moD0050000003oool000000?mo
D00000005@3oool00`000000ogm@0?moD0050?moD08000000P3oool00`000000ogm@0?moD0090?mo
D0030000003oool0oooo0080oooo0P00000>0?ooo`007@3oool00`000000ogm@0?moD0060?moD0<0
00000P3oOe0400000080oooo0P0000040?moD0050000003oool000000?moD00000005@3oool00`00
0000ogm@0?moD0060?moD0<000000P3oOe04000000<0oooo0P0000030?moD0050000003oool00000
0?moD00000005@3oool00`000000ogm@0?moD0070?moD0<000000P3oOe0400000080oooo0P000004
0?moD0050000003oool000000?moD00000001`3oool2000000D0oooo00<000000?moD03oOe00203o
Oe0500000080oooo00<000000?moD03oOe00100000030?ooo`8000000`3oOe001@000000oooo0000
003oOe00000001D0oooo00<000000?moD03oOe001`3oOe0300000080ogm@100000020?ooo`800000
103oOe001@000000oooo0000003oOe00000001D0oooo00<000000?moD03oOe001P3oOe0300000080
ogm@100000030?ooo`8000000`3oOe001@000000oooo0000003oOe00000000L0oooo00<000000?mo
D0000000103oool00`000000ogm@0?moD0090?moD0D000000P3oool00`000000ogm@0?moD0040000
0080oooo0P0000040?moD0050000003oool000000?moD0000000603oool00`000000ogm@0?moD00<
0?moD080000000<0oooo0000000000000`3oOe001@000000oooo0000003oOe00000001D0oooo00<0
00000?moD03oOe001`3oOe03000000`0ogm@00@000000?ooo`3oool0oooo0P00000>0?ooo`007P3o
ool00`000000ogm@0?moD0070?moD0<00000203oool200000080ogm@00D000000?ooo`000000ogm@
0000000F0?ooo`030000003oOe00ogm@00L0ogm@0`0000090?ooo`80000000H0ogm@0000003oool0
00000?moD000000F0?ooo`030000003oOe00ogm@00P0ogm@0`0000080?ooo`8000000P3oOe001@00
0000oooo0000003oOe00000000L0oooo0P0000050?ooo`030000003oOe00ogm@00d0ogm@1@000009
0?ooo`80000000H0ogm@0000003oool000000?moD000000F0?ooo`030000003oOe00ogm@00P0ogm@
0`0000080?ooo`8000000P3oOe001@000000oooo0000003oOe00000001H0oooo00<000000?moD03o
Oe001`3oOe03000000T0oooo0P0000001P3oOe0000000?ooo`000000ogm@000000L0oooo0P000006
0?ooo`030000003oOe00ogm@00d0ogm@1@0000080?ooo`8000000P3oOe001@000000oooo0000003o
Oe00000001T0oooo00<000000?moD03oOe002@3oOe02000000D0oooo0P0000001P3oOe0000000?oo
o`000000ogm@000001H0oooo00<000000?moD03oOe00203oOe04000000X0ogm@00D000000?ooo`00
0000ogm@0000000>0?ooo`007`3oool00`000000ogm@0?moD0050?moD0030000003oool0oooo00/0
oooo0P0000001@3oOe0000000?moD03oOe00000001L0oooo00<000000?moD03oOe001@3oOe000`00
0000oooo0?ooo`0<0?ooo`<000000P3oOe000`000000oooo0?ooo`0E0?ooo`030000003oOe00ogm@
00H0ogm@00<000000?ooo`3oool02`3oool2000000050?moD0000000ogm@0?moD00000001P3oool2
000000L0oooo00<000000?moD03oOe003P3oOe000`000000oooo0?ooo`0;0?ooo`<000000P3oOe00
0`000000oooo0?ooo`0E0?ooo`030000003oOe00ogm@00H0ogm@00<000000?ooo`3oool02`3oool2
000000050?moD0000000ogm@0?moD00000005`3oool00`000000ogm@0?moD0050?moD0030000003o
ool0oooo00`0oooo0`0000020?moD0030000003oool0oooo00@0oooo0P0000080?ooo`030000003o
Oe00ogm@00h0ogm@00<000000?ooo`3oool02P3oool2000000050?moD0000000ogm@0?moD0000000
6@3oool00`000000ogm@0?moD0070?moD08000002@3oool300000080ogm@00<000000?ooo`3oool0
5@3oool00`000000ogm@0?moD0060?moD0030000003oool0oooo0080oooo200000030?moD0800000
00<0ogm@0000003oool03@3oool000d0oooo0`00000@0?ooo`030000003oOe00ogm@00<0ogm@00<0
00000?ooo`3oool03P3oool200000080ogm@00<000000?ooo`3oool0103oool3000000l0oooo00<0
00000?moD03oOe000`3oOe000`000000oooo0?ooo`0?0?ooo`040000003oOe00ogm@000000H0oooo
00<000000?ooo`3oool03`3oool00`000000ogm@0?moD0040?moD0030000003oool0oooo00h0oooo
0P0000020?moD0030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000ogm@
0?moD00<0?moD0030000003oool0oooo00h0oooo00@000000?moD03oOe0000001P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oOe00ogm@00@0ogm@00<000000?ooo`3oool03P3oool200000080
ogm@00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oOe00ogm@00<0
ogm@00<000000?ooo`3oool03`3oool010000000ogm@0?moD00000060?ooo`030000003oool0oooo
00P0oooo00<000000?moD03oOe00303oOe000`000000oooo0?ooo`0=0?ooo`8000000P3oOe000`00
0000oooo0?ooo`040?ooo`<00000403oool00`000000ogm@0?moD0060?moD0030000003oool0oooo
00/0oooo00@000000?moD03oOe0000001P3oool3000000l0oooo00<000000?moD03oOe00103oOe00
0`000000oooo0?ooo`0;0?ooo`D0000000<0ogm@0000003oool03@3oool000h0oooo2000000:0?oo
o`030000003oOe00ogm@0080ogm@00<000000?ooo`3oool0403oool010000000ogm@0?moD0000007
0?ooo`L000002P3oool00`000000ogm@0?moD0020?moD0030000003oool0oooo0100oooo00@00000
0?moD03oOe0000001P3oool200000140oooo00<000000?moD03oOe000P3oOe000`000000oooo0?oo
o`0@0?ooo`040000003oOe00ogm@00000140oooo00<000000?moD03oOe002`3oOe000`000000oooo
0?ooo`0>0?ooo`040000003oOe00ogm@000000L0oooo0P00000@0?ooo`030000003oOe00ogm@0080
ogm@00<000000?ooo`3oool0403oool010000000ogm@0?moD00000060?ooo`800000403oool00`00
0000ogm@0?moD0020?moD0030000003oool0oooo0100oooo00@000000?moD03oOe0000004P3oool0
0`000000ogm@0?moD00;0?moD0030000003oool0oooo00h0oooo00@000000?moD03oOe0000001`3o
ool7000000`0oooo00<000000?moD03oOe000`3oOe02000000h0oooo00@000000?moD03oOe000000
1`3oool7000000/0oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`0@0?ooo`030000
003oOe00000000h0oooo000@0?ooo`800000103oOe05000000H0oooo00D000000?moD03oOe00ogm@
0000000C0?ooo`030000003oOe00000000T0oooo0P0000030?moD0H000001@3oool01@000000ogm@
0?moD03oOe00000001<0oooo00<000000?moD00000001`3oool200000100oooo00D000000?moD03o
Oe00ogm@0000000D0?ooo`030000003oOe0000000180oooo00<000000?moD03oOe002P3oOe000`00
0000oooo0?ooo`0?0?ooo`030000003oOe00000000P0oooo0`00000>0?ooo`050000003oOe00ogm@
0?moD0000000503oool00`000000ogm@000000070?ooo`030000003oool0oooo00l0oooo00D00000
0?moD03oOe00ogm@0000000C0?ooo`030000003oOe0000000180oooo00<000000?moD03oOe002P3o
Oe000`000000oooo0?ooo`0@0?ooo`030000003oOe00000000T0oooo0P0000030?moD0H000001P3o
ool010000000ogm@0?moD03oOe0200000140oooo00<000000?moD00000002@3oool2000000<0ogm@
1P0000050?ooo`050000003oOe00ogm@0?moD00000004`3oool00`000000ogm@0000000>0?ooo`00
4P3oool00`000000ogm@0?moD0060?moD0H0000000@0oooo0000003oOe000000503oool00`000000
ogm@0000000;0?ooo`030000003oOe00ogm@00H0ogm@1@000000103oool000000?moD000000D0?oo
o`030000003oOe00000000L0oooo00<000000?moD0000000403oool00`000000ogm@0000000E0?oo
o`030000003oOe00000001<0oooo00<000000?moD03oOe00203oOe000`000000oooo0?ooo`0@0?oo
o`030000003oOe00000000P0oooo00<000000?moD03oOe000P00000=0?ooo`030000003oOe000000
01D0oooo00<000000?moD00000001`3oool200000140oooo00<000000?moD0000000503oool00`00
0000ogm@0000000C0?ooo`030000003oOe00ogm@00T0ogm@00<000000?ooo`3oool0403oool00`00
0000ogm@0000000;0?ooo`030000003oOe00ogm@00H0ogm@1@0000020?ooo`<000004`3oool00`00
0000ogm@0000000;0?ooo`030000003oOe00ogm@00H0ogm@1@000000103oool000000?moD000000E
0?ooo`8000003P3oool001<0oooo0P00000<0?moD0<000005@3oool00`000000ogm@0000000<0?oo
o`8000002`3oOe03000001D0oooo00<000000?moD0000000203oool2000000l0oooo0`00000F0?oo
o`030000003oOe00000001<0oooo00<000000?moD03oOe00203oOe000`000000oooo0?ooo`0@0?oo
o`030000003oOe00000000T0oooo00D000000?moD03oOe00ogm@0000000=0?ooo`030000003oool0
oooo01@0oooo00<000000?moD00000001`3oool00`000000ogm@0000000A0?ooo`030000003oool0
oooo01<0oooo00<000000?moD0000000503oool00`000000ogm@0?moD0080?moD0030000003oool0
oooo0100oooo00<000000?moD0000000303oool2000000/0ogm@0`00000E0?ooo`030000003oOe00
000000`0oooo0P00000;0?moD0<000005P3oool2000000h0oooo000E0?ooo`800000303oOe000`00
0000oooo0?ooo`0D0?ooo`8000003P3oool00`000000ogm@0?moD00:0?moD0030000003oool0oooo
01@0oooo0P0000080?ooo`030000003oOe00000000T0oooo1@0000020?moD0030000003oool0oooo
01D0oooo0P00000D0?ooo`030000003oOe00ogm@00L0ogm@00<000000?ooo`3oool04@3oool20000
00X0oooo00@000000?moD03oOe00ogm@0P0000090?ooo`80000000<0ogm@0000003oool05@3oool2
000000P0oooo00<000000?moD00000003P3oool2000000030?moD0000000oooo01@0oooo0P00000E
0?ooo`030000003oOe00ogm@00H0ogm@00<000000?ooo`3oool04P3oool2000000h0oooo00<00000
0?moD03oOe002P3oOe000`000000oooo0?ooo`0D0?ooo`8000003P3oool00`000000ogm@0?moD00:
0?moD0030000003oool0oooo01@0oooo0P00000>0?ooo`005`3oool00`000000ogm@0?moD0090?mo
D0030000003oool0oooo01@0oooo0P00000?0?ooo`8000002P3oOe000`000000oooo0?ooo`0D0?oo
o`800000203oool010000000ogm@0?moD00000030?ooo`D00000203oOe000`000000oooo0?ooo`0D
0?ooo`8000005@3oool00`000000ogm@0?moD0050?moD0030000003oool0oooo0180oooo0P00000;
0?ooo`030000003oOe00ogm@0080ogm@0P0000050?ooo`800000103oOe000`000000oooo0?ooo`0C
0?ooo`800000203oool00`000000ogm@0000000<0?ooo`800000103oOe000`000000oooo0?ooo`0B
0?ooo`8000005@3oool00`000000ogm@0?moD0060?moD0030000003oool0oooo0180oooo0P00000?
0?ooo`8000002P3oOe000`000000oooo0?ooo`0D0?ooo`8000003`3oool2000000X0ogm@00<00000
0?ooo`3oool0503oool2000000h0oooo000H0?ooo`8000002@3oOe000`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00l0oooo0P0000080?moD0030000003oool0oooo01D0oooo00<000000?oo
o`3oool01`3oool00`000000ogm@0?moD003000000d0ogm@00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oOe00ogm@00@0ogm@00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oOe00ogm@00<0ogm@0P0000000`3oool00000000000060?mo
D0030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool00`000000ogm@0?moD0050000
00D0oooo0P0000060?moD0030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`00
0000ogm@0?moD0040?moD0030000003oool0oooo01@0oooo00<000000?ooo`3oool03`3oool20000
00P0ogm@00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`800000203oOe000`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo000J0?ooo`8000001`3oOe000`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?moD03oOe001@3oOe000`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo00<000000?moD03oOe000`00000>0?moD003
0000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000ogm@0?moD0030?moD003
0000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool00`000000ogm@0?moD0040?moD003
0000003oOe00ogm@00L0ogm@00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`04
0000003oOe000000000000<0ogm@1@0000090?moD0030000003oool0oooo0180oooo00<000000?oo
o`3oool05@3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo01@0oooo00<000000?oo
o`3oool04@3oool00`000000ogm@0?moD0050?moD0030000003oool0oooo01D0oooo00<000000?oo
o`3oool04@3oool00`000000ogm@0?moD0050?moD0030000003oool0oooo01D0oooo00<000000?oo
o`3oool0303oool001`0oooo0P0000050?moD0030000003oool0oooo02X0oooo0P0000050?moD003
0000003oool0oooo0200oooo00<000000?moD00000000P3oool2000000`0ogm@00<000000?ooo`3o
ool0;@3oool01@000000ogm@0?moD03oOe00000002@0oooo00<000000?moD03oOe00103oOe030000
00P0ogm@00<000000?ooo`3oool0703oool01@000000ogm@0000003oool0000000H0ogm@0`000008
0?moD0030000003oool0oooo02X0oooo00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`0Y
0?ooo`8000001@3oOe000`000000oooo0?ooo`0Z0?ooo`8000001@3oOe000`000000oooo0?ooo`0T
0?ooo`007P3oool00`000000ogm@0?moD0020?moD0030000003oool0oooo02`0oooo00<000000?mo
D03oOe000P3oOe000`000000oooo0?ooo`0P0?ooo`030000003oOe00000000@0oooo0P00000:0?mo
D0030000003oool0oooo02d0oooo00D000000?moD03oOe00ogm@0000000U0?ooo`030000003oOe00
ogm@00<0ogm@00<000000?ooo`3oool00P0000070?moD0030000003oool0oooo01/0oooo00<00000
0?moD00000000P3oool00`000000ogm@0?moD0040?moD0040000003oool00000000000L0ogm@00<0
00000?ooo`3oool0:P3oool010000000ogm@0?moD000000^0?ooo`030000003oOe00ogm@0080ogm@
00<000000?ooo`3oool0;03oool00`000000ogm@0?moD0020?moD0030000003oool0oooo02@0oooo
000O0?ooo`8000000P3oOe000`000000oooo0?ooo`0]0?ooo`8000000P3oOe000`000000oooo0?oo
o`0P0?ooo`030000003oOe00000000H0oooo00<000000?moD03oOe00203oOe000`000000oooo0?oo
o`0]0?ooo`040000003oOe00ogm@000002H0oooo00<000000?moD03oOe000P3oOe000`000000oooo
0?ooo`020?ooo`030000003oOe00ogm@00D0ogm@00<000000?ooo`3oool06`3oool200000080oooo
00<000000?moD03oOe00103oOe001@000000oooo0?ooo`3oool0000000L0ogm@00<000000?ooo`3o
ool0:@3oool010000000ogm@0?moD000000_0?ooo`8000000P3oOe000`000000oooo0?ooo`0]0?oo
o`8000000P3oOe000`000000oooo0?ooo`0T0?ooo`008@3oool300000340oooo0`00000S0?ooo`80
00001`3oool2000000P0ogm@00<000000?ooo`3oool0;P3oool2000002P0oooo00D000000?moD03o
Oe00ogm@000000050?ooo`8000001P3oOe000`000000oooo0?ooo`0J0?ooo`8000000`3oool00`00
0000ogm@0?moD0030?moD0030000003oool0oooo0080oooo0P0000060?moD0030000003oool0oooo
02T0oooo0P00000b0?ooo`<00000<@3oool3000002H0oooo000P0?ooo`@00000<`3oool00`000000
oooo0?ooo`0Q0?ooo`8000002@3oool2000000L0ogm@00<000000?ooo`3oool0:`3oool4000002T0
oooo00@000000?moD03oOe0000001`3oool00`000000ogm@0?moD0030?moD0030000003oool0oooo
01X0oooo0P0000040?ooo`030000003oOe00ogm@00<0ogm@00<000000?ooo`3oool00`3oool00`00
0000ogm@0?moD0030?moD0030000003oool0oooo02X0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo02@0oooo000H0?ooo`P00000103oOe000`000000
oooo0?ooo`0^0?ooo`80000000<0ogm@0000000000008P3oool00`000000oooo0?ooo`090?ooo`80
00001@3oOe000`000000oooo0?ooo`0S0?ooo`P00000103oOe000`000000oooo0?ooo`0W0?ooo`03
0000003oOe00000000P0oooo0P0000040?moD0030000003oool0oooo01X0oooo00<000000?ooo`3o
ool00`3oool00`000000ogm@0?moD0020?moD0030000003oool0oooo00@0oooo0P0000040?moD003
0000003oool0oooo02L0oooo0P0000000`3oOe0000000000000`0?ooo`80000000<0ogm@00000000
0000;`3oool2000000030?moD0000000000002@0oooo000C0?ooo`D000003@3oOe000`000000oooo
0?ooo`0O0?ooo`<000002@3oool2000000D0ogm@0P00000P0?ooo`030000003oool0oooo00/0oooo
00<000000?moD03oOe000P3oOe000`000000oooo0?ooo`0N0?ooo`D000003@3oOe000`000000oooo
0?ooo`0P0?ooo`800000103oool00`000000ogm@0000000:0?ooo`8000000`3oOe000`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00D000000?moD03oOe00ogm@000000080?ooo`80
00000`3oOe000`000000oooo0?ooo`0I0?ooo`8000002@3oool2000000D0ogm@0P00000P0?ooo`80
00002P3oool2000000D0ogm@0P00000P0?ooo`8000002@3oool2000000D0ogm@0P00000R0?ooo`00
5P3oool5000000X0ogm@00<000000?ooo`3oool0803oool6000000<0oooo0P0000090?moD0800000
;@3oool2000000<0ogm@00<000000?ooo`3oool0803oool5000000X0ogm@00<000000?ooo`3oool0
8@3oool5000000030?ooo`000000000000`0oooo00D000000?moD03oOe00ogm@0000000R0?ooo`05
0000003oOe00ogm@0?moD00000002@3oool01@000000ogm@0?moD03oOe00000001/0oooo1@000003
0?ooo`8000002@3oOe02000001l0oooo1@0000040?ooo`8000002@3oOe02000001l0oooo1@000003
0?ooo`8000002@3oOe0200000200oooo000K0?ooo`H000001@3oOe000`000000oooo0?ooo`0Q0?oo
o`8000000P3oOe05000000/0ogm@00<000000?ooo`3oool0;03oool2000000030?moD0000000oooo
02H0oooo1P0000050?moD0030000003oool0oooo0280oooo0P000000103oOe00000000000000000=
0?ooo`8000000P3oOe000`000000oooo0?ooo`0P0?ooo`040000003oOe00ogm@000000X0oooo0P00
00020?moD0030000003oool0oooo01X0oooo0P0000000`3oOe00000000000003000000/0ogm@00<0
00000?ooo`3oool07P3oool2000000030?moD0000000000000<00000303oOe000`000000oooo0?oo
o`0N0?ooo`80000000<0ogm@0000000000000`00000;0?moD0030000003oool0oooo01d0oooo000Q
0?ooo`D0000000<0ogm@0000003oool08`3oool2000000<0ogm@00<000000?ooo`00000010000007
0?moD0800000;P3oool3000002`0oooo1@0000000`3oOe0000000?ooo`0T0?ooo`8000000P3oOe00
0`000000oooo0?ooo`0<0?ooo`040000003oOe00ogm@00000280oooo00<000000?moD0000000303o
ool010000000ogm@0?moD000000M0?ooo`060000003oOe00ogm@0?moD0000000oooo1@0000070?mo
D0800000803oool200000080ogm@00<000000?ooo`0000001@0000070?moD0800000803oool01P00
0000ogm@0?moD03oOe0000000?ooo`D000001`3oOe02000001d0oooo000V0?ooo`@00000903oool0
1@000000ogm@0?moD03oOe00000000D0oooo1P0000030?moD0800000;P3oool200000300oooo1@00
000T0?ooo`040000003oOe00ogm@000000h0oooo0`00000R0?ooo`040000003oOe00ogm@000000`0
oooo0`00000N0?ooo`8000000P3oOe000`000000oooo0?ooo`030?ooo`H000000`3oOe0200000200
oooo00@000000?moD03oOe0000001P3oool5000000@0ogm@0P00000O0?ooo`8000000P3oOe000`00
0000oooo0?ooo`030?ooo`H000000`3oOe02000001/0oooo000V0?ooo`8000000P3oOe0400000240
oooo0P0000000`3oOe0000000?ooo`0:0?ooo`L00000:P3oool200000080ogm@1000000/0?ooo`80
00000`3oOe0400000240oooo0P0000000`3oOe0000000?ooo`0>0?ooo`8000008P3oool00`000000
ogm@0000000>0?ooo`8000007`3oool00`000000ogm@0000000;0?ooo`L000007`3oool200000003
0?moD0000000oooo00T0oooo2000000O0?ooo`030000003oOe00000000/0oooo1`00000I0?ooo`00
903oool2000000L0ogm@1000000P0?ooo`<000003`3oool3000002L0oooo0P0000070?moD0@00000
9`3oool2000000P0ogm@1000000P0?ooo`<00000403oool00`000000oooo0?ooo`0P0?ooo`800000
403oool00`000000oooo0?ooo`0M0?ooo`<000003`3oool300000200oooo0`00000?0?ooo`<00000
7`3oool3000000l0oooo0`00000H0?ooo`008P3oool2000000030?moD0000000000000H000009P3o
ool2000003H0oooo0P0000000`3oOe00000000000006000002T0oooo0P0000020?moD0P000009P3o
ool2000003<0oooo0P00000a0?ooo`800000<`3oool200000380oooo0P00000Y0?ooo`008@3oool4
00000300oooo00<000000?ooo`3oool0<P3oool400000300oooo1@00000`0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool09P3oool00?l0ooookP3oool00?l0ooookP3oool00?l0oooo
kP3oool00?l0ooookP3oool00?l0ooookP3oool00001\
\>"],
  ImageRangeCache->{{{0, 492.813}, {162.75, 0}} -> {-0.243972, -0.0746185, \
0.0192527, 0.0192527}, {{12.625, 60.3125}, {158.875, 110.438}} -> {-1.49196, \
-1.1275, 0.0401336, 0.0401336}, {{65.125, 112.813}, {158.875, 110.438}} -> \
{-3.59897, -1.1275, 0.0401336, 0.0401336}, {{117.563, 165.313}, {158.875, \
110.438}} -> {-5.70306, -1.12717, 0.0401218, 0.0401218}, {{170.063, 217.75}, \
{158.875, 110.438}} -> {-7.81048, -1.1275, 0.0401336, 0.0401336}, {{222.5, \
270.25}, {158.875, 110.438}} -> {-9.91335, -1.12717, 0.0401218, 0.0401218}, \
{{275, 322.688}, {158.875, 110.438}} -> {-12.022, -1.1275, 0.0401336, \
0.0401336}, {{327.438, 375.188}, {158.875, 110.438}} -> {-14.1236, -1.12717, \
0.0401218, 0.0401218}, {{379.938, 427.625}, {158.875, 110.438}} -> {-16.2335, \
-1.1275, 0.0401336, 0.0401336}, {{432.438, 480.125}, {158.875, 110.438}} -> \
{-18.3405, -1.1275, 0.0401336, 0.0401336}, {{12.625, 60.3125}, {105.563, \
57.125}} -> {-1.49196, -3.26712, 0.0401336, 0.0401336}, {{65.125, 112.813}, \
{105.563, 57.125}} -> {-3.59897, -3.26712, 0.0401336, 0.0401336}, {{117.563, \
165.313}, {105.563, 57.125}} -> {-5.70306, -3.26616, 0.0401218, 0.0401218}, \
{{170.063, 217.75}, {105.563, 57.125}} -> {-7.81048, -3.26712, 0.0401336, \
0.0401336}, {{222.5, 270.25}, {105.563, 57.125}} -> {-9.91335, -3.26616, \
0.0401218, 0.0401218}, {{275, 322.688}, {105.563, 57.125}} -> {-12.022, \
-3.26712, 0.0401336, 0.0401336}, {{327.438, 375.188}, {105.563, 57.125}} -> \
{-14.1236, -3.26616, 0.0401218, 0.0401218}, {{379.938, 427.625}, {105.563, \
57.125}} -> {-16.2335, -3.26712, 0.0401336, 0.0401336}, {{432.438, 480.125}, \
{105.563, 57.125}} -> {-18.3405, -3.26712, 0.0401336, 0.0401336}, {{12.625, \
60.3125}, {52.3125, 3.875}} -> {-1.49196, -5.40423, 0.0401336, 0.0401336}, \
{{65.125, 112.813}, {52.3125, 3.875}} -> {-3.59897, -5.40423, 0.0401336, \
0.0401336}, {{117.563, 165.313}, {52.3125, 3.875}} -> {-5.70306, -5.40265, \
0.0401218, 0.0401218}, {{170.063, 217.75}, {52.3125, 3.875}} -> {-7.81048, \
-5.40423, 0.0401336, 0.0401336}, {{222.5, 270.25}, {52.3125, 3.875}} -> \
{-9.91335, -5.40265, 0.0401218, 0.0401218}, {{275, 322.688}, {52.3125, \
3.875}} -> {-12.022, -5.40423, 0.0401336, 0.0401336}, {{327.438, 375.188}, \
{52.3125, 3.875}} -> {-14.1236, -5.40265, 0.0401218, 0.0401218}, {{379.938, \
427.625}, {52.3125, 3.875}} -> {-16.2335, -5.40423, 0.0401336, 0.0401336}, \
{{432.438, 480.125}, {52.3125, 3.875}} -> {-18.3405, -5.40423, 0.0401336, \
0.0401336}}]
}, Open  ]],

Cell[BoxData[
    \(triangulation4[s_String] := 
      Module[{u = functional[s], n, v, A, B, C}, \[IndentingNewLine]n = 
          numVar[u] + 
            1; \[IndentingNewLine]v = \(N[{Cos[\(\(\ \)\(2\ \[Pi]\ #\)\)\/n], 
                  Sin[\(\(\ \)\(2\ \[Pi]\ #\)\)\/n]}] &\) /@ 
            Range[n]; \[IndentingNewLine]Graphics[\(\(({A, B, 
                    C} = #; \[IndentingNewLine]\ {{Indigo, 
                    Spline[{\(A + C\)\/2, \(A + B + C\)\/3, C, \(B + C\)\/2}, 
                      Bezier], 
                    Spline[{\(A + C\)\/2, \(A + B + C\)\/3, A, \(A + B\)\/2}, 
                      Bezier], 
                    Spline[{\(A + B\)\/2, \(A + B + C\)\/3, B, \(B + C\)\/2}, 
                      Bezier]}})\) &\) /@ \ tri[u, v], 
          AspectRatio \[Rule] Automatic]]\)], "Input",
  CellLabel->"In[275]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[
          Partition[triangulation4\  /@ \ sweep["\<abcdefg\>"], 
            4]]];\)\)], "Input",
  CellLabel->"In[276]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74419 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0177187 0.238095 [
[ 0 0 0 0 ]
[ 1 .74419 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .74419 L
0 .74419 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0177187 0.245293 0.239203 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.538862 0.5 0.538862 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.03 .18 .33 r
.5 Mabswid
[ ] 0 setdash
.76943 .23057 m
.77066 .22952 L
.77201 .22868 L
.77347 .22806 L
.77425 .22783 L
.77506 .22765 L
.77676 .22744 L
.77857 .22742 L
.78048 .22759 L
.7825 .22795 L
.78683 .22919 L
.79153 .23109 L
.80194 .23673 L
.8135 .24448 L
.82599 .254 L
.8392 .2649 L
.85289 .27683 L
.86687 .28942 L
.88089 .30231 L
.89476 .31513 L
.90823 .32752 L
.9211 .33911 L
.93315 .34953 L
.94415 .35843 L
.95389 .36543 L
.95822 .36811 L
.96215 .37018 L
.96565 .37159 L
.96724 .37203 L
.96798 .37219 L
.9687 .3723 L
.97005 .37237 L
.97068 .37234 L
.97127 .37226 L
.97184 .37213 L
.97237 .37195 L
.97287 .37171 L
.9731 .37158 L
.97322 .3715 L
.97333 .37143 L
.97376 .37109 L
.97416 .3707 L
.97453 .37026 L
.9747 .37002 L
.97486 .36976 L
.97541 .3686 L
.97563 .36793 L
.97582 .36721 L
.97619 .36372 L
.97594 .35927 L
Mistroke
.97349 .34724 L
.96823 .33077 L
.95995 .30948 L
Mfstroke
.76943 .23057 m
.77048 .22934 L
.77132 .22799 L
.77194 .22653 L
.77217 .22575 L
.77235 .22494 L
.77256 .22324 L
.77258 .22143 L
.77241 .21952 L
.77205 .2175 L
.77081 .21317 L
.76891 .20847 L
.76327 .19806 L
.75552 .1865 L
.746 .17401 L
.7351 .1608 L
.72317 .14711 L
.71058 .13313 L
.69769 .11911 L
.68487 .10524 L
.67248 .09177 L
.66089 .0789 L
.65047 .06685 L
.64157 .05585 L
.63457 .04611 L
.63189 .04178 L
.62982 .03785 L
.62841 .03435 L
.62797 .03276 L
.62781 .03202 L
.6277 .0313 L
.62763 .02995 L
.62766 .02932 L
.62774 .02873 L
.62787 .02816 L
.62805 .02763 L
.62829 .02713 L
.62842 .0269 L
.6285 .02678 L
.62857 .02667 L
.62891 .02624 L
.6293 .02584 L
.62974 .02547 L
.62998 .0253 L
.63024 .02514 L
.6314 .02459 L
.63207 .02437 L
.63279 .02418 L
.63628 .02381 L
.64073 .02406 L
Mistroke
.65276 .02651 L
.66923 .03177 L
.69052 .04005 L
Mfstroke
.69052 .04005 m
.70482 .05807 L
.7187 .07392 L
.73219 .08783 L
.74531 .10001 L
.75807 .11068 L
.7705 .12004 L
.78262 .12831 L
.79444 .13571 L
.80599 .14244 L
.81728 .14873 L
.82834 .15478 L
.83918 .16082 L
.84983 .16705 L
.86031 .17368 L
.87063 .18094 L
.88083 .18903 L
.8909 .19817 L
.90089 .20857 L
.9108 .22045 L
.92065 .23402 L
.93048 .2495 L
.94029 .26709 L
.9501 .28701 L
.95995 .30948 L
s
.23057 .76943 m
.22934 .77048 L
.22799 .77132 L
.22653 .77194 L
.22575 .77217 L
.22494 .77235 L
.22324 .77256 L
.22143 .77258 L
.21952 .77241 L
.2175 .77205 L
.21317 .77081 L
.20847 .76891 L
.19806 .76327 L
.1865 .75552 L
.17401 .746 L
.1608 .7351 L
.14711 .72317 L
.13313 .71058 L
.11911 .69769 L
.10524 .68487 L
.09177 .67248 L
.0789 .66089 L
.06685 .65047 L
.05585 .64157 L
.04611 .63457 L
.04178 .63189 L
.03785 .62982 L
.03435 .62841 L
.03276 .62797 L
.03202 .62781 L
.0313 .6277 L
.02995 .62763 L
.02932 .62766 L
.02873 .62774 L
.02816 .62787 L
.02763 .62805 L
.02713 .62829 L
.0269 .62842 L
.02678 .6285 L
.02667 .62857 L
.02624 .62891 L
.02584 .6293 L
.02547 .62974 L
.0253 .62998 L
.02514 .63024 L
.02459 .6314 L
.02437 .63207 L
.02418 .63279 L
.02381 .63628 L
.02406 .64073 L
Mistroke
.02651 .65276 L
.03177 .66923 L
.04005 .69052 L
Mfstroke
.23057 .76943 m
.22952 .77066 L
.22868 .77201 L
.22806 .77347 L
.22783 .77425 L
.22765 .77506 L
.22744 .77676 L
.22742 .77857 L
.22759 .78048 L
.22795 .7825 L
.22919 .78683 L
.23109 .79153 L
.23673 .80194 L
.24448 .8135 L
.254 .82599 L
.2649 .8392 L
.27683 .85289 L
.28942 .86687 L
.30231 .88089 L
.31513 .89476 L
.32752 .90823 L
.33911 .9211 L
.34953 .93315 L
.35843 .94415 L
.36543 .95389 L
.36811 .95822 L
.37018 .96215 L
.37159 .96565 L
.37203 .96724 L
.37219 .96798 L
.3723 .9687 L
.37237 .97005 L
.37234 .97068 L
.37226 .97127 L
.37213 .97184 L
.37195 .97237 L
.37171 .97287 L
.37158 .9731 L
.3715 .97322 L
.37143 .97333 L
.37109 .97376 L
.3707 .97416 L
.37026 .97453 L
.37002 .9747 L
.36976 .97486 L
.3686 .97541 L
.36793 .97563 L
.36721 .97582 L
.36372 .97619 L
.35927 .97594 L
Mistroke
.34724 .97349 L
.33077 .96823 L
.30948 .95995 L
Mfstroke
.30948 .95995 m
.29518 .94193 L
.2813 .92608 L
.26781 .91217 L
.25469 .89999 L
.24193 .88932 L
.2295 .87996 L
.21738 .87169 L
.20556 .86429 L
.19401 .85756 L
.18272 .85127 L
.17166 .84522 L
.16082 .83918 L
.15017 .83295 L
.13969 .82632 L
.12937 .81906 L
.11917 .81097 L
.1091 .80183 L
.09911 .79143 L
.0892 .77955 L
.07935 .76598 L
.06952 .7505 L
.05971 .73291 L
.0499 .71299 L
.04005 .69052 L
s
.5 .5 m
.47744 .49808 L
.45472 .49261 L
.4319 .484 L
.40904 .47266 L
.3862 .459 L
.36345 .44344 L
.34085 .42639 L
.31846 .40827 L
.29634 .38949 L
.27456 .37045 L
.25318 .35159 L
.23226 .3333 L
.21187 .316 L
.19206 .30011 L
.1729 .28604 L
.15446 .2742 L
.13679 .26501 L
.12826 .26154 L
.11995 .25888 L
.11187 .25709 L
.10792 .25653 L
.10402 .25622 L
.09641 .25632 L
.0927 .25675 L
.08905 .25744 L
.08195 .25964 L
.07849 .26116 L
.07511 .26297 L
.06854 .26748 L
.06536 .27019 L
.06225 .27321 L
.05625 .28023 L
.05054 .28858 L
.04005 .30948 L
s
.5 .5 m
.48972 .50049 L
.48128 .50192 L
.47771 .50297 L
.47457 .50423 L
.47183 .50571 L
.47062 .50652 L
.47005 .50695 L
.4695 .50739 L
.46755 .50926 L
.46672 .51027 L
.46598 .51133 L
.46476 .51358 L
.46429 .51477 L
.4639 .516 L
.46338 .5186 L
.46319 .52136 L
.4633 .52427 L
.46348 .52579 L
.46373 .52734 L
.46543 .53391 L
.4682 .541 L
.47657 .55656 L
.48807 .57361 L
.50192 .59173 L
.51737 .61051 L
.53366 .62955 L
.55001 .64841 L
.56567 .6667 L
.57986 .684 L
.59183 .69989 L
.60082 .71396 L
.60395 .72018 L
.60605 .7258 L
.60668 .72836 L
.60702 .73075 L
.60705 .73296 L
.60695 .734 L
.60687 .7345 L
.60676 .73499 L
.6065 .73593 L
.60615 .73683 L
.60571 .73767 L
.60546 .73807 L
.60519 .73846 L
.60458 .73921 L
.60388 .7399 L
.60308 .74054 L
.60265 .74084 L
.60243 .74098 L
Mistroke
.6022 .74112 L
.60014 .74213 L
.59769 .74291 L
.59485 .74347 L
.59158 .74378 L
.58377 .74368 L
.57416 .74256 L
.54916 .73703 L
.51583 .72679 L
.47339 .71142 L
.42109 .69052 L
Mfstroke
.42109 .69052 m
.4072 .66767 L
.39093 .64664 L
.37256 .62726 L
.35241 .60937 L
.33078 .59281 L
.30797 .5774 L
.28427 .56298 L
.26 .54939 L
.23546 .53647 L
.21095 .52404 L
.18676 .51193 L
.16321 .5 L
.1406 .48807 L
.11922 .47596 L
.09938 .46353 L
.08139 .45061 L
.06554 .43702 L
.05214 .4226 L
.04645 .41503 L
.04148 .40719 L
.03728 .39907 L
.03388 .39063 L
.03132 .38186 L
.02964 .37274 L
.02887 .36325 L
.02905 .35336 L
.03242 .33233 L
.04005 .30948 L
s
.69052 .42109 m
.66767 .4072 L
.64664 .39093 L
.62726 .37256 L
.60937 .35241 L
.59281 .33078 L
.5774 .30797 L
.56298 .28427 L
.54939 .26 L
.53647 .23546 L
.52404 .21095 L
.51193 .18676 L
.5 .16321 L
.48807 .1406 L
.47596 .11922 L
.46353 .09938 L
.45061 .08139 L
.43702 .06554 L
.4226 .05214 L
.41503 .04645 L
.40719 .04148 L
.39907 .03728 L
.39063 .03388 L
.38186 .03132 L
.37274 .02964 L
.36325 .02887 L
.35336 .02905 L
.33233 .03242 L
.30948 .04005 L
s
.69052 .42109 m
.67934 .41564 L
.66958 .41183 L
.66117 .40956 L
.65744 .40898 L
.65402 .40876 L
.6509 .40888 L
.64808 .40933 L
.64553 .41011 L
.64436 .41061 L
.6438 .41089 L
.64326 .41119 L
.64125 .41258 L
.64034 .41338 L
.6395 .41425 L
.63799 .4162 L
.63732 .41728 L
.63671 .41842 L
.63567 .4209 L
.63484 .42362 L
.63422 .42658 L
.63381 .42976 L
.63396 .44451 L
.63659 .46198 L
.64112 .48146 L
.64698 .50227 L
.65358 .5237 L
.66035 .54506 L
.6667 .56567 L
.67206 .58481 L
.67585 .60179 L
.67698 .60926 L
.67749 .61592 L
.67733 .6217 L
.67696 .62423 L
.67671 .6254 L
.6764 .62651 L
.67564 .62852 L
.67517 .62942 L
.67466 .63025 L
.67408 .63102 L
.67345 .6317 L
.67276 .63232 L
.67239 .63259 L
.6722 .63273 L
.67201 .63285 L
.6712 .63331 L
.67032 .63369 L
.66939 .63399 L
.6689 .63412 L
Mistroke
.66839 .63421 L
.66619 .63441 L
.66499 .63437 L
.66372 .63426 L
.65795 .63289 L
.65098 .63003 L
.63319 .61946 L
.60977 .60188 L
.58015 .57657 L
.54376 .54284 L
.5 .5 L
Mfstroke
.5 .5 m
.49808 .47744 L
.49261 .45472 L
.484 .4319 L
.47266 .40904 L
.459 .3862 L
.44344 .36345 L
.42639 .34085 L
.40827 .31846 L
.38949 .29634 L
.37045 .27456 L
.35159 .25318 L
.3333 .23226 L
.316 .21187 L
.30011 .19206 L
.28604 .1729 L
.2742 .15446 L
.26501 .13679 L
.26154 .12826 L
.25888 .11995 L
.25709 .11187 L
.25653 .10792 L
.25622 .10402 L
.25632 .09641 L
.25675 .0927 L
.25744 .08905 L
.25964 .08195 L
.26116 .07849 L
.26297 .07511 L
.26748 .06854 L
.27019 .06536 L
.27321 .06225 L
.28023 .05625 L
.28858 .05054 L
.30948 .04005 L
s
.95995 .69052 m
.94273 .66162 L
.92914 .63554 L
.91879 .612 L
.91131 .59074 L
.9063 .57148 L
.90339 .55397 L
.90218 .53793 L
.90229 .52309 L
.90333 .50919 L
.90493 .49595 L
.90669 .48311 L
.90823 .47041 L
.90917 .45756 L
.90912 .44432 L
.90769 .4304 L
.9045 .41553 L
.89917 .39946 L
.89131 .38191 L
.88053 .36262 L
.86645 .34131 L
.84868 .31772 L
.82685 .29158 L
.80056 .26262 L
.76943 .23057 L
s
.95995 .69052 m
.94193 .66354 L
.92608 .64293 L
.91217 .628 L
.90587 .62246 L
.89999 .61808 L
.89448 .61478 L
.89186 .61352 L
.88932 .61248 L
.88449 .61109 L
.88219 .61071 L
.87996 .61053 L
.8757 .6107 L
.87367 .61104 L
.87169 .61153 L
.86789 .61293 L
.86429 .61482 L
.85756 .6197 L
.85127 .6255 L
.84522 .63153 L
.83918 .63711 L
.83611 .63952 L
.83295 .64156 L
.8297 .64315 L
.82803 .64375 L
.82632 .6442 L
.82457 .6445 L
.82278 .64463 L
.82095 .64459 L
.82001 .6445 L
.81906 .64435 L
.81514 .64328 L
.81309 .64242 L
.81097 .64133 L
.80655 .63842 L
.80183 .63445 L
.79143 .62303 L
.77955 .6064 L
.76598 .58386 L
.7505 .55475 L
.73291 .51836 L
.71299 .47404 L
.69052 .42109 L
s
.69052 .42109 m
.69401 .42174 L
.69723 .42207 L
.70019 .42209 L
.70158 .42198 L
.7029 .4218 L
.70536 .4212 L
.7065 .4208 L
.70758 .42032 L
.70956 .41916 L
.71047 .41847 L
.7109 .4181 L
.71132 .41772 L
.71285 .41601 L
.71354 .41507 L
.71417 .41405 L
.71528 .41185 L
.71576 .41065 L
.71619 .4094 L
.71744 .40383 L
.71797 .3974 L
.71707 .38225 L
.71394 .36453 L
.70901 .34476 L
.70271 .32351 L
.69547 .30132 L
.68773 .27875 L
.67992 .25635 L
.67248 .23466 L
.66584 .21423 L
.66042 .19562 L
.65668 .17938 L
.65556 .17232 L
.65503 .16606 L
.65513 .16067 L
.65543 .15831 L
.65565 .15723 L
.65591 .15621 L
.65658 .15435 L
.65699 .15352 L
.65744 .15275 L
.65794 .15205 L
.6585 .15142 L
.6591 .15086 L
.65943 .15061 L
.65959 .15049 L
.65976 .15037 L
.66047 .14995 L
.66124 .1496 L
.66206 .14933 L
Mistroke
.66249 .14922 L
.66294 .14913 L
.66486 .14896 L
.66591 .14899 L
.66701 .1491 L
.67205 .15036 L
.6781 .15296 L
.69345 .16248 L
.7135 .17822 L
.73868 .20073 L
.76943 .23057 L
Mfstroke
.42109 .69052 m
.42174 .69401 L
.42207 .69723 L
.42209 .70019 L
.42198 .70158 L
.4218 .7029 L
.4212 .70536 L
.4208 .7065 L
.42032 .70758 L
.41916 .70956 L
.41847 .71047 L
.4181 .7109 L
.41772 .71132 L
.41601 .71285 L
.41507 .71354 L
.41405 .71417 L
.41185 .71528 L
.41065 .71576 L
.4094 .71619 L
.40383 .71744 L
.3974 .71797 L
.38225 .71707 L
.36453 .71394 L
.34476 .70901 L
.32351 .70271 L
.30132 .69547 L
.27875 .68773 L
.25635 .67992 L
.23466 .67248 L
.21423 .66584 L
.19562 .66042 L
.17938 .65668 L
.17232 .65556 L
.16606 .65503 L
.16067 .65513 L
.15831 .65543 L
.15723 .65565 L
.15621 .65591 L
.15435 .65658 L
.15352 .65699 L
.15275 .65744 L
.15205 .65794 L
.15142 .6585 L
.15086 .6591 L
.15061 .65943 L
.15049 .65959 L
.15037 .65976 L
.14995 .66047 L
.1496 .66124 L
.14933 .66206 L
Mistroke
.14922 .66249 L
.14913 .66294 L
.14896 .66486 L
.14899 .66591 L
.1491 .66701 L
.15036 .67205 L
.15296 .6781 L
.16248 .69345 L
.17822 .7135 L
.20073 .73868 L
.23057 .76943 L
Mfstroke
.42109 .69052 m
.42325 .69772 L
.42642 .70482 L
.43054 .71181 L
.43555 .7187 L
.44803 .73219 L
.46341 .74531 L
.48124 .75807 L
.50107 .7705 L
.52246 .78262 L
.54497 .79444 L
.56813 .80599 L
.59151 .81728 L
.61465 .82834 L
.63711 .83918 L
.65844 .84983 L
.6782 .86031 L
.69593 .87063 L
.71118 .88083 L
.72352 .8909 L
.72845 .8959 L
.73249 .90089 L
.73557 .90585 L
.73674 .90832 L
.73765 .9108 L
.73829 .91326 L
.73865 .91573 L
.73874 .91819 L
.73867 .91942 L
.73854 .92065 L
.73804 .92311 L
.73724 .92557 L
.73614 .92802 L
.73547 .92925 L
.73472 .93048 L
.7309 .93538 L
.72574 .94029 L
.71115 .9501 L
.69052 .95995 L
s
.69052 .95995 m
.66162 .94273 L
.63554 .92914 L
.612 .91879 L
.59074 .91131 L
.57148 .9063 L
.55397 .90339 L
.53793 .90218 L
.52309 .90229 L
.50919 .90333 L
.49595 .90493 L
.48311 .90669 L
.47041 .90823 L
.45756 .90917 L
.44432 .90912 L
.4304 .90769 L
.41553 .9045 L
.39946 .89917 L
.38191 .89131 L
.36262 .88053 L
.34131 .86645 L
.31772 .84868 L
.29158 .82685 L
.26262 .80056 L
.23057 .76943 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0177187 0.488926 0.239203 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.523849 0.481362 0.523849 [
[ 0 0 0 0 ]
[ 1 .98091 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.03 .18 .33 r
.5 Mabswid
[ ] 0 setdash
.12958 .48136 m
.12802 .48124 L
.12652 .48089 L
.12508 .48031 L
.12439 .47993 L
.12371 .4795 L
.12239 .47848 L
.12114 .47725 L
.11994 .47581 L
.11879 .47418 L
.11667 .47035 L
.11475 .46581 L
.11147 .45478 L
.10886 .4415 L
.10681 .42638 L
.10523 .40981 L
.10401 .39219 L
.10306 .37393 L
.10228 .35542 L
.10156 .33708 L
.10081 .3193 L
.09993 .30249 L
.09882 .28704 L
.09737 .27336 L
.09549 .26186 L
.09435 .25704 L
.09307 .25292 L
.09163 .24954 L
.09085 .24815 L
.09044 .24753 L
.09003 .24696 L
.08915 .24598 L
.0887 .24557 L
.08823 .24522 L
.08776 .24492 L
.08727 .24468 L
.08676 .2445 L
.08651 .24443 L
.08638 .2444 L
.08625 .24437 L
.08572 .24431 L
.08518 .2443 L
.08462 .24435 L
.08434 .2444 L
.08405 .24447 L
.08287 .24489 L
.08226 .24519 L
.08164 .24556 L
.07899 .2477 L
.07609 .25094 L
Mistroke
.06952 .26089 L
.06181 .27583 L
.05287 .29615 L
Mfstroke
.12958 .48136 m
.12802 .48148 L
.12652 .48184 L
.12508 .48242 L
.12439 .48279 L
.12371 .48322 L
.12239 .48425 L
.12114 .48548 L
.11994 .48691 L
.11879 .48854 L
.11667 .49237 L
.11475 .49692 L
.11147 .50794 L
.10886 .52122 L
.10681 .53635 L
.10523 .55292 L
.10401 .57054 L
.10306 .5888 L
.10228 .6073 L
.10156 .62564 L
.10081 .64342 L
.09993 .66023 L
.09882 .67568 L
.09737 .68936 L
.09549 .70087 L
.09435 .70568 L
.09307 .7098 L
.09163 .71318 L
.09085 .71458 L
.09044 .7152 L
.09003 .71577 L
.08915 .71675 L
.0887 .71715 L
.08823 .71751 L
.08776 .7178 L
.08727 .71804 L
.08676 .71823 L
.08651 .7183 L
.08638 .71833 L
.08625 .71835 L
.08572 .71842 L
.08518 .71842 L
.08462 .71837 L
.08434 .71832 L
.08405 .71825 L
.08287 .71783 L
.08226 .71753 L
.08164 .71716 L
.07899 .71502 L
.07609 .71179 L
Mistroke
.06952 .70183 L
.06181 .6869 L
.05287 .66657 L
Mfstroke
.05287 .66657 m
.05542 .64436 L
.05677 .62391 L
.05706 .60508 L
.05642 .58769 L
.05498 .57158 L
.05287 .5566 L
.05023 .54259 L
.04718 .52938 L
.04388 .51681 L
.04044 .50473 L
.037 .49296 L
.03369 .48136 L
.03065 .46976 L
.028 .458 L
.0259 .44591 L
.02445 .43335 L
.02381 .42013 L
.0241 .40612 L
.02545 .39114 L
.028 .37504 L
.03189 .35765 L
.03724 .33881 L
.04419 .31837 L
.05287 .29615 L
s
.31479 .40465 m
.31133 .39821 L
.30863 .39115 L
.30665 .38351 L
.30536 .37533 L
.30466 .35748 L
.30622 .33789 L
.3097 .31686 L
.31479 .29468 L
.32117 .27165 L
.32851 .24805 L
.3365 .22419 L
.3448 .20036 L
.35311 .17685 L
.36109 .15396 L
.36844 .13197 L
.37481 .11119 L
.3799 .0919 L
.38339 .07441 L
.38494 .059 L
.38489 .05217 L
.38424 .04597 L
.38295 .04044 L
.38205 .03794 L
.38098 .03562 L
.37972 .03348 L
.37828 .03154 L
.37664 .02978 L
.37575 .02898 L
.37481 .02823 L
.37278 .02688 L
.37055 .02574 L
.3681 .02481 L
.36679 .02443 L
.36543 .0241 L
.35944 .02335 L
.35252 .02353 L
.33575 .02681 L
.31479 .03423 L
s
.31479 .40465 m
.31284 .40179 L
.31085 .39935 L
.30883 .3973 L
.3078 .39643 L
.30677 .39564 L
.30467 .39436 L
.30361 .39386 L
.30254 .39344 L
.30037 .39288 L
.29928 .39273 L
.29873 .39269 L
.29818 .39266 L
.29595 .39278 L
.29483 .39296 L
.2937 .39322 L
.29142 .39397 L
.29027 .39446 L
.28911 .39503 L
.28442 .398 L
.27964 .40206 L
.26984 .41308 L
.25981 .42742 L
.24961 .4444 L
.23934 .46334 L
.22906 .48357 L
.21886 .5044 L
.20883 .52517 L
.19904 .5452 L
.18956 .56381 L
.18049 .58032 L
.17191 .59406 L
.16782 .59967 L
.16388 .60435 L
.1601 .60799 L
.15828 .6094 L
.15738 .60999 L
.1565 .61051 L
.15476 .61133 L
.15391 .61162 L
.15307 .61184 L
.15225 .61197 L
.15143 .61202 L
.15063 .61199 L
.15023 .61195 L
.15004 .61191 L
.14984 .61188 L
.14906 .61168 L
.1483 .61139 L
.14755 .61101 L
Mistroke
.14717 .61079 L
.14681 .61055 L
.14537 .60934 L
.14467 .6086 L
.14398 .60776 L
.14138 .60344 L
.13901 .5975 L
.13501 .5804 L
.13205 .5558 L
.13021 .52301 L
.12958 .48136 L
Mfstroke
.12958 .48136 m
.14377 .45943 L
.15563 .43735 L
.16539 .41516 L
.17331 .39294 L
.17962 .37074 L
.18457 .34862 L
.18838 .32665 L
.19132 .30488 L
.19361 .28338 L
.1955 .2622 L
.19723 .24142 L
.19904 .22108 L
.20117 .20126 L
.20386 .182 L
.20736 .16338 L
.2119 .14544 L
.21773 .12827 L
.22508 .1119 L
.2342 .09641 L
.24534 .08186 L
.25872 .06831 L
.2746 .05581 L
.29321 .04443 L
.31479 .03423 L
s
.68521 .40465 m
.67387 .41301 L
.663 .41952 L
.65256 .4243 L
.6475 .42606 L
.64255 .42742 L
.63294 .42899 L
.62828 .42922 L
.62371 .4291 L
.61485 .42785 L
.61054 .42675 L
.60632 .42535 L
.59812 .42168 L
.59022 .41694 L
.57524 .40465 L
.56123 .38925 L
.54802 .37153 L
.53545 .35225 L
.52337 .33219 L
.5116 .31214 L
.5 .29286 L
.4884 .27514 L
.47663 .25974 L
.47064 .25316 L
.46455 .24745 L
.45834 .24271 L
.45518 .24074 L
.45198 .23904 L
.44875 .23764 L
.44547 .23653 L
.44214 .23575 L
.44046 .23548 L
.43877 .23529 L
.43535 .23517 L
.43188 .2354 L
.42835 .236 L
.42656 .23644 L
.42476 .23697 L
.4174 .24009 L
.41362 .24227 L
.40978 .24486 L
.40188 .25138 L
.39368 .25974 L
.37629 .28238 L
.35745 .31356 L
.337 .35406 L
.31479 .40465 L
s
.68521 .40465 m
.67434 .41415 L
.66486 .42402 L
.65668 .43423 L
.64973 .44475 L
.63927 .46665 L
.6329 .48952 L
.63008 .51316 L
.63022 .53739 L
.63278 .562 L
.63719 .58681 L
.64289 .61162 L
.6493 .63623 L
.65588 .66046 L
.66206 .6841 L
.66727 .70697 L
.67095 .72887 L
.67255 .7496 L
.67239 .75947 L
.67149 .76898 L
.66979 .77809 L
.66862 .7825 L
.66722 .7868 L
.6637 .79507 L
.66156 .79903 L
.65916 .80287 L
.65355 .8102 L
.65031 .81367 L
.64677 .81701 L
.63877 .82329 L
.62947 .82901 L
.60671 .83868 L
.57792 .84583 L
.54254 .85026 L
.5 .85178 L
s
.5 .85178 m
.49814 .81753 L
.49282 .7889 L
.48899 .77652 L
.48445 .76532 L
.47924 .75524 L
.47342 .74621 L
.46704 .73814 L
.46014 .73097 L
.45279 .72463 L
.44502 .71904 L
.42844 .70982 L
.41083 .70274 L
.39256 .6972 L
.37406 .69264 L
.35572 .68847 L
.33794 .6841 L
.32113 .67896 L
.30568 .67246 L
.2986 .66852 L
.292 .66402 L
.28595 .65889 L
.28315 .65606 L
.28049 .65305 L
.27568 .64644 L
.27353 .64282 L
.27156 .63898 L
.26818 .6306 L
.2656 .62123 L
.26301 .5992 L
.2642 .57232 L
.26957 .54001 L
.27953 .50168 L
.29447 .45675 L
.31479 .40465 L
s
.87042 .48136 m
.85623 .45943 L
.84437 .43735 L
.83461 .41516 L
.82669 .39294 L
.82038 .37074 L
.81543 .34862 L
.81162 .32665 L
.80868 .30488 L
.80639 .28338 L
.8045 .2622 L
.80277 .24142 L
.80096 .22108 L
.79883 .20126 L
.79614 .182 L
.79264 .16338 L
.7881 .14544 L
.78227 .12827 L
.77492 .1119 L
.7658 .09641 L
.75466 .08186 L
.74128 .06831 L
.7254 .05581 L
.70679 .04443 L
.68521 .03423 L
s
.87042 .48136 m
.85623 .46316 L
.85002 .45664 L
.84437 .45171 L
.84174 .44982 L
.83924 .44829 L
.83686 .44711 L
.83572 .44665 L
.83461 .44627 L
.83246 .44576 L
.83043 .44557 L
.82851 .44569 L
.82758 .44586 L
.82713 .44597 L
.82669 .4461 L
.82497 .44679 L
.82415 .44724 L
.82335 .44776 L
.82182 .44898 L
.82109 .44969 L
.82038 .45045 L
.81775 .45409 L
.81543 .45859 L
.81162 .46976 L
.80868 .48323 L
.80639 .49825 L
.8045 .51408 L
.80277 .52998 L
.80096 .5452 L
.79883 .559 L
.79614 .57064 L
.79451 .57541 L
.79264 .57937 L
.79162 .58101 L
.79052 .58242 L
.78935 .58357 L
.78874 .58405 L
.78842 .58426 L
.7881 .58446 L
.78745 .5848 L
.78678 .58507 L
.78608 .58527 L
.78573 .58535 L
.78536 .5854 L
.78463 .58545 L
.78387 .58543 L
.78308 .58533 L
.78268 .58525 L
.78248 .5852 L
.78227 .58515 L
Mistroke
.78059 .58455 L
.7788 .58362 L
.77691 .58234 L
.77492 .58071 L
.77059 .57633 L
.7658 .57039 L
.75466 .55346 L
.74128 .52916 L
.7254 .49675 L
.70679 .45549 L
.68521 .40465 L
Mfstroke
.68521 .40465 m
.68867 .39821 L
.69137 .39115 L
.69335 .38351 L
.69464 .37533 L
.69534 .35748 L
.69378 .33789 L
.6903 .31686 L
.68521 .29468 L
.67883 .27165 L
.67149 .24805 L
.6635 .22419 L
.6552 .20036 L
.64689 .17685 L
.63891 .15396 L
.63156 .13197 L
.62519 .11119 L
.6201 .0919 L
.61661 .07441 L
.61506 .059 L
.61511 .05217 L
.61576 .04597 L
.61705 .04044 L
.61795 .03794 L
.61902 .03562 L
.62028 .03348 L
.62172 .03154 L
.62336 .02978 L
.62425 .02898 L
.62519 .02823 L
.62722 .02688 L
.62945 .02574 L
.6319 .02481 L
.63321 .02443 L
.63457 .0241 L
.64056 .02335 L
.64748 .02353 L
.66425 .02681 L
.68521 .03423 L
s
.5 .85178 m
.49988 .85334 L
.49953 .85484 L
.49894 .85628 L
.49857 .85698 L
.49814 .85766 L
.49712 .85897 L
.49589 .86023 L
.49445 .86142 L
.49282 .86257 L
.48899 .86469 L
.48445 .86661 L
.47342 .86989 L
.46014 .87251 L
.44502 .87455 L
.42844 .87614 L
.41083 .87735 L
.39256 .8783 L
.37406 .87908 L
.35572 .8798 L
.33794 .88055 L
.32113 .88143 L
.30568 .88255 L
.292 .88399 L
.28049 .88588 L
.27568 .88701 L
.27156 .88829 L
.26818 .88973 L
.26678 .89051 L
.26616 .89092 L
.2656 .89134 L
.26462 .89221 L
.26421 .89266 L
.26386 .89313 L
.26356 .89361 L
.26332 .8941 L
.26313 .8946 L
.26306 .89486 L
.26304 .89499 L
.26301 .89512 L
.26294 .89564 L
.26294 .89619 L
.26299 .89674 L
.26304 .89702 L
.26311 .89731 L
.26353 .89849 L
.26383 .8991 L
.2642 .89973 L
.26634 .90238 L
.26957 .90527 L
Mistroke
.27953 .91185 L
.29447 .91956 L
.31479 .9285 L
Mfstroke
.5 .85178 m
.50012 .85334 L
.50047 .85484 L
.50106 .85628 L
.50143 .85698 L
.50186 .85766 L
.50288 .85897 L
.50411 .86023 L
.50555 .86142 L
.50718 .86257 L
.51101 .86469 L
.51555 .86661 L
.52658 .86989 L
.53986 .87251 L
.55498 .87455 L
.57156 .87614 L
.58917 .87735 L
.60744 .8783 L
.62594 .87908 L
.64428 .8798 L
.66206 .88055 L
.67887 .88143 L
.69432 .88255 L
.708 .88399 L
.71951 .88588 L
.72432 .88701 L
.72844 .88829 L
.73182 .88973 L
.73322 .89051 L
.73384 .89092 L
.7344 .89134 L
.73538 .89221 L
.73579 .89266 L
.73614 .89313 L
.73644 .89361 L
.73668 .8941 L
.73687 .8946 L
.73694 .89486 L
.73696 .89499 L
.73699 .89512 L
.73706 .89564 L
.73706 .89619 L
.73701 .89674 L
.73696 .89702 L
.73689 .89731 L
.73647 .89849 L
.73617 .8991 L
.7358 .89973 L
.73366 .90238 L
.73043 .90527 L
Mistroke
.72047 .91185 L
.70553 .91956 L
.68521 .9285 L
Mfstroke
.68521 .9285 m
.663 .92594 L
.64255 .92459 L
.62371 .9243 L
.60632 .92494 L
.59022 .92639 L
.57524 .9285 L
.56123 .93114 L
.54802 .93418 L
.53545 .93749 L
.52337 .94093 L
.5116 .94437 L
.5 .94767 L
.4884 .95072 L
.47663 .95336 L
.46455 .95547 L
.45198 .95691 L
.43877 .95755 L
.42476 .95726 L
.40978 .95591 L
.39368 .95336 L
.37629 .94947 L
.35745 .94412 L
.337 .93717 L
.31479 .9285 L
s
.94713 .66657 m
.94458 .64436 L
.94323 .62391 L
.94294 .60508 L
.94358 .58769 L
.94502 .57158 L
.94713 .5566 L
.94977 .54259 L
.95282 .52938 L
.95612 .51681 L
.95956 .50473 L
.963 .49296 L
.96631 .48136 L
.96935 .46976 L
.972 .458 L
.9741 .44591 L
.97555 .43335 L
.97619 .42013 L
.9759 .40612 L
.97455 .39114 L
.972 .37504 L
.96811 .35765 L
.96276 .33881 L
.95581 .31837 L
.94713 .29615 L
s
.94713 .66657 m
.94381 .64622 L
.94025 .63109 L
.9384 .62531 L
.9365 .62063 L
.93455 .61697 L
.93357 .6155 L
.93257 .61427 L
.93157 .61325 L
.93056 .61245 L
.92954 .61185 L
.92903 .61162 L
.92877 .61152 L
.92851 .61144 L
.92748 .61122 L
.92697 .61118 L
.92645 .61118 L
.92541 .6113 L
.92488 .61143 L
.92436 .61159 L
.92331 .61202 L
.92225 .6126 L
.9212 .61331 L
.92014 .61415 L
.91588 .61855 L
.91162 .62425 L
.9074 .63067 L
.90324 .63724 L
.89919 .64342 L
.89526 .64863 L
.89336 .6507 L
.89151 .65232 L
.8906 .65293 L
.8897 .65341 L
.88882 .65374 L
.88838 .65384 L
.88816 .65388 L
.88795 .65391 L
.88752 .65393 L
.88709 .65392 L
.88667 .65385 L
.88646 .65381 L
.88625 .65375 L
.88584 .6536 L
.88543 .6534 L
.88503 .65315 L
.88482 .65301 L
.88462 .65285 L
.88383 .65211 L
.88306 .65115 L
Mistroke
.8823 .64998 L
.88157 .64858 L
.87881 .64053 L
.87638 .62813 L
.87432 .61084 L
.87266 .58807 L
.87144 .55928 L
.87068 .5239 L
.87042 .48136 L
Mfstroke
.87042 .48136 m
.87198 .48124 L
.87348 .48089 L
.87492 .48031 L
.87561 .47993 L
.87629 .4795 L
.87761 .47848 L
.87886 .47725 L
.88006 .47581 L
.88121 .47418 L
.88333 .47035 L
.88525 .46581 L
.88853 .45478 L
.89114 .4415 L
.89319 .42638 L
.89477 .40981 L
.89599 .39219 L
.89694 .37393 L
.89772 .35542 L
.89844 .33708 L
.89919 .3193 L
.90007 .30249 L
.90118 .28704 L
.90263 .27336 L
.90451 .26186 L
.90565 .25704 L
.90693 .25292 L
.90837 .24954 L
.90915 .24815 L
.90956 .24753 L
.90997 .24696 L
.91085 .24598 L
.9113 .24557 L
.91177 .24522 L
.91224 .24492 L
.91273 .24468 L
.91324 .2445 L
.91349 .24443 L
.91362 .2444 L
.91375 .24437 L
.91428 .24431 L
.91482 .2443 L
.91538 .24435 L
.91566 .2444 L
.91595 .24447 L
.91713 .24489 L
.91774 .24519 L
.91836 .24556 L
.92101 .2477 L
.92391 .25094 L
Mistroke
.93048 .26089 L
.93819 .27583 L
.94713 .29615 L
Mfstroke
0 0 m
1 0 L
1 .98091 L
0 .98091 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0177187 0.732558 0.239203 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.523849 0.5 0.523849 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.03 .18 .33 r
.5 Mabswid
[ ] 0 setdash
.5 .12958 m
.50012 .12802 L
.50047 .12652 L
.50106 .12508 L
.50143 .12439 L
.50186 .12371 L
.50288 .12239 L
.50411 .12114 L
.50555 .11994 L
.50718 .11879 L
.51101 .11667 L
.51555 .11475 L
.52658 .11147 L
.53986 .10886 L
.55498 .10681 L
.57156 .10523 L
.58917 .10401 L
.60744 .10306 L
.62594 .10228 L
.64428 .10156 L
.66206 .10081 L
.67887 .09993 L
.69432 .09882 L
.708 .09737 L
.71951 .09549 L
.72432 .09435 L
.72844 .09307 L
.73182 .09163 L
.73322 .09085 L
.73384 .09044 L
.7344 .09003 L
.73538 .08915 L
.73579 .0887 L
.73614 .08823 L
.73644 .08776 L
.73668 .08727 L
.73687 .08676 L
.73694 .08651 L
.73696 .08638 L
.73699 .08625 L
.73706 .08572 L
.73706 .08518 L
.73701 .08462 L
.73696 .08434 L
.73689 .08405 L
.73647 .08287 L
.73617 .08226 L
.7358 .08164 L
.73366 .07899 L
.73043 .07609 L
Mistroke
.72047 .06952 L
.70553 .06181 L
.68521 .05287 L
Mfstroke
.5 .12958 m
.49988 .12802 L
.49953 .12652 L
.49894 .12508 L
.49857 .12439 L
.49814 .12371 L
.49712 .12239 L
.49589 .12114 L
.49445 .11994 L
.49282 .11879 L
.48899 .11667 L
.48445 .11475 L
.47342 .11147 L
.46014 .10886 L
.44502 .10681 L
.42844 .10523 L
.41083 .10401 L
.39256 .10306 L
.37406 .10228 L
.35572 .10156 L
.33794 .10081 L
.32113 .09993 L
.30568 .09882 L
.292 .09737 L
.28049 .09549 L
.27568 .09435 L
.27156 .09307 L
.26818 .09163 L
.26678 .09085 L
.26616 .09044 L
.2656 .09003 L
.26462 .08915 L
.26421 .0887 L
.26386 .08823 L
.26356 .08776 L
.26332 .08727 L
.26313 .08676 L
.26306 .08651 L
.26304 .08638 L
.26301 .08625 L
.26294 .08572 L
.26294 .08518 L
.26299 .08462 L
.26304 .08434 L
.26311 .08405 L
.26353 .08287 L
.26383 .08226 L
.2642 .08164 L
.26634 .07899 L
.26957 .07609 L
Mistroke
.27953 .06952 L
.29447 .06181 L
.31479 .05287 L
Mfstroke
.31479 .05287 m
.337 .05542 L
.35745 .05677 L
.37629 .05706 L
.39368 .05642 L
.40978 .05498 L
.42476 .05287 L
.43877 .05023 L
.45198 .04718 L
.46455 .04388 L
.47663 .04044 L
.4884 .037 L
.5 .03369 L
.5116 .03065 L
.52337 .028 L
.53545 .0259 L
.54802 .02445 L
.56123 .02381 L
.57524 .0241 L
.59022 .02545 L
.60632 .028 L
.62371 .03189 L
.64255 .03724 L
.663 .04419 L
.68521 .05287 L
s
.12958 .5 m
.12802 .49988 L
.12652 .49953 L
.12508 .49894 L
.12439 .49857 L
.12371 .49814 L
.12239 .49712 L
.12114 .49589 L
.11994 .49445 L
.11879 .49282 L
.11667 .48899 L
.11475 .48445 L
.11147 .47342 L
.10886 .46014 L
.10681 .44502 L
.10523 .42844 L
.10401 .41083 L
.10306 .39256 L
.10228 .37406 L
.10156 .35572 L
.10081 .33794 L
.09993 .32113 L
.09882 .30568 L
.09737 .292 L
.09549 .28049 L
.09435 .27568 L
.09307 .27156 L
.09163 .26818 L
.09085 .26678 L
.09044 .26616 L
.09003 .2656 L
.08915 .26462 L
.0887 .26421 L
.08823 .26386 L
.08776 .26356 L
.08727 .26332 L
.08676 .26313 L
.08651 .26306 L
.08638 .26304 L
.08625 .26301 L
.08572 .26294 L
.08518 .26294 L
.08462 .26299 L
.08434 .26304 L
.08405 .26311 L
.08287 .26353 L
.08226 .26383 L
.08164 .2642 L
.07899 .26634 L
.07609 .26957 L
Mistroke
.06952 .27953 L
.06181 .29447 L
.05287 .31479 L
Mfstroke
.12958 .5 m
.12802 .50012 L
.12652 .50047 L
.12508 .50106 L
.12439 .50143 L
.12371 .50186 L
.12239 .50288 L
.12114 .50411 L
.11994 .50555 L
.11879 .50718 L
.11667 .51101 L
.11475 .51555 L
.11147 .52658 L
.10886 .53986 L
.10681 .55498 L
.10523 .57156 L
.10401 .58917 L
.10306 .60744 L
.10228 .62594 L
.10156 .64428 L
.10081 .66206 L
.09993 .67887 L
.09882 .69432 L
.09737 .708 L
.09549 .71951 L
.09435 .72432 L
.09307 .72844 L
.09163 .73182 L
.09085 .73322 L
.09044 .73384 L
.09003 .7344 L
.08915 .73538 L
.0887 .73579 L
.08823 .73614 L
.08776 .73644 L
.08727 .73668 L
.08676 .73687 L
.08651 .73694 L
.08638 .73696 L
.08625 .73699 L
.08572 .73706 L
.08518 .73706 L
.08462 .73701 L
.08434 .73696 L
.08405 .73689 L
.08287 .73647 L
.08226 .73617 L
.08164 .7358 L
.07899 .73366 L
.07609 .73043 L
Mistroke
.06952 .72047 L
.06181 .70553 L
.05287 .68521 L
Mfstroke
.05287 .68521 m
.05542 .663 L
.05677 .64255 L
.05706 .62371 L
.05642 .60632 L
.05498 .59022 L
.05287 .57524 L
.05023 .56123 L
.04718 .54802 L
.04388 .53545 L
.04044 .52337 L
.037 .5116 L
.03369 .5 L
.03065 .4884 L
.028 .47663 L
.0259 .46455 L
.02445 .45198 L
.02381 .43877 L
.0241 .42476 L
.02545 .40978 L
.028 .39368 L
.03189 .37629 L
.03724 .35745 L
.04419 .337 L
.05287 .31479 L
s
.87042 .5 m
.84204 .48395 L
.81833 .46677 L
.79879 .44863 L
.78296 .42969 L
.77034 .4101 L
.76045 .39003 L
.75281 .36964 L
.74694 .34909 L
.74236 .32854 L
.73858 .30815 L
.73513 .28808 L
.73151 .26849 L
.72725 .24954 L
.72186 .2314 L
.71487 .21423 L
.70579 .19818 L
.69413 .18341 L
.67942 .1701 L
.66117 .15839 L
.63891 .14845 L
.61214 .14043 L
.58039 .13451 L
.54317 .13084 L
.5 .12958 L
s
.87042 .5 m
.84204 .48767 L
.82963 .48372 L
.81833 .48114 L
.80807 .47984 L
.80331 .47964 L
.79879 .47974 L
.79044 .48077 L
.7866 .48169 L
.78296 .48285 L
.77628 .48589 L
.77322 .48775 L
.77034 .48982 L
.76508 .49455 L
.76045 .5 L
.75281 .51275 L
.74694 .52744 L
.74236 .54341 L
.73858 .56002 L
.73513 .57663 L
.73151 .5926 L
.72725 .60729 L
.72473 .61395 L
.72186 .62004 L
.7186 .6255 L
.7168 .62796 L
.71487 .63022 L
.71281 .63229 L
.71062 .63415 L
.70828 .63579 L
.70705 .63652 L
.70579 .63719 L
.70313 .63836 L
.70031 .63927 L
.69731 .63992 L
.69575 .64014 L
.69413 .6403 L
.68719 .64021 L
.68341 .63971 L
.67942 .63891 L
.67077 .63632 L
.66117 .63237 L
.63891 .62004 L
.61214 .60129 L
.58039 .57546 L
.54317 .54191 L
.5 .5 L
s
.5 .5 m
.50693 .49213 L
.51233 .48395 L
.51628 .47549 L
.51774 .47116 L
.51886 .46677 L
.52016 .45781 L
.52026 .44863 L
.51923 .43925 L
.51715 .42969 L
.51411 .41997 L
.51018 .4101 L
.5 .39003 L
.48725 .36964 L
.47256 .34909 L
.45659 .32854 L
.43998 .30815 L
.42337 .28808 L
.4074 .26849 L
.39271 .24954 L
.37996 .2314 L
.36978 .21423 L
.36585 .20605 L
.36281 .19818 L
.36073 .19063 L
.36008 .18698 L
.3597 .18341 L
.3596 .17994 L
.35979 .17656 L
.36029 .17328 L
.36065 .17168 L
.36109 .1701 L
.36222 .16701 L
.36368 .16403 L
.36548 .16116 L
.36651 .15976 L
.36763 .15839 L
.37303 .15319 L
.3763 .15076 L
.37996 .14845 L
.38849 .14419 L
.39871 .14043 L
.42454 .13451 L
.45809 .13084 L
.5 .12958 L
s
.5 .5 m
.49213 .50693 L
.48395 .51233 L
.47549 .51628 L
.47116 .51774 L
.46677 .51886 L
.45781 .52016 L
.44863 .52026 L
.43925 .51923 L
.42969 .51715 L
.41997 .51411 L
.4101 .51018 L
.39003 .5 L
.36964 .48725 L
.34909 .47256 L
.32854 .45659 L
.30815 .43998 L
.28808 .42337 L
.26849 .4074 L
.24954 .39271 L
.2314 .37996 L
.21423 .36978 L
.20605 .36585 L
.19818 .36281 L
.19063 .36073 L
.18698 .36008 L
.18341 .3597 L
.17994 .3596 L
.17656 .35979 L
.17328 .36029 L
.17168 .36065 L
.1701 .36109 L
.16701 .36222 L
.16403 .36368 L
.16116 .36548 L
.15976 .36651 L
.15839 .36763 L
.15319 .37303 L
.15076 .3763 L
.14845 .37996 L
.14419 .38849 L
.14043 .39871 L
.13451 .42454 L
.13084 .45809 L
.12958 .5 L
s
.5 .5 m
.49307 .50787 L
.48767 .51605 L
.48372 .52451 L
.48226 .52884 L
.48114 .53323 L
.47984 .54219 L
.47974 .55137 L
.48077 .56075 L
.48285 .57031 L
.48589 .58003 L
.48982 .5899 L
.5 .60997 L
.51275 .63036 L
.52744 .65091 L
.54341 .67146 L
.56002 .69185 L
.57663 .71192 L
.5926 .73151 L
.60729 .75046 L
.62004 .7686 L
.63022 .78577 L
.63415 .79395 L
.63719 .80182 L
.63927 .80937 L
.63992 .81302 L
.6403 .81659 L
.6404 .82006 L
.64021 .82344 L
.63971 .82672 L
.63935 .82832 L
.63891 .8299 L
.63778 .83299 L
.63632 .83597 L
.63452 .83884 L
.63349 .84024 L
.63237 .84161 L
.62697 .84681 L
.6237 .84924 L
.62004 .85155 L
.61151 .85581 L
.60129 .85957 L
.57546 .86549 L
.54191 .86916 L
.5 .87042 L
s
.5 .87042 m
.48395 .84204 L
.46677 .81833 L
.44863 .79879 L
.42969 .78296 L
.4101 .77034 L
.39003 .76045 L
.36964 .75281 L
.34909 .74694 L
.32854 .74236 L
.30815 .73858 L
.28808 .73513 L
.26849 .73151 L
.24954 .72725 L
.2314 .72186 L
.21423 .71487 L
.19818 .70579 L
.18341 .69413 L
.1701 .67942 L
.15839 .66117 L
.14845 .63891 L
.14043 .61214 L
.13451 .58039 L
.13084 .54317 L
.12958 .5 L
s
.5 .87042 m
.49988 .87198 L
.49953 .87348 L
.49894 .87492 L
.49857 .87561 L
.49814 .87629 L
.49712 .87761 L
.49589 .87886 L
.49445 .88006 L
.49282 .88121 L
.48899 .88333 L
.48445 .88525 L
.47342 .88853 L
.46014 .89114 L
.44502 .89319 L
.42844 .89477 L
.41083 .89599 L
.39256 .89694 L
.37406 .89772 L
.35572 .89844 L
.33794 .89919 L
.32113 .90007 L
.30568 .90118 L
.292 .90263 L
.28049 .90451 L
.27568 .90565 L
.27156 .90693 L
.26818 .90837 L
.26678 .90915 L
.26616 .90956 L
.2656 .90997 L
.26462 .91085 L
.26421 .9113 L
.26386 .91177 L
.26356 .91224 L
.26332 .91273 L
.26313 .91324 L
.26306 .91349 L
.26304 .91362 L
.26301 .91375 L
.26294 .91428 L
.26294 .91482 L
.26299 .91538 L
.26304 .91566 L
.26311 .91595 L
.26353 .91713 L
.26383 .91774 L
.2642 .91836 L
.26634 .92101 L
.26957 .92391 L
Mistroke
.27953 .93048 L
.29447 .93819 L
.31479 .94713 L
Mfstroke
.5 .87042 m
.50012 .87198 L
.50047 .87348 L
.50106 .87492 L
.50143 .87561 L
.50186 .87629 L
.50288 .87761 L
.50411 .87886 L
.50555 .88006 L
.50718 .88121 L
.51101 .88333 L
.51555 .88525 L
.52658 .88853 L
.53986 .89114 L
.55498 .89319 L
.57156 .89477 L
.58917 .89599 L
.60744 .89694 L
.62594 .89772 L
.64428 .89844 L
.66206 .89919 L
.67887 .90007 L
.69432 .90118 L
.708 .90263 L
.71951 .90451 L
.72432 .90565 L
.72844 .90693 L
.73182 .90837 L
.73322 .90915 L
.73384 .90956 L
.7344 .90997 L
.73538 .91085 L
.73579 .9113 L
.73614 .91177 L
.73644 .91224 L
.73668 .91273 L
.73687 .91324 L
.73694 .91349 L
.73696 .91362 L
.73699 .91375 L
.73706 .91428 L
.73706 .91482 L
.73701 .91538 L
.73696 .91566 L
.73689 .91595 L
.73647 .91713 L
.73617 .91774 L
.7358 .91836 L
.73366 .92101 L
.73043 .92391 L
Mistroke
.72047 .93048 L
.70553 .93819 L
.68521 .94713 L
Mfstroke
.68521 .94713 m
.663 .94458 L
.64255 .94323 L
.62371 .94294 L
.60632 .94358 L
.59022 .94502 L
.57524 .94713 L
.56123 .94977 L
.54802 .95282 L
.53545 .95612 L
.52337 .95956 L
.5116 .963 L
.5 .96631 L
.4884 .96935 L
.47663 .972 L
.46455 .9741 L
.45198 .97555 L
.43877 .97619 L
.42476 .9759 L
.40978 .97455 L
.39368 .972 L
.37629 .96811 L
.35745 .96276 L
.337 .95581 L
.31479 .94713 L
s
.94713 .68521 m
.94458 .663 L
.94323 .64255 L
.94294 .62371 L
.94358 .60632 L
.94502 .59022 L
.94713 .57524 L
.94977 .56123 L
.95282 .54802 L
.95612 .53545 L
.95956 .52337 L
.963 .5116 L
.96631 .5 L
.96935 .4884 L
.972 .47663 L
.9741 .46455 L
.97555 .45198 L
.97619 .43877 L
.9759 .42476 L
.97455 .40978 L
.972 .39368 L
.96811 .37629 L
.96276 .35745 L
.95581 .337 L
.94713 .31479 L
s
.94713 .68521 m
.94381 .66486 L
.94025 .64973 L
.9384 .64395 L
.9365 .63927 L
.93455 .63561 L
.93357 .63414 L
.93257 .6329 L
.93157 .63189 L
.93056 .63108 L
.92954 .63048 L
.92903 .63026 L
.92877 .63016 L
.92851 .63008 L
.92748 .62986 L
.92697 .62981 L
.92645 .62981 L
.92541 .62994 L
.92488 .63006 L
.92436 .63022 L
.92331 .63066 L
.92225 .63124 L
.9212 .63195 L
.92014 .63278 L
.91588 .63719 L
.91162 .64289 L
.9074 .6493 L
.90324 .65588 L
.89919 .66206 L
.89526 .66727 L
.89336 .66934 L
.89151 .67095 L
.8906 .67157 L
.8897 .67205 L
.88882 .67238 L
.88838 .67248 L
.88816 .67252 L
.88795 .67255 L
.88752 .67257 L
.88709 .67255 L
.88667 .67249 L
.88646 .67244 L
.88625 .67239 L
.88584 .67223 L
.88543 .67203 L
.88503 .67179 L
.88482 .67164 L
.88462 .67149 L
.88383 .67074 L
.88306 .66979 L
Mistroke
.8823 .66862 L
.88157 .66722 L
.87881 .65916 L
.87638 .64677 L
.87432 .62947 L
.87266 .60671 L
.87144 .57792 L
.87068 .54254 L
.87042 .5 L
Mfstroke
.87042 .5 m
.87198 .49988 L
.87348 .49953 L
.87492 .49894 L
.87561 .49857 L
.87629 .49814 L
.87761 .49712 L
.87886 .49589 L
.88006 .49445 L
.88121 .49282 L
.88333 .48899 L
.88525 .48445 L
.88853 .47342 L
.89114 .46014 L
.89319 .44502 L
.89477 .42844 L
.89599 .41083 L
.89694 .39256 L
.89772 .37406 L
.89844 .35572 L
.89919 .33794 L
.90007 .32113 L
.90118 .30568 L
.90263 .292 L
.90451 .28049 L
.90565 .27568 L
.90693 .27156 L
.90837 .26818 L
.90915 .26678 L
.90956 .26616 L
.90997 .2656 L
.91085 .26462 L
.9113 .26421 L
.91177 .26386 L
.91224 .26356 L
.91273 .26332 L
.91324 .26313 L
.91349 .26306 L
.91362 .26304 L
.91375 .26301 L
.91428 .26294 L
.91482 .26294 L
.91538 .26299 L
.91566 .26304 L
.91595 .26311 L
.91713 .26353 L
.91774 .26383 L
.91836 .2642 L
.92101 .26634 L
.92391 .26957 L
Mistroke
.93048 .27953 L
.93819 .29447 L
.94713 .31479 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0177187 0.97619 0.239203 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.523849 0.480908 0.523849 [
[ 0 0 0 0 ]
[ 1 .96182 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.03 .18 .33 r
.5 Mabswid
[ ] 0 setdash
.12958 .48091 m
.12802 .48079 L
.12652 .48043 L
.12508 .47985 L
.12439 .47948 L
.12371 .47905 L
.12239 .47802 L
.12114 .47679 L
.11994 .47536 L
.11879 .47373 L
.11667 .4699 L
.11475 .46535 L
.11147 .45433 L
.10886 .44105 L
.10681 .42592 L
.10523 .40935 L
.10401 .39173 L
.10306 .37347 L
.10228 .35497 L
.10156 .33663 L
.10081 .31885 L
.09993 .30204 L
.09882 .28659 L
.09737 .27291 L
.09549 .2614 L
.09435 .25659 L
.09307 .25246 L
.09163 .24909 L
.09085 .24769 L
.09044 .24707 L
.09003 .2465 L
.08915 .24552 L
.0887 .24512 L
.08823 .24476 L
.08776 .24447 L
.08727 .24422 L
.08676 .24404 L
.08651 .24397 L
.08638 .24394 L
.08625 .24392 L
.08572 .24385 L
.08518 .24385 L
.08462 .2439 L
.08434 .24395 L
.08405 .24402 L
.08287 .24444 L
.08226 .24474 L
.08164 .24511 L
.07899 .24725 L
.07609 .25048 L
Mistroke
.06952 .26044 L
.06181 .27537 L
.05287 .2957 L
Mfstroke
.12958 .48091 m
.12802 .48103 L
.12652 .48138 L
.12508 .48196 L
.12439 .48234 L
.12371 .48277 L
.12239 .48379 L
.12114 .48502 L
.11994 .48646 L
.11879 .48809 L
.11667 .49192 L
.11475 .49646 L
.11147 .50749 L
.10886 .52077 L
.10681 .53589 L
.10523 .55246 L
.10401 .57008 L
.10306 .58834 L
.10228 .60685 L
.10156 .62519 L
.10081 .64297 L
.09993 .65978 L
.09882 .67523 L
.09737 .68891 L
.09549 .70041 L
.09435 .70523 L
.09307 .70935 L
.09163 .71273 L
.09085 .71412 L
.09044 .71474 L
.09003 .71531 L
.08915 .71629 L
.0887 .7167 L
.08823 .71705 L
.08776 .71735 L
.08727 .71759 L
.08676 .71777 L
.08651 .71784 L
.08638 .71787 L
.08625 .7179 L
.08572 .71796 L
.08518 .71797 L
.08462 .71792 L
.08434 .71786 L
.08405 .7178 L
.08287 .71738 L
.08226 .71708 L
.08164 .71671 L
.07899 .71457 L
.07609 .71133 L
Mistroke
.06952 .70138 L
.06181 .68644 L
.05287 .66612 L
Mfstroke
.05287 .66612 m
.05542 .6439 L
.05677 .62346 L
.05706 .60462 L
.05642 .58723 L
.05498 .57113 L
.05287 .55615 L
.05023 .54213 L
.04718 .52892 L
.04388 .51636 L
.04044 .50427 L
.037 .49251 L
.03369 .48091 L
.03065 .46931 L
.028 .45754 L
.0259 .44546 L
.02445 .43289 L
.02381 .41968 L
.0241 .40567 L
.02545 .39069 L
.028 .37458 L
.03189 .35719 L
.03724 .33836 L
.04419 .31791 L
.05287 .2957 L
s
.5 .48091 m
.48581 .46409 L
.47396 .44471 L
.46419 .4231 L
.45627 .39959 L
.44996 .3745 L
.44502 .34816 L
.4412 .32091 L
.43826 .29306 L
.43597 .26494 L
.43408 .23689 L
.43236 .20922 L
.43055 .18227 L
.42842 .15636 L
.42572 .13182 L
.42223 .10898 L
.41769 .08816 L
.41186 .0697 L
.40839 .06145 L
.4045 .05391 L
.40018 .04712 L
.39784 .04403 L
.39538 .04113 L
.39008 .03597 L
.38723 .03371 L
.38424 .03168 L
.37785 .02831 L
.37443 .02698 L
.37086 .0259 L
.36325 .02448 L
.3592 .02416 L
.35498 .0241 L
.34604 .0248 L
.33637 .02661 L
.31479 .03377 L
s
.5 .48091 m
.4926 .47418 L
.48581 .46935 L
.48264 .46762 L
.47961 .46633 L
.47671 .46547 L
.47532 .46519 L
.47463 .46509 L
.47396 .46502 L
.47133 .46497 L
.47006 .46509 L
.46883 .46531 L
.46645 .46602 L
.4653 .46651 L
.46419 .46709 L
.46204 .46852 L
.46001 .47028 L
.45809 .47237 L
.45717 .47353 L
.45627 .47477 L
.45293 .48045 L
.44996 .48724 L
.44502 .50368 L
.4412 .5233 L
.43826 .54528 L
.43597 .56882 L
.43408 .59309 L
.43236 .6173 L
.43055 .64064 L
.42842 .66229 L
.42572 .68144 L
.42223 .69729 L
.4201 .70372 L
.41769 .70902 L
.41636 .71122 L
.41495 .71309 L
.41345 .71463 L
.41266 .71528 L
.41226 .71557 L
.41186 .71583 L
.41103 .7163 L
.41017 .71667 L
.40929 .71695 L
.40884 .71706 L
.40839 .71714 L
.40745 .71723 L
.4065 .71722 L
.40551 .71711 L
.40501 .71702 L
.40476 .71697 L
Mistroke
.4045 .71691 L
.4024 .71619 L
.40018 .71504 L
.39784 .71347 L
.39538 .71144 L
.39008 .706 L
.38424 .69862 L
.37086 .67764 L
.35498 .64769 L
.33637 .60795 L
.31479 .55762 L
Mfstroke
.31479 .55762 m
.32095 .53237 L
.32422 .50673 L
.32492 .48078 L
.32337 .45464 L
.31988 .42838 L
.31479 .40211 L
.30841 .37591 L
.30107 .34989 L
.29309 .32413 L
.28478 .29873 L
.27647 .27379 L
.26849 .2494 L
.26115 .22565 L
.25477 .20263 L
.24968 .18045 L
.2462 .1592 L
.24464 .13896 L
.24534 .11984 L
.24663 .11072 L
.24861 .10192 L
.25131 .09345 L
.25477 .08531 L
.25904 .07753 L
.26415 .0701 L
.27014 .06304 L
.27706 .05637 L
.29384 .04423 L
.31479 .03377 L
s
.31479 .55762 m
.31284 .56048 L
.31085 .56292 L
.30883 .56497 L
.3078 .56584 L
.30677 .56663 L
.30467 .56791 L
.30361 .56841 L
.30254 .56883 L
.30037 .56939 L
.29928 .56954 L
.29873 .56958 L
.29818 .56961 L
.29595 .56949 L
.29483 .56931 L
.2937 .56905 L
.29142 .5683 L
.29027 .56781 L
.28911 .56724 L
.28442 .56427 L
.27964 .56021 L
.26984 .54919 L
.25981 .53485 L
.24961 .51787 L
.23934 .49893 L
.22906 .4787 L
.21886 .45787 L
.20883 .4371 L
.19904 .41707 L
.18956 .39846 L
.18049 .38195 L
.17191 .36821 L
.16782 .36259 L
.16388 .35792 L
.1601 .35428 L
.15828 .35287 L
.15738 .35228 L
.1565 .35176 L
.15476 .35094 L
.15391 .35065 L
.15307 .35043 L
.15225 .3503 L
.15143 .35025 L
.15063 .35028 L
.15023 .35032 L
.15004 .35036 L
.14984 .35039 L
.14906 .35059 L
.1483 .35088 L
.14755 .35126 L
Mistroke
.14717 .35148 L
.14681 .35172 L
.14537 .35293 L
.14467 .35367 L
.14398 .3545 L
.14138 .35883 L
.13901 .36477 L
.13501 .38187 L
.13205 .40647 L
.13021 .43926 L
.12958 .48091 L
Mfstroke
.31479 .55762 m
.31133 .56406 L
.30863 .57112 L
.30665 .57876 L
.30536 .58694 L
.30466 .60479 L
.30622 .62438 L
.3097 .64541 L
.31479 .66759 L
.32117 .69062 L
.32851 .71422 L
.3365 .73808 L
.3448 .76191 L
.35311 .78542 L
.36109 .80831 L
.36844 .8303 L
.37481 .85108 L
.3799 .87037 L
.38339 .88786 L
.38494 .90327 L
.38489 .9101 L
.38424 .9163 L
.38295 .92183 L
.38205 .92433 L
.38098 .92665 L
.37972 .92879 L
.37828 .93073 L
.37664 .93249 L
.37575 .93329 L
.37481 .93404 L
.37278 .93539 L
.37055 .93653 L
.3681 .93746 L
.36679 .93784 L
.36543 .93817 L
.35944 .93891 L
.35252 .93874 L
.33575 .93546 L
.31479 .92804 L
s
.31479 .92804 m
.30677 .89634 L
.29818 .86907 L
.28911 .84578 L
.27964 .82602 L
.26984 .80934 L
.25981 .7953 L
.24961 .78344 L
.23934 .77331 L
.22906 .76448 L
.21886 .75647 L
.20883 .74886 L
.19904 .74119 L
.18956 .733 L
.18049 .72386 L
.17191 .71331 L
.16388 .7009 L
.1565 .68619 L
.14984 .66872 L
.14398 .64805 L
.13901 .62372 L
.13501 .59529 L
.13205 .56231 L
.13021 .52434 L
.12958 .48091 L
s
.87042 .48091 m
.85623 .45898 L
.84437 .43689 L
.83461 .41471 L
.82669 .39248 L
.82038 .37028 L
.81543 .34816 L
.81162 .32619 L
.80868 .30442 L
.80639 .28292 L
.8045 .26175 L
.80277 .24096 L
.80096 .22063 L
.79883 .2008 L
.79614 .18155 L
.79264 .16292 L
.7881 .14499 L
.78227 .12781 L
.77492 .11145 L
.7658 .09596 L
.75466 .08141 L
.74128 .06785 L
.7254 .05535 L
.70679 .04397 L
.68521 .03377 L
s
.87042 .48091 m
.85623 .4627 L
.85002 .45618 L
.84437 .45126 L
.84174 .44936 L
.83924 .44783 L
.83686 .44665 L
.83572 .44619 L
.83461 .44582 L
.83246 .44531 L
.83043 .44512 L
.82851 .44523 L
.82758 .4454 L
.82713 .44552 L
.82669 .44565 L
.82497 .44634 L
.82415 .44679 L
.82335 .4473 L
.82182 .44853 L
.82109 .44923 L
.82038 .45 L
.81775 .45364 L
.81543 .45813 L
.81162 .46931 L
.80868 .48277 L
.80639 .49779 L
.8045 .51363 L
.80277 .52952 L
.80096 .54474 L
.79883 .55854 L
.79614 .57018 L
.79451 .57496 L
.79264 .57892 L
.79162 .58056 L
.79052 .58196 L
.78935 .58311 L
.78874 .58359 L
.78842 .58381 L
.7881 .584 L
.78745 .58435 L
.78678 .58462 L
.78608 .58482 L
.78573 .58489 L
.78536 .58495 L
.78463 .585 L
.78387 .58498 L
.78308 .58488 L
.78268 .5848 L
.78248 .58475 L
.78227 .5847 L
Mistroke
.78059 .5841 L
.7788 .58317 L
.77691 .58189 L
.77492 .58026 L
.77059 .57588 L
.7658 .56994 L
.75466 .553 L
.74128 .5287 L
.7254 .4963 L
.70679 .45504 L
.68521 .40419 L
Mfstroke
.68521 .40419 m
.68867 .39775 L
.69137 .39069 L
.69335 .38306 L
.69464 .37487 L
.69534 .35702 L
.69378 .33743 L
.6903 .3164 L
.68521 .29422 L
.67883 .27119 L
.67149 .2476 L
.6635 .22374 L
.6552 .19991 L
.64689 .1764 L
.63891 .1535 L
.63156 .13152 L
.62519 .11073 L
.6201 .09145 L
.61661 .07396 L
.61506 .05855 L
.61511 .05172 L
.61576 .04552 L
.61705 .03999 L
.61795 .03749 L
.61902 .03516 L
.62028 .03303 L
.62172 .03108 L
.62336 .02933 L
.62425 .02853 L
.62519 .02778 L
.62722 .02643 L
.62945 .02529 L
.6319 .02436 L
.63321 .02398 L
.63457 .02365 L
.64056 .0229 L
.64748 .02308 L
.66425 .02635 L
.68521 .03377 L
s
.68521 .40419 m
.68127 .41562 L
.67718 .42495 L
.67295 .43229 L
.67079 .43525 L
.6686 .43775 L
.66637 .43981 L
.66412 .44144 L
.66183 .44266 L
.66068 .44312 L
.6601 .44331 L
.65953 .44348 L
.65719 .44391 L
.65602 .44398 L
.65483 .44396 L
.65245 .44366 L
.65126 .44337 L
.65005 .44301 L
.64763 .44202 L
.64519 .44072 L
.64273 .43911 L
.64026 .43721 L
.63022 .42697 L
.62003 .41315 L
.60975 .39664 L
.59948 .37831 L
.58928 .35904 L
.57925 .3397 L
.56945 .32118 L
.55998 .30433 L
.55091 .29005 L
.54655 .28415 L
.54232 .27921 L
.53824 .27535 L
.53625 .27386 L
.53527 .27323 L
.5343 .27268 L
.53239 .27183 L
.53145 .27153 L
.53052 .27131 L
.5296 .27118 L
.5287 .27114 L
.5278 .2712 L
.52736 .27126 L
.52714 .2713 L
.52692 .27134 L
.52604 .27159 L
.52518 .27192 L
.52433 .27236 L
.52391 .27262 L
Mistroke
.52349 .2729 L
.52185 .27427 L
.52105 .27512 L
.52026 .27607 L
.51722 .28099 L
.5144 .28774 L
.50943 .30723 L
.50543 .33542 L
.50247 .37318 L
.50063 .42138 L
.5 .48091 L
Mfstroke
.68521 .40419 m
.67905 .42944 L
.67578 .45509 L
.67508 .48103 L
.67663 .50718 L
.68012 .53344 L
.68521 .55971 L
.69159 .58591 L
.69893 .61193 L
.70691 .63769 L
.71522 .66308 L
.72353 .68803 L
.73151 .71242 L
.73885 .73617 L
.74523 .75918 L
.75032 .78136 L
.7538 .80262 L
.75536 .82285 L
.75466 .84198 L
.75337 .85109 L
.75139 .85989 L
.74869 .86836 L
.74523 .8765 L
.74096 .88429 L
.73585 .89172 L
.72986 .89877 L
.72294 .90544 L
.70616 .91758 L
.68521 .92804 L
s
.68521 .92804 m
.67718 .89124 L
.6686 .86126 L
.65953 .83739 L
.65005 .81892 L
.64519 .81148 L
.64026 .80512 L
.63527 .79976 L
.63022 .7953 L
.62514 .79165 L
.62003 .78872 L
.6149 .78643 L
.60975 .78468 L
.59948 .78246 L
.58928 .78134 L
.57925 .7806 L
.56945 .77954 L
.56467 .77867 L
.55998 .77744 L
.55539 .77578 L
.55314 .77475 L
.55091 .77358 L
.54655 .77077 L
.54442 .7691 L
.54232 .76725 L
.53824 .76293 L
.5343 .75773 L
.52692 .7443 L
.52026 .72626 L
.5144 .70288 L
.50943 .67344 L
.50543 .63725 L
.50247 .59357 L
.50063 .54169 L
.5 .48091 L
s
.94713 .66612 m
.94458 .6439 L
.94323 .62346 L
.94294 .60462 L
.94358 .58723 L
.94502 .57113 L
.94713 .55615 L
.94977 .54213 L
.95282 .52892 L
.95612 .51636 L
.95956 .50427 L
.963 .49251 L
.96631 .48091 L
.96935 .46931 L
.972 .45754 L
.9741 .44546 L
.97555 .43289 L
.97619 .41968 L
.9759 .40567 L
.97455 .39069 L
.972 .37458 L
.96811 .35719 L
.96276 .33836 L
.95581 .31791 L
.94713 .2957 L
s
.94713 .66612 m
.94381 .64577 L
.94025 .63064 L
.9384 .62486 L
.9365 .62018 L
.93455 .61652 L
.93357 .61505 L
.93257 .61381 L
.93157 .6128 L
.93056 .61199 L
.92954 .61139 L
.92903 .61116 L
.92877 .61107 L
.92851 .61099 L
.92748 .61077 L
.92697 .61072 L
.92645 .61072 L
.92541 .61085 L
.92488 .61097 L
.92436 .61113 L
.92331 .61157 L
.92225 .61215 L
.9212 .61286 L
.92014 .61369 L
.91588 .6181 L
.91162 .62379 L
.9074 .63021 L
.90324 .63679 L
.89919 .64297 L
.89526 .64818 L
.89336 .65025 L
.89151 .65186 L
.8906 .65248 L
.8897 .65295 L
.88882 .65328 L
.88838 .65339 L
.88816 .65343 L
.88795 .65346 L
.88752 .65348 L
.88709 .65346 L
.88667 .6534 L
.88646 .65335 L
.88625 .65329 L
.88584 .65314 L
.88543 .65294 L
.88503 .65269 L
.88482 .65255 L
.88462 .6524 L
.88383 .65165 L
.88306 .6507 L
Mistroke
.8823 .64952 L
.88157 .64812 L
.87881 .64007 L
.87638 .62768 L
.87432 .61038 L
.87266 .58762 L
.87144 .55883 L
.87068 .52344 L
.87042 .48091 L
Mfstroke
.87042 .48091 m
.87198 .48079 L
.87348 .48043 L
.87492 .47985 L
.87561 .47948 L
.87629 .47905 L
.87761 .47802 L
.87886 .47679 L
.88006 .47536 L
.88121 .47373 L
.88333 .4699 L
.88525 .46535 L
.88853 .45433 L
.89114 .44105 L
.89319 .42592 L
.89477 .40935 L
.89599 .39173 L
.89694 .37347 L
.89772 .35497 L
.89844 .33663 L
.89919 .31885 L
.90007 .30204 L
.90118 .28659 L
.90263 .27291 L
.90451 .2614 L
.90565 .25659 L
.90693 .25246 L
.90837 .24909 L
.90915 .24769 L
.90956 .24707 L
.90997 .2465 L
.91085 .24552 L
.9113 .24512 L
.91177 .24476 L
.91224 .24447 L
.91273 .24422 L
.91324 .24404 L
.91349 .24397 L
.91362 .24394 L
.91375 .24392 L
.91428 .24385 L
.91482 .24385 L
.91538 .2439 L
.91566 .24395 L
.91595 .24402 L
.91713 .24444 L
.91774 .24474 L
.91836 .24511 L
.92101 .24725 L
.92391 .25048 L
Mistroke
.93048 .26044 L
.93819 .27537 L
.94713 .2957 L
Mfstroke
0 0 m
1 0 L
1 .96182 L
0 .96182 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.261351 0.245293 0.482835 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.493273 0.531249 0.487826 0.531249 [
[ 0 0 0 0 ]
[ 1 .98064 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.03 .18 .33 r
.5 Mabswid
[ ] 0 setdash
.30545 .56563 m
.29835 .56349 L
.29135 .56037 L
.28445 .55631 L
.27766 .55136 L
.26436 .53906 L
.25143 .5239 L
.23884 .50632 L
.22659 .48677 L
.21465 .46568 L
.20299 .44349 L
.19161 .42066 L
.18048 .39761 L
.16957 .3748 L
.15888 .35265 L
.14838 .33162 L
.13805 .31215 L
.12787 .29467 L
.11783 .27963 L
.10789 .26746 L
.10296 .2626 L
.09805 .25862 L
.09316 .25558 L
.09072 .25443 L
.08828 .25354 L
.08585 .25291 L
.08342 .25254 L
.08099 .25246 L
.07978 .25252 L
.07856 .25266 L
.07614 .25315 L
.07372 .25393 L
.0713 .25502 L
.07009 .25568 L
.06888 .25642 L
.06404 .26019 L
.05921 .26528 L
.04953 .27965 L
.03982 .3 L
s
.30545 .56563 m
.30201 .56498 L
.29883 .56465 L
.29591 .56464 L
.29454 .56474 L
.29324 .56493 L
.29081 .56551 L
.28969 .56591 L
.28863 .56638 L
.28667 .56753 L
.28578 .5682 L
.28535 .56857 L
.28494 .56895 L
.28343 .57063 L
.28275 .57156 L
.28213 .57256 L
.28103 .57473 L
.28056 .57591 L
.28013 .57715 L
.2789 .58264 L
.27838 .58898 L
.27926 .60391 L
.28235 .62139 L
.28721 .64087 L
.29343 .66182 L
.30056 .6837 L
.30819 .70595 L
.31589 .72804 L
.32323 .74942 L
.32978 .76956 L
.33512 .7879 L
.33881 .80391 L
.33991 .81087 L
.34044 .81705 L
.34034 .82237 L
.34004 .82468 L
.33982 .82575 L
.33956 .82676 L
.33891 .82859 L
.33851 .82941 L
.33806 .83017 L
.33756 .83086 L
.33701 .83148 L
.33642 .83203 L
.3361 .83228 L
.33593 .8324 L
.33577 .83252 L
.33507 .83293 L
.33431 .83327 L
.3335 .83354 L
Mistroke
.33308 .83365 L
.33264 .83374 L
.33074 .83391 L
.32971 .83387 L
.32862 .83377 L
.32365 .83253 L
.31769 .82997 L
.30256 .82058 L
.28279 .80506 L
.25796 .78286 L
.22765 .75345 L
Mfstroke
.22765 .75345 m
.2221 .72755 L
.21476 .70321 L
.20586 .6803 L
.1956 .65868 L
.1842 .63824 L
.17189 .61883 L
.15887 .60034 L
.14536 .58262 L
.13159 .56556 L
.11776 .54903 L
.10409 .53288 L
.09081 .517 L
.07812 .50126 L
.06624 .48552 L
.05539 .46965 L
.04579 .45354 L
.03765 .43704 L
.03119 .42003 L
.02663 .40238 L
.02418 .38396 L
.02405 .36464 L
.02648 .3443 L
.03166 .32279 L
.03982 .3 L
s
.22765 .75345 m
.22644 .75449 L
.22511 .75531 L
.22366 .75592 L
.22289 .75615 L
.2221 .75633 L
.22042 .75654 L
.21864 .75656 L
.21675 .75639 L
.21476 .75604 L
.21049 .75481 L
.20586 .75293 L
.1956 .74738 L
.1842 .73973 L
.17189 .73035 L
.15887 .7196 L
.14536 .70784 L
.13159 .69543 L
.11776 .68272 L
.10409 .67008 L
.09081 .65787 L
.07812 .64644 L
.06624 .63617 L
.05539 .6274 L
.04579 .62049 L
.04153 .61785 L
.03765 .61582 L
.0342 .61443 L
.03264 .61399 L
.0319 .61383 L
.03119 .61373 L
.02986 .61365 L
.02925 .61368 L
.02866 .61376 L
.0281 .61389 L
.02758 .61407 L
.02709 .6143 L
.02685 .61443 L
.02674 .61451 L
.02663 .61458 L
.0262 .61491 L
.02581 .6153 L
.02545 .61574 L
.02528 .61597 L
.02512 .61623 L
.02458 .61737 L
.02436 .61803 L
.02418 .61874 L
.02381 .62218 L
.02405 .62657 L
Mistroke
.02648 .63843 L
.03166 .65467 L
.03982 .67565 L
Mfstroke
.22765 .75345 m
.22661 .75466 L
.22579 .75599 L
.22518 .75744 L
.22495 .7582 L
.22477 .759 L
.22456 .76068 L
.22454 .76246 L
.22471 .76435 L
.22506 .76634 L
.22628 .77061 L
.22817 .77524 L
.23372 .7855 L
.24137 .7969 L
.25075 .80921 L
.2615 .82223 L
.27326 .83573 L
.28567 .84951 L
.29838 .86334 L
.31102 .877 L
.32323 .89029 L
.33465 .90298 L
.34493 .91486 L
.3537 .92571 L
.36061 .93531 L
.36324 .93957 L
.36528 .94345 L
.36667 .9469 L
.36711 .94846 L
.36727 .9492 L
.36737 .94991 L
.36745 .95123 L
.36742 .95185 L
.36734 .95244 L
.36721 .953 L
.36703 .95352 L
.3668 .95401 L
.36666 .95425 L
.36659 .95436 L
.36652 .95447 L
.36619 .9549 L
.3658 .95529 L
.36536 .95565 L
.36512 .95582 L
.36487 .95597 L
.36373 .95652 L
.36307 .95674 L
.36236 .95692 L
.35892 .95729 L
.35453 .95705 L
Mistroke
.34267 .95462 L
.32643 .94944 L
.30545 .94128 L
Mfstroke
.30545 .94128 m
.29135 .92352 L
.27766 .90788 L
.26436 .89417 L
.25143 .88216 L
.23884 .87165 L
.22659 .86242 L
.21465 .85426 L
.20299 .84697 L
.19161 .84033 L
.18048 .83413 L
.16957 .82816 L
.15888 .82222 L
.14838 .81608 L
.13805 .80954 L
.12787 .80238 L
.11783 .79441 L
.10789 .78539 L
.09805 .77514 L
.08828 .76343 L
.07856 .75005 L
.06888 .73479 L
.05921 .71745 L
.04953 .6978 L
.03982 .67565 L
s
.6811 .41003 m
.65857 .39634 L
.63784 .38029 L
.61873 .36219 L
.6011 .34232 L
.58477 .321 L
.56958 .2985 L
.55537 .27515 L
.54197 .25122 L
.52922 .22702 L
.51697 .20286 L
.50504 .17901 L
.49327 .15579 L
.48151 .1335 L
.46958 .11242 L
.45732 .09287 L
.44458 .07513 L
.43118 .0595 L
.41697 .04629 L
.40951 .04068 L
.40178 .03579 L
.39377 .03164 L
.38545 .02829 L
.3768 .02577 L
.36781 .02411 L
.35845 .02335 L
.34871 .02353 L
.32798 .02685 L
.30545 .03438 L
s
.6811 .41003 m
.67008 .40466 L
.66046 .4009 L
.65216 .39867 L
.64849 .3981 L
.64512 .39787 L
.64205 .39799 L
.63926 .39844 L
.63675 .3992 L
.6356 .3997 L
.63504 .39998 L
.63451 .40027 L
.63253 .40164 L
.63163 .40243 L
.6308 .40329 L
.62931 .40521 L
.62865 .40628 L
.62806 .4074 L
.62702 .40984 L
.62621 .41253 L
.6256 .41544 L
.62519 .41858 L
.62534 .43312 L
.62793 .45034 L
.6324 .46955 L
.63818 .49006 L
.64469 .51119 L
.65136 .53225 L
.65762 .55256 L
.66291 .57143 L
.66664 .58818 L
.66775 .59554 L
.66826 .60211 L
.66809 .60781 L
.66774 .6103 L
.66749 .61146 L
.66719 .61255 L
.66643 .61453 L
.66597 .61542 L
.66546 .61624 L
.66489 .61699 L
.66427 .61767 L
.66359 .61827 L
.66323 .61855 L
.66304 .61868 L
.66285 .6188 L
.66205 .61925 L
.66119 .61963 L
.66027 .61993 L
.65978 .62005 L
Mistroke
.65928 .62014 L
.65712 .62033 L
.65594 .6203 L
.65469 .62019 L
.64899 .61884 L
.64212 .61601 L
.62458 .6056 L
.60149 .58826 L
.57229 .56331 L
.53641 .53006 L
.49327 .48783 L
Mfstroke
.49327 .48783 m
.49138 .46559 L
.48599 .44319 L
.4775 .42069 L
.46632 .39815 L
.45285 .37564 L
.43751 .35321 L
.42071 .33092 L
.40284 .30885 L
.38432 .28705 L
.36556 .26557 L
.34696 .24449 L
.32893 .22387 L
.31187 .20376 L
.29621 .18423 L
.28234 .16535 L
.27067 .14716 L
.2616 .12974 L
.25818 .12134 L
.25556 .11315 L
.25379 .10518 L
.25325 .10128 L
.25293 .09744 L
.25304 .08994 L
.25346 .08628 L
.25414 .08268 L
.25631 .07568 L
.25781 .07227 L
.25959 .06893 L
.26403 .06246 L
.26671 .05932 L
.26969 .05626 L
.2766 .05034 L
.28484 .04472 L
.30545 .03438 L
s
.86892 .48783 m
.85453 .46559 L
.84251 .44319 L
.83261 .42069 L
.82458 .39815 L
.81818 .37564 L
.81316 .35321 L
.80929 .33092 L
.80631 .30885 L
.80399 .28705 L
.80208 .26557 L
.80032 .24449 L
.79849 .22387 L
.79633 .20376 L
.7936 .18423 L
.79005 .16535 L
.78545 .14716 L
.77954 .12974 L
.77208 .11315 L
.76282 .09744 L
.75153 .08268 L
.73796 .06893 L
.72186 .05626 L
.70299 .04472 L
.6811 .03438 L
s
.86892 .48783 m
.85453 .46937 L
.84824 .46275 L
.84251 .45775 L
.83984 .45583 L
.83731 .45428 L
.8349 .45309 L
.83374 .45262 L
.83261 .45224 L
.83043 .45172 L
.82837 .45153 L
.82642 .45165 L
.82549 .45182 L
.82503 .45193 L
.82458 .45207 L
.82283 .45277 L
.822 .45322 L
.82119 .45375 L
.81964 .45499 L
.8189 .4557 L
.81818 .45648 L
.81551 .46017 L
.81316 .46473 L
.80929 .47606 L
.80631 .48972 L
.80399 .50495 L
.80208 .52101 L
.80032 .53713 L
.79849 .55256 L
.79633 .56656 L
.7936 .57836 L
.79194 .58321 L
.79005 .58722 L
.78901 .58889 L
.7879 .59031 L
.78671 .59148 L
.78609 .59196 L
.78577 .59218 L
.78545 .59238 L
.78478 .59272 L
.7841 .593 L
.7834 .5932 L
.78303 .59328 L
.78267 .59333 L
.78192 .59339 L
.78115 .59336 L
.78035 .59326 L
.77995 .59318 L
.77974 .59313 L
.77954 .59308 L
Mistroke
.77783 .59247 L
.77601 .59153 L
.7741 .59023 L
.77208 .58858 L
.76769 .58414 L
.76282 .57812 L
.75153 .56094 L
.73796 .5363 L
.72186 .50343 L
.70299 .46159 L
.6811 .41003 L
Mfstroke
.6811 .41003 m
.68461 .4035 L
.68735 .39634 L
.68935 .38859 L
.69066 .38029 L
.69137 .36219 L
.68979 .34232 L
.68626 .321 L
.6811 .2985 L
.67463 .27515 L
.66719 .25122 L
.65909 .22702 L
.65066 .20286 L
.64224 .17901 L
.63414 .15579 L
.6267 .1335 L
.62023 .11242 L
.61507 .09287 L
.61153 .07513 L
.60996 .0595 L
.61 .05257 L
.61066 .04629 L
.61197 .04068 L
.61289 .03814 L
.61398 .03579 L
.61525 .03362 L
.61672 .03164 L
.61837 .02987 L
.61928 .02906 L
.62023 .02829 L
.62229 .02693 L
.62456 .02577 L
.62704 .02483 L
.62836 .02444 L
.62974 .02411 L
.63582 .02335 L
.64284 .02353 L
.65985 .02685 L
.6811 .03438 L
s
.49327 .48783 m
.49279 .49796 L
.49138 .50629 L
.49035 .5098 L
.4891 .5129 L
.48765 .51559 L
.48684 .51679 L
.48642 .51736 L
.48599 .5179 L
.48414 .51982 L
.48315 .52064 L
.48211 .52137 L
.47989 .52256 L
.47872 .52303 L
.4775 .52341 L
.47494 .52393 L
.47222 .52412 L
.46934 .524 L
.46785 .52383 L
.46632 .52359 L
.45984 .52191 L
.45285 .51917 L
.43751 .51092 L
.42071 .49959 L
.40284 .48593 L
.38432 .4707 L
.36556 .45465 L
.34696 .43852 L
.32893 .42309 L
.31187 .40909 L
.29621 .39729 L
.28234 .38843 L
.2762 .38534 L
.27067 .38327 L
.26814 .38265 L
.26578 .38232 L
.2636 .38229 L
.26258 .38239 L
.26209 .38247 L
.2616 .38257 L
.26067 .38283 L
.25979 .38318 L
.25896 .38361 L
.25856 .38385 L
.25818 .38412 L
.25745 .38473 L
.25676 .38542 L
.25613 .3862 L
.25584 .38662 L
.2557 .38685 L
Mistroke
.25556 .38707 L
.25456 .3891 L
.25379 .39151 L
.25325 .39432 L
.25293 .39754 L
.25304 .40524 L
.25414 .41471 L
.25959 .43936 L
.26969 .47222 L
.28484 .51406 L
.30545 .56563 L
Mfstroke
.49327 .48783 m
.49516 .51006 L
.50056 .53246 L
.50905 .55496 L
.52023 .5775 L
.53369 .60001 L
.54903 .62244 L
.56584 .64473 L
.58371 .6668 L
.60223 .68861 L
.62099 .71008 L
.63959 .73116 L
.65762 .75178 L
.67467 .77189 L
.69034 .79142 L
.70421 .8103 L
.71588 .82849 L
.72494 .84591 L
.72837 .85431 L
.73099 .8625 L
.73275 .87047 L
.7333 .87437 L
.73361 .87821 L
.73351 .88571 L
.73309 .88937 L
.7324 .89297 L
.73023 .89997 L
.72874 .90338 L
.72695 .90672 L
.72251 .91319 L
.71984 .91633 L
.71686 .91939 L
.70994 .92531 L
.70171 .93093 L
.6811 .94128 L
s
.6811 .94128 m
.65857 .90991 L
.63784 .88449 L
.61873 .86439 L
.6011 .84898 L
.58477 .83764 L
.56958 .82975 L
.55537 .82469 L
.54197 .82182 L
.52922 .82053 L
.51697 .82019 L
.50504 .82017 L
.49327 .81986 L
.48151 .81862 L
.46958 .81584 L
.45732 .81088 L
.44458 .80313 L
.43118 .79197 L
.41697 .77676 L
.40178 .75688 L
.38545 .73171 L
.36781 .70062 L
.34871 .66299 L
.32798 .6182 L
.30545 .56563 L
s
.94672 .67565 m
.94413 .65312 L
.94276 .63239 L
.94247 .61329 L
.94312 .59565 L
.94458 .57932 L
.94672 .56413 L
.9494 .54992 L
.95249 .53652 L
.95584 .52378 L
.95933 .51152 L
.96282 .49959 L
.96617 .48783 L
.96926 .47606 L
.97194 .46413 L
.97407 .45187 L
.97554 .43913 L
.97619 .42573 L
.9759 .41152 L
.97452 .39633 L
.97194 .38 L
.968 .36236 L
.96257 .34326 L
.95552 .32253 L
.94672 .3 L
s
.94672 .67565 m
.94335 .65501 L
.93974 .63967 L
.93786 .63381 L
.93593 .62906 L
.93396 .62535 L
.93296 .62386 L
.93196 .62261 L
.93094 .62158 L
.92991 .62076 L
.92888 .62015 L
.92836 .61992 L
.9281 .61983 L
.92784 .61974 L
.9268 .61952 L
.92627 .61947 L
.92574 .61947 L
.92469 .6196 L
.92416 .61973 L
.92363 .61989 L
.92256 .62033 L
.92149 .62092 L
.92042 .62164 L
.91934 .62249 L
.91503 .62696 L
.91071 .63273 L
.90643 .63924 L
.90221 .64591 L
.8981 .65217 L
.89412 .65746 L
.89219 .65956 L
.89031 .66119 L
.88939 .66182 L
.88848 .6623 L
.88758 .66264 L
.88714 .66274 L
.88692 .66278 L
.8867 .66281 L
.88627 .66284 L
.88584 .66282 L
.88541 .66275 L
.8852 .66271 L
.88498 .66265 L
.88456 .66249 L
.88415 .66229 L
.88374 .66204 L
.88353 .66189 L
.88333 .66174 L
.88253 .66098 L
.88174 .66001 L
Mistroke
.88098 .65882 L
.88023 .6574 L
.87743 .64924 L
.87497 .63667 L
.87289 .61913 L
.8712 .59605 L
.86996 .56685 L
.86919 .53096 L
.86892 .48783 L
Mfstroke
.86892 .48783 m
.87051 .4877 L
.87203 .48735 L
.87349 .48675 L
.87419 .48637 L
.87488 .48594 L
.87622 .4849 L
.87749 .48365 L
.8787 .4822 L
.87986 .48054 L
.88202 .47666 L
.88397 .47205 L
.88729 .46087 L
.88994 .4474 L
.89202 .43207 L
.89362 .41526 L
.89486 .39739 L
.89582 .37887 L
.89661 .36011 L
.89734 .34151 L
.8981 .32348 L
.89899 .30643 L
.90012 .29076 L
.90159 .27689 L
.9035 .26522 L
.90465 .26034 L
.90595 .25616 L
.90741 .25273 L
.9082 .25132 L
.90861 .25069 L
.90904 .25011 L
.90992 .24912 L
.91038 .2487 L
.91086 .24834 L
.91134 .24804 L
.91184 .2478 L
.91235 .24761 L
.91261 .24754 L
.91274 .24751 L
.91287 .24749 L
.91341 .24742 L
.91396 .24741 L
.91452 .24747 L
.91481 .24752 L
.9151 .24759 L
.91629 .24801 L
.91691 .24832 L
.91755 .2487 L
.92023 .25087 L
.92317 .25414 L
Mistroke
.92984 .26424 L
.93766 .27939 L
.94672 .3 L
Mfstroke
0 0 m
1 0 L
1 .98064 L
0 .98064 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.261351 0.488926 0.482835 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.523849 0.480908 0.523849 [
[ 0 0 0 0 ]
[ 1 .96182 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.03 .18 .33 r
.5 Mabswid
[ ] 0 setdash
.12958 .48091 m
.12802 .48079 L
.12652 .48043 L
.12508 .47985 L
.12439 .47948 L
.12371 .47905 L
.12239 .47802 L
.12114 .47679 L
.11994 .47536 L
.11879 .47373 L
.11667 .4699 L
.11475 .46535 L
.11147 .45433 L
.10886 .44105 L
.10681 .42592 L
.10523 .40935 L
.10401 .39173 L
.10306 .37347 L
.10228 .35497 L
.10156 .33663 L
.10081 .31885 L
.09993 .30204 L
.09882 .28659 L
.09737 .27291 L
.09549 .2614 L
.09435 .25659 L
.09307 .25246 L
.09163 .24909 L
.09085 .24769 L
.09044 .24707 L
.09003 .2465 L
.08915 .24552 L
.0887 .24512 L
.08823 .24476 L
.08776 .24447 L
.08727 .24422 L
.08676 .24404 L
.08651 .24397 L
.08638 .24394 L
.08625 .24392 L
.08572 .24385 L
.08518 .24385 L
.08462 .2439 L
.08434 .24395 L
.08405 .24402 L
.08287 .24444 L
.08226 .24474 L
.08164 .24511 L
.07899 .24725 L
.07609 .25048 L
Mistroke
.06952 .26044 L
.06181 .27537 L
.05287 .2957 L
Mfstroke
.12958 .48091 m
.12802 .48103 L
.12652 .48138 L
.12508 .48196 L
.12439 .48234 L
.12371 .48277 L
.12239 .48379 L
.12114 .48502 L
.11994 .48646 L
.11879 .48809 L
.11667 .49192 L
.11475 .49646 L
.11147 .50749 L
.10886 .52077 L
.10681 .53589 L
.10523 .55246 L
.10401 .57008 L
.10306 .58834 L
.10228 .60685 L
.10156 .62519 L
.10081 .64297 L
.09993 .65978 L
.09882 .67523 L
.09737 .68891 L
.09549 .70041 L
.09435 .70523 L
.09307 .70935 L
.09163 .71273 L
.09085 .71412 L
.09044 .71474 L
.09003 .71531 L
.08915 .71629 L
.0887 .7167 L
.08823 .71705 L
.08776 .71735 L
.08727 .71759 L
.08676 .71777 L
.08651 .71784 L
.08638 .71787 L
.08625 .7179 L
.08572 .71796 L
.08518 .71797 L
.08462 .71792 L
.08434 .71786 L
.08405 .7178 L
.08287 .71738 L
.08226 .71708 L
.08164 .71671 L
.07899 .71457 L
.07609 .71133 L
Mistroke
.06952 .70138 L
.06181 .68644 L
.05287 .66612 L
Mfstroke
.05287 .66612 m
.05542 .6439 L
.05677 .62346 L
.05706 .60462 L
.05642 .58723 L
.05498 .57113 L
.05287 .55615 L
.05023 .54213 L
.04718 .52892 L
.04388 .51636 L
.04044 .50427 L
.037 .49251 L
.03369 .48091 L
.03065 .46931 L
.028 .45754 L
.0259 .44546 L
.02445 .43289 L
.02381 .41968 L
.0241 .40567 L
.02545 .39069 L
.028 .37458 L
.03189 .35719 L
.03724 .33836 L
.04419 .31791 L
.05287 .2957 L
s
.31479 .55762 m
.31284 .56048 L
.31085 .56292 L
.30883 .56497 L
.3078 .56584 L
.30677 .56663 L
.30467 .56791 L
.30361 .56841 L
.30254 .56883 L
.30037 .56939 L
.29928 .56954 L
.29873 .56958 L
.29818 .56961 L
.29595 .56949 L
.29483 .56931 L
.2937 .56905 L
.29142 .5683 L
.29027 .56781 L
.28911 .56724 L
.28442 .56427 L
.27964 .56021 L
.26984 .54919 L
.25981 .53485 L
.24961 .51787 L
.23934 .49893 L
.22906 .4787 L
.21886 .45787 L
.20883 .4371 L
.19904 .41707 L
.18956 .39846 L
.18049 .38195 L
.17191 .36821 L
.16782 .36259 L
.16388 .35792 L
.1601 .35428 L
.15828 .35287 L
.15738 .35228 L
.1565 .35176 L
.15476 .35094 L
.15391 .35065 L
.15307 .35043 L
.15225 .3503 L
.15143 .35025 L
.15063 .35028 L
.15023 .35032 L
.15004 .35036 L
.14984 .35039 L
.14906 .35059 L
.1483 .35088 L
.14755 .35126 L
Mistroke
.14717 .35148 L
.14681 .35172 L
.14537 .35293 L
.14467 .35367 L
.14398 .3545 L
.14138 .35883 L
.13901 .36477 L
.13501 .38187 L
.13205 .40647 L
.13021 .43926 L
.12958 .48091 L
Mfstroke
.31479 .55762 m
.31133 .56406 L
.30863 .57112 L
.30665 .57876 L
.30536 .58694 L
.30466 .60479 L
.30622 .62438 L
.3097 .64541 L
.31479 .66759 L
.32117 .69062 L
.32851 .71422 L
.3365 .73808 L
.3448 .76191 L
.35311 .78542 L
.36109 .80831 L
.36844 .8303 L
.37481 .85108 L
.3799 .87037 L
.38339 .88786 L
.38494 .90327 L
.38489 .9101 L
.38424 .9163 L
.38295 .92183 L
.38205 .92433 L
.38098 .92665 L
.37972 .92879 L
.37828 .93073 L
.37664 .93249 L
.37575 .93329 L
.37481 .93404 L
.37278 .93539 L
.37055 .93653 L
.3681 .93746 L
.36679 .93784 L
.36543 .93817 L
.35944 .93891 L
.35252 .93874 L
.33575 .93546 L
.31479 .92804 L
s
.31479 .92804 m
.30677 .89634 L
.29818 .86907 L
.28911 .84578 L
.27964 .82602 L
.26984 .80934 L
.25981 .7953 L
.24961 .78344 L
.23934 .77331 L
.22906 .76448 L
.21886 .75647 L
.20883 .74886 L
.19904 .74119 L
.18956 .733 L
.18049 .72386 L
.17191 .71331 L
.16388 .7009 L
.1565 .68619 L
.14984 .66872 L
.14398 .64805 L
.13901 .62372 L
.13501 .59529 L
.13205 .56231 L
.13021 .52434 L
.12958 .48091 L
s
.68521 .40419 m
.663 .39069 L
.64255 .37487 L
.62371 .35702 L
.60632 .33743 L
.59022 .3164 L
.57524 .29422 L
.56123 .27119 L
.54802 .2476 L
.53545 .22374 L
.52337 .19991 L
.5116 .1764 L
.5 .1535 L
.4884 .13152 L
.47663 .11073 L
.46455 .09145 L
.45198 .07396 L
.43877 .05855 L
.42476 .04552 L
.4174 .03999 L
.40978 .03516 L
.40188 .03108 L
.39368 .02778 L
.38515 .02529 L
.37629 .02365 L
.36706 .0229 L
.35745 .02308 L
.337 .02635 L
.31479 .03377 L
s
.68521 .40419 m
.67434 .3989 L
.66486 .39519 L
.65668 .39299 L
.65305 .39243 L
.64973 .39221 L
.6467 .39233 L
.64395 .39277 L
.64148 .39352 L
.64034 .39401 L
.6398 .39428 L
.63927 .39457 L
.63731 .39592 L
.63643 .3967 L
.63561 .39755 L
.63414 .39945 L
.63349 .40049 L
.6329 .4016 L
.63189 .40401 L
.63108 .40666 L
.63048 .40953 L
.63008 .41263 L
.63022 .42697 L
.63278 .44394 L
.63719 .46288 L
.64289 .48311 L
.6493 .50395 L
.65588 .52472 L
.66206 .54474 L
.66727 .56335 L
.67095 .57986 L
.67205 .58712 L
.67255 .5936 L
.67239 .59922 L
.67203 .60168 L
.67179 .60282 L
.67149 .60389 L
.67074 .60585 L
.67029 .60672 L
.66979 .60753 L
.66923 .60827 L
.66862 .60894 L
.66795 .60954 L
.66759 .60981 L
.6674 .60993 L
.66722 .61006 L
.66643 .61051 L
.66558 .61088 L
.66467 .61117 L
.66419 .61129 L
Mistroke
.6637 .61138 L
.66156 .61157 L
.6604 .61154 L
.65916 .61142 L
.65355 .61009 L
.64677 .60731 L
.62947 .59704 L
.60671 .57995 L
.57792 .55534 L
.54254 .52255 L
.5 .48091 L
Mfstroke
.5 .48091 m
.49814 .45898 L
.49282 .43689 L
.48445 .41471 L
.47342 .39248 L
.46014 .37028 L
.44502 .34816 L
.42844 .32619 L
.41083 .30442 L
.39256 .28292 L
.37406 .26175 L
.35572 .24096 L
.33794 .22063 L
.32113 .2008 L
.30568 .18155 L
.292 .16292 L
.28049 .14499 L
.27156 .12781 L
.26818 .11952 L
.2656 .11145 L
.26386 .10359 L
.26332 .09975 L
.26301 .09596 L
.26311 .08856 L
.26353 .08495 L
.2642 .08141 L
.26634 .0745 L
.26782 .07114 L
.26957 .06785 L
.27395 .06147 L
.27659 .05837 L
.27953 .05535 L
.28635 .04952 L
.29447 .04397 L
.31479 .03377 L
s
.87042 .48091 m
.85623 .45898 L
.84437 .43689 L
.83461 .41471 L
.82669 .39248 L
.82038 .37028 L
.81543 .34816 L
.81162 .32619 L
.80868 .30442 L
.80639 .28292 L
.8045 .26175 L
.80277 .24096 L
.80096 .22063 L
.79883 .2008 L
.79614 .18155 L
.79264 .16292 L
.7881 .14499 L
.78227 .12781 L
.77492 .11145 L
.7658 .09596 L
.75466 .08141 L
.74128 .06785 L
.7254 .05535 L
.70679 .04397 L
.68521 .03377 L
s
.87042 .48091 m
.85623 .4627 L
.85002 .45618 L
.84437 .45126 L
.84174 .44936 L
.83924 .44783 L
.83686 .44665 L
.83572 .44619 L
.83461 .44582 L
.83246 .44531 L
.83043 .44512 L
.82851 .44523 L
.82758 .4454 L
.82713 .44552 L
.82669 .44565 L
.82497 .44634 L
.82415 .44679 L
.82335 .4473 L
.82182 .44853 L
.82109 .44923 L
.82038 .45 L
.81775 .45364 L
.81543 .45813 L
.81162 .46931 L
.80868 .48277 L
.80639 .49779 L
.8045 .51363 L
.80277 .52952 L
.80096 .54474 L
.79883 .55854 L
.79614 .57018 L
.79451 .57496 L
.79264 .57892 L
.79162 .58056 L
.79052 .58196 L
.78935 .58311 L
.78874 .58359 L
.78842 .58381 L
.7881 .584 L
.78745 .58435 L
.78678 .58462 L
.78608 .58482 L
.78573 .58489 L
.78536 .58495 L
.78463 .585 L
.78387 .58498 L
.78308 .58488 L
.78268 .5848 L
.78248 .58475 L
.78227 .5847 L
Mistroke
.78059 .5841 L
.7788 .58317 L
.77691 .58189 L
.77492 .58026 L
.77059 .57588 L
.7658 .56994 L
.75466 .553 L
.74128 .5287 L
.7254 .4963 L
.70679 .45504 L
.68521 .40419 L
Mfstroke
.68521 .40419 m
.68867 .39775 L
.69137 .39069 L
.69335 .38306 L
.69464 .37487 L
.69534 .35702 L
.69378 .33743 L
.6903 .3164 L
.68521 .29422 L
.67883 .27119 L
.67149 .2476 L
.6635 .22374 L
.6552 .19991 L
.64689 .1764 L
.63891 .1535 L
.63156 .13152 L
.62519 .11073 L
.6201 .09145 L
.61661 .07396 L
.61506 .05855 L
.61511 .05172 L
.61576 .04552 L
.61705 .03999 L
.61795 .03749 L
.61902 .03516 L
.62028 .03303 L
.62172 .03108 L
.62336 .02933 L
.62425 .02853 L
.62519 .02778 L
.62722 .02643 L
.62945 .02529 L
.6319 .02436 L
.63321 .02398 L
.63457 .02365 L
.64056 .0229 L
.64748 .02308 L
.66425 .02635 L
.68521 .03377 L
s
.5 .48091 m
.49953 .4909 L
.49814 .49911 L
.49712 .50258 L
.49589 .50563 L
.49445 .50829 L
.49366 .50947 L
.49324 .51003 L
.49282 .51056 L
.491 .51245 L
.49002 .51326 L
.48899 .51398 L
.4868 .51516 L
.48565 .51562 L
.48445 .516 L
.48192 .51651 L
.47924 .5167 L
.4764 .51658 L
.47493 .51641 L
.47342 .51617 L
.46704 .51451 L
.46014 .51182 L
.44502 .50368 L
.42844 .49251 L
.41083 .47904 L
.39256 .46402 L
.37406 .44819 L
.35572 .43229 L
.33794 .41707 L
.32113 .40327 L
.30568 .39163 L
.292 .3829 L
.28595 .37985 L
.28049 .37781 L
.278 .3772 L
.27568 .37687 L
.27353 .37684 L
.27252 .37694 L
.27203 .37702 L
.27156 .37712 L
.27064 .37738 L
.26977 .37772 L
.26895 .37814 L
.26856 .37838 L
.26818 .37865 L
.26746 .37924 L
.26678 .37993 L
.26616 .3807 L
.26587 .38112 L
.26573 .38133 L
Mistroke
.2656 .38156 L
.26462 .38356 L
.26386 .38594 L
.26332 .3887 L
.26301 .39187 L
.26311 .39947 L
.2642 .40881 L
.26957 .43311 L
.27953 .46552 L
.29447 .50678 L
.31479 .55762 L
Mfstroke
.5 .48091 m
.50186 .50283 L
.50718 .52492 L
.51555 .54711 L
.52658 .56933 L
.53986 .59153 L
.55498 .61365 L
.57156 .63562 L
.58917 .65739 L
.60744 .67889 L
.62594 .70006 L
.64428 .72085 L
.66206 .74119 L
.67887 .76101 L
.69432 .78027 L
.708 .79889 L
.71951 .81683 L
.72844 .834 L
.73182 .84229 L
.7344 .85037 L
.73614 .85822 L
.73668 .86207 L
.73699 .86586 L
.73689 .87325 L
.73647 .87686 L
.7358 .88041 L
.73366 .88731 L
.73218 .89067 L
.73043 .89396 L
.72605 .90035 L
.72341 .90344 L
.72047 .90646 L
.71365 .9123 L
.70553 .91784 L
.68521 .92804 L
s
.68521 .92804 m
.663 .89711 L
.64255 .87204 L
.62371 .85222 L
.60632 .83703 L
.59022 .82585 L
.57524 .81807 L
.56123 .81308 L
.54802 .81025 L
.53545 .80898 L
.52337 .80864 L
.5116 .80862 L
.5 .80831 L
.4884 .80709 L
.47663 .80435 L
.46455 .79946 L
.45198 .79182 L
.43877 .78081 L
.42476 .76581 L
.40978 .74621 L
.39368 .72139 L
.37629 .69074 L
.35745 .65364 L
.337 .60947 L
.31479 .55762 L
s
.94713 .66612 m
.94458 .6439 L
.94323 .62346 L
.94294 .60462 L
.94358 .58723 L
.94502 .57113 L
.94713 .55615 L
.94977 .54213 L
.95282 .52892 L
.95612 .51636 L
.95956 .50427 L
.963 .49251 L
.96631 .48091 L
.96935 .46931 L
.972 .45754 L
.9741 .44546 L
.97555 .43289 L
.97619 .41968 L
.9759 .40567 L
.97455 .39069 L
.972 .37458 L
.96811 .35719 L
.96276 .33836 L
.95581 .31791 L
.94713 .2957 L
s
.94713 .66612 m
.94381 .64577 L
.94025 .63064 L
.9384 .62486 L
.9365 .62018 L
.93455 .61652 L
.93357 .61505 L
.93257 .61381 L
.93157 .6128 L
.93056 .61199 L
.92954 .61139 L
.92903 .61116 L
.92877 .61107 L
.92851 .61099 L
.92748 .61077 L
.92697 .61072 L
.92645 .61072 L
.92541 .61085 L
.92488 .61097 L
.92436 .61113 L
.92331 .61157 L
.92225 .61215 L
.9212 .61286 L
.92014 .61369 L
.91588 .6181 L
.91162 .62379 L
.9074 .63021 L
.90324 .63679 L
.89919 .64297 L
.89526 .64818 L
.89336 .65025 L
.89151 .65186 L
.8906 .65248 L
.8897 .65295 L
.88882 .65328 L
.88838 .65339 L
.88816 .65343 L
.88795 .65346 L
.88752 .65348 L
.88709 .65346 L
.88667 .6534 L
.88646 .65335 L
.88625 .65329 L
.88584 .65314 L
.88543 .65294 L
.88503 .65269 L
.88482 .65255 L
.88462 .6524 L
.88383 .65165 L
.88306 .6507 L
Mistroke
.8823 .64952 L
.88157 .64812 L
.87881 .64007 L
.87638 .62768 L
.87432 .61038 L
.87266 .58762 L
.87144 .55883 L
.87068 .52344 L
.87042 .48091 L
Mfstroke
.87042 .48091 m
.87198 .48079 L
.87348 .48043 L
.87492 .47985 L
.87561 .47948 L
.87629 .47905 L
.87761 .47802 L
.87886 .47679 L
.88006 .47536 L
.88121 .47373 L
.88333 .4699 L
.88525 .46535 L
.88853 .45433 L
.89114 .44105 L
.89319 .42592 L
.89477 .40935 L
.89599 .39173 L
.89694 .37347 L
.89772 .35497 L
.89844 .33663 L
.89919 .31885 L
.90007 .30204 L
.90118 .28659 L
.90263 .27291 L
.90451 .2614 L
.90565 .25659 L
.90693 .25246 L
.90837 .24909 L
.90915 .24769 L
.90956 .24707 L
.90997 .2465 L
.91085 .24552 L
.9113 .24512 L
.91177 .24476 L
.91224 .24447 L
.91273 .24422 L
.91324 .24404 L
.91349 .24397 L
.91362 .24394 L
.91375 .24392 L
.91428 .24385 L
.91482 .24385 L
.91538 .2439 L
.91566 .24395 L
.91595 .24402 L
.91713 .24444 L
.91774 .24474 L
.91836 .24511 L
.92101 .24725 L
.92391 .25048 L
Mistroke
.93048 .26044 L
.93819 .27537 L
.94713 .2957 L
Mfstroke
0 0 m
1 0 L
1 .96182 L
0 .96182 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.261351 0.732558 0.482835 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.493273 0.531249 0.492937 0.531249 [
[ 0 0 0 0 ]
[ 1 .98587 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.03 .18 .33 r
.5 Mabswid
[ ] 0 setdash
.22765 .22731 m
.22661 .2261 L
.22579 .22477 L
.22518 .22333 L
.22495 .22256 L
.22477 .22176 L
.22456 .22009 L
.22454 .2183 L
.22471 .21642 L
.22506 .21443 L
.22628 .21016 L
.22817 .20552 L
.23372 .19526 L
.24137 .18387 L
.25075 .17155 L
.2615 .15853 L
.27326 .14503 L
.28567 .13125 L
.29838 .11742 L
.31102 .10376 L
.32323 .09047 L
.33465 .07778 L
.34493 .0659 L
.3537 .05506 L
.36061 .04545 L
.36324 .04119 L
.36528 .03732 L
.36667 .03386 L
.36711 .0323 L
.36727 .03156 L
.36737 .03086 L
.36745 .02953 L
.36742 .02891 L
.36734 .02832 L
.36721 .02777 L
.36703 .02724 L
.3668 .02675 L
.36666 .02652 L
.36659 .0264 L
.36652 .02629 L
.36619 .02586 L
.3658 .02547 L
.36536 .02511 L
.36512 .02495 L
.36487 .02479 L
.36373 .02424 L
.36307 .02402 L
.36236 .02384 L
.35892 .02347 L
.35453 .02372 L
Mistroke
.34267 .02614 L
.32643 .03132 L
.30545 .03949 L
Mfstroke
.22765 .22731 m
.22644 .22628 L
.22511 .22545 L
.22366 .22484 L
.22289 .22461 L
.2221 .22443 L
.22042 .22422 L
.21864 .22421 L
.21675 .22437 L
.21476 .22473 L
.21049 .22595 L
.20586 .22783 L
.1956 .23338 L
.1842 .24103 L
.17189 .25041 L
.15887 .26116 L
.14536 .27292 L
.13159 .28534 L
.11776 .29804 L
.10409 .31068 L
.09081 .32289 L
.07812 .33432 L
.06624 .3446 L
.05539 .35337 L
.04579 .36027 L
.04153 .36291 L
.03765 .36495 L
.0342 .36634 L
.03264 .36678 L
.0319 .36693 L
.03119 .36704 L
.02986 .36711 L
.02925 .36708 L
.02866 .367 L
.0281 .36687 L
.02758 .36669 L
.02709 .36646 L
.02685 .36633 L
.02674 .36626 L
.02663 .36618 L
.0262 .36585 L
.02581 .36546 L
.02545 .36503 L
.02528 .36479 L
.02512 .36454 L
.02458 .36339 L
.02436 .36273 L
.02418 .36202 L
.02381 .35859 L
.02405 .35419 L
Mistroke
.02648 .34234 L
.03166 .3261 L
.03982 .30511 L
Mfstroke
.03982 .30511 m
.05758 .29101 L
.07321 .27732 L
.08693 .26402 L
.09894 .25109 L
.10945 .23851 L
.11868 .22625 L
.12684 .21431 L
.13413 .20266 L
.14077 .19127 L
.14697 .18014 L
.15293 .16924 L
.15888 .15855 L
.16502 .14805 L
.17156 .13772 L
.17872 .12754 L
.18669 .11749 L
.1957 .10756 L
.20596 .09771 L
.21767 .08794 L
.23105 .07823 L
.24631 .06854 L
.26365 .05887 L
.2833 .04919 L
.30545 .03949 L
s
.22765 .75856 m
.22644 .7596 L
.22511 .76042 L
.22366 .76103 L
.22289 .76126 L
.2221 .76144 L
.22042 .76165 L
.21864 .76167 L
.21675 .7615 L
.21476 .76115 L
.21049 .75993 L
.20586 .75804 L
.1956 .75249 L
.1842 .74484 L
.17189 .73546 L
.15887 .72471 L
.14536 .71295 L
.13159 .70054 L
.11776 .68783 L
.10409 .67519 L
.09081 .66298 L
.07812 .65156 L
.06624 .64128 L
.05539 .63251 L
.04579 .6256 L
.04153 .62297 L
.03765 .62093 L
.0342 .61954 L
.03264 .6191 L
.0319 .61894 L
.03119 .61884 L
.02986 .61876 L
.02925 .61879 L
.02866 .61887 L
.0281 .619 L
.02758 .61918 L
.02709 .61941 L
.02685 .61955 L
.02674 .61962 L
.02663 .61969 L
.0262 .62002 L
.02581 .62041 L
.02545 .62085 L
.02528 .62109 L
.02512 .62134 L
.02458 .62248 L
.02436 .62314 L
.02418 .62385 L
.02381 .62729 L
.02405 .63168 L
Mistroke
.02648 .64354 L
.03166 .65978 L
.03982 .68076 L
Mfstroke
.22765 .75856 m
.22661 .75977 L
.22579 .7611 L
.22518 .76255 L
.22495 .76332 L
.22477 .76411 L
.22456 .76579 L
.22454 .76757 L
.22471 .76946 L
.22506 .77145 L
.22628 .77572 L
.22817 .78035 L
.23372 .79061 L
.24137 .80201 L
.25075 .81432 L
.2615 .82734 L
.27326 .84085 L
.28567 .85462 L
.29838 .86845 L
.31102 .88212 L
.32323 .8954 L
.33465 .90809 L
.34493 .91997 L
.3537 .93082 L
.36061 .94042 L
.36324 .94468 L
.36528 .94856 L
.36667 .95201 L
.36711 .95357 L
.36727 .95431 L
.36737 .95502 L
.36745 .95635 L
.36742 .95696 L
.36734 .95755 L
.36721 .95811 L
.36703 .95863 L
.3668 .95912 L
.36666 .95936 L
.36659 .95947 L
.36652 .95958 L
.36619 .96001 L
.3658 .9604 L
.36536 .96076 L
.36512 .96093 L
.36487 .96109 L
.36373 .96163 L
.36307 .96185 L
.36236 .96203 L
.35892 .9624 L
.35453 .96216 L
Mistroke
.34267 .95973 L
.32643 .95455 L
.30545 .94639 L
Mfstroke
.30545 .94639 m
.29135 .92863 L
.27766 .913 L
.26436 .89928 L
.25143 .88727 L
.23884 .87676 L
.22659 .86753 L
.21465 .85937 L
.20299 .85208 L
.19161 .84544 L
.18048 .83924 L
.16957 .83328 L
.15888 .82733 L
.14838 .82119 L
.13805 .81465 L
.12787 .80749 L
.11783 .79952 L
.10789 .79051 L
.09805 .78025 L
.08828 .76854 L
.07856 .75516 L
.06888 .7399 L
.05921 .72256 L
.04953 .70291 L
.03982 .68076 L
s
.6811 .41514 m
.66649 .41611 L
.65261 .41584 L
.63942 .41438 L
.6269 .41182 L
.60369 .40362 L
.58273 .39178 L
.56375 .37685 L
.54648 .35938 L
.53066 .33989 L
.51604 .31894 L
.50233 .29707 L
.48928 .27481 L
.47662 .25272 L
.4641 .23134 L
.45144 .2112 L
.43838 .19286 L
.42465 .17685 L
.41746 .16989 L
.41 .16371 L
.40224 .1584 L
.39824 .15608 L
.39416 .154 L
.3857 .15059 L
.38133 .14928 L
.37685 .14825 L
.36757 .14702 L
.36276 .14686 L
.35783 .147 L
.34759 .14823 L
.33682 .1508 L
.31356 .16018 L
.28779 .1757 L
.25924 .1979 L
.22765 .22731 L
s
.6811 .41514 m
.66697 .41727 L
.6545 .4204 L
.6436 .42446 L
.63871 .42682 L
.63418 .4294 L
.62616 .43516 L
.62266 .43834 L
.61947 .4417 L
.614 .44895 L
.6117 .45283 L
.60969 .45686 L
.60644 .46538 L
.60417 .47444 L
.60224 .49399 L
.60323 .51508 L
.60647 .53727 L
.61128 .5601 L
.617 .58315 L
.62294 .60597 L
.62845 .62811 L
.63284 .64914 L
.63544 .66862 L
.63586 .67763 L
.63559 .68609 L
.63453 .69395 L
.63368 .69763 L
.63261 .70114 L
.63129 .70446 L
.62973 .70761 L
.62791 .71055 L
.6269 .71195 L
.62583 .7133 L
.62346 .71584 L
.6208 .71816 L
.61784 .72027 L
.61624 .72123 L
.61457 .72214 L
.60705 .72518 L
.60279 .72633 L
.59817 .72723 L
.58783 .72822 L
.57595 .7281 L
.54725 .72434 L
.51138 .71549 L
.46768 .70111 L
.41547 .68076 L
s
.41547 .68076 m
.41645 .66616 L
.41617 .65227 L
.41472 .63909 L
.41215 .62656 L
.40395 .60335 L
.39212 .58239 L
.37719 .56341 L
.35971 .54614 L
.34023 .53033 L
.31928 .5157 L
.2974 .50199 L
.27515 .48894 L
.25306 .47629 L
.23168 .46376 L
.21154 .4511 L
.1932 .43804 L
.17719 .42432 L
.17023 .41712 L
.16405 .40966 L
.15873 .40191 L
.15641 .39791 L
.15434 .39382 L
.15093 .38537 L
.14962 .38099 L
.14858 .37652 L
.14736 .36724 L
.14719 .36243 L
.14733 .35749 L
.14857 .34726 L
.15113 .33649 L
.16052 .31323 L
.17604 .28746 L
.19824 .25891 L
.22765 .22731 L
s
.86892 .49294 m
.85453 .4707 L
.84251 .4483 L
.83261 .4258 L
.82458 .40326 L
.81818 .38075 L
.81316 .35832 L
.80929 .33604 L
.80631 .31396 L
.80399 .29216 L
.80208 .27068 L
.80032 .2496 L
.79849 .22898 L
.79633 .20887 L
.7936 .18935 L
.79005 .17046 L
.78545 .15227 L
.77954 .13485 L
.77208 .11826 L
.76282 .10255 L
.75153 .08779 L
.73796 .07405 L
.72186 .06137 L
.70299 .04983 L
.6811 .03949 L
s
.86892 .49294 m
.85453 .47448 L
.84824 .46786 L
.84251 .46287 L
.83984 .46094 L
.83731 .45939 L
.8349 .4582 L
.83374 .45773 L
.83261 .45735 L
.83043 .45684 L
.82837 .45664 L
.82642 .45676 L
.82549 .45693 L
.82503 .45704 L
.82458 .45718 L
.82283 .45788 L
.822 .45833 L
.82119 .45886 L
.81964 .4601 L
.8189 .46081 L
.81818 .46159 L
.81551 .46528 L
.81316 .46984 L
.80929 .48117 L
.80631 .49483 L
.80399 .51006 L
.80208 .52612 L
.80032 .54224 L
.79849 .55767 L
.79633 .57167 L
.7936 .58347 L
.79194 .58832 L
.79005 .59233 L
.78901 .594 L
.7879 .59542 L
.78671 .59659 L
.78609 .59707 L
.78577 .59729 L
.78545 .59749 L
.78478 .59784 L
.7841 .59811 L
.7834 .59832 L
.78303 .59839 L
.78267 .59844 L
.78192 .5985 L
.78115 .59848 L
.78035 .59837 L
.77995 .59829 L
.77974 .59825 L
.77954 .59819 L
Mistroke
.77783 .59758 L
.77601 .59664 L
.7741 .59535 L
.77208 .59369 L
.76769 .58925 L
.76282 .58323 L
.75153 .56605 L
.73796 .54141 L
.72186 .50854 L
.70299 .4667 L
.6811 .41514 L
Mfstroke
.6811 .41514 m
.68461 .40861 L
.68735 .40145 L
.68935 .3937 L
.69066 .3854 L
.69137 .3673 L
.68979 .34744 L
.68626 .32611 L
.6811 .30362 L
.67463 .28026 L
.66719 .25633 L
.65909 .23214 L
.65066 .20797 L
.64224 .18412 L
.63414 .16091 L
.6267 .13861 L
.62023 .11753 L
.61507 .09798 L
.61153 .08024 L
.60996 .06461 L
.61 .05768 L
.61066 .0514 L
.61197 .04579 L
.61289 .04325 L
.61398 .0409 L
.61525 .03873 L
.61672 .03676 L
.61837 .03498 L
.61928 .03417 L
.62023 .0334 L
.62229 .03204 L
.62456 .03088 L
.62704 .02994 L
.62836 .02955 L
.62974 .02922 L
.63582 .02846 L
.64284 .02864 L
.65985 .03196 L
.6811 .03949 L
s
.41547 .68076 m
.41612 .6842 L
.41645 .68738 L
.41646 .6903 L
.41636 .69167 L
.41617 .69297 L
.41559 .6954 L
.41519 .69652 L
.41472 .69758 L
.41357 .69954 L
.4129 .70043 L
.41253 .70086 L
.41215 .70127 L
.41047 .70278 L
.40954 .70346 L
.40854 .70408 L
.40637 .70518 L
.40519 .70565 L
.40395 .70608 L
.39846 .70731 L
.39212 .70783 L
.37719 .70694 L
.35971 .70386 L
.34023 .699 L
.31928 .69278 L
.2974 .68565 L
.27515 .67802 L
.25306 .67032 L
.23168 .66298 L
.21154 .65643 L
.1932 .65109 L
.17719 .6474 L
.17023 .6463 L
.16405 .64577 L
.15873 .64587 L
.15641 .64617 L
.15534 .64639 L
.15434 .64665 L
.15251 .6473 L
.15169 .6477 L
.15093 .64815 L
.15024 .64865 L
.14962 .6492 L
.14907 .64979 L
.14882 .65011 L
.1487 .65028 L
.14858 .65044 L
.14817 .65114 L
.14783 .6519 L
.14756 .65271 L
Mistroke
.14745 .65313 L
.14736 .65357 L
.14719 .65547 L
.14722 .6565 L
.14733 .65759 L
.14857 .66255 L
.15113 .66852 L
.16052 .68365 L
.17604 .70342 L
.19824 .72825 L
.22765 .75856 L
Mfstroke
.41547 .68076 m
.41761 .68786 L
.42073 .69486 L
.42479 .70176 L
.42973 .70855 L
.44204 .72185 L
.4572 .73478 L
.47478 .74737 L
.49433 .75962 L
.51542 .77156 L
.5376 .78322 L
.56044 .7946 L
.58349 .80573 L
.6063 .81664 L
.62845 .82733 L
.64948 .83783 L
.66895 .84816 L
.68643 .85834 L
.70147 .86838 L
.71364 .87832 L
.7185 .88325 L
.72248 .88816 L
.72552 .89305 L
.72667 .89549 L
.72756 .89793 L
.72819 .90036 L
.72855 .90279 L
.72864 .90522 L
.72858 .90643 L
.72844 .90765 L
.72795 .91007 L
.72717 .91249 L
.72608 .91491 L
.72541 .91612 L
.72467 .91733 L
.72091 .92217 L
.71582 .927 L
.70144 .93668 L
.6811 .94639 L
s
.6811 .94639 m
.65261 .92941 L
.6269 .91601 L
.60369 .90581 L
.58273 .89844 L
.56375 .8935 L
.54648 .89063 L
.53066 .88943 L
.51604 .88954 L
.50233 .89057 L
.48928 .89215 L
.47662 .89388 L
.4641 .8954 L
.45144 .89633 L
.43838 .89627 L
.42465 .89487 L
.41 .89172 L
.39416 .88647 L
.37685 .87871 L
.35783 .86809 L
.33682 .85421 L
.31356 .8367 L
.28779 .81517 L
.25924 .78925 L
.22765 .75856 L
s
.94672 .68076 m
.94413 .65823 L
.94276 .6375 L
.94247 .6184 L
.94312 .60076 L
.94458 .58443 L
.94672 .56924 L
.9494 .55503 L
.95249 .54163 L
.95584 .52889 L
.95933 .51663 L
.96282 .5047 L
.96617 .49294 L
.96926 .48117 L
.97194 .46924 L
.97407 .45699 L
.97554 .44424 L
.97619 .43084 L
.9759 .41663 L
.97452 .40144 L
.97194 .38511 L
.968 .36748 L
.96257 .34837 L
.95552 .32764 L
.94672 .30511 L
s
.94672 .68076 m
.94335 .66012 L
.93974 .64478 L
.93786 .63892 L
.93593 .63417 L
.93396 .63046 L
.93296 .62897 L
.93196 .62772 L
.93094 .62669 L
.92991 .62587 L
.92888 .62526 L
.92836 .62503 L
.9281 .62494 L
.92784 .62485 L
.9268 .62463 L
.92627 .62459 L
.92574 .62459 L
.92469 .62471 L
.92416 .62484 L
.92363 .625 L
.92256 .62544 L
.92149 .62603 L
.92042 .62675 L
.91934 .6276 L
.91503 .63207 L
.91071 .63784 L
.90643 .64435 L
.90221 .65102 L
.8981 .65728 L
.89412 .66257 L
.89219 .66467 L
.89031 .66631 L
.88939 .66693 L
.88848 .66741 L
.88758 .66775 L
.88714 .66786 L
.88692 .66789 L
.8867 .66792 L
.88627 .66795 L
.88584 .66793 L
.88541 .66787 L
.8852 .66782 L
.88498 .66776 L
.88456 .6676 L
.88415 .6674 L
.88374 .66715 L
.88353 .66701 L
.88333 .66685 L
.88253 .66609 L
.88174 .66513 L
Mistroke
.88098 .66394 L
.88023 .66251 L
.87743 .65435 L
.87497 .64178 L
.87289 .62424 L
.8712 .60116 L
.86996 .57196 L
.86919 .53608 L
.86892 .49294 L
Mfstroke
.86892 .49294 m
.87051 .49282 L
.87203 .49246 L
.87349 .49186 L
.87419 .49148 L
.87488 .49105 L
.87622 .49001 L
.87749 .48876 L
.8787 .48731 L
.87986 .48565 L
.88202 .48177 L
.88397 .47716 L
.88729 .46598 L
.88994 .45252 L
.89202 .43718 L
.89362 .42037 L
.89486 .4025 L
.89582 .38398 L
.89661 .36522 L
.89734 .34662 L
.8981 .32859 L
.89899 .31154 L
.90012 .29587 L
.90159 .282 L
.9035 .27033 L
.90465 .26545 L
.90595 .26127 L
.90741 .25784 L
.9082 .25643 L
.90861 .2558 L
.90904 .25522 L
.90992 .25423 L
.91038 .25381 L
.91086 .25346 L
.91134 .25315 L
.91184 .25291 L
.91235 .25273 L
.91261 .25265 L
.91274 .25262 L
.91287 .2526 L
.91341 .25253 L
.91396 .25253 L
.91452 .25258 L
.91481 .25263 L
.9151 .2527 L
.91629 .25312 L
.91691 .25343 L
.91755 .25381 L
.92023 .25598 L
.92317 .25926 L
Mistroke
.92984 .26935 L
.93766 .2845 L
.94672 .30511 L
Mfstroke
0 0 m
1 0 L
1 .98587 L
0 .98587 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.261351 0.97619 0.482835 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.493273 0.531249 0.506727 0.531249 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.03 .18 .33 r
.5 Mabswid
[ ] 0 setdash
.49327 .13108 m
.49339 .12949 L
.49375 .12797 L
.49435 .12651 L
.49473 .12581 L
.49516 .12512 L
.4962 .12378 L
.49745 .12251 L
.4989 .1213 L
.50056 .12014 L
.50444 .11798 L
.50905 .11603 L
.52023 .11271 L
.53369 .11006 L
.54903 .10798 L
.56584 .10638 L
.58371 .10514 L
.60223 .10418 L
.62099 .10339 L
.63959 .10266 L
.65762 .1019 L
.67467 .10101 L
.69034 .09988 L
.70421 .09841 L
.71588 .0965 L
.72076 .09535 L
.72494 .09405 L
.72837 .09259 L
.72978 .0918 L
.73041 .09139 L
.73099 .09096 L
.73198 .09008 L
.7324 .08962 L
.73275 .08914 L
.73306 .08866 L
.7333 .08816 L
.73348 .08765 L
.73356 .08739 L
.73359 .08726 L
.73361 .08713 L
.73368 .08659 L
.73368 .08604 L
.73363 .08548 L
.73358 .08519 L
.73351 .0849 L
.73309 .08371 L
.73278 .08309 L
.7324 .08245 L
.73023 .07977 L
.72695 .07683 L
Mistroke
.71686 .07016 L
.70171 .06234 L
.6811 .05328 L
Mfstroke
.49327 .13108 m
.49315 .12949 L
.49279 .12797 L
.4922 .12651 L
.49182 .12581 L
.49138 .12512 L
.49035 .12378 L
.4891 .12251 L
.48765 .1213 L
.48599 .12014 L
.48211 .11798 L
.4775 .11603 L
.46632 .11271 L
.45285 .11006 L
.43751 .10798 L
.42071 .10638 L
.40284 .10514 L
.38432 .10418 L
.36556 .10339 L
.34696 .10266 L
.32893 .1019 L
.31187 .10101 L
.29621 .09988 L
.28234 .09841 L
.27067 .0965 L
.26578 .09535 L
.2616 .09405 L
.25818 .09259 L
.25676 .0918 L
.25613 .09139 L
.25556 .09096 L
.25456 .09008 L
.25415 .08962 L
.25379 .08914 L
.25349 .08866 L
.25325 .08816 L
.25306 .08765 L
.25299 .08739 L
.25296 .08726 L
.25293 .08713 L
.25287 .08659 L
.25286 .08604 L
.25292 .08548 L
.25297 .08519 L
.25304 .0849 L
.25346 .08371 L
.25377 .08309 L
.25414 .08245 L
.25631 .07977 L
.25959 .07683 L
Mistroke
.26969 .07016 L
.28484 .06234 L
.30545 .05328 L
Mfstroke
.30545 .05328 m
.32798 .05587 L
.34871 .05724 L
.36781 .05753 L
.38545 .05688 L
.40178 .05542 L
.41697 .05328 L
.43118 .0506 L
.44458 .04751 L
.45732 .04416 L
.46958 .04067 L
.48151 .03718 L
.49327 .03383 L
.50504 .03074 L
.51697 .02806 L
.52922 .02593 L
.54197 .02446 L
.55537 .02381 L
.56958 .0241 L
.58477 .02548 L
.6011 .02806 L
.61873 .032 L
.63784 .03743 L
.65857 .04448 L
.6811 .05328 L
s
.22765 .77235 m
.22644 .77339 L
.22511 .77421 L
.22366 .77482 L
.22289 .77505 L
.2221 .77523 L
.22042 .77544 L
.21864 .77546 L
.21675 .77529 L
.21476 .77494 L
.21049 .77372 L
.20586 .77183 L
.1956 .76628 L
.1842 .75863 L
.17189 .74925 L
.15887 .7385 L
.14536 .72674 L
.13159 .71433 L
.11776 .70162 L
.10409 .68898 L
.09081 .67677 L
.07812 .66535 L
.06624 .65507 L
.05539 .6463 L
.04579 .63939 L
.04153 .63676 L
.03765 .63472 L
.0342 .63333 L
.03264 .63289 L
.0319 .63273 L
.03119 .63263 L
.02986 .63255 L
.02925 .63258 L
.02866 .63266 L
.0281 .63279 L
.02758 .63297 L
.02709 .6332 L
.02685 .63334 L
.02674 .63341 L
.02663 .63348 L
.0262 .63381 L
.02581 .6342 L
.02545 .63464 L
.02528 .63488 L
.02512 .63513 L
.02458 .63627 L
.02436 .63693 L
.02418 .63764 L
.02381 .64108 L
.02405 .64547 L
Mistroke
.02648 .65733 L
.03166 .67357 L
.03982 .69455 L
Mfstroke
.22765 .77235 m
.22661 .77356 L
.22579 .77489 L
.22518 .77634 L
.22495 .77711 L
.22477 .7779 L
.22456 .77958 L
.22454 .78136 L
.22471 .78325 L
.22506 .78524 L
.22628 .78951 L
.22817 .79414 L
.23372 .8044 L
.24137 .8158 L
.25075 .82811 L
.2615 .84113 L
.27326 .85464 L
.28567 .86841 L
.29838 .88224 L
.31102 .89591 L
.32323 .90919 L
.33465 .92188 L
.34493 .93376 L
.3537 .94461 L
.36061 .95421 L
.36324 .95847 L
.36528 .96235 L
.36667 .9658 L
.36711 .96736 L
.36727 .9681 L
.36737 .96881 L
.36745 .97014 L
.36742 .97075 L
.36734 .97134 L
.36721 .9719 L
.36703 .97242 L
.3668 .97291 L
.36666 .97315 L
.36659 .97326 L
.36652 .97337 L
.36619 .9738 L
.3658 .97419 L
.36536 .97455 L
.36512 .97472 L
.36487 .97488 L
.36373 .97542 L
.36307 .97564 L
.36236 .97582 L
.35892 .97619 L
.35453 .97595 L
Mistroke
.34267 .97352 L
.32643 .96834 L
.30545 .96018 L
Mfstroke
.30545 .96018 m
.29135 .94242 L
.27766 .92679 L
.26436 .91307 L
.25143 .90106 L
.23884 .89055 L
.22659 .88132 L
.21465 .87316 L
.20299 .86587 L
.19161 .85923 L
.18048 .85303 L
.16957 .84707 L
.15888 .84112 L
.14838 .83498 L
.13805 .82844 L
.12787 .82128 L
.11783 .81331 L
.10789 .8043 L
.09805 .79404 L
.08828 .78233 L
.07856 .76895 L
.06888 .75369 L
.05921 .73635 L
.04953 .7167 L
.03982 .69455 L
s
.49327 .50673 m
.47104 .50484 L
.44864 .49944 L
.42614 .49095 L
.4036 .47977 L
.38109 .46631 L
.35866 .45097 L
.33637 .43416 L
.3143 .41629 L
.29249 .39777 L
.27102 .37901 L
.24994 .36041 L
.22932 .34238 L
.20921 .32533 L
.18968 .30966 L
.1708 .29579 L
.15261 .28412 L
.13519 .27506 L
.12678 .27163 L
.11859 .26901 L
.11063 .26725 L
.10673 .2667 L
.10289 .26639 L
.09539 .26649 L
.09173 .26691 L
.08813 .2676 L
.08112 .26977 L
.07772 .27126 L
.07438 .27305 L
.06791 .27749 L
.06477 .28016 L
.06171 .28314 L
.05579 .29006 L
.05017 .29829 L
.03982 .3189 L
s
.49327 .50673 m
.48314 .50721 L
.47481 .50862 L
.4713 .50965 L
.4682 .5109 L
.4655 .51235 L
.4643 .51316 L
.46374 .51358 L
.4632 .51401 L
.46128 .51586 L
.46046 .51685 L
.45973 .51789 L
.45854 .52011 L
.45807 .52128 L
.45769 .5225 L
.45717 .52506 L
.45698 .52778 L
.4571 .53066 L
.45727 .53215 L
.45751 .53368 L
.45919 .54016 L
.46193 .54715 L
.47018 .56249 L
.48151 .57929 L
.49517 .59716 L
.5104 .61568 L
.52645 .63444 L
.54257 .65304 L
.55801 .67107 L
.57201 .68813 L
.58381 .70379 L
.59267 .71766 L
.59576 .7238 L
.59783 .72933 L
.59845 .73186 L
.59878 .73422 L
.59881 .7364 L
.59871 .73742 L
.59863 .73791 L
.59853 .7384 L
.59827 .73933 L
.59792 .74021 L
.59749 .74104 L
.59724 .74144 L
.59698 .74182 L
.59637 .74255 L
.59568 .74324 L
.5949 .74387 L
.59447 .74416 L
.59425 .7443 L
Mistroke
.59403 .74444 L
.592 .74544 L
.58959 .74621 L
.58678 .74675 L
.58356 .74707 L
.57586 .74696 L
.56639 .74586 L
.54174 .74041 L
.50888 .73031 L
.46704 .71516 L
.41547 .69455 L
Mfstroke
.41547 .69455 m
.40179 .67202 L
.38574 .65129 L
.36764 .63219 L
.34777 .61455 L
.32644 .59822 L
.30395 .58303 L
.28059 .56882 L
.25667 .55542 L
.23247 .54268 L
.2083 .53042 L
.18446 .51849 L
.16124 .50673 L
.13895 .49496 L
.11787 .48303 L
.09831 .47078 L
.08057 .45803 L
.06495 .44463 L
.05174 .43042 L
.04613 .42296 L
.04123 .41523 L
.03709 .40722 L
.03374 .3989 L
.03122 .39026 L
.02956 .38127 L
.0288 .37191 L
.02898 .36216 L
.0323 .34143 L
.03982 .3189 L
s
.86892 .50673 m
.84015 .49045 L
.8161 .47303 L
.79629 .45463 L
.78023 .43542 L
.76743 .41556 L
.7574 .39521 L
.74966 .37453 L
.74371 .35368 L
.73906 .33284 L
.73523 .31216 L
.73172 .29181 L
.72805 .27195 L
.72373 .25273 L
.71827 .23434 L
.71118 .21692 L
.70197 .20064 L
.69015 .18567 L
.67523 .17216 L
.65672 .16029 L
.63414 .15021 L
.607 .14208 L
.57479 .13608 L
.53705 .13235 L
.49327 .13108 L
s
.86892 .50673 m
.84015 .49423 L
.82756 .49022 L
.8161 .4876 L
.80569 .48628 L
.80087 .48608 L
.79629 .48618 L
.78782 .48723 L
.78392 .48816 L
.78023 .48934 L
.77345 .49242 L
.77035 .4943 L
.76743 .4964 L
.7621 .5012 L
.7574 .50673 L
.74966 .51966 L
.74371 .53455 L
.73906 .55075 L
.73523 .5676 L
.73172 .58444 L
.72805 .60064 L
.72373 .61553 L
.72118 .62228 L
.71827 .62847 L
.71496 .634 L
.71313 .63649 L
.71118 .63879 L
.70909 .64089 L
.70687 .64277 L
.7045 .64443 L
.70325 .64517 L
.70197 .64586 L
.69928 .64704 L
.69641 .64796 L
.69337 .64862 L
.69178 .64885 L
.69015 .64901 L
.68311 .64891 L
.67928 .64841 L
.67523 .6476 L
.66645 .64497 L
.65672 .64097 L
.63414 .62847 L
.607 .60944 L
.57479 .58325 L
.53705 .54923 L
.49327 .50673 L
s
.49327 .50673 m
.5003 .49874 L
.50577 .49045 L
.50978 .48187 L
.51126 .47748 L
.5124 .47303 L
.51372 .46395 L
.51382 .45463 L
.51277 .44512 L
.51066 .43542 L
.50758 .42556 L
.5036 .41556 L
.49327 .39521 L
.48034 .37453 L
.46545 .35368 L
.44925 .33284 L
.4324 .31216 L
.41556 .29181 L
.39936 .27195 L
.38447 .25273 L
.37153 .23434 L
.36121 .21692 L
.35723 .20863 L
.35414 .20064 L
.35204 .19298 L
.35138 .18928 L
.35099 .18567 L
.35089 .18215 L
.35109 .17872 L
.35159 .17539 L
.35196 .17377 L
.3524 .17216 L
.35355 .16904 L
.35503 .16601 L
.35685 .1631 L
.3579 .16168 L
.35903 .16029 L
.36451 .15501 L
.36782 .15255 L
.37153 .15021 L
.38019 .14589 L
.39056 .14208 L
.41675 .13608 L
.45077 .13235 L
.49327 .13108 L
s
.41547 .69455 m
.41612 .69799 L
.41645 .70117 L
.41646 .70409 L
.41636 .70546 L
.41617 .70676 L
.41559 .70919 L
.41519 .71031 L
.41472 .71137 L
.41357 .71333 L
.4129 .71422 L
.41253 .71465 L
.41215 .71506 L
.41047 .71657 L
.40954 .71725 L
.40854 .71787 L
.40637 .71897 L
.40519 .71944 L
.40395 .71987 L
.39846 .7211 L
.39212 .72162 L
.37719 .72074 L
.35971 .71765 L
.34023 .71279 L
.31928 .70657 L
.2974 .69944 L
.27515 .69181 L
.25306 .68411 L
.23168 .67677 L
.21154 .67022 L
.1932 .66488 L
.17719 .66119 L
.17023 .66009 L
.16405 .65956 L
.15873 .65966 L
.15641 .65996 L
.15534 .66018 L
.15434 .66044 L
.15251 .66109 L
.15169 .66149 L
.15093 .66194 L
.15024 .66244 L
.14962 .66299 L
.14907 .66358 L
.14882 .6639 L
.1487 .66407 L
.14858 .66423 L
.14817 .66493 L
.14783 .66569 L
.14756 .6665 L
Mistroke
.14745 .66692 L
.14736 .66736 L
.14719 .66926 L
.14722 .67029 L
.14733 .67138 L
.14857 .67635 L
.15113 .68231 L
.16052 .69744 L
.17604 .71721 L
.19824 .74204 L
.22765 .77235 L
Mfstroke
.41547 .69455 m
.41761 .70165 L
.42073 .70865 L
.42479 .71555 L
.42973 .72234 L
.44204 .73564 L
.4572 .74857 L
.47478 .76116 L
.49433 .77341 L
.51542 .78535 L
.5376 .79701 L
.56044 .80839 L
.58349 .81952 L
.6063 .83043 L
.62845 .84112 L
.64948 .85162 L
.66895 .86195 L
.68643 .87213 L
.70147 .88217 L
.71364 .89211 L
.7185 .89704 L
.72248 .90195 L
.72552 .90684 L
.72667 .90928 L
.72756 .91172 L
.72819 .91415 L
.72855 .91658 L
.72864 .91901 L
.72858 .92022 L
.72844 .92144 L
.72795 .92386 L
.72717 .92628 L
.72608 .9287 L
.72541 .92991 L
.72467 .93112 L
.72091 .93596 L
.71582 .94079 L
.70144 .95047 L
.6811 .96018 L
s
.6811 .96018 m
.65261 .9432 L
.6269 .9298 L
.60369 .9196 L
.58273 .91223 L
.56375 .90729 L
.54648 .90442 L
.53066 .90322 L
.51604 .90333 L
.50233 .90436 L
.48928 .90594 L
.47662 .90767 L
.4641 .90919 L
.45144 .91012 L
.43838 .91006 L
.42465 .90866 L
.41 .90551 L
.39416 .90026 L
.37685 .8925 L
.35783 .88188 L
.33682 .868 L
.31356 .85049 L
.28779 .82896 L
.25924 .80304 L
.22765 .77235 L
s
.94672 .69455 m
.94413 .67202 L
.94276 .65129 L
.94247 .63219 L
.94312 .61455 L
.94458 .59822 L
.94672 .58303 L
.9494 .56882 L
.95249 .55542 L
.95584 .54268 L
.95933 .53042 L
.96282 .51849 L
.96617 .50673 L
.96926 .49496 L
.97194 .48303 L
.97407 .47078 L
.97554 .45803 L
.97619 .44463 L
.9759 .43042 L
.97452 .41523 L
.97194 .3989 L
.968 .38127 L
.96257 .36216 L
.95552 .34143 L
.94672 .3189 L
s
.94672 .69455 m
.94335 .67391 L
.93974 .65857 L
.93786 .65271 L
.93593 .64796 L
.93396 .64425 L
.93296 .64276 L
.93196 .64151 L
.93094 .64048 L
.92991 .63966 L
.92888 .63905 L
.92836 .63882 L
.9281 .63873 L
.92784 .63864 L
.9268 .63842 L
.92627 .63838 L
.92574 .63838 L
.92469 .6385 L
.92416 .63863 L
.92363 .63879 L
.92256 .63923 L
.92149 .63982 L
.92042 .64054 L
.91934 .64139 L
.91503 .64586 L
.91071 .65163 L
.90643 .65814 L
.90221 .66481 L
.8981 .67107 L
.89412 .67636 L
.89219 .67846 L
.89031 .6801 L
.88939 .68072 L
.88848 .6812 L
.88758 .68154 L
.88714 .68165 L
.88692 .68168 L
.8867 .68171 L
.88627 .68174 L
.88584 .68172 L
.88541 .68166 L
.8852 .68161 L
.88498 .68155 L
.88456 .68139 L
.88415 .68119 L
.88374 .68094 L
.88353 .6808 L
.88333 .68064 L
.88253 .67988 L
.88174 .67892 L
Mistroke
.88098 .67773 L
.88023 .6763 L
.87743 .66814 L
.87497 .65557 L
.87289 .63803 L
.8712 .61495 L
.86996 .58575 L
.86919 .54987 L
.86892 .50673 L
Mfstroke
.86892 .50673 m
.87051 .50661 L
.87203 .50625 L
.87349 .50565 L
.87419 .50527 L
.87488 .50484 L
.87622 .5038 L
.87749 .50255 L
.8787 .5011 L
.87986 .49944 L
.88202 .49556 L
.88397 .49095 L
.88729 .47977 L
.88994 .46631 L
.89202 .45097 L
.89362 .43416 L
.89486 .41629 L
.89582 .39777 L
.89661 .37901 L
.89734 .36041 L
.8981 .34238 L
.89899 .32533 L
.90012 .30966 L
.90159 .29579 L
.9035 .28412 L
.90465 .27924 L
.90595 .27506 L
.90741 .27163 L
.9082 .27022 L
.90861 .26959 L
.90904 .26901 L
.90992 .26802 L
.91038 .2676 L
.91086 .26725 L
.91134 .26694 L
.91184 .2667 L
.91235 .26652 L
.91261 .26644 L
.91274 .26641 L
.91287 .26639 L
.91341 .26632 L
.91396 .26632 L
.91452 .26637 L
.91481 .26642 L
.9151 .26649 L
.91629 .26691 L
.91691 .26722 L
.91755 .2676 L
.92023 .26977 L
.92317 .27305 L
Mistroke
.92984 .28314 L
.93766 .29829 L
.94672 .3189 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.504983 0.245293 0.726467 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.490731 0.534046 0.490731 0.534046 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.03 .18 .33 r
.5 Mabswid
[ ] 0 setdash
.49073 .49073 m
.46838 .48883 L
.44586 .48341 L
.42324 .47487 L
.40059 .46363 L
.37795 .4501 L
.3554 .43468 L
.333 .41778 L
.31081 .39982 L
.28889 .3812 L
.26731 .36234 L
.24612 .34364 L
.22539 .32552 L
.20517 .30838 L
.18554 .29263 L
.16656 .27868 L
.14828 .26695 L
.13076 .25784 L
.12231 .2544 L
.11408 .25176 L
.10607 .24999 L
.10215 .24944 L
.09829 .24913 L
.09075 .24923 L
.08707 .24966 L
.08345 .25034 L
.07641 .25252 L
.07299 .25403 L
.06963 .25582 L
.06313 .26029 L
.05997 .26297 L
.05689 .26597 L
.05095 .27292 L
.04529 .2812 L
.03489 .30192 L
s
.49073 .49073 m
.48054 .49121 L
.47217 .49263 L
.46864 .49367 L
.46553 .49493 L
.46282 .49639 L
.46161 .4972 L
.46104 .49762 L
.4605 .49805 L
.45857 .49991 L
.45775 .50091 L
.45701 .50196 L
.45581 .50419 L
.45534 .50537 L
.45496 .50659 L
.45444 .50916 L
.45425 .5119 L
.45436 .51479 L
.45454 .51629 L
.45478 .51783 L
.45647 .52434 L
.45922 .53137 L
.46751 .54679 L
.4789 .56368 L
.49263 .58164 L
.50795 .60026 L
.52409 .61912 L
.54029 .63782 L
.55581 .65594 L
.56988 .67308 L
.58175 .68883 L
.59065 .70278 L
.59375 .70895 L
.59583 .71451 L
.59646 .71705 L
.59679 .71942 L
.59683 .72161 L
.59672 .72264 L
.59664 .72314 L
.59654 .72362 L
.59628 .72455 L
.59593 .72544 L
.5955 .72628 L
.59525 .72668 L
.59498 .72706 L
.59437 .7278 L
.59368 .72849 L
.59289 .72912 L
.59247 .72942 L
.59224 .72956 L
Mistroke
.59202 .7297 L
.58998 .7307 L
.58755 .73147 L
.58473 .73202 L
.5815 .73233 L
.57375 .73223 L
.56423 .73112 L
.53946 .72564 L
.50642 .71549 L
.46436 .70026 L
.41252 .67955 L
Mfstroke
.41252 .67955 m
.39876 .6569 L
.38263 .63606 L
.36443 .61685 L
.34446 .59912 L
.32302 .58271 L
.30041 .56744 L
.27693 .55315 L
.25288 .53968 L
.22856 .52687 L
.20426 .51455 L
.18029 .50256 L
.15695 .49073 L
.13454 .4789 L
.11335 .46691 L
.09369 .45459 L
.07586 .44178 L
.06015 .42831 L
.04687 .41403 L
.04123 .40652 L
.03631 .39876 L
.03215 .3907 L
.02878 .38234 L
.02624 .37365 L
.02457 .36461 L
.02381 .3552 L
.02399 .34541 L
.02733 .32456 L
.03489 .30192 L
s
.67955 .41252 m
.6569 .39876 L
.63606 .38263 L
.61685 .36443 L
.59912 .34446 L
.58271 .32302 L
.56744 .30041 L
.55315 .27693 L
.53968 .25288 L
.52687 .22856 L
.51455 .20426 L
.50256 .18029 L
.49073 .15695 L
.4789 .13454 L
.46691 .11335 L
.45459 .09369 L
.44178 .07586 L
.42831 .06015 L
.41403 .04687 L
.40652 .04123 L
.39876 .03631 L
.3907 .03215 L
.38234 .02878 L
.37365 .02624 L
.36461 .02457 L
.3552 .02381 L
.34541 .02399 L
.32456 .02733 L
.30192 .03489 L
s
.67955 .41252 m
.66847 .40712 L
.6588 .40335 L
.65046 .4011 L
.64676 .40053 L
.64338 .40031 L
.64029 .40043 L
.63749 .40087 L
.63496 .40164 L
.6338 .40214 L
.63325 .40242 L
.63271 .40272 L
.63072 .40409 L
.62982 .40488 L
.62898 .40575 L
.62748 .40768 L
.62682 .40875 L
.62622 .40988 L
.62519 .41234 L
.62437 .41504 L
.62375 .41797 L
.62334 .42112 L
.62349 .43574 L
.6261 .45305 L
.63059 .47236 L
.6364 .49298 L
.64294 .51422 L
.64965 .53539 L
.65594 .55581 L
.66126 .57478 L
.66501 .59161 L
.66613 .59901 L
.66664 .60562 L
.66647 .61135 L
.66611 .61385 L
.66586 .61501 L
.66556 .61611 L
.6648 .6181 L
.66434 .619 L
.66383 .61982 L
.66326 .62058 L
.66263 .62126 L
.66195 .62186 L
.66158 .62214 L
.66139 .62227 L
.6612 .6224 L
.6604 .62285 L
.65953 .62323 L
.65861 .62353 L
.65812 .62365 L
Mistroke
.65761 .62375 L
.65544 .62394 L
.65425 .6239 L
.65299 .62379 L
.64727 .62243 L
.64036 .61959 L
.62273 .60913 L
.59952 .5917 L
.57017 .56661 L
.5341 .53319 L
.49073 .49073 L
Mfstroke
.49073 .49073 m
.48883 .46838 L
.48341 .44586 L
.47487 .42324 L
.46363 .40059 L
.4501 .37795 L
.43468 .3554 L
.41778 .333 L
.39982 .31081 L
.3812 .28889 L
.36234 .26731 L
.34364 .24612 L
.32552 .22539 L
.30838 .20517 L
.29263 .18554 L
.27868 .16656 L
.26695 .14828 L
.25784 .13076 L
.2544 .12231 L
.25176 .11408 L
.24999 .10607 L
.24944 .10215 L
.24913 .09829 L
.24923 .09075 L
.24966 .08707 L
.25034 .08345 L
.25252 .07641 L
.25403 .07299 L
.25582 .06963 L
.26029 .06313 L
.26297 .05997 L
.26597 .05689 L
.27292 .05095 L
.2812 .04529 L
.30192 .03489 L
s
.41252 .67955 m
.40596 .68308 L
.39876 .68583 L
.39097 .68784 L
.38263 .68916 L
.36443 .68987 L
.34446 .68829 L
.32302 .68474 L
.30041 .67955 L
.27693 .67304 L
.25288 .66556 L
.22856 .65742 L
.20426 .64895 L
.18029 .64048 L
.15695 .63234 L
.13454 .62486 L
.11335 .61836 L
.09369 .61317 L
.07586 .60961 L
.06015 .60803 L
.05319 .60808 L
.04687 .60874 L
.04123 .61006 L
.03868 .61098 L
.03631 .61207 L
.03413 .61335 L
.03215 .61482 L
.03036 .61649 L
.02955 .6174 L
.02878 .61836 L
.02741 .62043 L
.02624 .62271 L
.0253 .6252 L
.02491 .62653 L
.02457 .62792 L
.02381 .63403 L
.02399 .64108 L
.02733 .65818 L
.03489 .67955 L
s
.41252 .67955 m
.40961 .68153 L
.40712 .68356 L
.40504 .68562 L
.40414 .68667 L
.40335 .68773 L
.40204 .68986 L
.40152 .69095 L
.4011 .69204 L
.40053 .69424 L
.40037 .69536 L
.40033 .69592 L
.40031 .69648 L
.40043 .69875 L
.40061 .6999 L
.40087 .70105 L
.40164 .70337 L
.40214 .70455 L
.40272 .70573 L
.40575 .71051 L
.40988 .71538 L
.42112 .72537 L
.43574 .7356 L
.45305 .74599 L
.47236 .75647 L
.49298 .76695 L
.51422 .77734 L
.53539 .78757 L
.55581 .79755 L
.57478 .80721 L
.59161 .81646 L
.60562 .82521 L
.61135 .82938 L
.61611 .83339 L
.61982 .83724 L
.62126 .8391 L
.62186 .84002 L
.6224 .84092 L
.62323 .84269 L
.62353 .84356 L
.62375 .84441 L
.62388 .84525 L
.62394 .84608 L
.6239 .8469 L
.62386 .84731 L
.62382 .84751 L
.62379 .84771 L
.62358 .8485 L
.62329 .84928 L
.62291 .85005 L
Mistroke
.62268 .85042 L
.62243 .8508 L
.6212 .85227 L
.62045 .85298 L
.61959 .85368 L
.61519 .85633 L
.60913 .85874 L
.5917 .86283 L
.56661 .86585 L
.53319 .86772 L
.49073 .86836 L
Mfstroke
.49073 .86836 m
.46838 .85389 L
.44586 .84181 L
.42324 .83185 L
.40059 .82378 L
.37795 .81734 L
.3554 .8123 L
.333 .80841 L
.31081 .80542 L
.28889 .80309 L
.26731 .80116 L
.24612 .7994 L
.22539 .79755 L
.20517 .79538 L
.18554 .79264 L
.16656 .78907 L
.14828 .78444 L
.13076 .7785 L
.11408 .771 L
.09829 .7617 L
.08345 .75035 L
.06963 .73671 L
.05689 .72052 L
.04529 .70155 L
.03489 .67955 L
s
.86836 .49073 m
.85389 .46838 L
.84181 .44586 L
.83185 .42324 L
.82378 .40059 L
.81734 .37795 L
.8123 .3554 L
.80841 .333 L
.80542 .31081 L
.80309 .28889 L
.80116 .26731 L
.7994 .24612 L
.79755 .22539 L
.79538 .20517 L
.79264 .18554 L
.78907 .16656 L
.78444 .14828 L
.7785 .13076 L
.771 .11408 L
.7617 .09829 L
.75035 .08345 L
.73671 .06963 L
.72052 .05689 L
.70155 .04529 L
.67955 .03489 L
s
.86836 .49073 m
.85389 .47217 L
.84757 .46553 L
.84181 .4605 L
.83913 .45857 L
.83658 .45701 L
.83415 .45581 L
.83299 .45534 L
.83185 .45496 L
.82966 .45444 L
.82759 .45425 L
.82563 .45436 L
.82469 .45454 L
.82423 .45465 L
.82378 .45478 L
.82203 .45549 L
.82119 .45595 L
.82037 .45647 L
.81881 .45772 L
.81807 .45844 L
.81734 .45922 L
.81467 .46293 L
.8123 .46751 L
.80841 .4789 L
.80542 .49263 L
.80309 .50795 L
.80116 .52409 L
.7994 .54029 L
.79755 .55581 L
.79538 .56988 L
.79264 .58175 L
.79097 .58661 L
.78907 .59065 L
.78802 .59232 L
.78691 .59375 L
.78571 .59493 L
.78509 .59541 L
.78477 .59563 L
.78444 .59583 L
.78378 .59618 L
.78309 .59646 L
.78238 .59666 L
.78202 .59674 L
.78165 .59679 L
.7809 .59685 L
.78012 .59683 L
.77932 .59672 L
.77891 .59664 L
.77871 .59659 L
.7785 .59654 L
Mistroke
.77678 .59593 L
.77496 .59498 L
.77304 .59368 L
.771 .59202 L
.76659 .58755 L
.7617 .5815 L
.75035 .56423 L
.73671 .53946 L
.72052 .50642 L
.70155 .46436 L
.67955 .41252 L
Mfstroke
.67955 .41252 m
.68308 .40596 L
.68583 .39876 L
.68784 .39097 L
.68916 .38263 L
.68987 .36443 L
.68829 .34446 L
.68474 .32302 L
.67955 .30041 L
.67304 .27693 L
.66556 .25288 L
.65742 .22856 L
.64895 .20426 L
.64048 .18029 L
.63234 .15695 L
.62486 .13454 L
.61836 .11335 L
.61317 .09369 L
.60961 .07586 L
.60803 .06015 L
.60808 .05319 L
.60874 .04687 L
.61006 .04123 L
.61098 .03868 L
.61207 .03631 L
.61335 .03413 L
.61482 .03215 L
.61649 .03036 L
.6174 .02955 L
.61836 .02878 L
.62043 .02741 L
.62271 .02624 L
.6252 .0253 L
.62653 .02491 L
.62792 .02457 L
.63403 .02381 L
.64108 .02399 L
.65818 .02733 L
.67955 .03489 L
s
.49073 .86836 m
.49061 .86995 L
.49025 .87148 L
.48965 .87295 L
.48927 .87366 L
.48883 .87435 L
.48779 .87569 L
.48654 .87697 L
.48507 .87819 L
.48341 .87936 L
.47951 .88152 L
.47487 .88348 L
.46363 .88682 L
.4501 .88949 L
.43468 .89158 L
.41778 .89319 L
.39982 .89443 L
.3812 .8954 L
.36234 .89619 L
.34364 .89692 L
.32552 .89769 L
.30838 .89859 L
.29263 .89972 L
.27868 .9012 L
.26695 .90312 L
.26204 .90427 L
.25784 .90558 L
.2544 .90705 L
.25298 .90784 L
.25234 .90826 L
.25176 .90869 L
.25077 .90957 L
.25035 .91004 L
.24999 .91051 L
.24969 .911 L
.24944 .9115 L
.24926 .91201 L
.24918 .91227 L
.24915 .91241 L
.24913 .91254 L
.24906 .91308 L
.24905 .91363 L
.24911 .9142 L
.24916 .91448 L
.24923 .91478 L
.24966 .91598 L
.24997 .9166 L
.25034 .91724 L
.25252 .91994 L
.25582 .92289 L
Mistroke
.26597 .9296 L
.2812 .93745 L
.30192 .94657 L
Mfstroke
.49073 .86836 m
.49085 .86995 L
.49121 .87148 L
.49181 .87295 L
.49219 .87366 L
.49263 .87435 L
.49367 .87569 L
.49493 .87697 L
.49639 .87819 L
.49805 .87936 L
.50196 .88152 L
.50659 .88348 L
.51783 .88682 L
.53137 .88949 L
.54679 .89158 L
.56368 .89319 L
.58164 .89443 L
.60026 .8954 L
.61912 .89619 L
.63782 .89692 L
.65594 .89769 L
.67308 .89859 L
.68883 .89972 L
.70278 .9012 L
.71451 .90312 L
.71942 .90427 L
.72362 .90558 L
.72706 .90705 L
.72849 .90784 L
.72912 .90826 L
.7297 .90869 L
.7307 .90957 L
.73111 .91004 L
.73147 .91051 L
.73178 .911 L
.73202 .9115 L
.73221 .91201 L
.73228 .91227 L
.73231 .91241 L
.73233 .91254 L
.7324 .91308 L
.73241 .91363 L
.73235 .9142 L
.7323 .91448 L
.73223 .91478 L
.73181 .91598 L
.7315 .9166 L
.73112 .91724 L
.72894 .91994 L
.72564 .92289 L
Mistroke
.71549 .9296 L
.70026 .93745 L
.67955 .94657 L
Mfstroke
.67955 .94657 m
.6569 .94397 L
.63606 .94258 L
.61685 .94229 L
.59912 .94295 L
.58271 .94442 L
.56744 .94657 L
.55315 .94926 L
.53968 .95236 L
.52687 .95573 L
.51455 .95924 L
.50256 .96275 L
.49073 .96612 L
.4789 .96922 L
.46691 .97191 L
.45459 .97406 L
.44178 .97553 L
.42831 .97619 L
.41403 .9759 L
.39876 .97452 L
.38234 .97191 L
.36461 .96795 L
.34541 .9625 L
.32456 .95542 L
.30192 .94657 L
s
.94657 .67955 m
.94397 .6569 L
.94258 .63606 L
.94229 .61685 L
.94295 .59912 L
.94442 .58271 L
.94657 .56744 L
.94926 .55315 L
.95236 .53968 L
.95573 .52687 L
.95924 .51455 L
.96275 .50256 L
.96612 .49073 L
.96922 .4789 L
.97191 .46691 L
.97406 .45459 L
.97553 .44178 L
.97619 .42831 L
.9759 .41403 L
.97452 .39876 L
.97191 .38234 L
.96795 .36461 L
.9625 .34541 L
.95542 .32456 L
.94657 .30192 L
s
.94657 .67955 m
.94318 .6588 L
.93955 .64338 L
.93766 .63749 L
.93572 .63271 L
.93374 .62898 L
.93274 .62748 L
.93172 .62622 L
.9307 .62519 L
.92967 .62437 L
.92863 .62375 L
.92811 .62352 L
.92785 .62343 L
.92759 .62334 L
.92654 .62312 L
.92601 .62307 L
.92548 .62307 L
.92442 .6232 L
.92388 .62333 L
.92335 .62349 L
.92228 .62394 L
.9212 .62452 L
.92012 .62525 L
.91904 .6261 L
.9147 .63059 L
.91037 .6364 L
.90606 .64294 L
.90182 .64965 L
.89769 .65594 L
.89369 .66126 L
.89175 .66336 L
.88986 .66501 L
.88893 .66564 L
.88802 .66613 L
.88712 .66646 L
.88667 .66657 L
.88645 .66661 L
.88623 .66664 L
.88579 .66666 L
.88536 .66664 L
.88493 .66658 L
.88472 .66653 L
.8845 .66647 L
.88408 .66632 L
.88366 .66611 L
.88325 .66586 L
.88305 .66572 L
.88284 .66556 L
.88204 .6648 L
.88125 .66383 L
Mistroke
.88048 .66263 L
.87972 .6612 L
.87691 .65299 L
.87444 .64036 L
.87234 .62273 L
.87065 .59952 L
.8694 .57017 L
.86862 .5341 L
.86836 .49073 L
Mfstroke
.86836 .49073 m
.86995 .49061 L
.87148 .49025 L
.87295 .48965 L
.87366 .48927 L
.87435 .48883 L
.87569 .48779 L
.87697 .48654 L
.87819 .48507 L
.87936 .48341 L
.88152 .47951 L
.88348 .47487 L
.88682 .46363 L
.88949 .4501 L
.89158 .43468 L
.89319 .41778 L
.89443 .39982 L
.8954 .3812 L
.89619 .36234 L
.89692 .34364 L
.89769 .32552 L
.89859 .30838 L
.89972 .29263 L
.9012 .27868 L
.90312 .26695 L
.90427 .26204 L
.90558 .25784 L
.90705 .2544 L
.90784 .25298 L
.90826 .25234 L
.90869 .25176 L
.90957 .25077 L
.91004 .25035 L
.91051 .24999 L
.911 .24969 L
.9115 .24944 L
.91201 .24926 L
.91227 .24918 L
.91241 .24915 L
.91254 .24913 L
.91308 .24906 L
.91363 .24905 L
.9142 .24911 L
.91448 .24916 L
.91478 .24923 L
.91598 .24966 L
.9166 .24997 L
.91724 .25034 L
.91994 .25252 L
.92289 .25582 L
Mistroke
.9296 .26597 L
.93745 .2812 L
.94657 .30192 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.504983 0.488926 0.726467 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.493273 0.531249 0.487826 0.531249 [
[ 0 0 0 0 ]
[ 1 .98064 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.03 .18 .33 r
.5 Mabswid
[ ] 0 setdash
.22765 .75345 m
.22644 .75449 L
.22511 .75531 L
.22366 .75592 L
.22289 .75615 L
.2221 .75633 L
.22042 .75654 L
.21864 .75656 L
.21675 .75639 L
.21476 .75604 L
.21049 .75481 L
.20586 .75293 L
.1956 .74738 L
.1842 .73973 L
.17189 .73035 L
.15887 .7196 L
.14536 .70784 L
.13159 .69543 L
.11776 .68272 L
.10409 .67008 L
.09081 .65787 L
.07812 .64644 L
.06624 .63617 L
.05539 .6274 L
.04579 .62049 L
.04153 .61785 L
.03765 .61582 L
.0342 .61443 L
.03264 .61399 L
.0319 .61383 L
.03119 .61373 L
.02986 .61365 L
.02925 .61368 L
.02866 .61376 L
.0281 .61389 L
.02758 .61407 L
.02709 .6143 L
.02685 .61443 L
.02674 .61451 L
.02663 .61458 L
.0262 .61491 L
.02581 .6153 L
.02545 .61574 L
.02528 .61597 L
.02512 .61623 L
.02458 .61737 L
.02436 .61803 L
.02418 .61874 L
.02381 .62218 L
.02405 .62657 L
Mistroke
.02648 .63843 L
.03166 .65467 L
.03982 .67565 L
Mfstroke
.22765 .75345 m
.22661 .75466 L
.22579 .75599 L
.22518 .75744 L
.22495 .7582 L
.22477 .759 L
.22456 .76068 L
.22454 .76246 L
.22471 .76435 L
.22506 .76634 L
.22628 .77061 L
.22817 .77524 L
.23372 .7855 L
.24137 .7969 L
.25075 .80921 L
.2615 .82223 L
.27326 .83573 L
.28567 .84951 L
.29838 .86334 L
.31102 .877 L
.32323 .89029 L
.33465 .90298 L
.34493 .91486 L
.3537 .92571 L
.36061 .93531 L
.36324 .93957 L
.36528 .94345 L
.36667 .9469 L
.36711 .94846 L
.36727 .9492 L
.36737 .94991 L
.36745 .95123 L
.36742 .95185 L
.36734 .95244 L
.36721 .953 L
.36703 .95352 L
.3668 .95401 L
.36666 .95425 L
.36659 .95436 L
.36652 .95447 L
.36619 .9549 L
.3658 .95529 L
.36536 .95565 L
.36512 .95582 L
.36487 .95597 L
.36373 .95652 L
.36307 .95674 L
.36236 .95692 L
.35892 .95729 L
.35453 .95705 L
Mistroke
.34267 .95462 L
.32643 .94944 L
.30545 .94128 L
Mfstroke
.30545 .94128 m
.29135 .92352 L
.27766 .90788 L
.26436 .89417 L
.25143 .88216 L
.23884 .87165 L
.22659 .86242 L
.21465 .85426 L
.20299 .84697 L
.19161 .84033 L
.18048 .83413 L
.16957 .82816 L
.15888 .82222 L
.14838 .81608 L
.13805 .80954 L
.12787 .80238 L
.11783 .79441 L
.10789 .78539 L
.09805 .77514 L
.08828 .76343 L
.07856 .75005 L
.06888 .73479 L
.05921 .71745 L
.04953 .6978 L
.03982 .67565 L
s
.49327 .48783 m
.47104 .48594 L
.44864 .48054 L
.42614 .47205 L
.4036 .46087 L
.38109 .4474 L
.35866 .43207 L
.33637 .41526 L
.3143 .39739 L
.29249 .37887 L
.27102 .36011 L
.24994 .34151 L
.22932 .32348 L
.20921 .30643 L
.18968 .29076 L
.1708 .27689 L
.15261 .26522 L
.13519 .25616 L
.12678 .25273 L
.11859 .25011 L
.11063 .24834 L
.10673 .2478 L
.10289 .24749 L
.09539 .24759 L
.09173 .24801 L
.08813 .2487 L
.08112 .25087 L
.07772 .25236 L
.07438 .25414 L
.06791 .25859 L
.06477 .26126 L
.06171 .26424 L
.05579 .27116 L
.05017 .27939 L
.03982 .3 L
s
.49327 .48783 m
.48314 .48831 L
.47481 .48971 L
.4713 .49075 L
.4682 .492 L
.4655 .49345 L
.4643 .49426 L
.46374 .49468 L
.4632 .49511 L
.46128 .49696 L
.46046 .49795 L
.45973 .49899 L
.45854 .50121 L
.45807 .50238 L
.45769 .5036 L
.45717 .50616 L
.45698 .50888 L
.4571 .51176 L
.45727 .51325 L
.45751 .51478 L
.45919 .52125 L
.46193 .52825 L
.47018 .54359 L
.48151 .56039 L
.49517 .57826 L
.5104 .59678 L
.52645 .61554 L
.54257 .63414 L
.55801 .65217 L
.57201 .66922 L
.58381 .68489 L
.59267 .69876 L
.59576 .7049 L
.59783 .71043 L
.59845 .71296 L
.59878 .71532 L
.59881 .7175 L
.59871 .71852 L
.59863 .71901 L
.59853 .7195 L
.59827 .72042 L
.59792 .72131 L
.59749 .72214 L
.59724 .72254 L
.59698 .72292 L
.59637 .72365 L
.59568 .72434 L
.5949 .72496 L
.59447 .72526 L
.59425 .7254 L
Mistroke
.59403 .72554 L
.592 .72653 L
.58959 .72731 L
.58678 .72785 L
.58356 .72816 L
.57586 .72806 L
.56639 .72695 L
.54174 .72151 L
.50888 .71141 L
.46704 .69626 L
.41547 .67565 L
Mfstroke
.41547 .67565 m
.40179 .65312 L
.38574 .63239 L
.36764 .61329 L
.34777 .59565 L
.32644 .57932 L
.30395 .56413 L
.28059 .54992 L
.25667 .53652 L
.23247 .52378 L
.2083 .51152 L
.18446 .49959 L
.16124 .48783 L
.13895 .47606 L
.11787 .46413 L
.09831 .45187 L
.08057 .43913 L
.06495 .42573 L
.05174 .41152 L
.04613 .40406 L
.04123 .39633 L
.03709 .38832 L
.03374 .38 L
.03122 .37136 L
.02956 .36236 L
.0288 .35301 L
.02898 .34326 L
.0323 .32253 L
.03982 .3 L
s
.6811 .41003 m
.65857 .39634 L
.63784 .38029 L
.61873 .36219 L
.6011 .34232 L
.58477 .321 L
.56958 .2985 L
.55537 .27515 L
.54197 .25122 L
.52922 .22702 L
.51697 .20286 L
.50504 .17901 L
.49327 .15579 L
.48151 .1335 L
.46958 .11242 L
.45732 .09287 L
.44458 .07513 L
.43118 .0595 L
.41697 .04629 L
.40951 .04068 L
.40178 .03579 L
.39377 .03164 L
.38545 .02829 L
.3768 .02577 L
.36781 .02411 L
.35845 .02335 L
.34871 .02353 L
.32798 .02685 L
.30545 .03438 L
s
.6811 .41003 m
.67008 .40466 L
.66046 .4009 L
.65216 .39867 L
.64849 .3981 L
.64512 .39787 L
.64205 .39799 L
.63926 .39844 L
.63675 .3992 L
.6356 .3997 L
.63504 .39998 L
.63451 .40027 L
.63253 .40164 L
.63163 .40243 L
.6308 .40329 L
.62931 .40521 L
.62865 .40628 L
.62806 .4074 L
.62702 .40984 L
.62621 .41253 L
.6256 .41544 L
.62519 .41858 L
.62534 .43312 L
.62793 .45034 L
.6324 .46955 L
.63818 .49006 L
.64469 .51119 L
.65136 .53225 L
.65762 .55256 L
.66291 .57143 L
.66664 .58818 L
.66775 .59554 L
.66826 .60211 L
.66809 .60781 L
.66774 .6103 L
.66749 .61146 L
.66719 .61255 L
.66643 .61453 L
.66597 .61542 L
.66546 .61624 L
.66489 .61699 L
.66427 .61767 L
.66359 .61827 L
.66323 .61855 L
.66304 .61868 L
.66285 .6188 L
.66205 .61925 L
.66119 .61963 L
.66027 .61993 L
.65978 .62005 L
Mistroke
.65928 .62014 L
.65712 .62033 L
.65594 .6203 L
.65469 .62019 L
.64899 .61884 L
.64212 .61601 L
.62458 .6056 L
.60149 .58826 L
.57229 .56331 L
.53641 .53006 L
.49327 .48783 L
Mfstroke
.49327 .48783 m
.49138 .46559 L
.48599 .44319 L
.4775 .42069 L
.46632 .39815 L
.45285 .37564 L
.43751 .35321 L
.42071 .33092 L
.40284 .30885 L
.38432 .28705 L
.36556 .26557 L
.34696 .24449 L
.32893 .22387 L
.31187 .20376 L
.29621 .18423 L
.28234 .16535 L
.27067 .14716 L
.2616 .12974 L
.25818 .12134 L
.25556 .11315 L
.25379 .10518 L
.25325 .10128 L
.25293 .09744 L
.25304 .08994 L
.25346 .08628 L
.25414 .08268 L
.25631 .07568 L
.25781 .07227 L
.25959 .06893 L
.26403 .06246 L
.26671 .05932 L
.26969 .05626 L
.2766 .05034 L
.28484 .04472 L
.30545 .03438 L
s
.86892 .48783 m
.85453 .46559 L
.84251 .44319 L
.83261 .42069 L
.82458 .39815 L
.81818 .37564 L
.81316 .35321 L
.80929 .33092 L
.80631 .30885 L
.80399 .28705 L
.80208 .26557 L
.80032 .24449 L
.79849 .22387 L
.79633 .20376 L
.7936 .18423 L
.79005 .16535 L
.78545 .14716 L
.77954 .12974 L
.77208 .11315 L
.76282 .09744 L
.75153 .08268 L
.73796 .06893 L
.72186 .05626 L
.70299 .04472 L
.6811 .03438 L
s
.86892 .48783 m
.85453 .46937 L
.84824 .46275 L
.84251 .45775 L
.83984 .45583 L
.83731 .45428 L
.8349 .45309 L
.83374 .45262 L
.83261 .45224 L
.83043 .45172 L
.82837 .45153 L
.82642 .45165 L
.82549 .45182 L
.82503 .45193 L
.82458 .45207 L
.82283 .45277 L
.822 .45322 L
.82119 .45375 L
.81964 .45499 L
.8189 .4557 L
.81818 .45648 L
.81551 .46017 L
.81316 .46473 L
.80929 .47606 L
.80631 .48972 L
.80399 .50495 L
.80208 .52101 L
.80032 .53713 L
.79849 .55256 L
.79633 .56656 L
.7936 .57836 L
.79194 .58321 L
.79005 .58722 L
.78901 .58889 L
.7879 .59031 L
.78671 .59148 L
.78609 .59196 L
.78577 .59218 L
.78545 .59238 L
.78478 .59272 L
.7841 .593 L
.7834 .5932 L
.78303 .59328 L
.78267 .59333 L
.78192 .59339 L
.78115 .59336 L
.78035 .59326 L
.77995 .59318 L
.77974 .59313 L
.77954 .59308 L
Mistroke
.77783 .59247 L
.77601 .59153 L
.7741 .59023 L
.77208 .58858 L
.76769 .58414 L
.76282 .57812 L
.75153 .56094 L
.73796 .5363 L
.72186 .50343 L
.70299 .46159 L
.6811 .41003 L
Mfstroke
.6811 .41003 m
.68461 .4035 L
.68735 .39634 L
.68935 .38859 L
.69066 .38029 L
.69137 .36219 L
.68979 .34232 L
.68626 .321 L
.6811 .2985 L
.67463 .27515 L
.66719 .25122 L
.65909 .22702 L
.65066 .20286 L
.64224 .17901 L
.63414 .15579 L
.6267 .1335 L
.62023 .11242 L
.61507 .09287 L
.61153 .07513 L
.60996 .0595 L
.61 .05257 L
.61066 .04629 L
.61197 .04068 L
.61289 .03814 L
.61398 .03579 L
.61525 .03362 L
.61672 .03164 L
.61837 .02987 L
.61928 .02906 L
.62023 .02829 L
.62229 .02693 L
.62456 .02577 L
.62704 .02483 L
.62836 .02444 L
.62974 .02411 L
.63582 .02335 L
.64284 .02353 L
.65985 .02685 L
.6811 .03438 L
s
.41547 .67565 m
.41612 .67909 L
.41645 .68227 L
.41646 .68519 L
.41636 .68656 L
.41617 .68786 L
.41559 .69028 L
.41519 .69141 L
.41472 .69247 L
.41357 .69443 L
.4129 .69532 L
.41253 .69574 L
.41215 .69616 L
.41047 .69767 L
.40954 .69835 L
.40854 .69897 L
.40637 .70007 L
.40519 .70054 L
.40395 .70097 L
.39846 .7022 L
.39212 .70272 L
.37719 .70183 L
.35971 .69875 L
.34023 .69388 L
.31928 .68767 L
.2974 .68054 L
.27515 .67291 L
.25306 .66521 L
.23168 .65787 L
.21154 .65132 L
.1932 .64598 L
.17719 .64229 L
.17023 .64119 L
.16405 .64066 L
.15873 .64076 L
.15641 .64106 L
.15534 .64128 L
.15434 .64154 L
.15251 .64219 L
.15169 .64259 L
.15093 .64304 L
.15024 .64354 L
.14962 .64409 L
.14907 .64468 L
.14882 .645 L
.1487 .64516 L
.14858 .64533 L
.14817 .64603 L
.14783 .64679 L
.14756 .6476 L
Mistroke
.14745 .64802 L
.14736 .64846 L
.14719 .65036 L
.14722 .65139 L
.14733 .65248 L
.14857 .65744 L
.15113 .66341 L
.16052 .67854 L
.17604 .69831 L
.19824 .72313 L
.22765 .75345 L
Mfstroke
.41547 .67565 m
.41761 .68275 L
.42073 .68975 L
.42479 .69664 L
.42973 .70344 L
.44204 .71674 L
.4572 .72967 L
.47478 .74225 L
.49433 .75451 L
.51542 .76645 L
.5376 .77811 L
.56044 .78949 L
.58349 .80062 L
.6063 .81152 L
.62845 .82222 L
.64948 .83272 L
.66895 .84305 L
.68643 .85322 L
.70147 .86327 L
.71364 .87321 L
.7185 .87814 L
.72248 .88305 L
.72552 .88794 L
.72667 .89038 L
.72756 .89282 L
.72819 .89525 L
.72855 .89768 L
.72864 .90011 L
.72858 .90132 L
.72844 .90254 L
.72795 .90496 L
.72717 .90738 L
.72608 .9098 L
.72541 .91101 L
.72467 .91222 L
.72091 .91706 L
.71582 .92189 L
.70144 .93157 L
.6811 .94128 L
s
.6811 .94128 m
.65261 .9243 L
.6269 .9109 L
.60369 .9007 L
.58273 .89333 L
.56375 .88839 L
.54648 .88551 L
.53066 .88432 L
.51604 .88443 L
.50233 .88546 L
.48928 .88703 L
.47662 .88877 L
.4641 .89029 L
.45144 .89121 L
.43838 .89116 L
.42465 .88976 L
.41 .88661 L
.39416 .88135 L
.37685 .8736 L
.35783 .86298 L
.33682 .8491 L
.31356 .83158 L
.28779 .81006 L
.25924 .78414 L
.22765 .75345 L
s
.94672 .67565 m
.94413 .65312 L
.94276 .63239 L
.94247 .61329 L
.94312 .59565 L
.94458 .57932 L
.94672 .56413 L
.9494 .54992 L
.95249 .53652 L
.95584 .52378 L
.95933 .51152 L
.96282 .49959 L
.96617 .48783 L
.96926 .47606 L
.97194 .46413 L
.97407 .45187 L
.97554 .43913 L
.97619 .42573 L
.9759 .41152 L
.97452 .39633 L
.97194 .38 L
.968 .36236 L
.96257 .34326 L
.95552 .32253 L
.94672 .3 L
s
.94672 .67565 m
.94335 .65501 L
.93974 .63967 L
.93786 .63381 L
.93593 .62906 L
.93396 .62535 L
.93296 .62386 L
.93196 .62261 L
.93094 .62158 L
.92991 .62076 L
.92888 .62015 L
.92836 .61992 L
.9281 .61983 L
.92784 .61974 L
.9268 .61952 L
.92627 .61947 L
.92574 .61947 L
.92469 .6196 L
.92416 .61973 L
.92363 .61989 L
.92256 .62033 L
.92149 .62092 L
.92042 .62164 L
.91934 .62249 L
.91503 .62696 L
.91071 .63273 L
.90643 .63924 L
.90221 .64591 L
.8981 .65217 L
.89412 .65746 L
.89219 .65956 L
.89031 .66119 L
.88939 .66182 L
.88848 .6623 L
.88758 .66264 L
.88714 .66274 L
.88692 .66278 L
.8867 .66281 L
.88627 .66284 L
.88584 .66282 L
.88541 .66275 L
.8852 .66271 L
.88498 .66265 L
.88456 .66249 L
.88415 .66229 L
.88374 .66204 L
.88353 .66189 L
.88333 .66174 L
.88253 .66098 L
.88174 .66001 L
Mistroke
.88098 .65882 L
.88023 .6574 L
.87743 .64924 L
.87497 .63667 L
.87289 .61913 L
.8712 .59605 L
.86996 .56685 L
.86919 .53096 L
.86892 .48783 L
Mfstroke
.86892 .48783 m
.87051 .4877 L
.87203 .48735 L
.87349 .48675 L
.87419 .48637 L
.87488 .48594 L
.87622 .4849 L
.87749 .48365 L
.8787 .4822 L
.87986 .48054 L
.88202 .47666 L
.88397 .47205 L
.88729 .46087 L
.88994 .4474 L
.89202 .43207 L
.89362 .41526 L
.89486 .39739 L
.89582 .37887 L
.89661 .36011 L
.89734 .34151 L
.8981 .32348 L
.89899 .30643 L
.90012 .29076 L
.90159 .27689 L
.9035 .26522 L
.90465 .26034 L
.90595 .25616 L
.90741 .25273 L
.9082 .25132 L
.90861 .25069 L
.90904 .25011 L
.90992 .24912 L
.91038 .2487 L
.91086 .24834 L
.91134 .24804 L
.91184 .2478 L
.91235 .24761 L
.91261 .24754 L
.91274 .24751 L
.91287 .24749 L
.91341 .24742 L
.91396 .24741 L
.91452 .24747 L
.91481 .24752 L
.9151 .24759 L
.91629 .24801 L
.91691 .24832 L
.91755 .2487 L
.92023 .25087 L
.92317 .25414 L
Mistroke
.92984 .26424 L
.93766 .27939 L
.94672 .3 L
Mfstroke
0 0 m
1 0 L
1 .98064 L
0 .98064 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.504983 0.732558 0.726467 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.523849 0.481362 0.523849 [
[ 0 0 0 0 ]
[ 1 .98091 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.03 .18 .33 r
.5 Mabswid
[ ] 0 setdash
.12958 .48136 m
.12802 .48124 L
.12652 .48089 L
.12508 .48031 L
.12439 .47993 L
.12371 .4795 L
.12239 .47848 L
.12114 .47725 L
.11994 .47581 L
.11879 .47418 L
.11667 .47035 L
.11475 .46581 L
.11147 .45478 L
.10886 .4415 L
.10681 .42638 L
.10523 .40981 L
.10401 .39219 L
.10306 .37393 L
.10228 .35542 L
.10156 .33708 L
.10081 .3193 L
.09993 .30249 L
.09882 .28704 L
.09737 .27336 L
.09549 .26186 L
.09435 .25704 L
.09307 .25292 L
.09163 .24954 L
.09085 .24815 L
.09044 .24753 L
.09003 .24696 L
.08915 .24598 L
.0887 .24557 L
.08823 .24522 L
.08776 .24492 L
.08727 .24468 L
.08676 .2445 L
.08651 .24443 L
.08638 .2444 L
.08625 .24437 L
.08572 .24431 L
.08518 .2443 L
.08462 .24435 L
.08434 .2444 L
.08405 .24447 L
.08287 .24489 L
.08226 .24519 L
.08164 .24556 L
.07899 .2477 L
.07609 .25094 L
Mistroke
.06952 .26089 L
.06181 .27583 L
.05287 .29615 L
Mfstroke
.12958 .48136 m
.12802 .48148 L
.12652 .48184 L
.12508 .48242 L
.12439 .48279 L
.12371 .48322 L
.12239 .48425 L
.12114 .48548 L
.11994 .48691 L
.11879 .48854 L
.11667 .49237 L
.11475 .49692 L
.11147 .50794 L
.10886 .52122 L
.10681 .53635 L
.10523 .55292 L
.10401 .57054 L
.10306 .5888 L
.10228 .6073 L
.10156 .62564 L
.10081 .64342 L
.09993 .66023 L
.09882 .67568 L
.09737 .68936 L
.09549 .70087 L
.09435 .70568 L
.09307 .7098 L
.09163 .71318 L
.09085 .71458 L
.09044 .7152 L
.09003 .71577 L
.08915 .71675 L
.0887 .71715 L
.08823 .71751 L
.08776 .7178 L
.08727 .71804 L
.08676 .71823 L
.08651 .7183 L
.08638 .71833 L
.08625 .71835 L
.08572 .71842 L
.08518 .71842 L
.08462 .71837 L
.08434 .71832 L
.08405 .71825 L
.08287 .71783 L
.08226 .71753 L
.08164 .71716 L
.07899 .71502 L
.07609 .71179 L
Mistroke
.06952 .70183 L
.06181 .6869 L
.05287 .66657 L
Mfstroke
.05287 .66657 m
.05542 .64436 L
.05677 .62391 L
.05706 .60508 L
.05642 .58769 L
.05498 .57158 L
.05287 .5566 L
.05023 .54259 L
.04718 .52938 L
.04388 .51681 L
.04044 .50473 L
.037 .49296 L
.03369 .48136 L
.03065 .46976 L
.028 .458 L
.0259 .44591 L
.02445 .43335 L
.02381 .42013 L
.0241 .40612 L
.02545 .39114 L
.028 .37504 L
.03189 .35765 L
.03724 .33881 L
.04419 .31837 L
.05287 .29615 L
s
.68521 .40465 m
.663 .39115 L
.64255 .37533 L
.62371 .35748 L
.60632 .33789 L
.59022 .31686 L
.57524 .29468 L
.56123 .27165 L
.54802 .24805 L
.53545 .22419 L
.52337 .20036 L
.5116 .17685 L
.5 .15396 L
.4884 .13197 L
.47663 .11119 L
.46455 .0919 L
.45198 .07441 L
.43877 .059 L
.42476 .04597 L
.4174 .04044 L
.40978 .03562 L
.40188 .03154 L
.39368 .02823 L
.38515 .02574 L
.37629 .0241 L
.36706 .02335 L
.35745 .02353 L
.337 .02681 L
.31479 .03423 L
s
.68521 .40465 m
.67434 .39935 L
.66486 .39564 L
.65668 .39344 L
.65305 .39288 L
.64973 .39266 L
.6467 .39278 L
.64395 .39322 L
.64148 .39397 L
.64034 .39446 L
.6398 .39474 L
.63927 .39503 L
.63731 .39637 L
.63643 .39715 L
.63561 .398 L
.63414 .3999 L
.63349 .40095 L
.6329 .40206 L
.63189 .40447 L
.63108 .40711 L
.63048 .40999 L
.63008 .41308 L
.63022 .42742 L
.63278 .4444 L
.63719 .46334 L
.64289 .48357 L
.6493 .5044 L
.65588 .52517 L
.66206 .5452 L
.66727 .56381 L
.67095 .58032 L
.67205 .58758 L
.67255 .59406 L
.67239 .59967 L
.67203 .60213 L
.67179 .60327 L
.67149 .60435 L
.67074 .6063 L
.67029 .60718 L
.66979 .60799 L
.66923 .60873 L
.66862 .6094 L
.66795 .60999 L
.66759 .61026 L
.6674 .61039 L
.66722 .61051 L
.66643 .61096 L
.66558 .61133 L
.66467 .61162 L
.66419 .61174 L
Mistroke
.6637 .61184 L
.66156 .61202 L
.6604 .61199 L
.65916 .61188 L
.65355 .61055 L
.64677 .60776 L
.62947 .5975 L
.60671 .5804 L
.57792 .5558 L
.54254 .52301 L
.5 .48136 L
Mfstroke
.5 .48136 m
.49814 .45943 L
.49282 .43735 L
.48445 .41516 L
.47342 .39294 L
.46014 .37074 L
.44502 .34862 L
.42844 .32665 L
.41083 .30488 L
.39256 .28338 L
.37406 .2622 L
.35572 .24142 L
.33794 .22108 L
.32113 .20126 L
.30568 .182 L
.292 .16338 L
.28049 .14544 L
.27156 .12827 L
.26818 .11998 L
.2656 .1119 L
.26386 .10404 L
.26332 .1002 L
.26301 .09641 L
.26311 .08902 L
.26353 .08541 L
.2642 .08186 L
.26634 .07495 L
.26782 .0716 L
.26957 .06831 L
.27395 .06192 L
.27659 .05883 L
.27953 .05581 L
.28635 .04997 L
.29447 .04443 L
.31479 .03423 L
s
.5 .48136 m
.49213 .48829 L
.48395 .49369 L
.47549 .49764 L
.47116 .4991 L
.46677 .50023 L
.45781 .50153 L
.44863 .50162 L
.43925 .50059 L
.42969 .49851 L
.41997 .49547 L
.4101 .49154 L
.39003 .48136 L
.36964 .46861 L
.34909 .45392 L
.32854 .43795 L
.30815 .42134 L
.28808 .40473 L
.26849 .38876 L
.24954 .37407 L
.2314 .36132 L
.21423 .35114 L
.20605 .34721 L
.19818 .34417 L
.19063 .34209 L
.18698 .34144 L
.18341 .34106 L
.17994 .34096 L
.17656 .34116 L
.17328 .34165 L
.17168 .34201 L
.1701 .34246 L
.16701 .34358 L
.16403 .34504 L
.16116 .34684 L
.15976 .34787 L
.15839 .34899 L
.15319 .35439 L
.15076 .35766 L
.14845 .36132 L
.14419 .36985 L
.14043 .38008 L
.13451 .40591 L
.13084 .43945 L
.12958 .48136 L
s
.5 .48136 m
.49307 .48924 L
.48767 .49741 L
.48372 .50587 L
.48226 .5102 L
.48114 .51459 L
.47984 .52355 L
.47974 .53273 L
.48077 .54211 L
.48285 .55167 L
.48589 .5614 L
.48982 .57126 L
.5 .59133 L
.51275 .61172 L
.52744 .63227 L
.54341 .65282 L
.56002 .67322 L
.57663 .69329 L
.5926 .71287 L
.60729 .73182 L
.62004 .74996 L
.63022 .76713 L
.63415 .77531 L
.63719 .78318 L
.63927 .79074 L
.63992 .79439 L
.6403 .79795 L
.6404 .80142 L
.64021 .8048 L
.63971 .80808 L
.63935 .80969 L
.63891 .81127 L
.63778 .81435 L
.63632 .81733 L
.63452 .82021 L
.63349 .8216 L
.63237 .82297 L
.62697 .82818 L
.6237 .83061 L
.62004 .83292 L
.61151 .83717 L
.60129 .84093 L
.57546 .84685 L
.54191 .85052 L
.5 .85178 L
s
.5 .85178 m
.48395 .8234 L
.46677 .79969 L
.44863 .78016 L
.42969 .76432 L
.4101 .7517 L
.39003 .74181 L
.36964 .73418 L
.34909 .72831 L
.32854 .72373 L
.30815 .71995 L
.28808 .71649 L
.26849 .71287 L
.24954 .70861 L
.2314 .70323 L
.21423 .69623 L
.19818 .68715 L
.18341 .67549 L
.1701 .66078 L
.15839 .64254 L
.14845 .62027 L
.14043 .5935 L
.13451 .56175 L
.13084 .52453 L
.12958 .48136 L
s
.87042 .48136 m
.85623 .45943 L
.84437 .43735 L
.83461 .41516 L
.82669 .39294 L
.82038 .37074 L
.81543 .34862 L
.81162 .32665 L
.80868 .30488 L
.80639 .28338 L
.8045 .2622 L
.80277 .24142 L
.80096 .22108 L
.79883 .20126 L
.79614 .182 L
.79264 .16338 L
.7881 .14544 L
.78227 .12827 L
.77492 .1119 L
.7658 .09641 L
.75466 .08186 L
.74128 .06831 L
.7254 .05581 L
.70679 .04443 L
.68521 .03423 L
s
.87042 .48136 m
.85623 .46316 L
.85002 .45664 L
.84437 .45171 L
.84174 .44982 L
.83924 .44829 L
.83686 .44711 L
.83572 .44665 L
.83461 .44627 L
.83246 .44576 L
.83043 .44557 L
.82851 .44569 L
.82758 .44586 L
.82713 .44597 L
.82669 .4461 L
.82497 .44679 L
.82415 .44724 L
.82335 .44776 L
.82182 .44898 L
.82109 .44969 L
.82038 .45045 L
.81775 .45409 L
.81543 .45859 L
.81162 .46976 L
.80868 .48323 L
.80639 .49825 L
.8045 .51408 L
.80277 .52998 L
.80096 .5452 L
.79883 .559 L
.79614 .57064 L
.79451 .57541 L
.79264 .57937 L
.79162 .58101 L
.79052 .58242 L
.78935 .58357 L
.78874 .58405 L
.78842 .58426 L
.7881 .58446 L
.78745 .5848 L
.78678 .58507 L
.78608 .58527 L
.78573 .58535 L
.78536 .5854 L
.78463 .58545 L
.78387 .58543 L
.78308 .58533 L
.78268 .58525 L
.78248 .5852 L
.78227 .58515 L
Mistroke
.78059 .58455 L
.7788 .58362 L
.77691 .58234 L
.77492 .58071 L
.77059 .57633 L
.7658 .57039 L
.75466 .55346 L
.74128 .52916 L
.7254 .49675 L
.70679 .45549 L
.68521 .40465 L
Mfstroke
.68521 .40465 m
.68867 .39821 L
.69137 .39115 L
.69335 .38351 L
.69464 .37533 L
.69534 .35748 L
.69378 .33789 L
.6903 .31686 L
.68521 .29468 L
.67883 .27165 L
.67149 .24805 L
.6635 .22419 L
.6552 .20036 L
.64689 .17685 L
.63891 .15396 L
.63156 .13197 L
.62519 .11119 L
.6201 .0919 L
.61661 .07441 L
.61506 .059 L
.61511 .05217 L
.61576 .04597 L
.61705 .04044 L
.61795 .03794 L
.61902 .03562 L
.62028 .03348 L
.62172 .03154 L
.62336 .02978 L
.62425 .02898 L
.62519 .02823 L
.62722 .02688 L
.62945 .02574 L
.6319 .02481 L
.63321 .02443 L
.63457 .0241 L
.64056 .02335 L
.64748 .02353 L
.66425 .02681 L
.68521 .03423 L
s
.5 .85178 m
.49988 .85334 L
.49953 .85484 L
.49894 .85628 L
.49857 .85698 L
.49814 .85766 L
.49712 .85897 L
.49589 .86023 L
.49445 .86142 L
.49282 .86257 L
.48899 .86469 L
.48445 .86661 L
.47342 .86989 L
.46014 .87251 L
.44502 .87455 L
.42844 .87614 L
.41083 .87735 L
.39256 .8783 L
.37406 .87908 L
.35572 .8798 L
.33794 .88055 L
.32113 .88143 L
.30568 .88255 L
.292 .88399 L
.28049 .88588 L
.27568 .88701 L
.27156 .88829 L
.26818 .88973 L
.26678 .89051 L
.26616 .89092 L
.2656 .89134 L
.26462 .89221 L
.26421 .89266 L
.26386 .89313 L
.26356 .89361 L
.26332 .8941 L
.26313 .8946 L
.26306 .89486 L
.26304 .89499 L
.26301 .89512 L
.26294 .89564 L
.26294 .89619 L
.26299 .89674 L
.26304 .89702 L
.26311 .89731 L
.26353 .89849 L
.26383 .8991 L
.2642 .89973 L
.26634 .90238 L
.26957 .90527 L
Mistroke
.27953 .91185 L
.29447 .91956 L
.31479 .9285 L
Mfstroke
.5 .85178 m
.50012 .85334 L
.50047 .85484 L
.50106 .85628 L
.50143 .85698 L
.50186 .85766 L
.50288 .85897 L
.50411 .86023 L
.50555 .86142 L
.50718 .86257 L
.51101 .86469 L
.51555 .86661 L
.52658 .86989 L
.53986 .87251 L
.55498 .87455 L
.57156 .87614 L
.58917 .87735 L
.60744 .8783 L
.62594 .87908 L
.64428 .8798 L
.66206 .88055 L
.67887 .88143 L
.69432 .88255 L
.708 .88399 L
.71951 .88588 L
.72432 .88701 L
.72844 .88829 L
.73182 .88973 L
.73322 .89051 L
.73384 .89092 L
.7344 .89134 L
.73538 .89221 L
.73579 .89266 L
.73614 .89313 L
.73644 .89361 L
.73668 .8941 L
.73687 .8946 L
.73694 .89486 L
.73696 .89499 L
.73699 .89512 L
.73706 .89564 L
.73706 .89619 L
.73701 .89674 L
.73696 .89702 L
.73689 .89731 L
.73647 .89849 L
.73617 .8991 L
.7358 .89973 L
.73366 .90238 L
.73043 .90527 L
Mistroke
.72047 .91185 L
.70553 .91956 L
.68521 .9285 L
Mfstroke
.68521 .9285 m
.663 .92594 L
.64255 .92459 L
.62371 .9243 L
.60632 .92494 L
.59022 .92639 L
.57524 .9285 L
.56123 .93114 L
.54802 .93418 L
.53545 .93749 L
.52337 .94093 L
.5116 .94437 L
.5 .94767 L
.4884 .95072 L
.47663 .95336 L
.46455 .95547 L
.45198 .95691 L
.43877 .95755 L
.42476 .95726 L
.40978 .95591 L
.39368 .95336 L
.37629 .94947 L
.35745 .94412 L
.337 .93717 L
.31479 .9285 L
s
.94713 .66657 m
.94458 .64436 L
.94323 .62391 L
.94294 .60508 L
.94358 .58769 L
.94502 .57158 L
.94713 .5566 L
.94977 .54259 L
.95282 .52938 L
.95612 .51681 L
.95956 .50473 L
.963 .49296 L
.96631 .48136 L
.96935 .46976 L
.972 .458 L
.9741 .44591 L
.97555 .43335 L
.97619 .42013 L
.9759 .40612 L
.97455 .39114 L
.972 .37504 L
.96811 .35765 L
.96276 .33881 L
.95581 .31837 L
.94713 .29615 L
s
.94713 .66657 m
.94381 .64622 L
.94025 .63109 L
.9384 .62531 L
.9365 .62063 L
.93455 .61697 L
.93357 .6155 L
.93257 .61427 L
.93157 .61325 L
.93056 .61245 L
.92954 .61185 L
.92903 .61162 L
.92877 .61152 L
.92851 .61144 L
.92748 .61122 L
.92697 .61118 L
.92645 .61118 L
.92541 .6113 L
.92488 .61143 L
.92436 .61159 L
.92331 .61202 L
.92225 .6126 L
.9212 .61331 L
.92014 .61415 L
.91588 .61855 L
.91162 .62425 L
.9074 .63067 L
.90324 .63724 L
.89919 .64342 L
.89526 .64863 L
.89336 .6507 L
.89151 .65232 L
.8906 .65293 L
.8897 .65341 L
.88882 .65374 L
.88838 .65384 L
.88816 .65388 L
.88795 .65391 L
.88752 .65393 L
.88709 .65392 L
.88667 .65385 L
.88646 .65381 L
.88625 .65375 L
.88584 .6536 L
.88543 .6534 L
.88503 .65315 L
.88482 .65301 L
.88462 .65285 L
.88383 .65211 L
.88306 .65115 L
Mistroke
.8823 .64998 L
.88157 .64858 L
.87881 .64053 L
.87638 .62813 L
.87432 .61084 L
.87266 .58807 L
.87144 .55928 L
.87068 .5239 L
.87042 .48136 L
Mfstroke
.87042 .48136 m
.87198 .48124 L
.87348 .48089 L
.87492 .48031 L
.87561 .47993 L
.87629 .4795 L
.87761 .47848 L
.87886 .47725 L
.88006 .47581 L
.88121 .47418 L
.88333 .47035 L
.88525 .46581 L
.88853 .45478 L
.89114 .4415 L
.89319 .42638 L
.89477 .40981 L
.89599 .39219 L
.89694 .37393 L
.89772 .35542 L
.89844 .33708 L
.89919 .3193 L
.90007 .30249 L
.90118 .28704 L
.90263 .27336 L
.90451 .26186 L
.90565 .25704 L
.90693 .25292 L
.90837 .24954 L
.90915 .24815 L
.90956 .24753 L
.90997 .24696 L
.91085 .24598 L
.9113 .24557 L
.91177 .24522 L
.91224 .24492 L
.91273 .24468 L
.91324 .2445 L
.91349 .24443 L
.91362 .2444 L
.91375 .24437 L
.91428 .24431 L
.91482 .2443 L
.91538 .24435 L
.91566 .2444 L
.91595 .24447 L
.91713 .24489 L
.91774 .24519 L
.91836 .24556 L
.92101 .2477 L
.92391 .25094 L
Mistroke
.93048 .26089 L
.93819 .27583 L
.94713 .29615 L
Mfstroke
0 0 m
1 0 L
1 .98091 L
0 .98091 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.504983 0.97619 0.726467 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.493273 0.531249 0.493273 0.531249 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.03 .18 .33 r
.5 Mabswid
[ ] 0 setdash
.22765 .22765 m
.22661 .22644 L
.22579 .22511 L
.22518 .22366 L
.22495 .22289 L
.22477 .2221 L
.22456 .22042 L
.22454 .21864 L
.22471 .21675 L
.22506 .21476 L
.22628 .21049 L
.22817 .20586 L
.23372 .1956 L
.24137 .1842 L
.25075 .17189 L
.2615 .15887 L
.27326 .14536 L
.28567 .13159 L
.29838 .11776 L
.31102 .10409 L
.32323 .09081 L
.33465 .07812 L
.34493 .06624 L
.3537 .05539 L
.36061 .04579 L
.36324 .04153 L
.36528 .03765 L
.36667 .0342 L
.36711 .03264 L
.36727 .0319 L
.36737 .03119 L
.36745 .02986 L
.36742 .02925 L
.36734 .02866 L
.36721 .0281 L
.36703 .02758 L
.3668 .02709 L
.36666 .02685 L
.36659 .02674 L
.36652 .02663 L
.36619 .0262 L
.3658 .02581 L
.36536 .02545 L
.36512 .02528 L
.36487 .02512 L
.36373 .02458 L
.36307 .02436 L
.36236 .02418 L
.35892 .02381 L
.35453 .02405 L
Mistroke
.34267 .02648 L
.32643 .03166 L
.30545 .03982 L
Mfstroke
.22765 .22765 m
.22644 .22661 L
.22511 .22579 L
.22366 .22518 L
.22289 .22495 L
.2221 .22477 L
.22042 .22456 L
.21864 .22454 L
.21675 .22471 L
.21476 .22506 L
.21049 .22628 L
.20586 .22817 L
.1956 .23372 L
.1842 .24137 L
.17189 .25075 L
.15887 .2615 L
.14536 .27326 L
.13159 .28567 L
.11776 .29838 L
.10409 .31102 L
.09081 .32323 L
.07812 .33465 L
.06624 .34493 L
.05539 .3537 L
.04579 .36061 L
.04153 .36324 L
.03765 .36528 L
.0342 .36667 L
.03264 .36711 L
.0319 .36727 L
.03119 .36737 L
.02986 .36745 L
.02925 .36742 L
.02866 .36734 L
.0281 .36721 L
.02758 .36703 L
.02709 .3668 L
.02685 .36666 L
.02674 .36659 L
.02663 .36652 L
.0262 .36619 L
.02581 .3658 L
.02545 .36536 L
.02528 .36512 L
.02512 .36487 L
.02458 .36373 L
.02436 .36307 L
.02418 .36236 L
.02381 .35892 L
.02405 .35453 L
Mistroke
.02648 .34267 L
.03166 .32643 L
.03982 .30545 L
Mfstroke
.03982 .30545 m
.05758 .29135 L
.07321 .27766 L
.08693 .26436 L
.09894 .25143 L
.10945 .23884 L
.11868 .22659 L
.12684 .21465 L
.13413 .20299 L
.14077 .19161 L
.14697 .18048 L
.15293 .16957 L
.15888 .15888 L
.16502 .14838 L
.17156 .13805 L
.17872 .12787 L
.18669 .11783 L
.1957 .10789 L
.20596 .09805 L
.21767 .08828 L
.23105 .07856 L
.24631 .06888 L
.26365 .05921 L
.2833 .04953 L
.30545 .03982 L
s
.6811 .41547 m
.66649 .41645 L
.65261 .41617 L
.63942 .41472 L
.6269 .41215 L
.60369 .40395 L
.58273 .39212 L
.56375 .37719 L
.54648 .35971 L
.53066 .34023 L
.51604 .31928 L
.50233 .2974 L
.48928 .27515 L
.47662 .25306 L
.4641 .23168 L
.45144 .21154 L
.43838 .1932 L
.42465 .17719 L
.41746 .17023 L
.41 .16405 L
.40224 .15873 L
.39824 .15641 L
.39416 .15434 L
.3857 .15093 L
.38133 .14962 L
.37685 .14858 L
.36757 .14736 L
.36276 .14719 L
.35783 .14733 L
.34759 .14857 L
.33682 .15113 L
.31356 .16052 L
.28779 .17604 L
.25924 .19824 L
.22765 .22765 L
s
.6811 .41547 m
.66697 .41761 L
.6545 .42073 L
.6436 .42479 L
.63871 .42716 L
.63418 .42973 L
.62616 .4355 L
.62266 .43868 L
.61947 .44204 L
.614 .44929 L
.6117 .45316 L
.60969 .4572 L
.60644 .46571 L
.60417 .47478 L
.60224 .49433 L
.60323 .51542 L
.60647 .5376 L
.61128 .56044 L
.617 .58349 L
.62294 .6063 L
.62845 .62845 L
.63284 .64948 L
.63544 .66895 L
.63586 .67797 L
.63559 .68643 L
.63453 .69428 L
.63368 .69797 L
.63261 .70147 L
.63129 .7048 L
.62973 .70794 L
.62791 .71089 L
.6269 .71229 L
.62583 .71364 L
.62346 .71618 L
.6208 .7185 L
.61784 .7206 L
.61624 .72157 L
.61457 .72248 L
.60705 .72552 L
.60279 .72667 L
.59817 .72756 L
.58783 .72855 L
.57595 .72844 L
.54725 .72467 L
.51138 .71582 L
.46768 .70144 L
.41547 .6811 L
s
.41547 .6811 m
.41645 .66649 L
.41617 .65261 L
.41472 .63942 L
.41215 .6269 L
.40395 .60369 L
.39212 .58273 L
.37719 .56375 L
.35971 .54648 L
.34023 .53066 L
.31928 .51604 L
.2974 .50233 L
.27515 .48928 L
.25306 .47662 L
.23168 .4641 L
.21154 .45144 L
.1932 .43838 L
.17719 .42465 L
.17023 .41746 L
.16405 .41 L
.15873 .40224 L
.15641 .39824 L
.15434 .39416 L
.15093 .3857 L
.14962 .38133 L
.14858 .37685 L
.14736 .36757 L
.14719 .36276 L
.14733 .35783 L
.14857 .34759 L
.15113 .33682 L
.16052 .31356 L
.17604 .28779 L
.19824 .25924 L
.22765 .22765 L
s
.41547 .6811 m
.40894 .68461 L
.40179 .68735 L
.39404 .68935 L
.38574 .69066 L
.36764 .69137 L
.34777 .68979 L
.32644 .68626 L
.30395 .6811 L
.28059 .67463 L
.25667 .66719 L
.23247 .65909 L
.2083 .65066 L
.18446 .64224 L
.16124 .63414 L
.13895 .6267 L
.11787 .62023 L
.09831 .61507 L
.08057 .61153 L
.06495 .60996 L
.05802 .61 L
.05174 .61066 L
.04613 .61197 L
.04359 .61289 L
.04123 .61398 L
.03907 .61525 L
.03709 .61672 L
.03532 .61837 L
.0345 .61928 L
.03374 .62023 L
.03237 .62229 L
.03122 .62456 L
.03028 .62704 L
.02989 .62836 L
.02956 .62974 L
.0288 .63582 L
.02898 .64284 L
.0323 .65985 L
.03982 .6811 L
s
.41547 .6811 m
.41258 .68307 L
.4101 .68509 L
.40803 .68715 L
.40714 .68819 L
.40634 .68924 L
.40504 .69136 L
.40453 .69244 L
.40411 .69353 L
.40354 .69572 L
.40339 .69683 L
.40334 .69739 L
.40332 .69795 L
.40344 .7002 L
.40362 .70134 L
.40389 .70249 L
.40465 .7048 L
.40515 .70597 L
.40572 .70714 L
.40874 .7119 L
.41285 .71675 L
.42403 .72668 L
.43857 .73686 L
.45579 .7472 L
.475 .75762 L
.49551 .76804 L
.51664 .77838 L
.5377 .78856 L
.55801 .79849 L
.57688 .80809 L
.59363 .81729 L
.60756 .826 L
.61326 .83015 L
.618 .83414 L
.62169 .83797 L
.62311 .83982 L
.62372 .84073 L
.62425 .84163 L
.62508 .84339 L
.62538 .84425 L
.62559 .8451 L
.62573 .84594 L
.62578 .84676 L
.62575 .84758 L
.6257 .84798 L
.62567 .84818 L
.62563 .84838 L
.62543 .84917 L
.62514 .84994 L
.62476 .85071 L
Mistroke
.62453 .85108 L
.62428 .85146 L
.62306 .85291 L
.62231 .85362 L
.62146 .85432 L
.61708 .85695 L
.61105 .85936 L
.59371 .86342 L
.56876 .86642 L
.53551 .86828 L
.49327 .86892 L
Mfstroke
.49327 .86892 m
.47104 .85453 L
.44864 .84251 L
.42614 .83261 L
.4036 .82458 L
.38109 .81818 L
.35866 .81316 L
.33637 .80929 L
.3143 .80631 L
.29249 .80399 L
.27102 .80208 L
.24994 .80032 L
.22932 .79849 L
.20921 .79633 L
.18968 .7936 L
.1708 .79005 L
.15261 .78545 L
.13519 .77954 L
.11859 .77208 L
.10289 .76282 L
.08813 .75153 L
.07438 .73796 L
.06171 .72186 L
.05017 .70299 L
.03982 .6811 L
s
.86892 .49327 m
.85453 .47104 L
.84251 .44864 L
.83261 .42614 L
.82458 .4036 L
.81818 .38109 L
.81316 .35866 L
.80929 .33637 L
.80631 .3143 L
.80399 .29249 L
.80208 .27102 L
.80032 .24994 L
.79849 .22932 L
.79633 .20921 L
.7936 .18968 L
.79005 .1708 L
.78545 .15261 L
.77954 .13519 L
.77208 .11859 L
.76282 .10289 L
.75153 .08813 L
.73796 .07438 L
.72186 .06171 L
.70299 .05017 L
.6811 .03982 L
s
.86892 .49327 m
.85453 .47481 L
.84824 .4682 L
.84251 .4632 L
.83984 .46128 L
.83731 .45973 L
.8349 .45854 L
.83374 .45807 L
.83261 .45769 L
.83043 .45717 L
.82837 .45698 L
.82642 .4571 L
.82549 .45727 L
.82503 .45738 L
.82458 .45751 L
.82283 .45822 L
.822 .45867 L
.82119 .45919 L
.81964 .46043 L
.8189 .46115 L
.81818 .46193 L
.81551 .46562 L
.81316 .47018 L
.80929 .48151 L
.80631 .49517 L
.80399 .5104 L
.80208 .52645 L
.80032 .54257 L
.79849 .55801 L
.79633 .57201 L
.7936 .58381 L
.79194 .58865 L
.79005 .59267 L
.78901 .59433 L
.7879 .59576 L
.78671 .59692 L
.78609 .59741 L
.78577 .59763 L
.78545 .59783 L
.78478 .59817 L
.7841 .59845 L
.7834 .59865 L
.78303 .59873 L
.78267 .59878 L
.78192 .59883 L
.78115 .59881 L
.78035 .59871 L
.77995 .59863 L
.77974 .59858 L
.77954 .59853 L
Mistroke
.77783 .59792 L
.77601 .59698 L
.7741 .59568 L
.77208 .59403 L
.76769 .58959 L
.76282 .58356 L
.75153 .56639 L
.73796 .54174 L
.72186 .50888 L
.70299 .46704 L
.6811 .41547 L
Mfstroke
.6811 .41547 m
.68461 .40894 L
.68735 .40179 L
.68935 .39404 L
.69066 .38574 L
.69137 .36764 L
.68979 .34777 L
.68626 .32644 L
.6811 .30395 L
.67463 .28059 L
.66719 .25667 L
.65909 .23247 L
.65066 .2083 L
.64224 .18446 L
.63414 .16124 L
.6267 .13895 L
.62023 .11787 L
.61507 .09831 L
.61153 .08057 L
.60996 .06495 L
.61 .05802 L
.61066 .05174 L
.61197 .04613 L
.61289 .04359 L
.61398 .04123 L
.61525 .03907 L
.61672 .03709 L
.61837 .03532 L
.61928 .0345 L
.62023 .03374 L
.62229 .03237 L
.62456 .03122 L
.62704 .03028 L
.62836 .02989 L
.62974 .02956 L
.63582 .0288 L
.64284 .02898 L
.65985 .0323 L
.6811 .03982 L
s
.49327 .86892 m
.49315 .87051 L
.49279 .87203 L
.4922 .87349 L
.49182 .87419 L
.49138 .87488 L
.49035 .87622 L
.4891 .87749 L
.48765 .8787 L
.48599 .87986 L
.48211 .88202 L
.4775 .88397 L
.46632 .88729 L
.45285 .88994 L
.43751 .89202 L
.42071 .89362 L
.40284 .89486 L
.38432 .89582 L
.36556 .89661 L
.34696 .89734 L
.32893 .8981 L
.31187 .89899 L
.29621 .90012 L
.28234 .90159 L
.27067 .9035 L
.26578 .90465 L
.2616 .90595 L
.25818 .90741 L
.25676 .9082 L
.25613 .90861 L
.25556 .90904 L
.25456 .90992 L
.25415 .91038 L
.25379 .91086 L
.25349 .91134 L
.25325 .91184 L
.25306 .91235 L
.25299 .91261 L
.25296 .91274 L
.25293 .91287 L
.25287 .91341 L
.25286 .91396 L
.25292 .91452 L
.25297 .91481 L
.25304 .9151 L
.25346 .91629 L
.25377 .91691 L
.25414 .91755 L
.25631 .92023 L
.25959 .92317 L
Mistroke
.26969 .92984 L
.28484 .93766 L
.30545 .94672 L
Mfstroke
.49327 .86892 m
.49339 .87051 L
.49375 .87203 L
.49435 .87349 L
.49473 .87419 L
.49516 .87488 L
.4962 .87622 L
.49745 .87749 L
.4989 .8787 L
.50056 .87986 L
.50444 .88202 L
.50905 .88397 L
.52023 .88729 L
.53369 .88994 L
.54903 .89202 L
.56584 .89362 L
.58371 .89486 L
.60223 .89582 L
.62099 .89661 L
.63959 .89734 L
.65762 .8981 L
.67467 .89899 L
.69034 .90012 L
.70421 .90159 L
.71588 .9035 L
.72076 .90465 L
.72494 .90595 L
.72837 .90741 L
.72978 .9082 L
.73041 .90861 L
.73099 .90904 L
.73198 .90992 L
.7324 .91038 L
.73275 .91086 L
.73306 .91134 L
.7333 .91184 L
.73348 .91235 L
.73356 .91261 L
.73359 .91274 L
.73361 .91287 L
.73368 .91341 L
.73368 .91396 L
.73363 .91452 L
.73358 .91481 L
.73351 .9151 L
.73309 .91629 L
.73278 .91691 L
.7324 .91755 L
.73023 .92023 L
.72695 .92317 L
Mistroke
.71686 .92984 L
.70171 .93766 L
.6811 .94672 L
Mfstroke
.6811 .94672 m
.65857 .94413 L
.63784 .94276 L
.61873 .94247 L
.6011 .94312 L
.58477 .94458 L
.56958 .94672 L
.55537 .9494 L
.54197 .95249 L
.52922 .95584 L
.51697 .95933 L
.50504 .96282 L
.49327 .96617 L
.48151 .96926 L
.46958 .97194 L
.45732 .97407 L
.44458 .97554 L
.43118 .97619 L
.41697 .9759 L
.40178 .97452 L
.38545 .97194 L
.36781 .968 L
.34871 .96257 L
.32798 .95552 L
.30545 .94672 L
s
.94672 .6811 m
.94413 .65857 L
.94276 .63784 L
.94247 .61873 L
.94312 .6011 L
.94458 .58477 L
.94672 .56958 L
.9494 .55537 L
.95249 .54197 L
.95584 .52922 L
.95933 .51697 L
.96282 .50504 L
.96617 .49327 L
.96926 .48151 L
.97194 .46958 L
.97407 .45732 L
.97554 .44458 L
.97619 .43118 L
.9759 .41697 L
.97452 .40178 L
.97194 .38545 L
.968 .36781 L
.96257 .34871 L
.95552 .32798 L
.94672 .30545 L
s
.94672 .6811 m
.94335 .66046 L
.93974 .64512 L
.93786 .63926 L
.93593 .63451 L
.93396 .6308 L
.93296 .62931 L
.93196 .62806 L
.93094 .62702 L
.92991 .62621 L
.92888 .6256 L
.92836 .62537 L
.9281 .62527 L
.92784 .62519 L
.9268 .62497 L
.92627 .62492 L
.92574 .62492 L
.92469 .62505 L
.92416 .62517 L
.92363 .62534 L
.92256 .62578 L
.92149 .62637 L
.92042 .62709 L
.91934 .62793 L
.91503 .6324 L
.91071 .63818 L
.90643 .64469 L
.90221 .65136 L
.8981 .65762 L
.89412 .66291 L
.89219 .665 L
.89031 .66664 L
.88939 .66727 L
.88848 .66775 L
.88758 .66808 L
.88714 .66819 L
.88692 .66823 L
.8867 .66826 L
.88627 .66828 L
.88584 .66826 L
.88541 .6682 L
.8852 .66815 L
.88498 .66809 L
.88456 .66794 L
.88415 .66774 L
.88374 .66749 L
.88353 .66734 L
.88333 .66719 L
.88253 .66643 L
.88174 .66546 L
Mistroke
.88098 .66427 L
.88023 .66285 L
.87743 .65469 L
.87497 .64212 L
.87289 .62458 L
.8712 .60149 L
.86996 .57229 L
.86919 .53641 L
.86892 .49327 L
Mfstroke
.86892 .49327 m
.87051 .49315 L
.87203 .49279 L
.87349 .4922 L
.87419 .49182 L
.87488 .49138 L
.87622 .49035 L
.87749 .4891 L
.8787 .48765 L
.87986 .48599 L
.88202 .48211 L
.88397 .4775 L
.88729 .46632 L
.88994 .45285 L
.89202 .43751 L
.89362 .42071 L
.89486 .40284 L
.89582 .38432 L
.89661 .36556 L
.89734 .34696 L
.8981 .32893 L
.89899 .31187 L
.90012 .29621 L
.90159 .28234 L
.9035 .27067 L
.90465 .26578 L
.90595 .2616 L
.90741 .25818 L
.9082 .25676 L
.90861 .25613 L
.90904 .25556 L
.90992 .25456 L
.91038 .25415 L
.91086 .25379 L
.91134 .25349 L
.91184 .25325 L
.91235 .25306 L
.91261 .25299 L
.91274 .25296 L
.91287 .25293 L
.91341 .25287 L
.91396 .25286 L
.91452 .25292 L
.91481 .25297 L
.9151 .25304 L
.91629 .25346 L
.91691 .25377 L
.91755 .25414 L
.92023 .25631 L
.92317 .25959 L
Mistroke
.92984 .26969 L
.93766 .28484 L
.94672 .30545 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[276]:=",
  ImageSize->{487, 362.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007W0001JR000`400?l00000o`00003oo`3ooooX
0?ooo`00o`3ooooX0?ooo`00o`3ooooX0?ooo`00o`3ooooX0?ooo`00o`3ooooX0?ooo`00o`3ooooX
0?ooo`00o`3ooooX0?ooo`00o`3ooooX0?ooo`00o`3ooooX0?ooo`00o`3ooooX0?ooo`00o`3ooooX
0?ooo`00C`3oool200L^E>80oooo1007;UB`0?ooo`00;`3oool700L^E1T0oooo00<01biD0?ooo`07
;U@00`07;UAB0?ooo`<01biD6`3oool300L^E6H0oooo1@07;U@40?ooo`D01biDZ`3oool002`0oooo
0`07;U@70?ooo`801biD5`3oool00`07;U@0oooo0?ooo`030?ooo`801biDC03oool400L^E080oooo
0P07;U@I0?ooo`801biD0P3oool400L^E5h0oooo1007;U@>0?ooo`801biDE@3oool300L^E1`0oooo
0`07;U@b0?ooo`00:P3oool200L^E0`0oooo0P07;U@F0?ooo`0300L^E03oool0oooo00<0oooo00<0
1biD0?ooo`3oool0B@3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo01H0oooo00<0
1biD0?ooo`3oool01@3oool200L^E4`0oooo00<01biD0?ooo`3oool02@3oool400L^E1@0oooo1@07
;UA=0?ooo`<01biD0`3oool300L^E1P0oooo0P07;U@20?ooo`@01biD;P3oool002T0oooo00<01biD
0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo00@0oooo00<01biD
0?ooo`3oool0A`3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo01H0oooo00<01biD
0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`170?ooo`801biD00<0oooo00L^E007;U@02@07;U@M
0?ooo`801biDBP3oool00`07;U@0oooo0?ooo`060?ooo`801biD5P3oool200L^E0L0oooo00<01biD
0?ooo`3oool0:`3oool002P0oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`0D0?oo
o`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool0A03oool200L^E0X0oooo00<01biD0?oo
o`3oool05P3oool00`07;U@0oooo0?ooo`080?ooo`801biDA@3oool200L^E2d0oooo00<01biD0?oo
o`3oool0AP3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?oo
o`3oool01`3oool00`07;U@0oooo0?ooo`0Z0?ooo`009`3oool200L^E180oooo00<01biD0?ooo`3o
ool0503oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo0440oooo0P07;U@<0?ooo`03
00L^E03oool0oooo01H0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`110?ooo`03
00L^E03oool0oooo02h0oooo0P07;UA40?ooo`801biD303oool00`07;U@0oooo0?ooo`0C0?ooo`03
00L^E03oool0oooo00P0oooo0P07;U@Z0?ooo`009`3oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^
E03oool0oooo01@0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0o0?ooo`0300L^
E03oool0oooo00`0oooo00<01biD0?ooo`3oool05P3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^
E03oool0oooo03l0oooo00<01biD0?ooo`3oool0<03oool00`07;U@0oooo0?ooo`110?ooo`0300L^
E03oool0oooo00`0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo0?ooo`0:0?ooo`801biD
:03oool002L0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03o
ool0oooo00<0oooo00<01biD0?ooo`3oool0?`3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03o
ool0oooo01L0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0n0?ooo`H01biD:@3o
ool500L^E480oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03o
ool0oooo00/0oooo00<01biD0?ooo`3oool09P3oool002L0oooo00<01biD0?ooo`3oool04`3oool0
0`07;U@0oooo0?ooo`0E0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool0?@3oool0
0`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo01L0oooo00<01biD0?ooo`3oool03@3oool0
0`07;U@0oooo0?ooo`130?oooa001biD203ooolA00L^E4L0oooo00<01biD0?ooo`3oool03P3oool0
0`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool09@3oool0
02L0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo
00@0oooo0P07;U@l0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool05`3oool00`07
;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo05<0oooo0`07;U@20?ooo`<01biDE`3oool00`07
;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool0303oool00`07
;U@0oooo0?ooo`0T0?ooo`009`3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo01D0
oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0i0?ooo`0300L^E03oool0oooo00d0
oooo00<01biD0?ooo`3oool0603oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo05D0
oooo0P07;UAJ0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool04P3oool00`07;U@0
oooo0?ooo`0<0?ooo`0300L^E03oool0oooo02@0oooo000W0?ooo`801biD5P3oool00`07;U@0oooo
0?ooo`0E0?ooo`801biD1P3oool300L^E3L0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo
0?ooo`0I0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool0C@3ooolC00L^E540oooo
00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo00d0oooo
00<01biD0?ooo`3oool08`3oool002P0oooo00<01biD0?ooo`3oool05@3oool00`07;U@0oooo0?oo
o`0E0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool0=03oool00`07;U@0oooo0?oo
o`0=0?ooo`0300L^E03oool0oooo01T0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?oo
o`190?ooo`<01biD4`3oool400L^E4d0oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?oo
o`0B0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool08`3oool002T0oooo00<01biD
0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0?0?ooo`<01biD103oool00`07;U@0oooo0?ooo`07
0?ooo`801biD<`3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo01X0oooo00<01biD
0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`170?ooo`801biD6P3oool200L^E4X0oooo00<01biD
0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo00d0oooo00<01biD
0?ooo`3oool08P3oool002T0oooo00<01biD0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`0>0?oo
o`0300L^E03oool0oooo00801biD0`3oool00`07;U@0oooo0?ooo`080?ooo`801biD<@3oool00`07
;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo01/0oooo00<01biD0?ooo`3oool03@3oool00`07
;U@0oooo0?ooo`160?ooo`0300L^E03oool0oooo01`0oooo0P07;UA80?ooo`0300L^E03oool0oooo
0140oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo
0240oooo000Z0?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0
oooo0?ooo`020?ooo`0500L^E03oool0oooo0?ooo`07;U@02`3oool200L^E2l0oooo00<01biD0?oo
o`3oool03@3oool00`07;U@0oooo0?ooo`0K0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?oo
o`3oool0A@3oool00`07;U@0oooo0?ooo`0N0?ooo`801biDAP3oool00`07;U@0oooo0?ooo`0A0?oo
o`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0Q0?oo
o`00:`3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3o
ool00`3oool01@07;U@0oooo0?ooo`3oool01biD00`0oooo00<01biD0?ooo`3oool0:`3oool00`07
;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo01`0oooo00<01biD0?ooo`3oool03@3oool00`07
;U@0oooo0?ooo`150?ooo`0300L^E03oool0oooo0200oooo00<01biD0?ooo`3oool0A03oool00`07
;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool03@3oool00`07
;U@0oooo0?ooo`0Q0?ooo`00;03oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo00d0
oooo00<01biD0?ooo`3oool0103oool200L^E080oooo00<01biD0?ooo`3oool02P3oool00`07;U@0
oooo0?ooo`0Z0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool0703oool00`07;U@0
oooo0?ooo`0=0?ooo`0300L^E03oool0oooo04D0oooo00<01biD0?ooo`3oool08@3oool00`07;U@0
oooo0?ooo`130?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool05@3oool00`07;U@0
oooo0?ooo`0<0?ooo`0300L^E03oool0oooo0240oooo000/0?ooo`0300L^E03oool0oooo01@0oooo
00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool01biD00d0oooo
00<01biD0?ooo`3oool0:@3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo01d0oooo
00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`150?ooo`0300L^E03oool0oooo0280oooo
00<01biD0?ooo`3oool0@P3oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo01D0oooo
00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0P0?ooo`00;@3oool00`07;U@0oooo0?oo
o`0D0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo00L^
E00=0?ooo`0300L^E03oool0oooo02P0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?oo
o`0N0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0A@3oool00`07;U@0oooo0?oo
o`0R0?ooo`0300L^E03oool0oooo0480oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?oo
o`0E0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool0803oool002d0oooo00<01biD
0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00H0oooo00<01biD
0?ooo`07;U@03P3oool00`07;U@0oooo0?ooo`0W0?ooo`0300L^E03oool0oooo00d0oooo00<01biD
0?ooo`3oool07P3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo04H0oooo00<01biD
0?ooo`3oool08P3oool00`07;U@0oooo0?ooo`120?ooo`0300L^E03oool0oooo0100oooo00<01biD
0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo0200oooo000^0?oo
o`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`070?oo
o`@01biD303oool00`07;U@0oooo0?ooo`0W0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?oo
o`3oool0803oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo04D0oooo00<01biD0?oo
o`3oool08P3oool00`07;U@0oooo0?ooo`120?ooo`0300L^E03oool0oooo0100oooo00<01biD0?oo
o`3oool05@3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo0200oooo000_0?ooo`03
00L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`070?ooo`03
00L^E03oool01biD00801biD2`3oool00`07;U@0oooo0?ooo`0V0?ooo`0300L^E03oool0oooo00`0
oooo00<01biD0?ooo`3oool0803oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo04H0
oooo00<01biD0?ooo`3oool08@3oool00`07;U@0oooo0?ooo`120?ooo`0300L^E03oool0oooo0100
oooo00<01biD0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo0200
oooo000`0?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo
0?ooo`080?ooo`0500L^E03oool0oooo0?ooo`07;U@02P3oool00`07;U@0oooo0?ooo`0V0?ooo`03
00L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool01`3oool400L^E1H0oooo00<01biD0?ooo`3o
ool0303oool00`07;U@0oooo0?ooo`160?ooo`0300L^E03oool0oooo0240oooo00<01biD0?ooo`3o
ool0@P3oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo01D0oooo00<01biD0?ooo`3o
ool0303oool00`07;U@0oooo0?ooo`0P0?ooo`005@3oool300L^E1T0oooo00<01biD0?ooo`3oool0
4P3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00T0oooo00D01biD0?ooo`3oool0
oooo00L^E00:0?ooo`0300L^E03oool0oooo01P0oooo0P07;U@;0?ooo`0300L^E03oool0oooo00/0
oooo00<01biD0?ooo`3oool01P3oool01007;U@0oooo0?ooo`3oool300L^E1D0oooo00<01biD0?oo
o`3oool02`3oool00`07;U@0oooo0?ooo`080?ooo`<01biD?03oool00`07;U@0oooo0?ooo`0Q0?oo
o`0300L^E03oool0oooo0440oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`0E0?oo
o`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0803oool001<0oooo0P07;U@30?ooo`<0
1biD5`3oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3o
ool02P3oool01007;U@0oooo0?ooo`3oool200L^E0T0oooo00<01biD0?ooo`3oool05`3oool300L^
E0X0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo
00@0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo
00P0oooo00<01biD0?ooo`07;U@06P3oool300L^E200oooo00<01biD0?ooo`3oool0803oool00`07
;U@0oooo0?ooo`0A0?ooo`801biD6`3oool200L^E180oooo00<01biD0?ooo`3oool03`3oool00`07
;U@0oooo0?ooo`0F0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool02@3oool200L^
E1D0oooo000B0?ooo`801biD1`3oool200L^E1H0oooo00<01biD0?ooo`3oool04@3oool00`07;U@0
oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00X0oooo00D01biD0?ooo`3oool0oooo00L^E0090?oo
o`0300L^E03oool0oooo01H0oooo00@01biD0?ooo`3oool01biD2P3oool00`07;U@0oooo0?ooo`0:
0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0C
0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool0203oool01007;U@0oooo0?ooo`07
;U@I0?ooo`0300L^E03oool01biD0240oooo00<01biD0?ooo`3oool0803oool00`07;U@0oooo0?oo
o`0?0?ooo`<01biD6P3oool00`07;U@0oooo00L^E00B0?ooo`0300L^E03oool0oooo00l0oooo00<0
1biD0?ooo`3oool05P3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00T0oooo00<0
1biD0?ooo`07;U@0503oool00140oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`0D
0?ooo`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`0;
0?ooo`0500L^E03oool0oooo0?ooo`07;U@02@3oool00`07;U@0oooo0?ooo`0D0?ooo`0500L^E03o
ool0oooo0?ooo`07;U@02@3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00@0oooo
00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo00X0oooo
00<01biD0?ooo`3oool0203oool01007;U@0oooo0?ooo`07;U@H0?ooo`0400L^E03oool0oooo00L^
E240oooo00<01biD0?ooo`3oool0803oool00`07;U@0oooo0?ooo`0?0?ooo`0400L^E03oool0oooo
00L^E1T0oooo00<01biD0?ooo`07;U@04P3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0
oooo01L0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`070?ooo`0400L^E03oool0
oooo00L^E1@0oooo000A0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool04`3oool0
0`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool0303oool0
1@07;U@0oooo0?ooo`3oool01biD00P0oooo00<01biD0?ooo`3oool0503oool01@07;U@0oooo0?oo
o`3oool01biD00T0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`040?ooo`0300L^
E03oool0oooo00T0oooo00<01biD0?ooo`3oool04P3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^
E03oool0oooo00L0oooo00D01biD0?ooo`3oool0oooo00L^E00H0?ooo`0400L^E03oool0oooo00L^
E280oooo00<01biD0?ooo`3oool07`3oool00`07;U@0oooo0?ooo`0?0?ooo`0500L^E03oool0oooo
0?ooo`07;U@05`3oool01@07;U@0oooo0?ooo`3oool01biD0180oooo00<01biD0?ooo`3oool03P3o
ool00`07;U@0oooo0?ooo`060?ooo`<01biD3P3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03o
ool0oooo00L0oooo00D01biD0?ooo`3oool0oooo00L^E00C0?ooo`00403oool00`07;U@0oooo0?oo
o`0<0?ooo`801biD503oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00X0oooo00<0
1biD0?ooo`3oool0303oool01007;U@0oooo0?ooo`3oool200L^E0L0oooo00<01biD0?ooo`3oool0
4P3oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool0
2P3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool0
4@3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool0
0P3oool00`07;U@0oooo0?ooo`0E0?ooo`0400L^E03oool0oooo00L^E2<0oooo00<01biD0?ooo`3o
ool07P3oool00`07;U@0oooo0?ooo`0?0?ooo`0500L^E03oool0oooo0?ooo`07;U@05`3oool01@07
;U@0oooo0?ooo`3oool01biD0180oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`06
0?ooo`0400L^E03oool01biD00L^E0d0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?oo
o`070?ooo`0500L^E03oool0oooo0?ooo`07;U@04`3oool00100oooo00<01biD0?ooo`3oool03P3o
ool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool02P3o
ool00`07;U@0oooo0?ooo`0=0?ooo`0500L^E03oool0oooo0?ooo`07;U@0203oool00`07;U@0oooo
0?ooo`0A0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo
0?ooo`0:0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo
0?ooo`0@0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo
0?ooo`020?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo
0?ooo`0Q0?ooo`0300L^E03oool0oooo01d0oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo
0?ooo`020?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo
0?ooo`0A0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool01@3oool01@07;U@0oooo
0?ooo`3oool01biD00h0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`070?ooo`03
00L^E03oool0oooo0080oooo00<01biD0?ooo`3oool0403oool000l0oooo00<01biD0?ooo`3oool0
403oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool0
2P3oool00`07;U@0oooo0?ooo`0=0?ooo`0500L^E03oool0oooo0?ooo`07;U@01`3oool00`07;U@0
oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0
oooo0?ooo`0:0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool03P3oool00`07;U@0
oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00T0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0
oooo0?ooo`020?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0
oooo0?ooo`0R0?ooo`0300L^E03oool0oooo01`0oooo00<01biD0?ooo`3oool03`3oool00`07;U@0
oooo0?ooo`020?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0
oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool01@3oool01@07;U@0
oooo0?ooo`3oool01biD00h0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`070?oo
o`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool0403oool000l0oooo00<01biD0?ooo`3o
ool04@3oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3o
ool02@3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo0080oooo0P07;U@50?ooo`03
00L^E03oool0oooo0100oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`070?ooo`03
00L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0>0?ooo`03
00L^E03oool0oooo0100oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`070?ooo`03
00L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool04P3oool00`07;U@0oooo0?ooo`030?ooo`03
00L^E03oool0oooo02<0oooo00<01biD0?ooo`3oool0703oool00`07;U@0oooo0?ooo`0>0?ooo`03
00L^E03oool0oooo0080oooo00<01biD0?ooo`3oool04P3oool00`07;U@0oooo0?ooo`030?ooo`03
00L^E03oool0oooo0140oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`040?ooo`03
00L^E03oool0oooo0080oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`0:0?ooo`03
00L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0@0?ooo`00
3`3oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool0
403oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool0
0`3oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool0
0`3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00T0oooo00<01biD0?ooo`3oool0
0P3oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool0
2P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool0
4P3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo02@0oooo00<01biD0?ooo`3oool0
6`3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool0
4@3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool0
3@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool0
2P3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool0
0`3oool00`07;U@0oooo0?ooo`0?0?ooo`003P3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03o
ool0oooo0180oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`090?ooo`0300L^E03o
ool0oooo00h0oooo00<01biD0?ooo`3oool00`3oool200L^E0<0oooo00<01biD0?ooo`3oool03`3o
ool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool02P3o
ool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool03`3o
ool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0103o
ool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool09@3o
ool00`07;U@0oooo0?ooo`0J0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool0103o
ool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool04P3o
ool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool0103o
ool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool01`3o
ool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo00l0oooo000>0?ooo`0300L^E03oool0
oooo01D0oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0
oooo00P0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`050?ooo`0400L^E03oool0
oooo00L^E100oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03o
ool0oooo00X0oooo00D01biD0?ooo`3oool0oooo00L^E00C0?ooo`0300L^E03oool0oooo00l0oooo
00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00@0oooo
00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00D0oooo
0P07;U@N0?ooo`0300L^E03oool0oooo01X0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo
0?ooo`040?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo
0?ooo`0B0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo
0?ooo`050?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo
0?ooo`070?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool03P3oool000h0oooo00<0
1biD0?ooo`3oool05P3oool200L^E180oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?oo
o`070?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo00L^
E00@0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?oo
o`0:0?ooo`0500L^E03oool0oooo0?ooo`07;U@0503oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^
E03oool0oooo00X0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`050?ooo`0300L^
E03oool0oooo00h0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`030?ooo`H01biD
7@3oool00`07;U@0oooo0?ooo`0J0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0
103oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool0
0P3oool200L^E0l0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`030?ooo`0300L^
E03oool0oooo00H0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^
E03oool0oooo00H0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0>0?ooo`003P3o
ool00`07;U@0oooo0?ooo`0H0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool0403o
ool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool01P3o
ool200L^E100oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03o
ool0oooo00X0oooo00@01biD0?ooo`3oool01biD5@3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^
E03oool0oooo00/0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^
E03oool0oooo00h0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`020?ooo`0300L^
E03oool0oooo00@0oooo00<01biD0?ooo`3oool06P3oool00`07;U@0oooo0?ooo`0J0?ooo`0300L^
E03oool0oooo00`0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^
E03oool0oooo00@0oooo00@01biD0?ooo`3oool0oooo1007;U@>0?ooo`0300L^E03oool0oooo00`0
oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00P0
oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00@0
oooo00<01biD0?ooo`3oool03P3oool000l0oooo00<01biD0?ooo`3oool0603oool00`07;U@0oooo
0?ooo`0@0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo
0?ooo`0@0?ooo`0300L^E03oool0oooo01L0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo
0?ooo`050?ooo`0300L^E03oool0oooo00X0oooo00@01biD0?ooo`3oool01biD5P3oool00`07;U@0
oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0
oooo0?ooo`050?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0
oooo0?ooo`020?ooo`0300L^E03oool0oooo00D0oooo0P07;U@K0?ooo`0300L^E03oool0oooo01T0
oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00h0
oooo00<01biD0?ooo`3oool01@3oool01@07;U@0oooo0?ooo`3oool01biD0080oooo0P07;U@=0?oo
o`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`070?oo
o`0300L^E03oool0oooo00P0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`060?oo
o`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool03P3oool000l0oooo00<01biD0?ooo`3o
ool06@3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3o
ool0103oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo01H0oooo00<01biD0?ooo`3o
ool01P3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00`0oooo0P07;U@H0?ooo`03
00L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`050?ooo`03
00L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`050?ooo`05
00L^E03oool0oooo0?ooo`07;U@02P3oool200L^E1X0oooo00<01biD0?ooo`3oool06@3oool00`07
;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool03P3oool00`07
;U@0oooo0?ooo`050?ooo`0500L^E03oool0oooo0?ooo`07;U@00`3oool00`07;U@0oooo0?ooo`0;
0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`08
0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`06
0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool03@3oool000l0oooo00<01biD0?oo
o`3oool06P3oool200L^E100oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`030?oo
o`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`060?oo
o`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool02P3oool400L^E1T0oooo00<01biD0?oo
o`3oool02`3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?oo
o`3oool01@3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo00D0oooo00D01biD0?oo
o`3oool0oooo00L^E00<0?ooo`0300L^E03oool0oooo01L0oooo00<01biD0?ooo`3oool06@3oool0
0`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool03P3oool0
0`07;U@0oooo0?ooo`050?ooo`0500L^E03oool0oooo0?ooo`07;U@0103oool00`07;U@0oooo0?oo
o`0:0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?oo
o`080?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?oo
o`060?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool03@3oool00100oooo00<01biD
0?ooo`3oool06`3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00l0oooo1@07;U@3
0?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`06
0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool02P3oool01007;U@0oooo0?ooo`07
;U@K0?ooo`0300L^E03oool0oooo00T0oooo0P07;U@=0?ooo`0300L^E03oool0oooo00D0oooo00<0
1biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo00D0oooo00@0
1biD0?ooo`3oool01biD3P3oool00`07;U@0oooo0?ooo`0G0?ooo`0300L^E03oool0oooo01T0oooo
00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00d0oooo
00<01biD0?ooo`3oool01@3oool01@07;U@0oooo0?ooo`3oool01biD00@0oooo00<01biD0?ooo`3o
ool02`3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3o
ool02@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3o
ool01@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00d0oooo000A0?ooo`0300L^
E03oool0oooo01/0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^
E03oool0oooo0080oooo1007;U@D0?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool0
1P3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo00T0oooo00D01biD0?ooo`3oool0
oooo00L^E00L0?ooo`0300L^E03oool0oooo00L0oooo0P07;U@?0?ooo`0300L^E03oool0oooo00@0
oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00H0
oooo00@01biD0?ooo`3oool01biD3`3oool200L^E1L0oooo00<01biD0?ooo`3oool06@3oool00`07
;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool03@3oool00`07
;U@0oooo0?ooo`050?ooo`0400L^E03oool0oooo00L^E0H0oooo00<01biD0?ooo`3oool02P3oool0
0`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool02@3oool0
0`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0103oool0
0`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00d0oooo000A0?ooo`0300L^E03oool0oooo
01`0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo
00@0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo
00H0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`080?ooo`0500L^E03oool0oooo
0?ooo`07;U@07P3oool200L^E0D0oooo0P07;U@20?ooo`0300L^E03oool0oooo00`0oooo00<01biD
0?ooo`3oool0103oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00`0oooo00<01biD
0?ooo`3oool01P3oool01007;U@0oooo0?ooo`07;U@A0?ooo`0300L^E03oool0oooo01@0oooo00<0
1biD0?ooo`3oool06P3oool00`07;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo00H0oooo00<0
1biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`050?ooo`0400L^E03oool0oooo00L^E0H0oooo
00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo0080oooo
00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`030?ooo`801biD3`3oool00`07;U@0oooo
0?ooo`030?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool03@3oool00180oooo00<0
1biD0?ooo`3oool0703oool200L^E0`0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?oo
o`050?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?oo
o`060?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?oo
o`020?ooo`0300L^E03oool0oooo01h0oooo1P07;U@30?ooo`0300L^E03oool0oooo00d0oooo00<0
1biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00d0oooo00<0
1biD0?ooo`3oool01P3oool01007;U@0oooo0?ooo`07;U@B0?ooo`0300L^E03oool0oooo01@0oooo
00<01biD0?ooo`3oool06P3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00H0oooo
00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`050?ooo`0400L^E03oool0oooo00L^E0L0
oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`0<0?ooo`0500L^E03oool0oooo0?oo
o`07;U@0303oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool01biD00h0oooo00<01biD0?oo
o`3oool00`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00d0oooo000C0?ooo`80
1biD7P3oool200L^E0/0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`050?ooo`03
00L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`060?ooo`03
00L^E03oool0oooo0080oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`030?ooo`03
00L^E03oool0oooo0280oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0<0?ooo`03
00L^E03oool0oooo0080oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0>0?ooo`03
00L^E03oool0oooo00D0oooo00@01biD0?ooo`3oool01biD4`3oool00`07;U@0oooo0?ooo`0C0?oo
o`0300L^E03oool0oooo01/0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`060?oo
o`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo00L^E0070?oo
o`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool0303oool01@07;U@0oooo0?ooo`3oool0
1biD00d0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo00L^E00?0?ooo`0300L^E03oool0
oooo0080oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0=0?ooo`005@3oool00`07
;U@0oooo0?ooo`0M0?ooo`0300L^E03oool0oooo00P0oooo00<01biD0?ooo`3oool03@3oool00`07
;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool0503oool00`07
;U@0oooo0?ooo`060?ooo`0500L^E03oool0oooo0?ooo`07;U@02P3oool00`07;U@0oooo0?ooo`02
0?ooo`0300L^E03oool0oooo02<0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0:
0?ooo`@01biD0`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00h0oooo00<01biD
0?ooo`3oool01P3oool00`07;U@0oooo00L^E00D0?ooo`0300L^E03oool0oooo0180oooo00<01biD
0?ooo`3oool0703oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00H0oooo00<01biD
0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool01biD00P0oooo00<01biD
0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`0=0?ooo`0400L^E03oool0oooo00L^E0h0oooo1@07
;U@00`3oool01biD0?ooo`0>0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool01P3o
ool00`07;U@0oooo0?ooo`0=0?ooo`005P3oool00`07;U@0oooo0?ooo`0M0?ooo`0300L^E03oool0
oooo00L0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0
oooo0180oooo00<01biD0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`060?ooo`0400L^E03oool0
oooo00L^E0T0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0R0?ooo`0300L^E03o
ool0oooo00D0oooo00<01biD0?ooo`3oool0203oool01007;U@0oooo0?ooo`3oool200L^E080oooo
00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo00H0oooo
00<01biD0?ooo`07;U@05@3oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo01d0oooo
00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00d0oooo
00<01biD0?ooo`3oool01P3oool00`07;U@0oooo00L^E0080?ooo`0300L^E03oool0oooo00T0oooo
00<01biD0?ooo`3oool03@3oool01007;U@0oooo0?ooo`07;U@?0?ooo`801biD00D0oooo00L^E03o
ool0oooo00L^E00;0?ooo`@01biD103oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
00d0oooo000G0?ooo`801biD7P3oool200L^E0P0oooo00<01biD0?ooo`3oool0303oool00`07;U@0
oooo0?ooo`050?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool05@3oool00`07;U@0
oooo0?ooo`060?ooo`0300L^E03oool01biD00X0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0
oooo0?ooo`0R0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0203oool00`07;U@0
oooo0?ooo`020?ooo`0400L^E03oool0oooo00L^E0P0oooo00<01biD0?ooo`3oool03P3oool00`07
;U@0oooo0?ooo`060?ooo`0300L^E03oool01biD01H0oooo0P07;U@@0?ooo`0300L^E03oool0oooo
01/0oooo0`07;U@00`3oool01biD0?ooo`040?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?oo
o`3oool03P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool01biD00T0oooo00<01biD0?oo
o`3oool0203oool00`07;U@0oooo0?ooo`0=0?ooo`0400L^E03oool0oooo00L^E180oooo00@01biD
0?ooo`3oool01biD2`3oool01@07;U@0oooo0?ooo`3oool01biD00<0oooo00<01biD0?ooo`3oool0
1P3oool00`07;U@0oooo0?ooo`0=0?ooo`006@3oool200L^E1h0oooo0P07;U@60?ooo`0300L^E03o
ool0oooo00`0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03o
ool0oooo01D0oooo00<01biD0?ooo`3oool01P3oool300L^E0T0oooo00<01biD0?ooo`3oool0103o
ool00`07;U@0oooo0?ooo`0R0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool01P3o
ool00`07;U@0oooo0?ooo`030?ooo`<01biD203oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03o
ool0oooo00H0oooo00<01biD0?ooo`07;U@0603oool200L^E0h0oooo00<01biD0?ooo`3oool06@3o
ool200L^E0<0oooo0`07;U@40?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool03P3o
ool00`07;U@0oooo0?ooo`060?ooo`<01biD2@3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03o
ool0oooo00`0oooo0`07;U@00`3oool01biD0?ooo`0A0?ooo`0400L^E03oool0oooo00L^E0X0oooo
00<01biD0?ooo`3oool00P3oool200L^E0030?ooo`07;U@0oooo00L0oooo00<01biD0?ooo`3oool0
3P3oool001/0oooo0P07;U@N0?ooo`D01biD00<0oooo00L^E03oool03@3oool00`07;U@0oooo0?oo
o`060?ooo`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool05@3oool00`07;U@0oooo0?oo
o`060?ooo`801biD2P3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo02<0oooo00<0
1biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00@0oooo00<0
1biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo00L0oooo0P07
;U@J0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool06@3oool00`07;U@0oooo0?oo
o`060?ooo`801biD00<0oooo00L^E007;U@0203oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03o
ool0oooo00L0oooo0P07;U@:0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool02`3o
ool01007;U@0oooo0?ooo`3oool200L^E180oooo00D01biD0?ooo`3oool0oooo00L^E0090?ooo`03
00L^E03oool0oooo00<0oooo0`07;U@80?ooo`0300L^E03oool0oooo00h0oooo000M0?ooo`0300L^
E03oool0oooo01h0oooo1007;U@?0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0
403oool00`07;U@0oooo0?ooo`0G0?ooo`0300L^E03oool0oooo00D0oooo0P07;U@90?ooo`0300L^
E03oool0oooo00@0oooo00<01biD0?ooo`3oool08`3oool00`07;U@0oooo0?ooo`070?ooo`0300L^
E03oool0oooo00D0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`070?ooo`0300L^
E03oool0oooo00l0oooo00<01biD0?ooo`3oool01`3oool200L^E1/0oooo00<01biD0?ooo`3oool0
203oool200L^E1/0oooo00<01biD0?ooo`3oool0203oool200L^E0T0oooo00<01biD0?ooo`3oool0
3`3oool00`07;U@0oooo0?ooo`060?ooo`801biD2P3oool00`07;U@0oooo0?ooo`070?ooo`0300L^
E03oool0oooo00/0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0@0?ooo`0500L^
E03oool0oooo0?ooo`07;U@02@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00L0
oooo00<01biD0?ooo`3oool03P3oool001h0oooo0`07;U@L0?ooo`801biD0`3oool00`07;U@0oooo
0?ooo`0<0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo
0?ooo`0G0?ooo`0300L^E03oool0oooo00D0oooo0P07;U@90?ooo`0300L^E03oool0oooo00@0oooo
00<01biD0?ooo`3oool08P3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00D0oooo
00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo0100oooo
00<01biD0?ooo`3oool01@3oool00`07;U@0oooo00L^E00L0?ooo`@01biD103oool200L^E080oooo
00<01biD0?ooo`3oool05`3oool00`07;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo00L0oooo
00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`050?ooo`<01biD2`3oool00`07;U@0oooo
0?ooo`060?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo
0?ooo`0@0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo
0?ooo`040?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool03P3oool00240oooo0`07
;U@I0?ooo`0300L^E03oool0oooo00<0oooo0P07;U@=0?ooo`0300L^E03oool0oooo00D0oooo00<0
1biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`0G0?ooo`0300L^E03oool0oooo00@0oooo00@0
1biD0?ooo`3oool01biD1`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo0280oooo
00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00@0oooo
00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00D0oooo
00<01biD0?ooo`07;U@0803oool400L^E0030?ooo`07;U@0oooo0080oooo00<01biD0?ooo`3oool0
5@3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool0
403oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool01biD00/0oooo00<01biD0?ooo`3oool0
1P3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool0
403oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0
103oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00l0oooo000T0?ooo`801biD5`3o
ool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool01P3o
ool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo01L0oooo00<01biD0?ooo`3oool0103o
ool01007;U@0oooo0?ooo`07;U@70?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool0
8`3oool00`07;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool0
103oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool0
103oool00`07;U@0oooo00L^E00U0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool0
503oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool0
4@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool01biD00`0oooo00<01biD0?ooo`3oool0
1@3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool0
403oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0
103oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00l0oooo000V0?ooo`0300L^E03o
ool0oooo01D0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`090?ooo`0300L^E03o
ool0oooo00H0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`0H0?ooo`0300L^E03o
ool0oooo00<0oooo00@01biD0?ooo`3oool01biD1P3oool00`07;U@0oooo0?ooo`050?ooo`0300L^
E03oool0oooo02<0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^
E03oool0oooo00@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^
E03oool0oooo00@0oooo00<01biD0?ooo`07;U@0903oool00`07;U@0oooo0?ooo`040?ooo`0300L^
E03oool0oooo01<0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^
E03oool0oooo0180oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo00L^E00<0?ooo`0300L^
E03oool0oooo00D0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`030?ooo`0300L^
E03oool0oooo0100oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`040?ooo`0300L^
E03oool0oooo00D0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0?0?ooo`009`3o
ool200L^E1D0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03o
ool0oooo00L0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0H0?ooo`0300L^E03o
ool0oooo00<0oooo00@01biD0?ooo`3oool01biD1P3oool00`07;U@0oooo0?ooo`050?ooo`0300L^
E03oool0oooo02<0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`030?ooo`0300L^
E03oool0oooo00@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^
E03oool0oooo00<0oooo00@01biD0?ooo`3oool01biD903oool00`07;U@0oooo0?ooo`050?ooo`03
00L^E03oool0oooo0140oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`060?ooo`03
00L^E03oool0oooo0180oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo00L^E00=0?ooo`03
00L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`040?ooo`03
00L^E03oool0oooo0100oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`030?ooo`03
00L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0?0?ooo`00
:@3oool200L^E1@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`080?ooo`0300L^
E03oool0oooo00H0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0H0?ooo`0300L^
E03oool0oooo00<0oooo00@01biD0?ooo`3oool01biD1@3oool00`07;U@0oooo0?ooo`060?ooo`03
00L^E03oool0oooo02<0oooo00<01biD0?ooo`3oool02`3oool01@07;U@0oooo0?ooo`3oool01biD
00L0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo
00<0oooo00@01biD0?ooo`3oool01biD9@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0
oooo0100oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0
oooo01<0oooo00<01biD0?ooo`3oool00P3oool01007;U@0oooo0?ooo`07;U@=0?ooo`0300L^E03o
ool0oooo00@0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03o
ool0oooo0100oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03o
ool0oooo00D0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0@0?ooo`00:`3oool0
0`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool01`3oool0
0`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool05`3oool0
0`07;U@0oooo0?ooo`030?ooo`0400L^E03oool0oooo00L^E0D0oooo00<01biD0?ooo`3oool01@3o
ool00`07;U@0oooo0?ooo`0U0?ooo`0300L^E03oool0oooo00X0oooo00D01biD0?ooo`3oool0oooo
00L^E0070?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo
0?ooo`030?ooo`0400L^E03oool0oooo00L^E2D0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0
oooo0?ooo`0?0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0
oooo0?ooo`0C0?ooo`0300L^E03oool0oooo0080oooo00@01biD0?ooo`3oool01biD3P3oool00`07
;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool0103oool00`07
;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool00P3oool00`07
;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0403oool002`0
oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00H0
oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo01L0
oooo00<01biD0?ooo`3oool00`3oool01007;U@0oooo0?ooo`07;U@40?ooo`0300L^E03oool0oooo
00H0oooo00<01biD0?ooo`3oool09@3oool00`07;U@0oooo0?ooo`0;0?ooo`0400L^E03oool0oooo
00L^E0L0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0
oooo0080oooo00@01biD0?ooo`3oool01biD9@3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03o
ool0oooo00h0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03o
ool0oooo01<0oooo00<01biD0?ooo`3oool00P3oool01007;U@0oooo0?ooo`07;U@?0?ooo`801biD
0P3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool0
4@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool0
1@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo0100oooo000]0?ooo`801biD4P3o
ool00`07;U@0oooo0?ooo`070?ooo`801biD1`3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03o
ool0oooo00`0oooo00<01biD0?ooo`3oool05`3oool00`07;U@0oooo0?ooo`030?ooo`0400L^E03o
ool0oooo00L^E0@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0U0?ooo`0300L^
E03oool0oooo00/0oooo1007;U@70?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0
503oool00`07;U@0oooo0?ooo`020?ooo`0400L^E03oool0oooo00L^E2H0oooo00<01biD0?ooo`3o
ool01`3oool200L^E0h0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`040?ooo`03
00L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool00P3oool01007;U@0oooo0?ooo`07;U@@0?oo
o`@01biD303oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo0140oooo00<01biD0?oo
o`3oool01@3oool01@07;U@0oooo0?ooo`3oool01biD00L0oooo00<01biD0?ooo`3oool01@3oool0
0`07;U@0oooo0?ooo`0@0?ooo`00;`3oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo
00P0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo
00`0oooo00<01biD0?ooo`3oool0603oool00`07;U@0oooo0?ooo`020?ooo`0400L^E03oool0oooo
00L^E0<0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`0U0?ooo`0300L^E03oool0
oooo00`0oooo0P07;U@80?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0503oool0
0`07;U@0oooo0?ooo`020?ooo`0400L^E03oool0oooo00L^E2H0oooo00<01biD0?ooo`3oool02@3o
ool200L^E0/0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03o
ool0oooo01@0oooo00<01biD0?ooo`3oool00P3oool01007;U@0oooo0?ooo`07;U@B0?ooo`0300L^
E03oool01biD00/0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^
E03oool0oooo00D0oooo1007;U@70?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0
403oool00300oooo0P07;U@A0?ooo`0300L^E03oool0oooo00P0oooo00<01biD0?ooo`3oool00`3o
ool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00L0oooo0P07;U@30?ooo`0300L^E03o
ool0oooo01L0oooo00<01biD0?ooo`3oool00P3oool01@07;U@0oooo0?ooo`3oool01biD0080oooo
00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`0U0?ooo`0300L^E03oool0oooo01H0oooo
00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo0080oooo
00D01biD0?ooo`3oool0oooo00L^E00V0?ooo`0300L^E03oool0oooo00X0oooo0P07;U@90?ooo`03
00L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0D0?ooo`03
00L^E03oool0oooo0080oooo00D01biD0?ooo`3oool0oooo00L^E00A0?ooo`0300L^E03oool01biD
00/0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo
00H0oooo0P07;U@80?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0403oool00380
oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo0080
oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`050?ooo`<01biD00D0oooo00L^E007
;U@0oooo00L^E00I0?ooo`0300L^E03oool0oooo0080oooo00@01biD0?ooo`3oool0oooo0`07;U@:
0?ooo`0300L^E03oool0oooo02H0oooo00<01biD0?ooo`3oool05P3oool00`07;U@0oooo0?ooo`03
0?ooo`801biD5P3oool00`07;U@0oooo0?ooo`020?ooo`0500L^E03oool0oooo0?ooo`07;U@09P3o
ool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00D0oooo0P07;U@?0?ooo`0300L^E03o
ool0oooo00@0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`020?ooo`0500L^E03o
ool0oooo0?ooo`07;U@04@3oool01007;U@0oooo0?ooo`07;U@:0?ooo`0300L^E03oool0oooo00@0
oooo00<01biD0?ooo`3oool04P3oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00D0
oooo00<01biD0?ooo`3oool0403oool000h0oooo0P07;U@S0?ooo`0300L^E03oool0oooo00l0oooo
00<01biD0?ooo`3oool0203oool01@07;U@0oooo0?ooo`3oool01biD00/0oooo00<01biD0?ooo`3o
ool0103oool00`07;U@0oooo0?ooo`030?ooo`801biD6@3oool01@07;U@0oooo0?ooo`3oool01biD
00D0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`0V0?ooo`0300L^E03oool0oooo
01H0oooo00@01biD0?ooo`3oool0oooo1007;U@F0?ooo`0300L^E03oool0oooo0080oooo00D01biD
0?ooo`3oool0oooo00L^E00W0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0103o
ool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo0080oooo0`07;U@F0?ooo`0300L^E03o
ool0oooo0080oooo00D01biD0?ooo`3oool0oooo00L^E00A0?ooo`0400L^E03oool0oooo00L^E0X0
oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo0100
oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo00L^E00B0?ooo`003P3oool00`07;U@0oooo
00L^E00S0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool02@3oool400L^E0`0oooo
0P07;U@30?ooo`0300L^E03oool0oooo00D0oooo0P07;U@H0?ooo`0500L^E03oool0oooo0?ooo`07
;U@04@3oool00`07;U@0oooo0?ooo`0V0?ooo`0300L^E03oool0oooo01H0oooo00H01biD0?ooo`3o
ool0oooo00L^E03oool200L^E1H0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`02
0?ooo`0300L^E03oool0oooo02@0oooo00<01biD0?ooo`3oool03@3oool300L^E0040?ooo`07;U@0
1biD00L^E100oooo00@01biD0?ooo`3oool0oooo1007;U@F0?ooo`0300L^E03oool0oooo0080oooo
00D01biD0?ooo`3oool0oooo00L^E00A0?ooo`0400L^E03oool0oooo00L^E0X0oooo00<01biD0?oo
o`3oool0103oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?oo
o`3oool00P3oool400L^E180oooo000>0?ooo`0400L^E03oool0oooo00L^E2<0oooo00<01biD0?oo
o`3oool03P3oool00`07;U@0oooo0?ooo`0I0?ooo`@01biD2@3oool200L^E1L0oooo00D01biD0?oo
o`3oool0oooo00L^E00A0?ooo`801biD9`3oool00`07;U@0oooo0?ooo`0F0?ooo`0400L^E03oool0
oooo00L^E0<0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03o
ool0oooo0080oooo00<01biD0?ooo`3oool09@3oool00`07;U@0oooo0?ooo`0>0?ooo`<01biD4P3o
ool01@07;U@0oooo0?ooo`3oool01biD0080oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo
0?ooo`020?ooo`0500L^E03oool0oooo0?ooo`07;U@04@3oool01@07;U@0oooo0?ooo`3oool01biD
00T0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo
0100oooo00D01biD0?ooo`3oool0oooo00L^E0020?ooo`801biD4P3oool000h0oooo00D01biD0?oo
o`3oool0oooo00L^E0090?ooo`@01biD5P3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0
oooo02H0oooo00<01biD0?ooo`3oool05@3oool01@07;U@0oooo0?ooo`3oool01biD0180oooo00<0
1biD0?ooo`3oool09@3oool00`07;U@0oooo0?ooo`0F0?ooo`0300L^E03oool01biD00@0oooo00<0
1biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo00<0oooo00<0
1biD0?ooo`3oool09@3oool00`07;U@0oooo0?ooo`0R0?ooo`0400L^E03oool0oooo00L^E0<0oooo
00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`020?ooo`0500L^E03oool0oooo0?ooo`07
;U@04@3oool01@07;U@0oooo0?ooo`3oool01biD00P0oooo00<01biD0?ooo`3oool01@3oool00`07
;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool00P07;U@20?oo
o`801biD4P3oool000h0oooo00<01biD0?ooo`3oool00P3oool200L^E0H0oooo0P07;U@30?ooo`<0
1biD4`3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo02H0oooo00<01biD0?ooo`3o
ool04`3oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3o
ool09@3oool00`07;U@0oooo0?ooo`0E0?ooo`<01biD103oool00`07;U@0oooo0?ooo`0D0?ooo`03
00L^E03oool0oooo0080oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0U0?ooo`03
00L^E03oool0oooo0280oooo00@01biD0?ooo`3oool01biD0`3oool00`07;U@0oooo0?ooo`0D0?oo
o`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0>0?oo
o`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`050?oo
o`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo00L^E0040?oo
o`0300L^E03oool0oooo0100oooo000?0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3o
ool00`3oool00`07;U@0oooo0?ooo`050?ooo`<01biD4@3oool00`07;U@0oooo0?ooo`0?0?ooo`03
00L^E03oool0oooo02H0oooo00<01biD0?ooo`3oool04P3oool00`07;U@0oooo0?ooo`020?ooo`03
00L^E03oool0oooo0140oooo0P07;U@V0?ooo`0300L^E03oool0oooo01`0oooo00<01biD0?ooo`3o
ool0503oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3o
ool09P3oool00`07;U@0oooo0?ooo`0R0?ooo`801biD103oool00`07;U@0oooo0?ooo`0D0?ooo`03
00L^E03oool0oooo0080oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0>0?ooo`03
00L^E03oool0oooo0080oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`050?ooo`03
00L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool03`3oool200L^E0D0oooo00<01biD0?ooo`3o
ool0403oool000l0oooo00<01biD0?ooo`3oool0103oool200L^E0@0oooo00<01biD0?ooo`3oool0
1`3oool200L^E100oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`0U0?ooo`0300L^
E03oool0oooo0180oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^
E03oool0oooo02<0oooo00<01biD0?ooo`3oool0<`3oool00`07;U@0oooo0?ooo`020?ooo`0300L^
E03oool0oooo00@0oooo00<01biD0?ooo`3oool09P3oool00`07;U@0oooo0?ooo`0X0?ooo`0300L^
E03oool0oooo01<0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`020?ooo`0300L^
E03oool0oooo00l0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`040?ooo`0300L^
E03oool0oooo00H0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo0?ooo`0F0?ooo`0300L^
E03oool0oooo0100oooo000@0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool00`3o
ool00`07;U@0oooo0?ooo`080?ooo`<01biD3P3oool200L^E0l0oooo00<01biD0?ooo`3oool09P3o
ool00`07;U@0oooo0?ooo`0B0?ooo`0500L^E03oool0oooo0?ooo`07;U@05P3oool400L^E280oooo
00<01biD0?ooo`3oool0<P3oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo00D0oooo
0P07;U@W0?ooo`0300L^E03oool0oooo03d0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo
0?ooo`020?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo
0?ooo`040?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo
0?ooo`0Y0?ooo`00403oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo0080oooo00<0
1biD0?ooo`3oool02`3oool400L^E0X0oooo00@01biD0?ooo`07;U@01biD3P3oool00`07;U@0oooo
0?ooo`0j0?ooo`0500L^E03oool0oooo0?ooo`07;U@06P3oool400L^E1h0oooo00<01biD0?ooo`3o
ool0<`3oool01007;U@0oooo0?ooo`07;U@90?ooo`0300L^E03oool0oooo02H0oooo00<01biD0?oo
o`3oool0?@3oool01@07;U@0oooo0?ooo`3oool01biD00@0oooo00<01biD0?ooo`3oool03`3oool0
0`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool01P3oool0
0`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo02P0oooo000A0?ooo`0300L^E03oool0oooo
00D0oooo0P07;U@30?ooo`0300L^E03oool0oooo00h0oooo0P07;U@70?ooo`<01biD0P3oool300L^
E0/0oooo00<01biD0?ooo`3oool0>`3oool01007;U@0oooo0?ooo`07;U@N0?ooo`@01biD6P3oool0
0`07;U@0oooo0?ooo`0c0?ooo`0400L^E03oool0oooo00L^E0X0oooo00<01biD0?ooo`3oool09P3o
ool00`07;U@0oooo0?ooo`0l0?ooo`0500L^E03oool0oooo0?ooo`07;U@01@3oool00`07;U@0oooo
0?ooo`0?0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo
0?ooo`060?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool0:03oool00140oooo00<0
1biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo00l0oooo2007
;U@00`3oool01biD0?ooo`040?ooo`801biD2P3oool00`07;U@0oooo0?ooo`0k0?ooo`<01biD8P3o
ool200L^E1P0oooo00<01biD0?ooo`3oool0<`3oool01007;U@0oooo0?ooo`07;U@;0?ooo`@01biD
9@3oool00`07;U@0oooo0?ooo`0l0?ooo`0300L^E03oool01biD00L0oooo00<01biD0?ooo`3oool0
3P3oool00`07;U@0oooo0?ooo`030?ooo`0400L^E03oool0oooo0?ooo`801biD203oool00`07;U@0
oooo0?ooo`0D0?ooo`0300L^E03oool0oooo02P0oooo000B0?ooo`0300L^E03oool0oooo00H0oooo
00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0G0?ooo`0300L^E03oool0oooo00D0oooo
0`07;U@70?ooo`801biD?03oool200L^E2D0oooo00<01biD0?ooo`3oool05@3oool00`07;U@0oooo
0?ooo`0d0?ooo`0300L^E03oool01biD00l0oooo1007;U@R0?ooo`0300L^E03oool0oooo03/0oooo
00<01biD0?ooo`07;U@01`3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo00@0oooo
0P07;U@00`3oool01biD0?ooo`080?ooo`0300L^E03oool0oooo01D0oooo00<01biD0?ooo`3oool0
9`3oool00180oooo00<01biD0?ooo`3oool01`3oool200L^E0<0oooo00<01biD0?ooo`3oool05`3o
ool00`07;U@0oooo0?ooo`070?ooo`<01biD103oool200L^E6@0oooo0P07;U@F0?ooo`0300L^E03o
ool0oooo03<0oooo0`07;U@C0?ooo`@01biD7P3oool00`07;U@0oooo0?ooo`0l0?ooo`801biD203o
ool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00D0oooo0`07;U@:0?ooo`0300L^E03o
ool0oooo01@0oooo00<01biD0?ooo`3oool09`3oool001<0oooo00<01biD0?ooo`3oool0203oool0
1@07;U@0oooo0?ooo`3oool01biD01T0oooo0P07;U@:0?ooo`D01biDI`3oool00`07;U@0oooo0?oo
o`0C0?ooo`0300L^E03oool0oooo04d0oooo1@07;U@J0?ooo`0300L^E03oool0oooo04H0oooo00<0
1biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo01D0oooo00<0
1biD0?ooo`3oool09P3oool001<0oooo00<01biD0?ooo`3oool02@3oool01007;U@0oooo0?ooo`07
;U@K0?ooo`801biDM03oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo0580oooo0P07
;U@I0?ooo`0300L^E03oool0oooo04H0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?oo
o`0A0?ooo`0300L^E03oool0oooo01D0oooo00<01biD0?ooo`3oool09P3oool001@0oooo00<01biD
0?ooo`3oool02@3oool400L^E1`0oooo00<01biD0?ooo`3oool0LP3oool00`07;U@0oooo0?ooo`0B
0?ooo`0300L^E03oool0oooo05@0oooo0P07;U@H0?ooo`0300L^E03oool0oooo04H0oooo0P07;U@<
0?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0V
0?ooo`00503oool00`07;U@0oooo0?ooo`0;0?ooo`<01biD703oool00`07;U@0oooo0?ooo`1b0?oo
o`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool0EP3oool200L^E1H0oooo00<01biD0?oo
o`3oool0B03oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo0180oooo00<01biD0?oo
o`3oool04`3oool00`07;U@0oooo0?ooo`0V0?ooo`005@3oool00`07;U@0oooo0?ooo`0<0?ooo`80
1biD703oool300L^E740oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`1H0?ooo`80
1biD5@3oool00`07;U@0oooo0?ooo`180?ooo`0300L^E03oool0oooo00T0oooo00<01biD0?ooo`3o
ool04P3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo02H0oooo000F0?ooo`0300L^
E03oool0oooo00/0oooo00@01biD0?ooo`07;U@01biD7@3oool200L^E6l0oooo00<01biD0?ooo`3o
ool0403oool00`07;U@0oooo0?ooo`1K0?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3o
ool0B@3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo01<0oooo0P07;U@D0?ooo`03
00L^E03oool0oooo02D0oooo000G0?ooo`0300L^E03oool0oooo00/0oooo00@01biD0?ooo`3oool0
1biD7P3oool200L^E6h0oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`1L0?ooo`03
00L^E03oool0oooo0140oooo00<01biD0?ooo`3oool0BP3oool00`07;U@0oooo0?ooo`080?ooo`03
00L^E03oool0oooo01@0oooo1P07;U@>0?ooo`0300L^E03oool0oooo02D0oooo000H0?ooo`0300L^
E03oool0oooo00/0oooo00@01biD0?ooo`3oool01biD7`3oool200L^E6`0oooo00<01biD0?ooo`3o
ool03P3oool200L^E5l0oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`1:0?ooo`03
00L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool06P3oool200L^E0`0oooo00<01biD0?ooo`3o
ool09@3oool001T0oooo00<01biD0?ooo`3oool02P3oool01@07;U@0oooo0?ooo`3oool01biD0200
oooo00<01biD0?ooo`3oool0J@3oool00`07;U@0oooo0?ooo`0=0?ooo`801biDH@3oool00`07;U@0
oooo0?ooo`0@0?ooo`0300L^E03oool0oooo04X0oooo00<01biD0?ooo`3oool0203oool00`07;U@0
oooo0?ooo`0J0?ooo`801biD2`3oool00`07;U@0oooo0?ooo`0U0?ooo`006P3oool200L^E0/0oooo
00D01biD0?ooo`3oool0oooo00L^E00P0?ooo`<01biDJ03oool00`07;U@0oooo0?ooo`0<0?ooo`80
1biDH`3oool00`07;U@0oooo0?ooo`0>0?ooo`801biDC@3oool00`07;U@0oooo0?ooo`070?ooo`03
00L^E03oool0oooo01`0oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`0U0?ooo`00
703oool200L^E0X0oooo00D01biD0?ooo`3oool0oooo00L^E00R0?ooo`801biDIP3oool00`07;U@0
oooo0?ooo`0;0?ooo`0300L^E03oool0oooo06@0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0
oooo0?ooo`1<0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool0703oool00`07;U@0
oooo0?ooo`080?ooo`0300L^E03oool0oooo02D0oooo000N0?ooo`801biD2@3oool01@07;U@0oooo
0?ooo`3oool01biD02<0oooo0P07;UAT0?ooo`0300L^E03oool0oooo00P0oooo0`07;UAX0?ooo`03
00L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool0CP3oool00`07;U@0oooo0?ooo`070?ooo`03
00L^E03oool0oooo01/0oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`0U0?ooo`00
803oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo0080oooo0P07;U@S0?ooo`801biD
HP3oool;00L^E6/0oooo00<01biD0?ooo`3oool0203oool300L^E540oooo00<01biD0?ooo`3oool0
1`3oool00`07;U@0oooo0?ooo`0L0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool0
9@3oool00240oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03o
ool0oooo0280oooo0P07;UAP0?ooo`801biDM@3oool:00L^E5D0oooo00<01biD0?ooo`3oool01P3o
ool00`07;U@0oooo0?ooo`0L0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool09@3o
ool00280oooo0`07;U@60?ooo`801biD103oool200L^E2@0oooo0P07;UAK0?ooo`L01biDLP3oool2
00L^E5h0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0M0?ooo`0300L^E03oool0
oooo00H0oooo00<01biD0?ooo`3oool09@3oool002D0oooo00<01biD0?ooo`3oool0103oool00`07
;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo0280oooo00<01biD0?ooo`3oool0B`3oool>00L^
E0L0oooo3`07;UAQ0?ooo`H01biDG@3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
01`0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0U0?ooo`009P3oool00`07;U@0
oooo0?ooo`040?ooo`0300L^E03oool0oooo00@0oooo0`07;U@R0?ooo`801biD@`3oool800L^E2@0
oooo1`07;UA;0?ooo`l01biD1P3oool?00L^E4h0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0
oooo0?ooo`0L0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool09P3oool002L0oooo
00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`060?ooo`@01biD0`3oool<00L^E100oooo
00<01biD0?ooo`3oool0@@3oool00`07;U@0oooo0?ooo`0_0?ooo`801biD@`3oool700L^E2@0oooo
2007;UA70?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool07@3oool00`07;U@0oooo
0?ooo`040?ooo`0300L^E03oool0oooo02H0oooo000X0?ooo`0300L^E03oool0oooo00@0oooo00<0
1biD0?ooo`3oool02@3oool300L^E0`0oooo0P07;U@?0?ooo`0300L^E03oool0oooo0400oooo0P07
;U@`0?ooo`801biD@P3oool200L^E340oooo00<01biD0?ooo`3oool0A@3oool00`07;U@0oooo0?oo
o`050?ooo`0300L^E03oool0oooo01d0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?oo
o`0W0?ooo`00:@3oool200L^E0D0oooo00<01biD0?ooo`3oool06@3oool300L^E0`0oooo00<01biD
0?ooo`3oool0@P3oool00`07;U@0oooo0?ooo`0/0?ooo`0300L^E03oool0oooo0480oooo0P07;U@`
0?ooo`801biDA`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo01`0oooo00<01biD
0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0X0?ooo`00:P3oool00`07;U@0oooo0?ooo`040?oo
o`0300L^E03oool0oooo01/0oooo0P07;U@90?ooo`0300L^E03oool0oooo04@0oooo00<01biD0?oo
o`3oool07@3oool900L^E0<0oooo0P07;UA70?ooo`0300L^E03oool0oooo02`0oooo00<01biD0?oo
o`3oool0A`3oool00`07;U@0oooo0?ooo`050?ooo`801biD7P3oool00`07;U@0oooo0?ooo`0200L^
E2/0oooo000[0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool0703oool200L^E0H0
oooo00<01biD0?ooo`3oool0AP3oool300L^E1L0oooo1@07;U@90?ooo`<01biDBP3oool200L^E1h0
oooo2P07;U@30?ooo`0300L^E03oool0oooo04T0oooo00<01biD0?ooo`3oool0103oool00`07;U@0
oooo0?ooo`0N0?ooo`801biD;@3oool002`0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo
0?ooo`0M0?ooo`801biD0`3oool00`07;U@0oooo0?ooo`1:0?ooo`@01biD403oool300L^E5d0oooo
0P07;U@H0?ooo`@01biD2P3oool300L^E4`0oooo0`07;U@30?ooo`801biD803oool00`07;U@0oooo
0?ooo`0/0?ooo`00;@3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo01l0oooo0`07
;UAA0?ooo`@01biD203oool400L^E680oooo1007;U@@0?ooo`@01biDH03oool400L^E500oooo000^
0?ooo`@01biD00<0oooo00L^E03oool0N03oool800L^E6X0oooo1007;U@70?ooo`D01biD^03oool0
0380oooo0P07;UC_0?ooo`L01biD_@3oool00?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03o
ool00?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03o
ool00?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03o
ool00?l0ooooj03oool00?l0ooooj03oool00?l0oooo7`3oool300L^E8<0oooo3007;U@g0?ooo`00
;P3oool800L^E1P0oooo1P07;UC70?ooo`<01biD00<0oooo00L^E03oool06P3oool500L^E640oooo
0`07;U@<0?ooo`@01biD<`3oool002`0oooo0P07;U@80?ooo`801biD5@3oool200L^E0D0oooo0P07
;UA?0?ooo`T01biD5P3oool600L^E4h0oooo0`07;U@40?ooo`0300L^E03oool0oooo01P0oooo00<0
1biD0?ooo`3oool00`3oool200L^E5`0oooo0`07;U@C0?ooo`801biD<@3oool002X0oooo0P07;U@<
0?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool01P3oool200L^E4/0oooo0P07;U@9
0?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool00`3oool300L^E4T0oooo0P07;U@7
0?ooo`0300L^E03oool0oooo01P0oooo00<01biD0?ooo`3oool01@3oool200L^E4/0oooo3`07;U@H
0?ooo`<01biD;P3oool002P0oooo0P07;U@?0?ooo`0300L^E03oool0oooo0140oooo00<01biD0?oo
o`3oool0203oool200L^E4H0oooo0`07;U@<0?ooo`0300L^E03oool0oooo0180oooo00<01biD0?oo
o`3oool01P3oool200L^E4D0oooo0P07;U@80?ooo`0300L^E03oool0oooo01P0oooo00<01biD0?oo
o`3oool0203oool200L^E4L0oooo0P07;U@Z0?ooo`801biD;03oool002P0oooo00<01biD0?ooo`3o
ool03`3oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3o
ool0@P3oool200L^E0l0oooo0P07;U@B0?ooo`0300L^E03oool0oooo00P0oooo0P07;UA10?ooo`80
1biD2@3oool00`07;U@0oooo0?ooo`0I0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3o
ool0@@3oool300L^E2h0oooo0P07;U@Z0?ooo`009`3oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^
E03oool0oooo00l0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`110?ooo`0300L^
E03oool0oooo00l0oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^
E03oool0oooo03d0oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`0K0?ooo`0300L^
E03oool0oooo00X0oooo00<01biD0?ooo`3oool0?`3oool200L^E380oooo00<01biD0?ooo`3oool0
9`3oool002L0oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03o
ool0oooo00`0oooo00<01biD0?ooo`3oool0?`3oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03o
ool0oooo00l0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`0j0?ooo`801biD2P3o
ool00`07;U@0oooo0?ooo`0L0?ooo`0300L^E03oool0oooo00/0oooo0P07;U@o0?ooo`<01biD;`3o
ool300L^E2T0oooo000V0?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool03P3oool0
0`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo03l0oooo00<01biD0?ooo`3oool04P3oool0
0`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0>03oool0
0`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo01`0oooo00<01biD0?ooo`3oool0303oool0
0`07;U@0oooo0?ooo`100?ooo`h01biD4`3oool>00L^E2`0oooo000V0?ooo`801biD5@3oool00`07
;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool0?P3oool00`07
;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool03@3oool00`07
;U@0oooo0?ooo`0f0?ooo`0300L^E03oool0oooo00T0oooo0P07;U@O0?ooo`0300L^E03oool0oooo
00d0oooo00<01biD0?ooo`3oool0C@3oool700L^E0D0oooo1`07;U@j0?ooo`009`3oool00`07;U@0
oooo0?ooo`0D0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0
oooo0?ooo`0m0?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0
oooo0?ooo`0=0?ooo`0300L^E03oool0oooo03D0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0
oooo0?ooo`0P0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0E03oool500L^E440
oooo000W0?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo
0?ooo`0=0?ooo`0300L^E03oool0oooo03d0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo
0?ooo`0=0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool0<`3oool00`07;U@0oooo
0?ooo`090?ooo`0300L^E03oool0oooo0240oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo
0?ooo`1@0?ooo``01biD?@3oool002L0oooo00<01biD0?ooo`3oool05@3oool00`07;U@0oooo0?oo
o`0=0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool0?03oool00`07;U@0oooo0?oo
o`0D0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?oo
o`0c0?ooo`0300L^E03oool0oooo00T0oooo00<01biD0?ooo`3oool08@3oool00`07;U@0oooo0?oo
o`0>0?ooo`0300L^E03oool0oooo04T0oooo1P07;U@<0?ooo`L01biD=P3oool002L0oooo00<01biD
0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00d0oooo00<01biD
0?ooo`3oool0?@3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo00`0oooo00<01biD
0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`0a0?ooo`0300L^E03oool0oooo00P0oooo0P07;U@T
0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool0A`3oool200L^E1T0oooo0`07;U@c
0?ooo`00:03oool00`07;U@0oooo0?ooo`0E0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?oo
o`3oool03P3oool00`07;U@0oooo0?ooo`0l0?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?oo
o`3oool0303oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo0340oooo00<01biD0?oo
o`3oool01`3oool00`07;U@0oooo0?ooo`050?ooo`L01biD603oool00`07;U@0oooo0?ooo`0>0?oo
o`0300L^E03oool0oooo04H0oooo00<01biD0?ooo`3oool0703oool200L^E340oooo000Y0?ooo`03
00L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0>0?ooo`03
00L^E03oool0oooo03d0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0<0?ooo`03
00L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool0<03oool00`07;U@0oooo0?ooo`080?ooo`03
00L^E03oool0oooo00<0oooo0P07;U@70?ooo`801biD5`3oool00`07;U@0oooo0?ooo`0=0?ooo`03
00L^E03oool0oooo04D0oooo0P07;U@P0?ooo`0300L^E03oool0oooo02h0oooo000Z0?ooo`0300L^
E03oool0oooo01@0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^
E03oool0oooo03d0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^
E03oool0oooo00d0oooo00<01biD0?ooo`3oool0;`3oool00`07;U@0oooo0?ooo`080?ooo`0300L^
E03oool0oooo0080oooo0P07;U@;0?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool0
3P3oool00`07;U@0oooo0?ooo`140?ooo`0300L^E03oool0oooo0200oooo00<01biD0?ooo`3oool0
;@3oool002X0oooo00<01biD0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03o
ool0oooo00d0oooo00<01biD0?ooo`3oool0?P3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03o
ool0oooo00/0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`0^0?ooo`0300L^E03o
ool0oooo00L0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03o
ool0oooo01@0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`140?ooo`0300L^E03o
ool0oooo0240oooo00<01biD0?ooo`3oool0;03oool002/0oooo00<01biD0?ooo`3oool0503oool0
0`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool0?@3oool0
0`07;U@0oooo0?ooo`0E0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool03@3oool0
0`07;U@0oooo0?ooo`0]0?ooo`0300L^E03oool0oooo00P0oooo00<01biD0?ooo`3oool00P07;U@?
0?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`14
0?ooo`0300L^E03oool0oooo0280oooo00<01biD0?ooo`3oool0:`3oool002`0oooo00<01biD0?oo
o`3oool0503oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?oo
o`3oool0?P3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?oo
o`3oool03@3oool00`07;U@0oooo0?ooo`0/0?ooo`0300L^E03oool0oooo00P0oooo00@01biD0?oo
o`3oool01biD4P3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo00d0oooo00<01biD
0?ooo`3oool0A03oool00`07;U@0oooo0?ooo`0S0?ooo`0300L^E03oool0oooo02X0oooo000]0?oo
o`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`0=0?oo
o`0300L^E03oool0oooo03l0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0;0?oo
o`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0;03oool00`07;U@0oooo0?ooo`070?oo
o`0400L^E03oool0oooo00L^E1<0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0<
0?ooo`0300L^E03oool0oooo04D0oooo00<01biD0?ooo`3oool08`3oool00`07;U@0oooo0?ooo`0Y
0?ooo`00;P3oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?oo
o`3oool03@3oool00`07;U@0oooo0?ooo`100?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?oo
o`3oool02`3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo02`0oooo00<01biD0?oo
o`3oool01`3oool300L^E1D0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo0?ooo`0<0?oo
o`0300L^E03oool0oooo04D0oooo00<01biD0?ooo`3oool08`3oool00`07;U@0oooo0?ooo`0Y0?oo
o`00;`3oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3o
ool0303oool00`07;U@0oooo0?ooo`110?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3o
ool02`3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo02/0oooo00<01biD0?ooo`3o
ool01P3oool300L^E1P0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo0?ooo`0<0?ooo`03
00L^E03oool0oooo04D0oooo00<01biD0?ooo`3oool08P3oool00`07;U@0oooo0?ooo`0Y0?ooo`00
<03oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool0
303oool00`07;U@0oooo0?ooo`120?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool0
2`3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo02T0oooo00<01biD0?ooo`3oool0
1P3oool00`07;U@0oooo00L^E00J0?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool0
303oool00`07;U@0oooo0?ooo`150?ooo`0300L^E03oool0oooo0280oooo00<01biD0?ooo`3oool0
:@3oool00340oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03o
ool0oooo00`0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`0f0?ooo`0300L^E03o
ool0oooo0140oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03o
ool0oooo02P0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo00L^E00K0?ooo`0300L^E03o
ool0oooo0180oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`160?ooo`0300L^E03o
ool0oooo0280oooo00<01biD0?ooo`3oool0:03oool001<0oooo0`07;U@L0?ooo`0300L^E03oool0
oooo0140oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0
oooo00T0oooo0`07;U@J0?ooo`801biD703oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0
oooo00/0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`090?ooo`0300L^E03oool0
oooo01`0oooo00<01biD0?ooo`3oool0103oool200L^E080oooo00<01biD0?ooo`3oool06P3oool0
0`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool02@3oool2
00L^E3`0oooo00<01biD0?ooo`3oool08@3oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0
oooo01<0oooo000B0?ooo`801biD00<0oooo00L^E007;U@06`3oool00`07;U@0oooo0?ooo`0A0?oo
o`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`080?oo
o`0300L^E03oool01biD01X0oooo0`07;U@L0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?oo
o`3oool02`3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00P0oooo00<01biD0?oo
o`07;U@06`3oool200L^E0H0oooo00D01biD0?ooo`3oool0oooo00L^E00M0?ooo`0300L^E03oool0
oooo0180oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0
1biD01X0oooo1`07;U@L0?ooo`0300L^E03oool0oooo0200oooo00<01biD0?ooo`3oool04@3oool2
00L^E1D0oooo000B0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool06@3oool00`07
;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool02`3oool00`07
;U@0oooo0?ooo`070?ooo`0400L^E03oool0oooo00L^E1T0oooo00@01biD0?ooo`3oool01biD7@3o
ool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool02`3o
ool00`07;U@0oooo0?ooo`080?ooo`0400L^E03oool0oooo00L^E1T0oooo00<01biD0?ooo`3oool0
1@3oool01@07;U@0oooo0?ooo`3oool01biD01l0oooo00<01biD0?ooo`3oool04@3oool00`07;U@0
oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00P0oooo00@01biD0?ooo`3oool01biD603oool00`07
;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo01X0oooo00<01biD0?ooo`3oool07`3oool00`07
;U@0oooo0?ooo`0@0?ooo`<01biD5@3oool00140oooo00<01biD0?ooo`3oool0103oool00`07;U@0
oooo0?ooo`0I0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool02P3oool00`07;U@0
oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00L0oooo00D01biD0?ooo`3oool0oooo00L^E00G0?oo
o`0500L^E03oool0oooo0?ooo`07;U@07P3oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0
oooo00X0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`080?ooo`0400L^E03oool0
oooo00L^E1T0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03o
ool0oooo01h0oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03o
ool0oooo00P0oooo00D01biD0?ooo`3oool0oooo00L^E00F0?ooo`801biD203oool200L^E1/0oooo
00<01biD0?ooo`3oool07`3oool00`07;U@0oooo0?ooo`0?0?ooo`0400L^E03oool0oooo00L^E1@0
oooo000@0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool06P3oool00`07;U@0oooo
0?ooo`0@0?ooo`0300L^E03oool0oooo00T0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo
0?ooo`070?ooo`0500L^E03oool0oooo0?ooo`07;U@05`3oool01@07;U@0oooo0?ooo`3oool01biD
01h0oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo
00X0oooo00<01biD0?ooo`3oool01`3oool01@07;U@0oooo0?ooo`3oool01biD01L0oooo0P07;U@6
0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool07`3oool00`07;U@0oooo0?ooo`0@
0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool0203oool01@07;U@0oooo0?ooo`3o
ool01biD01H0oooo00<01biD0?ooo`3oool02@3oool200L^E1X0oooo00<01biD0?ooo`3oool07P3o
ool00`07;U@0oooo0?ooo`0?0?ooo`0500L^E03oool0oooo0?ooo`07;U@04`3oool00100oooo00<0
1biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0J0?ooo`0300L^E03oool0oooo0100oooo00<0
1biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00L0oooo00<0
1biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo0080oooo00<0
1biD0?ooo`3oool07@3oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00T0oooo00<0
1biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`070?ooo`0500L^E03oool0oooo0?ooo`07;U@0
5P3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool0
8@3oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool0
203oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool0
303oool200L^E1P0oooo00<01biD0?ooo`3oool07P3oool00`07;U@0oooo0?ooo`0?0?ooo`0500L^
E03oool0oooo0?ooo`07;U@04`3oool00100oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo
0?ooo`0K0?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo
0?ooo`0:0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo
0?ooo`0C0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool07P3oool00`07;U@0oooo
0?ooo`0?0?ooo`0300L^E03oool0oooo00T0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo
0?ooo`070?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool04P3oool00`07;U@0oooo
0?ooo`040?ooo`801biD1@3oool00`07;U@0oooo0?ooo`0Q0?ooo`0300L^E03oool0oooo0100oooo
00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo0080oooo
00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo01H0oooo
00<01biD0?ooo`3oool07@3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo0080oooo
00<01biD0?ooo`3oool0403oool000l0oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?oo
o`0K0?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?oo
o`0:0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?oo
o`0A0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool07`3oool00`07;U@0oooo0?oo
o`0?0?ooo`0300L^E03oool0oooo00P0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?oo
o`070?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?oo
o`040?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool08`3oool00`07;U@0oooo0?oo
o`0@0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?oo
o`030?ooo`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?oo
o`0E0?ooo`0300L^E03oool0oooo01d0oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?oo
o`020?ooo`0300L^E03oool0oooo0100oooo000?0?ooo`0300L^E03oool0oooo00P0oooo00<01biD
0?ooo`3oool06`3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo00P0oooo00<01biD
0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00<0oooo00<01biD
0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo0200oooo00<01biD
0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00T0oooo00<01biD
0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo0100oooo00<01biD
0?ooo`3oool0103oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo02D0oooo00<01biD
0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00H0oooo00<01biD
0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo0140oooo00<01biD
0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`0M0?ooo`0300L^E03oool0oooo00h0oooo00<01biD
0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0?0?ooo`003P3oool00`07;U@0oooo0?ooo`0:0?oo
o`0300L^E03oool0oooo01/0oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`070?oo
o`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`030?oo
o`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0Q0?oo
o`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`0:0?oo
o`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0@0?oo
o`0300L^E03oool0oooo0080oooo0P07;U@60?ooo`0300L^E03oool0oooo02H0oooo00<01biD0?oo
o`3oool03P3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?oo
o`3oool0103oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo0180oooo00<01biD0?oo
o`3oool05@3oool00`07;U@0oooo0?ooo`0L0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?oo
o`3oool00`3oool00`07;U@0oooo0?ooo`0?0?ooo`003P3oool00`07;U@0oooo0?ooo`0:0?ooo`03
00L^E03oool0oooo01/0oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`060?ooo`03
00L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`040?ooo`03
00L^E03oool0oooo0100oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0Q0?ooo`03
00L^E03oool0oooo0100oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0:0?ooo`03
00L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0?0?ooo`05
00L^E03oool0oooo0?ooo`07;U@0203oool00`07;U@0oooo0?ooo`0W0?ooo`0300L^E03oool0oooo
00d0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
00@0oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo
01D0oooo00<01biD0?ooo`3oool06`3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo
00<0oooo00<01biD0?ooo`3oool03`3oool000h0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0
oooo0?ooo`0K0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool01@3oool00`07;U@0
oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0103oool00`07;U@0
oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool08P3oool00`07;U@0
oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0
oooo0?ooo`060?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool03P3oool01@07;U@0
oooo0?ooo`3oool01biD00T0oooo00<01biD0?ooo`3oool0:03oool00`07;U@0oooo0?ooo`0<0?oo
o`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`040?oo
o`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`0E0?oo
o`0300L^E03oool0oooo01X0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`040?oo
o`0300L^E03oool0oooo00h0oooo000>0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3o
ool0703oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3o
ool02P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3o
ool03`3oool00`07;U@0oooo0?ooo`050?ooo`0400L^E03oool0oooo0?ooo`<01biD7@3oool00`07
;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool02P3oool00`07
;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool03P3oool400L^
E0X0oooo00<01biD0?ooo`3oool0:03oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo
00X0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo
00h0oooo00<01biD0?ooo`3oool05P3oool00`07;U@0oooo0?ooo`0E0?ooo`0300L^E03oool0oooo
01X0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo
00h0oooo000>0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool06`3oool00`07;U@0
oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0
oooo0?ooo`060?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool03`3oool00`07;U@0
oooo0?ooo`050?ooo`0600L^E03oool0oooo0?ooo`07;U@0oooo0P07;U@M0?ooo`0300L^E03oool0
oooo0100oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0
oooo00H0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0K0?ooo`0300L^E03oool0
oooo02T0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0
oooo00D0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0
oooo01L0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0J0?ooo`0300L^E03oool0
oooo00d0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0>0?ooo`003P3oool00`07
;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00H0oooo0P07;U@C0?ooo`0300L^E03oool0oooo
0140oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo
00H0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo
00D0oooo00@01biD0?ooo`3oool01biD0`3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0
oooo0140oooo00<01biD0?ooo`3oool0403oool200L^E0@0oooo00<01biD0?ooo`3oool02`3oool0
0`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool06`3oool0
0`07;U@0oooo0?ooo`0Z0?ooo`801biD2`3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0
oooo00D0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0
oooo01P0oooo0P07;U@E0?ooo`0300L^E03oool0oooo01X0oooo00<01biD0?ooo`3oool02`3oool0
0`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00h0oooo000>0?ooo`0300L^E03oool0oooo
00d0oooo00<01biD0?ooo`3oool01P3oool01007;U@0oooo00L^E007;U@A0?ooo`0300L^E03oool0
oooo0180oooo00D01biD0?ooo`3oool0oooo00L^E00=0?ooo`0300L^E03oool0oooo00H0oooo00<0
1biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00H0oooo00@0
1biD0?ooo`3oool01biD103oool00`07;U@0oooo0?ooo`060?ooo`@01biD4@3oool00`07;U@0oooo
0?ooo`0B0?ooo`0500L^E03oool0oooo0?ooo`07;U@03@3oool00`07;U@0oooo0?ooo`050?ooo`03
00L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool06`3oool00`07;U@0oooo0?ooo`0/0?ooo`03
00L^E03oool0oooo00P0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`050?ooo`03
00L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`0I0?ooo`03
00L^E03oool0oooo0180oooo00<01biD0?ooo`3oool06P3oool00`07;U@0oooo0?ooo`0;0?ooo`03
00L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool03@3oool000h0oooo00<01biD0?ooo`3oool0
3P3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool0
3`3oool00`07;U@0oooo0?ooo`0?0?ooo`D01biD00<0oooo00L^E03oool03@3oool00`07;U@0oooo
0?ooo`050?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo
0?ooo`060?ooo`0400L^E03oool0oooo00L^E0@0oooo00<01biD0?ooo`3oool01P3oool01@07;U@0
oooo0?ooo`3oool01biD0140oooo00<01biD0?ooo`3oool0403oool300L^E080oooo00<01biD0?oo
o`3oool02`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?oo
o`3oool0703oool00`07;U@0oooo0?ooo`0/0?ooo`801biD203oool00`07;U@0oooo0?ooo`0<0?oo
o`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0>0?oo
o`0300L^E03oool0oooo01X0oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`0J0?oo
o`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0=0?oo
o`003P3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3o
ool00`3oool200L^E100oooo00<01biD0?ooo`3oool03P3oool01007;U@0oooo0?ooo`3oool300L^
E0h0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
00d0oooo00<01biD0?ooo`3oool01P3oool01007;U@0oooo0?ooo`07;U@50?ooo`0300L^E03oool0
oooo00D0oooo00<01biD0?ooo`3oool00P3oool200L^E100oooo00<01biD0?ooo`3oool03P3oool0
0`07;U@0oooo0?ooo`0200L^E0030?ooo`07;U@0oooo00`0oooo00<01biD0?ooo`3oool01@3oool0
0`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo01d0oooo00<01biD0?ooo`3oool0;@3oool4
00L^E0<0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0
oooo00H0oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`0J0?ooo`0300L^E03oool0
oooo0140oooo00<01biD0?ooo`3oool06P3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0
oooo00H0oooo00<01biD0?ooo`3oool03@3oool000l0oooo00<01biD0?ooo`3oool03P3oool00`07
;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool03P3oool00`07
;U@0oooo0?ooo`0<0?ooo`801biD1@3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo
00<0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo
00H0oooo00@01biD0?ooo`3oool01biD1@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0
oooo00@0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0
oooo00<0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0
oooo00D0oooo00<01biD0?ooo`3oool07@3oool200L^E340oooo1@07;U@?0?ooo`0300L^E03oool0
oooo00@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0?0?ooo`801biD703oool0
0`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo01T0oooo00<01biD0?ooo`3oool02P3oool0
0`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00d0oooo000?0?ooo`0300L^E03oool0oooo
00h0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo
00d0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo
00`0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
00d0oooo00<01biD0?ooo`3oool01P3oool01007;U@0oooo0?ooo`07;U@60?ooo`0300L^E03oool0
oooo00@0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0
oooo00`0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0
oooo00@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0N0?ooo`0300L^E03oool0
oooo02d0oooo0P07;U@40?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0103oool0
0`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool06`3oool0
0`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo01X0oooo00<01biD0?ooo`3oool02@3oool0
0`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00d0oooo000?0?ooo`0300L^E03oool0oooo
00l0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`060?ooo`801biD3P3oool00`07
;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool03@3oool00`07
;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool03@3oool00`07
;U@0oooo0?ooo`060?ooo`0400L^E03oool0oooo00L^E0H0oooo00<01biD0?ooo`3oool01@3oool0
0`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0303oool0
0`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0103oool0
0`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo0200oooo00<01biD0?ooo`3oool0:P3oool2
00L^E0H0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0
oooo00H0oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`0K0?ooo`801biD403oool0
0`07;U@0oooo0?ooo`0K0?ooo`0300L^E03oool0oooo00P0oooo00<01biD0?ooo`3oool01P3oool0
0`07;U@0oooo0?ooo`0=0?ooo`003`3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo
00<0oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo
00`0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool01biD
00@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo
00H0oooo00@01biD0?ooo`3oool01biD1`3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0
oooo00H0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0
oooo00D0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0
oooo00H0oooo00<01biD0?ooo`3oool08@3oool200L^E2X0oooo00<01biD0?ooo`3oool01@3oool0
0`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool01P3oool0
0`07;U@0oooo0?ooo`0B0?ooo`801biD7@3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0
oooo01`0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0
oooo00d0oooo000@0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool00`3oool00`07
;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool0303oool00`07
;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00T0oooo1007;U@40?ooo`0300L^E03oool0oooo
00H0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`060?ooo`0400L^E03oool0oooo
00L^E0L0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`070?ooo`801biD303oool0
0`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool02P3oool4
00L^E0<0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0S0?ooo`0300L^E03oool0
oooo02H0oooo0P07;U@80?ooo`0300L^E03oool0oooo00X0oooo1007;U@30?ooo`0300L^E03oool0
oooo00L0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0K0?ooo`801biD3@3oool0
0`07;U@0oooo0?ooo`0M0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool01P3oool0
0`07;U@0oooo0?ooo`0=0?ooo`00403oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo
00<0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo
00`0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo
00801biD0`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?oo
o`3oool01P3oool00`07;U@0oooo00L^E0080?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?oo
o`3oool0203oool00`07;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?oo
o`3oool01@3oool00`07;U@0oooo0?ooo`080?ooo`801biD00@0oooo00L^E007;U@01biD0P3oool0
0`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo02@0oooo00<01biD0?ooo`3oool09@3oool0
0`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00T0oooo0P07;U@0103oool01biD00L^E007
;U@20?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool05P3oool00`07;U@0oooo0?oo
o`0L0?ooo`801biD2`3oool00`07;U@0oooo0?ooo`0N0?ooo`0300L^E03oool0oooo00D0oooo00<0
1biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0=0?ooo`004@3oool00`07;U@0oooo0?ooo`0?
0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`08
0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`08
0?ooo`0300L^E03oool0oooo0080oooo0P07;U@00`3oool01biD0?ooo`080?ooo`0300L^E03oool0
oooo00h0oooo00<01biD0?ooo`3oool01P3oool200L^E0T0oooo00<01biD0?ooo`3oool0103oool0
0`07;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo00P0oooo00<01biD0?ooo`3oool0303oool0
0`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00P0oooo00<01biD0?ooo`3oool00P3oool0
1007;U@0oooo0?ooo`07;U@80?ooo`0300L^E03oool0oooo02D0oooo0P07;U@U0?ooo`0300L^E03o
ool0oooo00L0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`020?ooo`0400L^E03o
ool0oooo00L^E0P0oooo00<01biD0?ooo`3oool05`3oool200L^E1h0oooo00<01biD0?ooo`3oool0
203oool00`07;U@0oooo0?ooo`0K0?ooo`<01biD00<0oooo00L^E03oool01@3oool00`07;U@0oooo
0?ooo`060?ooo`0300L^E03oool0oooo00d0oooo000B0?ooo`0300L^E03oool0oooo00l0oooo00D0
1biD0?ooo`3oool0oooo00L^E00=0?ooo`801biD203oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^
E03oool0oooo00H0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`030?ooo`<01biD
203oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo00H0oooo0P07;U@:0?ooo`0300L^
E03oool0oooo00<0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`070?ooo`0300L^
E03oool0oooo00`0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`070?ooo`0300L^
E03oool0oooo0080oooo1007;U@80?ooo`0300L^E03oool0oooo02L0oooo0P07;U@S0?ooo`0300L^
E03oool0oooo00P0oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`020?ooo`@01biD
203oool00`07;U@0oooo0?ooo`0I0?ooo`801biD7@3oool200L^E0P0oooo00<01biD0?ooo`3oool0
6@3oool200L^E0<0oooo0`07;U@40?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0
3P3oool001<0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03o
ool0oooo00`0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03o
ool0oooo00D0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03o
ool0oooo00L0oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`060?ooo`801biD2P3o
ool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool01P3o
ool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool01P3o
ool00`07;U@0oooo0?ooo`040?ooo`801biD203oool00`07;U@0oooo0?ooo`0Z0?ooo`801biD8@3o
ool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00P0oooo00<01biD0?ooo`3oool00`3o
ool200L^E0T0oooo00<01biD0?ooo`3oool06`3oool00`07;U@0oooo0?ooo`0L0?ooo`D01biD0P3o
ool00`07;U@0oooo0?ooo`0I0?ooo`0300L^E03oool0oooo00H0oooo0P07;U@00`3oool01biD00L^
E0080?ooo`0300L^E03oool0oooo00h0oooo000D0?ooo`0300L^E03oool0oooo00h0oooo00D01biD
0?ooo`3oool0oooo00L^E00?0?ooo`0300L^E03oool0oooo00@0oooo0P07;U@>0?ooo`0300L^E03o
ool0oooo00H0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03o
ool0oooo00L0oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`050?ooo`801biD2P3o
ool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00/0oooo0P07;U@60?ooo`801biD3P3o
ool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0103o
ool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo02`0oooo00<01biD0?ooo`3oool07P3o
ool00`07;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0103o
ool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo01d0oooo0P07;U@O0?ooo`@01biD703o
ool00`07;U@0oooo0?ooo`080?ooo`801biD2@3oool00`07;U@0oooo0?ooo`0>0?ooo`00503oool0
0`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool03@3oool0
0`07;U@0oooo0?ooo`030?ooo`@01biD3@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0
oooo00H0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0
oooo0140oooo00<01biD0?ooo`3oool01@3oool200L^E0/0oooo00<01biD0?ooo`3oool00`3oool0
0`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00<0oooo1007;U@<0?ooo`0300L^E03oool0
oooo00H0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0
oooo00L0oooo00<01biD0?ooo`3oool0;@3oool200L^E1h0oooo00<01biD0?ooo`3oool02@3oool0
0`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool01`3oool0
0`07;U@0oooo0?ooo`0O0?ooo`<01biD6`3oool200L^E0<0oooo00<01biD0?ooo`3oool0603oool0
0`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool03P3oool0
01D0oooo00<01biD0?ooo`3oool03P3oool01@07;U@0oooo0?ooo`3oool01biD0100oooo1`07;U@2
0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`05
0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0A
0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`07;U@02P3oool00`07;U@0oooo0?ooo`03
0?ooo`0300L^E03oool0oooo00h0oooo0`07;U@0103oool01biD00L^E007;U@20?ooo`0300L^E03o
ool0oooo00T0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03o
ool0oooo00@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0`0?ooo`0300L^E03o
ool0oooo01/0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03o
ool0oooo00@0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`0R0?ooo`801biD6@3o
ool00`07;U@0oooo0?ooo`030?ooo`801biD5`3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03o
ool0oooo00H0oooo00<01biD0?ooo`3oool03`3oool001H0oooo00<01biD0?ooo`3oool03P3oool0
1@07;U@0oooo0?ooo`3oool01biD01D0oooo00D01biD0?ooo`3oool0oooo00L^E00;0?ooo`0300L^
E03oool0oooo00H0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`050?ooo`0300L^
E03oool0oooo00H0oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`040?ooo`0400L^
E03oool0oooo00L^E0/0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0@0?ooo`<0
1biD00<0oooo00L^E03oool00P3oool00`07;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo00H0
oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00H0
oooo00<01biD0?ooo`3oool0<@3oool00`07;U@0oooo0?ooo`0J0?ooo`0300L^E03oool0oooo00X0
oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00L0
oooo00<01biD0?ooo`3oool0903oool200L^E1P0oooo00<01biD0?ooo`3oool0103oool00`07;U@0
oooo0?ooo`0D0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0
oooo0?ooo`0?0?ooo`005`3oool00`07;U@0oooo0?ooo`0>0?ooo`0400L^E03oool0oooo00L^E1D0
oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00L0
oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00H0
oooo00<01biD0?ooo`3oool04P3oool00`07;U@0oooo0?ooo`030?ooo`0400L^E03oool0oooo00L^
E0/0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo
0080oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
00@0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
0380oooo0P07;U@J0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool0103oool00`07
;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool09`3oool200L^
E1H0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo
00/0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0?0?ooo`00603oool00`07;U@0
oooo0?ooo`0>0?ooo`0300L^E03oool01biD01H0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0
oooo0?ooo`080?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0
oooo0?ooo`050?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0
oooo0?ooo`030?ooo`0400L^E03oool0oooo00L^E0`0oooo00<01biD0?ooo`3oool00P3oool00`07
;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool01`3oool00`07
;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool0103oool00`07
;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo03@0oooo00<01biD0?ooo`3oool05`3oool00`07
;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool0103oool00`07
;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo02T0oooo00<01biD0?ooo`3oool04`3oool00`07
;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool0303oool00`07
;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00l0oooo000H0?ooo`0300L^E03oool0oooo00l0
oooo0`07;U@E0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0
oooo0?ooo`070?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool01@3oool00`07;U@0
oooo0?ooo`050?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool00`3oool01007;U@0
oooo0?ooo`07;U@=0?ooo`801biD0`3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo
00<0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
00<0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo
03H0oooo00<01biD0?ooo`3oool05`3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo
00<0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
02X0oooo0P07;U@D0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0403oool00`07
;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0403oool001T0
oooo00<01biD0?ooo`3oool03P3oool300L^E1D0oooo00<01biD0?ooo`3oool0103oool00`07;U@0
oooo0?ooo`060?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0
oooo0?ooo`050?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0
oooo0?ooo`030?ooo`0400L^E03oool0oooo00L^E0l0oooo00@01biD0?ooo`3oool01biD5@3oool0
0`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool01`3oool0
1@07;U@0oooo0?ooo`3oool01biD00L0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?oo
o`0g0?ooo`0300L^E03oool0oooo01H0oooo00<01biD0?ooo`3oool0303oool01@07;U@0oooo0?oo
o`3oool01biD00L0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0/0?ooo`801biD
4`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool0
303oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo0100oooo000J0?ooo`0300L^E03o
ool0oooo00`0oooo0P07;U@00`3oool01biD0?ooo`0E0?ooo`0300L^E03oool0oooo00@0oooo0P07
;U@70?ooo`0300L^E03oool0oooo00L0oooo00D01biD0?ooo`3oool0oooo00L^E0070?ooo`0300L^
E03oool0oooo00D0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo0?ooo`030?ooo`0400L^
E03oool0oooo00L^E0l0oooo1007;U@F0?ooo`0300L^E03oool0oooo00@0oooo0P07;U@60?ooo`03
00L^E03oool0oooo00P0oooo00@01biD0?ooo`3oool01biD1`3oool00`07;U@0oooo0?ooo`050?oo
o`0300L^E03oool0oooo03P0oooo00<01biD0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`0<0?oo
o`0500L^E03oool0oooo0?ooo`07;U@01`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0
oooo02l0oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0
oooo00h0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0
oooo0100oooo000K0?ooo`0300L^E03oool0oooo00/0oooo00D01biD0?ooo`3oool0oooo00L^E00F
0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`08
0?ooo`0300L^E03oool01biD00P0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0C
0?ooo`0300L^E03oool0oooo00<0oooo00@01biD0?ooo`3oool01biD4P3oool200L^E1H0oooo00<0
1biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00L0oooo00@0
1biD0?ooo`3oool01biD1`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo03P0oooo
00<01biD0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`0=0?ooo`0400L^E03oool0oooo00L^E0P0
oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0`0?ooo`801biD4@3oool00`07;U@0
oooo0?ooo`070?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0
oooo0?ooo`050?ooo`0300L^E03oool0oooo0100oooo000K0?ooo`0300L^E03oool0oooo00/0oooo
00D01biD0?ooo`3oool0oooo00L^E00F0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3o
ool00`3oool00`07;U@0oooo0?ooo`090?ooo`801biD203oool00`07;U@0oooo0?ooo`050?ooo`03
00L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool00P3oool01007;U@0oooo0?ooo`07;U@A0?oo
o`0300L^E03oool01biD01H0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`030?oo
o`0300L^E03oool0oooo00P0oooo0`07;U@70?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?oo
o`3oool0>@3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo00h0oooo0`07;U@80?oo
o`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool0<P3oool200L^E100oooo00<01biD0?oo
o`3oool01`3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?oo
o`3oool01@3oool00`07;U@0oooo0?ooo`0@0?ooo`00703oool00`07;U@0oooo0?ooo`0:0?ooo`03
00L^E03oool0oooo0080oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`060?ooo`03
00L^E03oool0oooo0080oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo0?ooo`050?ooo`03
00L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool00P3oool01007;U@0oooo0?ooo`07;U@A0?oo
o`0400L^E03oool0oooo00L^E1H0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`02
0?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0i
0?ooo`0300L^E03oool0oooo01D0oooo00<01biD0?ooo`3oool0603oool00`07;U@0oooo0?ooo`04
0?ooo`0300L^E03oool0oooo03@0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`07
0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`05
0?ooo`0300L^E03oool0oooo0100oooo000>0?ooo`801biD3@3oool00`07;U@0oooo0?ooo`090?oo
o`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`070?oo
o`801biD0P3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?oo
o`3oool0503oool00`07;U@0oooo0?ooo`020?ooo`0400L^E03oool0oooo00L^E140oooo00@01biD
0?ooo`3oool01biD5P3oool00`07;U@0oooo0?ooo`070?ooo`801biD0P3oool00`07;U@0oooo0?oo
o`0C0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool04@3oool200L^E2H0oooo00<0
1biD0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`0H0?ooo`0300L^E03oool0oooo00@0oooo00<0
1biD0?ooo`3oool0=@3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo00L0oooo0P07
;U@:0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?oo
o`0@0?ooo`003P3oool00`07;U@0oooo00L^E00=0?ooo`0300L^E03oool0oooo00T0oooo00<01biD
0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo00P0oooo0`07;U@E
0?ooo`0300L^E03oool0oooo0080oooo1007;U@F0?ooo`0500L^E03oool0oooo0?ooo`07;U@0103o
ool00`07;U@0oooo0?ooo`0>0?ooo`0500L^E03oool0oooo0?ooo`07;U@05P3oool00`07;U@0oooo
0?ooo`080?ooo`<01biD5@3oool01007;U@0oooo0?ooo`3oool400L^E180oooo1007;U@V0?ooo`03
00L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool0603oool00`07;U@0oooo0?ooo`020?ooo`<0
1biD4`3oool200L^E2<0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`080?ooo`80
1biD1`3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3o
ool0403oool000h0oooo00@01biD0?ooo`3oool01biD303oool00`07;U@0oooo0?ooo`090?ooo`03
00L^E03oool0oooo0080oooo00<01biD0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`0O0?ooo`04
00L^E03oool0oooo0?ooo`801biD00<0oooo00L^E007;U@05P3oool01@07;U@0oooo0?ooo`3oool0
1biD00@0oooo00<01biD0?ooo`3oool03P3oool01@07;U@0oooo0?ooo`3oool01biD01L0oooo00<0
1biD0?ooo`3oool07`3oool01P07;U@0oooo0?ooo`3oool01biD0?ooo`801biD4P3oool01@07;U@0
oooo0?ooo`3oool01biD02D0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0H0?oo
o`0600L^E03oool0oooo0?ooo`07;U@0oooo0P07;U@C0?ooo`0300L^E03oool01biD02<0oooo00<0
1biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0:0?ooo`<01biD0`3oool200L^E100oooo00<0
1biD0?ooo`3oool00P3oool400L^E180oooo000>0?ooo`0500L^E03oool0oooo0?ooo`07;U@0303o
ool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool05@3o
ool00`07;U@0oooo0?ooo`0N0?ooo`0500L^E03oool0oooo0?ooo`07;U@00P3oool200L^E1H0oooo
00D01biD0?ooo`3oool0oooo00L^E0040?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3o
ool00P3oool00`07;U@0oooo0?ooo`0E0?ooo`0300L^E03oool0oooo01h0oooo00@01biD0?ooo`3o
ool01biD0`3oool00`07;U@0oooo0?ooo`0A0?ooo`0500L^E03oool0oooo0?ooo`07;U@0203oool4
00L^E1P0oooo00<01biD0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`0G0?ooo`0400L^E03oool0
oooo00L^E0<0oooo00<01biD0?ooo`3oool04@3oool01007;U@0oooo0?ooo`07;U@S0?ooo`0300L^
E03oool0oooo00d0oooo00<01biD0?ooo`3oool0303oool400L^E140oooo00@01biD0?ooo`3oool0
oooo0P07;U@00`3oool01biD00L^E00B0?ooo`003P3oool00`07;U@0oooo0?ooo`020?ooo`801biD
2P3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool0
5P3oool00`07;U@0oooo0?ooo`0N0?ooo`0300L^E03oool01biD00<0oooo0P07;U@F0?ooo`0500L^
E03oool0oooo0?ooo`07;U@0103oool00`07;U@0oooo0?ooo`0?0?ooo`0500L^E03oool0oooo0?oo
o`07;U@0603oool00`07;U@0oooo0?ooo`0M0?ooo`0400L^E03oool01biD00L^E0<0oooo00<01biD
0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo00D0oooo00@01biD
0?ooo`3oool0oooo1007;U@E0?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool05`3o
ool01007;U@0oooo0?ooo`07;U@30?ooo`0300L^E03oool0oooo0140oooo00D01biD0?ooo`3oool0
oooo00L^E0080?ooo`@01biD5P3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo0200
oooo00D01biD0?ooo`3oool0oooo00L^E0020?ooo`801biD4P3oool000l0oooo00<01biD0?ooo`3o
ool00`3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00P0oooo00<01biD0?ooo`3o
ool00`3oool00`07;U@0oooo0?ooo`0E0?ooo`0300L^E03oool0oooo01h0oooo0P07;U@50?ooo`03
00L^E03oool0oooo01@0oooo00D01biD0?ooo`3oool0oooo00L^E0040?ooo`0300L^E03oool0oooo
00l0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0E0?ooo`0300L^E03oool0oooo
01d0oooo0`07;U@40?ooo`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool00`3oool200L^
E0D0oooo00<01biD0?ooo`3oool01@3oool200L^E1<0oooo00<01biD0?ooo`3oool0503oool00`07
;U@0oooo0?ooo`0H0?ooo`801biD103oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo
0080oooo0P07;U@60?ooo`0400L^E03oool0oooo0?ooo`@01biD4`3oool00`07;U@0oooo0?ooo`0>
0?ooo`0300L^E03oool0oooo0200oooo00<01biD0?ooo`07;U@00`3oool200L^E180oooo000?0?oo
o`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`080?oo
o`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool05P3oool00`07;U@0oooo0?ooo`0T0?oo
o`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`020?oo
o`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0F0?oo
o`0300L^E03oool0oooo02<0oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`050?oo
o`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool01`3oool200L^E140oooo00<01biD0?oo
o`3oool0503oool00`07;U@0oooo0?ooo`0H0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?oo
o`3oool04P3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?oo
o`3oool01@3oool200L^E180oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`0O0?oo
o`801biD1@3oool00`07;U@0oooo0?ooo`0@0?ooo`00403oool00`07;U@0oooo0?ooo`040?ooo`03
00L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`030?ooo`03
00L^E03oool0oooo01H0oooo00<01biD0?ooo`3oool08`3oool00`07;U@0oooo0?ooo`0C0?ooo`03
00L^E03oool0oooo0080oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0>0?ooo`03
00L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool05P3oool00`07;U@0oooo0?ooo`0R0?ooo`03
00L^E03oool0oooo0180oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`020?ooo`03
00L^E03oool0oooo00P0oooo0`07;U@>0?ooo`801biD5@3oool00`07;U@0oooo0?ooo`0O0?ooo`03
00L^E03oool0oooo0140oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`020?ooo`03
00L^E03oool0oooo00L0oooo1@07;U@=0?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3o
ool09@3oool00`07;U@0oooo0?ooo`0@0?ooo`00403oool00`07;U@0oooo0?ooo`050?ooo`0300L^
E03oool0oooo00H0oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`030?ooo`0300L^
E03oool0oooo01L0oooo00<01biD0?ooo`3oool0>03oool00`07;U@0oooo0?ooo`020?ooo`0300L^
E03oool0oooo00<0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`030?ooo`0300L^
E03oool0oooo01L0oooo00<01biD0?ooo`3oool0=P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^
E03oool0oooo0080oooo00<01biD0?ooo`3oool02P3oool400L^E0X0oooo00@01biD0?ooo`07;U@0
1biD4`3oool00`07;U@0oooo0?ooo`0c0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3o
ool00P3oool00`07;U@0oooo0?ooo`0;0?ooo`801biD303oool200L^E0l0oooo00<01biD0?ooo`3o
ool09@3oool00`07;U@0oooo0?ooo`0@0?ooo`004@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^
E03oool0oooo00H0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`040?ooo`0300L^
E03oool0oooo01L0oooo00<01biD0?ooo`3oool0>03oool01@07;U@0oooo0?ooo`3oool01biD00D0
oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo01L0
oooo00<01biD0?ooo`3oool0=P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo0080
oooo00<01biD0?ooo`3oool03@3oool300L^E0H0oooo0`07;U@20?ooo`<01biD403oool00`07;U@0
oooo0?ooo`0c0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0
oooo0?ooo`0<0?ooo`<01biD2@3oool01007;U@0oooo00L^E007;U@>0?ooo`0300L^E03oool0oooo
03L0oooo000A0?ooo`0300L^E03oool0oooo00H0oooo0P07;U@60?ooo`0300L^E03oool0oooo00L0
oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0H0?ooo`0300L^E03oool0oooo03L0
oooo00D01biD0?ooo`3oool0oooo00L^E0060?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?oo
o`3oool00`3oool00`07;U@0oooo0?ooo`0H0?ooo`0300L^E03oool0oooo03D0oooo00<01biD0?oo
o`3oool01`3oool200L^E0<0oooo00<01biD0?ooo`3oool03`3oool700L^E0030?ooo`07;U@0oooo
00@0oooo0P07;U@=0?ooo`801biD=P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
0080oooo00<01biD0?ooo`3oool03P3oool400L^E0@0oooo0`07;U@20?ooo`<01biD303oool00`07
;U@0oooo0?ooo`0f0?ooo`004P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00@0
oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo01P0
oooo00<01biD0?ooo`3oool0=`3oool01007;U@0oooo0?ooo`07;U@60?ooo`0300L^E03oool0oooo
00l0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0H0?ooo`0300L^E03oool0oooo
03D0oooo00<01biD0?ooo`3oool01`3oool01@07;U@0oooo0?ooo`3oool01biD01X0oooo00<01biD
0?ooo`3oool0103oool300L^E0T0oooo0P07;U@g0?ooo`0300L^E03oool0oooo00L0oooo0P07;U@3
0?ooo`0300L^E03oool0oooo0140oooo1007;U@20?ooo`0300L^E03oool0oooo00<0oooo0P07;U@:
0?ooo`0300L^E03oool0oooo03H0oooo000B0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?oo
o`3oool0103oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?oo
o`3oool0603oool00`07;U@0oooo0?ooo`0h0?ooo`801biD203oool00`07;U@0oooo0?ooo`0>0?oo
o`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool0603oool00`07;U@0oooo0?ooo`0e0?oo
o`0300L^E03oool0oooo00P0oooo00D01biD0?ooo`3oool0oooo00L^E00J0?ooo`0300L^E03oool0
oooo00H0oooo2@07;U@j0?ooo`0300L^E03oool0oooo00P0oooo00@01biD0?ooo`3oool01biD6P3o
ool200L^E0D0oooo0`07;U@70?ooo`801biD=`3oool001<0oooo00<01biD0?ooo`3oool01`3oool2
00L^E0@0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0
oooo01P0oooo00<01biD0?ooo`3oool0@P3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0
oooo00@0oooo00<01biD0?ooo`3oool0603oool00`07;U@0oooo0?ooo`0e0?ooo`0300L^E03oool0
oooo00P0oooo00D01biD0?ooo`3oool0oooo00L^E00J0?ooo`0300L^E03oool0oooo04T0oooo00<0
1biD0?ooo`3oool0203oool01007;U@0oooo0?ooo`07;U@J0?ooo`0300L^E03oool0oooo00H0oooo
2007;U@h0?ooo`004`3oool00`07;U@0oooo0?ooo`090?ooo`801biD0`3oool00`07;U@0oooo0?oo
o`070?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool06@3oool00`07;U@0oooo0?oo
o`120?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?oo
o`0H0?ooo`0300L^E03oool0oooo03@0oooo00<01biD0?ooo`3oool02@3oool200L^E080oooo00<0
1biD0?ooo`3oool0603oool200L^E4X0oooo00<01biD0?ooo`3oool0203oool01007;U@0oooo0?oo
o`07;U@J0?ooo`0300L^E03oool0oooo04D0oooo000D0?ooo`0300L^E03oool0oooo00X0oooo1007
;U@90?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool06@3oool00`07;U@0oooo0?oo
o`120?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?oo
o`0H0?ooo`0300L^E03oool0oooo03@0oooo00<01biD0?ooo`3oool02P3oool200L^E0030?ooo`07
;U@0oooo01X0oooo00<01biD0?ooo`3oool0A`3oool00`07;U@0oooo0?ooo`090?ooo`801biD00<0
oooo00L^E007;U@06@3oool200L^E4D0oooo000E0?ooo`0300L^E03oool0oooo00/0oooo00<01biD
0?ooo`07;U@0203oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo01X0oooo00<01biD
0?ooo`3oool0@P3oool200L^E0d0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0I
0?ooo`0300L^E03oool0oooo03@0oooo00<01biD0?ooo`3oool02`3oool300L^E1/0oooo00<01biD
0?ooo`3oool0A`3oool00`07;U@0oooo0?ooo`0:0?ooo`@01biD6P3oool200L^E4<0oooo000F0?oo
o`0300L^E03oool0oooo00X0oooo0P07;U@00`3oool01biD0?ooo`070?ooo`0300L^E03oool0oooo
00D0oooo00<01biD0?ooo`3oool06P3oool00`07;U@0oooo0?ooo`130?ooo`0300L^E03oool0oooo
00X0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0I0?ooo`0300L^E03oool0oooo
03<0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo00L^E00K0?ooo`<01biDA`3oool00`07
;U@0oooo0?ooo`0;0?ooo`0300L^E03oool01biD01/0oooo0P07;UA10?ooo`005P3oool00`07;U@0
oooo0?ooo`0;0?ooo`0400L^E03oool0oooo00L^E0L0oooo00<01biD0?ooo`3oool01P3oool00`07
;U@0oooo0?ooo`0J0?ooo`0300L^E03oool0oooo04<0oooo00<01biD0?ooo`3oool02@3oool00`07
;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo01P0oooo00<01biD0?ooo`3oool0=03oool00`07
;U@0oooo0?ooo`0;0?ooo`0400L^E03oool0oooo00L^E1d0oooo0P07;UA60?ooo`0300L^E03oool0
oooo00X0oooo0P07;U@00`3oool01biD0?ooo`0K0?ooo`0300L^E03oool0oooo03h0oooo000G0?oo
o`0300L^E03oool0oooo00X0oooo00D01biD0?ooo`3oool0oooo00L^E0060?ooo`0300L^E03oool0
oooo00L0oooo0P07;U@K0?ooo`0300L^E03oool0oooo04<0oooo00<01biD0?ooo`3oool02@3oool0
0`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo01P0oooo00<01biD0?ooo`3oool0=03oool0
0`07;U@0oooo0?ooo`0;0?ooo`0400L^E03oool0oooo00L^E1h0oooo0`07;UA30?ooo`0300L^E03o
ool0oooo00/0oooo00@01biD0?ooo`3oool01biD703oool200L^E3h0oooo000H0?ooo`801biD2`3o
ool01@07;U@0oooo0?ooo`3oool01biD00D0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo
0?ooo`0H0?ooo`0300L^E03oool0oooo04<0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo
0?ooo`070?ooo`0300L^E03oool0oooo01P0oooo00<01biD0?ooo`3oool0=03oool200L^E0`0oooo
00<01biD0?ooo`3oool00P07;U@O0?ooo`801biD@P3oool00`07;U@0oooo0?ooo`0:0?ooo`0500L^
E03oool0oooo0?ooo`07;U@07@3oool300L^E3/0oooo000J0?ooo`0300L^E03oool0oooo00T0oooo
00D01biD0?ooo`3oool0oooo00L^E0050?ooo`0300L^E03oool0oooo00T0oooo00<01biD0?ooo`3o
ool0603oool00`07;U@0oooo0?ooo`130?ooo`0300L^E03oool0oooo00P0oooo00<01biD0?ooo`3o
ool0203oool200L^E1T0oooo00<01biD0?ooo`3oool0=@3oool200L^E0/0oooo00D01biD0?ooo`3o
ool0oooo00L^E00P0?ooo`0300L^E03oool0oooo0400oooo0P07;U@;0?ooo`0500L^E03oool0oooo
0?ooo`07;U@07`3oool200L^E3T0oooo000K0?ooo`0300L^E03oool0oooo00P0oooo00<01biD0?oo
o`3oool00P3oool200L^E0<0oooo00<01biD0?ooo`3oool02P3oool:00L^E100oooo00<01biD0?oo
o`3oool0A03oool200L^E0P0oooo00<01biD0?ooo`3oool02P3oool800L^E140oooo00<01biD0?oo
o`3oool0=`3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo0080oooo00<01biD0?oo
o`3oool07P3oool00`07;U@0oooo0?ooo`110?ooo`0300L^E03oool0oooo00T0oooo00D01biD0?oo
o`3oool0oooo00L^E00P0?ooo`801biD=`3oool001`0oooo0P07;U@90?ooo`0300L^E03oool0oooo
00<0oooo00@01biD0?ooo`3oool01biD5P3oool300L^E0h0oooo00<01biD0?ooo`3oool0A03oool0
0`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo0180oooo0`07;U@?0?ooo`0300L^E03oool0
oooo03L0oooo0P07;U@90?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool07P3oool3
00L^E440oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0
oooo01l0oooo0P07;U@e0?ooo`007P3oool300L^E0L0oooo0P07;U@40?ooo`<01biD6@3oool00`07
;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo04D0oooo00<01biD0?ooo`3oool01P3oool00`07
;U@0oooo0?ooo`0D0?ooo`801biD3@3oool00`07;U@0oooo0?ooo`0i0?ooo`0300L^E03oool0oooo
00L0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0P0?ooo`801biD@03oool200L^
E0T0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0P0?ooo`0300L^E03oool0oooo
0380oooo000Q0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool07P3oool200L^E0`0
oooo00<01biD0?ooo`3oool0A03oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo01H0
oooo0P07;U@<0?ooo`0300L^E03oool0oooo03T0oooo0`07;U@70?ooo`0300L^E03oool0oooo0080
oooo00<01biD0?ooo`3oool08@3oool200L^E400oooo0`07;U@70?ooo`801biD0`3oool00`07;U@0
oooo0?ooo`0P0?ooo`801biD<P3oool00280oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo
0?ooo`0P0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool0A03oool00`07;U@0oooo
0?ooo`060?ooo`0300L^E03oool0oooo01L0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo
0?ooo`0l0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo
0?ooo`0R0?ooo`801biD@@3oool00`07;U@0oooo0?ooo`060?ooo`0400L^E03oool0oooo0?ooo`80
1biD8P3oool200L^E300oooo000S0?ooo`801biD1P3oool00`07;U@0oooo0?ooo`0P0?ooo`0300L^
E03oool0oooo00T0oooo00<01biD0?ooo`3oool0A03oool00`07;U@0oooo0?ooo`060?ooo`0300L^
E03oool0oooo01P0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`0l0?ooo`0300L^
E03oool0oooo00D0oooo00<01biD0?ooo`3oool00P3oool200L^E2@0oooo00<01biD0?ooo`3oool0
?`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00<0oooo0P07;U@R0?ooo`801biD
;P3oool002D0oooo00<01biD0?ooo`3oool0103oool200L^E240oooo00<01biD0?ooo`3oool0203o
ool00`07;U@0oooo0?ooo`150?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool06@3o
ool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo03d0oooo0P07;U@50?ooo`0300L^E03o
ool0oooo00@0oooo0P07;U@S0?ooo`801biD@03oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03o
ool0oooo00@0oooo00<01biD0?ooo`3oool08@3oool200L^E2`0oooo000V0?ooo`0300L^E03oool0
oooo00@0oooo00<01biD0?ooo`3oool0803oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0
oooo04D0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0J0?ooo`0300L^E03oool0
oooo00L0oooo00<01biD0?ooo`3oool0?`3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0
oooo00D0oooo0P07;U@<0?ooo`<01biD4`3oool200L^E400oooo0P07;U@60?ooo`801biD1@3oool2
00L^E2<0oooo00<01biD0?ooo`3oool0:@3oool002L0oooo0P07;U@50?ooo`0300L^E03oool0oooo
0200oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`150?ooo`0300L^E03oool0oooo
00D0oooo00<01biD0?ooo`3oool06`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
03l0oooo00<01biD0?ooo`3oool0103oool200L^E0L0oooo3007;U@30?ooo`H01biD3P3oool00`07
;U@0oooo0?ooo`100?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool01@3oool300L^
E0T0oooo1P07;U@A0?ooo`801biD:P3oool002P0oooo00<01biD0?ooo`3oool0103oool00`07;U@0
oooo0?ooo`0O0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0AP3oool00`07;U@0
oooo0?ooo`050?ooo`0300L^E03oool0oooo01X0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0
oooo0?ooo`110?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool06@3oool200L^E0`0
oooo00<01biD0?ooo`3oool0@@3oool200L^E0D0oooo00<01biD0?ooo`3oool01`3oool900L^E0H0
oooo1007;U@>0?ooo`0300L^E03oool0oooo02P0oooo000Y0?ooo`0300L^E03oool0oooo00<0oooo
00<01biD0?ooo`3oool0803oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo04L0oooo
00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0K0?ooo`0300L^E03oool0oooo00<0oooo
0P07;UA40?ooo`801biD1@3oool00`07;U@0oooo0?ooo`0K0?ooo`801biD2P3oool00`07;U@0oooo
0?ooo`120?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool06@3oool300L^E0/0oooo
0P07;U@Y0?ooo`00:P3oool200L^E0@0oooo00<01biD0?ooo`3oool0803oool00`07;U@0oooo0?oo
o`020?ooo`801biDB@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo01`0oooo00@0
1biD0?ooo`3oool0oooo0P07;UA60?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool0
703oool200L^E0L0oooo00<01biD0?ooo`3oool0A03oool00`07;U@0oooo0?ooo`040?ooo`0300L^
E03oool0oooo01/0oooo0P07;U@90?ooo`0300L^E03oool0oooo02P0oooo000[0?ooo`0300L^E03o
ool0oooo00<0oooo00<01biD0?ooo`3oool0803oool00`07;U@0oooo0?ooo`0200L^E4X0oooo00<0
1biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0L0?ooo`0400L^E03oool0oooo00L^E4T0oooo
00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0M0?ooo`0300L^E03oool0oooo00@0oooo
00<01biD0?ooo`3oool0A@3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo01d0oooo
00<01biD0?ooo`3oool01@3oool200L^E2X0oooo000/0?ooo`0300L^E03oool0oooo00<0oooo00<0
1biD0?ooo`3oool0803oool200L^E4`0oooo0P07;U@50?ooo`801biD7`3oool200L^E4/0oooo00<0
1biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0M0?ooo`801biD0P3oool200L^E4T0oooo00<0
1biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0M0?ooo`801biD0`3oool200L^E2`0oooo000]
0?ooo`801biD103oool00`07;U@0oooo0?ooo`1_0?ooo`H01biDKP3oool300L^E0<0oooo00<01biD
0?ooo`3oool07`3oool200L^E4`0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0N
0?ooo`<01biD;P3oool002l0oooo1@07;UCX0?ooo`D01biDK`3oool200L^E0<0oooo0P07;UA@0?oo
o`00o`3ooonC0?ooo`D01biDD03oool00?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03oool0
0?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03oool0
0?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03oool0
0?l0ooooj03oool00?l0ooooj03oool002h0oooo1`07;U@I0?ooo`D01biDo`3ooom10?ooo`@01biD
703oool00`07;U@0oooo0?ooo`0a0?ooo`00:`3oool300L^E0L0oooo0P07;U@F0?ooo`801biD103o
ool300L^E4h0oooo2007;U@H0?ooo`H01biDDP3oool700L^E1P0oooo1P07;UA@0?ooo`801biD0P3o
ool200L^E1T0oooo0`07;U@00`3oool01biD00L^E00a0?ooo`00:@3oool200L^E0`0oooo0P07;U@D
0?ooo`0300L^E03oool0oooo00H0oooo0P07;UA:0?ooo`801biD203oool200L^E1H0oooo00<01biD
0?ooo`3oool00`3oool200L^E4h0oooo0P07;U@70?ooo`801biD5@3oool200L^E0D0oooo0P07;UA<
0?ooo`801biD103oool00`07;U@0oooo0?ooo`0H0?ooo`0300L^E03oool0oooo00<0oooo0`07;U@^
0?ooo`00:03oool200L^E0h0oooo00<01biD0?ooo`3oool04P3oool00`07;U@0oooo0?ooo`080?oo
o`801biDAP3oool200L^E0`0oooo00<01biD0?ooo`3oool04P3oool00`07;U@0oooo0?ooo`060?oo
o`801biDBP3oool200L^E0/0oooo0P07;U@C0?ooo`0300L^E03oool0oooo00H0oooo0P07;UA70?oo
o`<01biD1@3oool00`07;U@0oooo0?ooo`0I0?ooo`0300L^E03oool0oooo00H0oooo0P07;U@/0?oo
o`009`3oool200L^E100oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`090?ooo`03
00L^E03oool0oooo04<0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0A0?ooo`03
00L^E03oool0oooo00P0oooo0P07;UA60?ooo`801biD3P3oool00`07;U@0oooo0?ooo`0A0?ooo`03
00L^E03oool0oooo00P0oooo0P07;UA30?ooo`801biD1`3oool00`07;U@0oooo0?ooo`0J0?ooo`03
00L^E03oool0oooo00P0oooo0P07;U@Z0?ooo`009`3oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^
E03oool0oooo0100oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`110?ooo`0300L^
E03oool0oooo00l0oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^
E03oool0oooo0480oooo0P07;U@@0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool0
2P3oool00`07;U@0oooo0?ooo`0o0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0
6`3oool00`07;U@0oooo0?ooo`0:0?ooo`801biD:03oool002H0oooo00<01biD0?ooo`3oool04P3o
ool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo00/0oooo0P07;UA00?ooo`0300L^E03o
ool0oooo0100oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03o
ool0oooo0440oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03o
ool0oooo00/0oooo00<01biD0?ooo`3oool0?03oool200L^E0T0oooo00<01biD0?ooo`3oool06`3o
ool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo02H0oooo000V0?ooo`0300L^E03oool0
oooo01<0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0
oooo03h0oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0
oooo00`0oooo00<01biD0?ooo`3oool0?`3oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0
oooo00h0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0j0?ooo`0300L^E03oool0
oooo00P0oooo00<01biD0?ooo`3oool0703oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0
oooo02D0oooo000V0?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool03P3oool00`07
;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo03d0oooo00<01biD0?ooo`3oool04P3oool200L^
E100oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0n0?ooo`0300L^E03oool0oooo
01<0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo
03P0oooo0P07;U@:0?ooo`0300L^E03oool0oooo01d0oooo00<01biD0?ooo`3oool03@3oool00`07
;U@0oooo0?ooo`0T0?ooo`009P3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo00h0
oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0m0?ooo`0300L^E03oool0oooo01<0
oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo03d0
oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo00`0
oooo00<01biD0?ooo`3oool0=P3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo01d0
oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0T0?ooo`009P3oool00`07;U@0oooo
0?ooo`0D0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo
0?ooo`0l0?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo
0?ooo`0=0?ooo`0300L^E03oool0oooo03d0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo
0?ooo`0=0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool0=03oool00`07;U@0oooo
0?ooo`090?ooo`801biD8@3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo02<0oooo
000W0?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?oo
o`0>0?ooo`0300L^E03oool0oooo03/0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?oo
o`0=0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool0?@3oool00`07;U@0oooo0?oo
o`0C0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?oo
o`0c0?ooo`0300L^E03oool0oooo00T0oooo00<01biD0?ooo`3oool08@3oool00`07;U@0oooo0?oo
o`0=0?ooo`0300L^E03oool0oooo02<0oooo000W0?ooo`0300L^E03oool0oooo01D0oooo00<01biD
0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo03`0oooo00<01biD
0?ooo`3oool04`3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00h0oooo00<01biD
0?ooo`3oool0?@3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo00d0oooo00<01biD
0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0b0?ooo`0300L^E03oool0oooo00T0oooo00<01biD
0?ooo`3oool08P3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo0280oooo000X0?oo
o`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0?0?oo
o`0300L^E03oool0oooo03/0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0=0?oo
o`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool0?@3oool00`07;U@0oooo0?ooo`0D0?oo
o`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0a0?oo
o`0300L^E03oool0oooo00T0oooo00<01biD0?ooo`3oool01@3oool400L^E1X0oooo00<01biD0?oo
o`3oool03@3oool00`07;U@0oooo0?ooo`0R0?ooo`00:03oool00`07;U@0oooo0?ooo`0E0?ooo`03
00L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`0l0?ooo`03
00L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0>0?ooo`03
00L^E03oool0oooo03d0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0<0?ooo`03
00L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool0;`3oool00`07;U@0oooo0?ooo`080?ooo`80
1biD1P3oool200L^E0@0oooo0P07;U@H0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3o
ool08@3oool002T0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^
E03oool0oooo00h0oooo00<01biD0?ooo`3oool0?03oool00`07;U@0oooo0?ooo`0E0?ooo`0300L^
E03oool0oooo00`0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0m0?ooo`0300L^
E03oool0oooo01D0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^
E03oool0oooo02l0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`030?ooo`<01biD
203oool00`07;U@0oooo0?ooo`0E0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool0
8@3oool002X0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03o
ool0oooo00d0oooo00<01biD0?ooo`3oool0?@3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03o
ool0oooo00`0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0n0?ooo`0300L^E03o
ool0oooo01@0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03o
ool0oooo02l0oooo00<01biD0?ooo`3oool01`3oool01007;U@0oooo0?ooo`3oool200L^E0`0oooo
0P07;U@E0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool08@3oool002/0oooo00<0
1biD0?ooo`3oool04`3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00h0oooo00<0
1biD0?ooo`3oool0?03oool00`07;U@0oooo0?ooo`0E0?ooo`0300L^E03oool0oooo00`0oooo00<0
1biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0o0?ooo`0300L^E03oool0oooo01@0oooo00<0
1biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo02h0oooo00<0
1biD0?ooo`3oool01`3oool01@07;U@0oooo0?ooo`3oool01biD00l0oooo00<01biD0?ooo`3oool0
503oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo0240oooo000[0?ooo`0300L^E03o
ool0oooo01@0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03o
ool0oooo03d0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03o
ool0oooo00d0oooo00<01biD0?ooo`3oool0?`3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03o
ool0oooo00/0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0]0?ooo`0300L^E03o
ool0oooo00L0oooo00D01biD0?ooo`3oool0oooo00L^E00A0?ooo`0300L^E03oool0oooo01<0oooo
00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0Q0?ooo`00;03oool00`07;U@0oooo0?oo
o`0D0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?oo
o`0n0?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?oo
o`0=0?ooo`0300L^E03oool0oooo03l0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?oo
o`0;0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0;@3oool00`07;U@0oooo0?oo
o`070?ooo`0400L^E03oool0oooo00L^E1<0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo
0?ooo`0<0?ooo`0300L^E03oool0oooo0240oooo000]0?ooo`0300L^E03oool0oooo01<0oooo00<0
1biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo03l0oooo00<0
1biD0?ooo`3oool04`3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00`0oooo00<0
1biD0?ooo`3oool0@03oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo00/0oooo00<0
1biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0[0?ooo`0300L^E03oool0oooo00L0oooo0P07
;U@00`3oool01biD0?ooo`0D0?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool03@3o
ool00`07;U@0oooo0?ooo`0P0?ooo`00;@3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0
oooo00/0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`100?ooo`0300L^E03oool0
oooo0180oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0
oooo0440oooo00<01biD0?ooo`3oool04P3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0
oooo00d0oooo00<01biD0?ooo`3oool0:P3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0
1biD01H0oooo00<01biD0?ooo`3oool04P3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0
oooo0200oooo000^0?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool02`3oool00`07
;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo0400oooo00<01biD0?ooo`3oool04`3oool00`07
;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0@P3oool00`07
;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool0303oool00`07
;U@0oooo0?ooo`0Z0?ooo`0300L^E03oool0oooo00H0oooo1007;U@H0?ooo`0300L^E03oool0oooo
0180oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0P0?ooo`00;`3oool00`07;U@0
oooo0?ooo`0B0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool0303oool00`07;U@0
oooo0?ooo`110?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool02`3oool00`07;U@0
oooo0?ooo`0<0?ooo`0300L^E03oool0oooo04<0oooo00<01biD0?ooo`3oool04@3oool00`07;U@0
oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0:@3oool00`07;U@0
oooo0?ooo`050?ooo`801biD0P3oool00`07;U@0oooo0?ooo`0G0?ooo`0300L^E03oool0oooo0180
oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0P0?ooo`00503oool500L^E1L0oooo
00<01biD0?ooo`3oool04P3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00/0oooo
00<01biD0?ooo`3oool02@3oool200L^E3L0oooo00<01biD0?ooo`3oool04P3oool00`07;U@0oooo
0?ooo`0:0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool09`3oool00`07;U@0oooo
0?ooo`0J0?ooo`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo
0?ooo`0<0?ooo`0300L^E03oool0oooo00T0oooo0P07;U@M0?ooo`0300L^E03oool0oooo00D0oooo
00<01biD0?ooo`3oool00P07;U@K0?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool0
2`3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo01<0oooo000B0?ooo`801biD103o
ool200L^E1L0oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03o
ool0oooo00/0oooo00<01biD0?ooo`3oool02@3oool300L^E1X0oooo1@07;U@H0?ooo`0300L^E03o
ool0oooo0180oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03o
ool0oooo00P0oooo0P07;U@K0?ooo`<01biD703oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03o
ool0oooo00X0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`090?ooo`801biD703o
ool00`07;U@0oooo0?ooo`050?ooo`0400L^E03oool0oooo00L^E1d0oooo00<01biD0?ooo`3oool0
4P3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00T0oooo0P07;U@E0?ooo`004@3o
ool200L^E0L0oooo0P07;U@F0?ooo`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool02P3o
ool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00P0oooo0P07;U@00`3oool01biD0?oo
o`0H0?ooo`801biD103oool200L^E1L0oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?oo
o`0:0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo00L^
E00I0?ooo`0400L^E03oool0oooo00L^E1`0oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo
0?ooo`0:0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool0203oool01007;U@0oooo
0?ooo`07;U@J0?ooo`0300L^E03oool0oooo00D0oooo00@01biD0?ooo`3oool01biD7`3oool00`07
;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool0203oool200L^
E0030?ooo`07;U@0oooo01<0oooo000A0?ooo`0300L^E03oool0oooo00P0oooo0P07;U@E0?ooo`03
00L^E03oool0oooo0140oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`0:0?ooo`03
00L^E03oool0oooo00P0oooo00@01biD0?ooo`3oool01biD603oool200L^E0L0oooo0P07;U@F0?oo
o`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`0;0?oo
o`0300L^E03oool0oooo00P0oooo00@01biD0?ooo`3oool01biD603oool01007;U@0oooo0?ooo`07
;U@M0?ooo`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?oo
o`0:0?ooo`0300L^E03oool0oooo00P0oooo00@01biD0?ooo`3oool01biD6@3oool00`07;U@0oooo
0?ooo`050?ooo`0500L^E03oool0oooo0?ooo`07;U@0803oool00`07;U@0oooo0?ooo`0A0?ooo`03
00L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool0203oool01007;U@0oooo0?ooo`07;U@D0?oo
o`00403oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3o
ool0403oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3o
ool01`3oool01@07;U@0oooo0?ooo`3oool01biD01H0oooo0P07;U@:0?ooo`801biD5@3oool00`07
;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool02`3oool00`07
;U@0oooo0?ooo`070?ooo`0500L^E03oool0oooo0?ooo`07;U@0603oool01007;U@0oooo0?ooo`07
;U@N0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?oo
o`0:0?ooo`0300L^E03oool0oooo00P0oooo00D01biD0?ooo`3oool0oooo00L^E00G0?ooo`0300L^
E03oool0oooo00@0oooo0P07;U@30?ooo`0300L^E03oool0oooo01l0oooo00<01biD0?ooo`3oool0
4@3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00P0oooo00D01biD0?ooo`3oool0
oooo00L^E00C0?ooo`003`3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo01<0oooo
00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo00/0oooo
00<01biD0?ooo`3oool01`3oool01@07;U@0oooo0?ooo`3oool01biD01H0oooo00<01biD0?ooo`3o
ool02`3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3o
ool02@3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00L0oooo00D01biD0?ooo`3o
ool0oooo00L^E00G0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool0703oool00`07
;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00T0oooo00<01biD0?ooo`3oool02`3oool00`07
;U@0oooo0?ooo`070?ooo`0500L^E03oool0oooo0?ooo`07;U@05P3oool00`07;U@0oooo0?ooo`04
0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool08@3oool00`07;U@0oooo0?ooo`0@
0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool01`3oool01@07;U@0oooo0?ooo`3o
ool01biD01<0oooo000?0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool04P3oool0
0`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00T0oooo00<01biD0?ooo`3oool02`3oool0
0`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool04P3oool0
0`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool03`3oool0
0`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool01`3oool0
0`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool00P3oool0
0`07;U@0oooo0?ooo`0M0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool02@3oool0
0`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool00P3oool0
0`07;U@0oooo0?ooo`0A0?ooo`801biD1P3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0
oooo0280oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0
oooo00L0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0@0?ooo`003P3oool00`07
;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool0403oool00`07
;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool01`3oool00`07
;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool03P3oool200L^
E1<0oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo
00X0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo
01@0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0N0?ooo`0300L^E03oool0oooo
00l0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo
00L0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo
00@0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0S0?ooo`0300L^E03oool0oooo
00l0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo
0080oooo00<01biD0?ooo`3oool0403oool000h0oooo00<01biD0?ooo`3oool04@3oool200L^E1<0
oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00X0
oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo0100
oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00l0
oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00L0
oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo00<0
oooo00<01biD0?ooo`3oool07`3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo00P0
oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00<0
oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo00@0
oooo00<01biD0?ooo`3oool0903oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo00X0
oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo00l0
oooo000>0?ooo`0300L^E03oool0oooo01<0oooo0P07;U@B0?ooo`0300L^E03oool0oooo0100oooo
00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00L0oooo
00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo0180oooo
00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo00P0oooo
00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00<0oooo
00<01biD0?ooo`3oool04P3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo01l0oooo
00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00X0oooo
00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo00l0oooo
00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo02D0oooo
00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00L0oooo
00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0?0?ooo`003P3oool00`07;U@0oooo0?oo
o`0E0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?oo
o`060?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?oo
o`040?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo0?oo
o`0A0?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?oo
o`0;0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?oo
o`0A0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool0803oool00`07;U@0oooo0?oo
o`0?0?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?oo
o`060?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool03`3oool01007;U@0oooo0?oo
o`3oool200L^E0L0oooo00<01biD0?ooo`3oool09P3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^
E03oool0oooo00X0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`030?ooo`0300L^
E03oool0oooo00l0oooo000>0?ooo`0300L^E03oool0oooo01H0oooo00<01biD0?ooo`3oool03`3o
ool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool02`3o
ool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool03`3o
ool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool03`3o
ool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool01P3o
ool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool0103o
ool00`07;U@0oooo0?ooo`040?ooo`@01biD6@3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03o
ool0oooo00H0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03o
ool0oooo00@0oooo00<01biD0?ooo`3oool03`3oool01007;U@0oooo0?ooo`07;U@90?ooo`0300L^
E03oool0oooo02L0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^
E03oool0oooo00L0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0>0?ooo`003P3o
ool00`07;U@0oooo0?ooo`0G0?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool0403o
ool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool01P3o
ool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool05@3o
ool200L^E180oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03o
ool0oooo00X0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03o
ool0oooo00l0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`030?ooo`801biD0`3o
ool200L^E1P0oooo00<01biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03o
ool0oooo00/0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03o
ool0oooo00l0oooo00<01biD0?ooo`07;U@02P3oool00`07;U@0oooo0?ooo`0X0?ooo`0300L^E03o
ool0oooo00`0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03o
ool0oooo00@0oooo00<01biD0?ooo`3oool03P3oool000h0oooo00<01biD0?ooo`3oool0603oool0
0`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool0103oool0
0`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0103oool0
0`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo01L0oooo00<01biD0?ooo`3oool03`3oool0
0`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool02P3oool0
0`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool03P3oool0
0`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool01@3oool2
00L^E1H0oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0
oooo00X0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0
oooo00h0oooo0P07;U@;0?ooo`0300L^E03oool0oooo02T0oooo00<01biD0?ooo`3oool02`3oool0
0`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0103oool0
0`07;U@0oooo0?ooo`0>0?ooo`003P3oool00`07;U@0oooo0?ooo`0I0?ooo`0300L^E03oool0oooo
00l0oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo
00/0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo
00h0oooo00<01biD0?ooo`3oool0603oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo
0100oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo
00D0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo
00D0oooo00D01biD0?ooo`3oool0oooo00L^E00:0?ooo`0300L^E03oool0oooo01@0oooo00<01biD
0?ooo`3oool0403oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00X0oooo00<01biD
0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo01/0oooo00<01biD
0?ooo`3oool0:P3oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00/0oooo00<01biD
0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00h0oooo000?0?oo
o`0300L^E03oool0oooo01T0oooo0P07;U@?0?ooo`0300L^E03oool0oooo0140oooo00<01biD0?oo
o`3oool00P3oool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?oo
o`3oool01P3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo01T0oooo00<01biD0?oo
o`3oool03P3oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?oo
o`3oool02`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?oo
o`3oool03P3oool00`07;U@0oooo0?ooo`050?ooo`0500L^E03oool0oooo0?ooo`07;U@02`3oool0
0`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool00`3oool0
0`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool01@3oool0
0`07;U@0oooo0?ooo`0K0?ooo`0300L^E03oool0oooo02/0oooo00<01biD0?ooo`3oool02@3oool0
0`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool01P3oool0
0`07;U@0oooo0?ooo`0=0?ooo`003`3oool00`07;U@0oooo0?ooo`0K0?ooo`0300L^E03oool0oooo
00d0oooo00<01biD0?ooo`3oool0403oool300L^E080oooo00<01biD0?ooo`3oool0303oool00`07
;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool03`3oool00`07
;U@0oooo0?ooo`0I0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool04@3oool00`07
;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool01@3oool00`07
;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool01@3oool01@07
;U@0oooo0?ooo`3oool01biD00`0oooo0P07;U@D0?ooo`0300L^E03oool0oooo0140oooo0P07;U@2
0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`06
0?ooo`0300L^E03oool0oooo01/0oooo00<01biD0?ooo`3oool0:`3oool00`07;U@0oooo0?ooo`08
0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`06
0?ooo`0300L^E03oool0oooo00d0oooo000@0?ooo`0300L^E03oool0oooo01/0oooo00<01biD0?oo
o`3oool0303oool00`07;U@0oooo0?ooo`0?0?ooo`D01biD00<0oooo00L^E03oool03@3oool00`07
;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool03`3oool00`07
;U@0oooo0?ooo`0J0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool03`3oool300L^
E080oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo
00D0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`060?ooo`0400L^E03oool0oooo
00L^E0l0oooo00<01biD0?ooo`3oool04P3oool00`07;U@0oooo0?ooo`0>0?ooo`L01biD3P3oool0
0`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool06`3oool2
00L^E2d0oooo0`07;U@70?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool0103oool0
0`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00d0oooo000@0?ooo`0300L^E03oool0oooo
01`0oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo
00<0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo
00H0oooo00<01biD0?ooo`3oool0403oool00`07;U@0oooo0?ooo`0J0?ooo`801biD3P3oool00`07
;U@0oooo0?ooo`0>0?ooo`801biD0P3oool300L^E0h0oooo00<01biD0?ooo`3oool01@3oool00`07
;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool01P3oool01007
;U@0oooo0?ooo`07;U@@0?ooo`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool03P3oool0
0`07;U@0oooo0?ooo`020?ooo`801biD3P3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0
oooo00H0oooo00<01biD0?ooo`3oool0703oool00`07;U@0oooo0?ooo`0^0?ooo`L01biD3`3oool0
0`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool03@3oool0
0140oooo0P07;U@M0?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool03@3oool00`07
;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool00`3oool00`07
;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool0703oool00`07
;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool00`3oool00`07
;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool01@3oool00`07
;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00H0oooo00@01biD0?ooo`3oool01biD4@3oool0
0`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool00`3oool0
0`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool01P3oool0
0`07;U@0oooo0?ooo`0M0?ooo`0300L^E03oool0oooo02l0oooo0`07;U@00`3oool01biD0?ooo`0?
0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0=
0?ooo`004P3oool00`07;U@0oooo0?ooo`0L0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?oo
o`3oool03@3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?oo
o`3oool00`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo0140oooo0P07;U@M0?oo
o`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`030?oo
o`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`070?oo
o`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool01P3oool01007;U@0oooo0?ooo`07;U@B
0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`04
0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`06
0?ooo`0300L^E03oool0oooo01h0oooo00<01biD0?ooo`3oool0;03oool200L^E0D0oooo00<01biD
0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0oooo00H0oooo00<01biD
0?ooo`3oool03@3oool001<0oooo00<01biD0?ooo`3oool0703oool200L^E0/0oooo00<01biD0?oo
o`3oool0303oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?oo
o`3oool00P3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo0180oooo00<01biD0?oo
o`3oool0703oool00`07;U@0oooo0?ooo`0:0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?oo
o`3oool0103oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?oo
o`3oool01P3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo00D0oooo00@01biD0?oo
o`3oool01biD4`3oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^E03oool0oooo00`0oooo00<01biD
0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo0080oooo00<01biD
0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0O0?ooo`0300L^E03oool0oooo02/0oooo00<01biD
0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo0080oooo00<01biD
0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0=0?ooo`00503oool200L^E1h0oooo00<01biD0?oo
o`3oool0203oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?oo
o`3oool02P3oool400L^E0@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0C0?oo
o`0300L^E03oool0oooo01`0oooo0P07;U@;0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?oo
o`3oool0103oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?oo
o`3oool01P3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?oo
o`07;U@0503oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?oo
o`3oool01@3oool00`07;U@0oooo0?ooo`0:0?ooo`<01biD103oool00`07;U@0oooo0?ooo`060?oo
o`0300L^E03oool0oooo0200oooo0P07;U@Z0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?oo
o`3oool02`3oool00`07;U@0oooo00L^E0040?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?oo
o`3oool03@3oool001H0oooo00<01biD0?ooo`3oool0703oool300L^E0P0oooo00<01biD0?ooo`3o
ool0303oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00T0oooo00<01biD0?ooo`07
;U@00P07;U@30?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0503oool200L^E1h0
oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00D0
oooo00<01biD0?ooo`3oool02P3oool300L^E0@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0
oooo0?ooo`0>0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`07;U@05@3oool200L^E0l0
oooo00<01biD0?ooo`3oool0303oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00T0
oooo00<01biD0?ooo`07;U@00P07;U@20?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3o
ool08`3oool200L^E2L0oooo0P07;U@80?ooo`0300L^E03oool0oooo00X0oooo1007;U@40?ooo`03
00L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool03@3oool001L0oooo0P07;U@O0?ooo`801biD
1P3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0
2@3oool01@07;U@0oooo0?ooo`3oool01biD0080oooo00<01biD0?ooo`3oool01`3oool00`07;U@0
oooo0?ooo`0F0?ooo`801biD7@3oool200L^E0P0oooo00<01biD0?ooo`3oool0303oool00`07;U@0
oooo0?ooo`050?ooo`0300L^E03oool0oooo00T0oooo0P07;U@00`3oool01biD00L^E0030?ooo`03
00L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool03P3oool00`07;U@0oooo0?ooo`060?ooo`03
00L^E03oool01biD01L0oooo0P07;U@=0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3o
ool01@3oool00`07;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo00801biD0P3oool00`07;U@0
oooo0?ooo`060?ooo`0300L^E03oool0oooo02D0oooo00<01biD0?ooo`3oool0903oool00`07;U@0
oooo0?ooo`080?ooo`0300L^E03oool0oooo00T0oooo00<01biD0?ooo`3oool00P07;U@30?ooo`03
00L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool03@3oool001T0oooo0P07;U@O0?ooo`<01biD
0`3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0
1`3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool01biD00T0oooo00<01biD0?ooo`3oool0
603oool200L^E1d0oooo0`07;U@50?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool0
103oool00`07;U@0oooo0?ooo`090?ooo`0400L^E03oool0oooo0?ooo`801biD0P3oool00`07;U@0
oooo0?ooo`060?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`3oool01P3oool300L^E1T0
oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00H0
oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`020?ooo`0400L^E03oool0oooo00L^
E0P0oooo00<01biD0?ooo`3oool09P3oool200L^E2@0oooo00<01biD0?ooo`3oool0203oool00`07
;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`07;U@0203oool00`07
;U@0oooo0?ooo`0>0?ooo`006`3oool300L^E1l0oooo1007;U@?0?ooo`0300L^E03oool0oooo00D0
oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`040?ooo`801biD203oool00`07;U@0
oooo0?ooo`0K0?ooo`0300L^E03oool0oooo01d0oooo0P07;U@40?ooo`0300L^E03oool0oooo00`0
oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo0080
oooo00<01biD0?ooo`07;U@02@3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo00L0
oooo0P07;U@J0?ooo`801biD2`3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00D0
oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`030?ooo`801biD2@3oool00`07;U@0
oooo0?ooo`0X0?ooo`801biD8P3oool00`07;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo00L0
oooo00<01biD0?ooo`3oool0103oool200L^E0P0oooo00<01biD0?ooo`3oool03P3oool001h0oooo
0P07;U@L0?ooo`801biD0`3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0oooo00H0oooo
00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00L0oooo
00<01biD0?ooo`3oool0703oool200L^E1l0oooo1@07;U@>0?ooo`0300L^E03oool0oooo00D0oooo
00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`040?ooo`801biD203oool00`07;U@0oooo
0?ooo`0@0?ooo`0300L^E03oool0oooo00D0oooo0`07;U@L0?ooo`801biD203oool00`07;U@0oooo
00L^E00=0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo
0?ooo`030?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool0:`3oool200L^E200oooo
00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00@0oooo
00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`0>0?ooo`00803oool00`07;U@0oooo0?oo
o`0I0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?oo
o`060?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?oo
o`060?ooo`0300L^E03oool0oooo01l0oooo0`07;U@L0?ooo`0300L^E03oool0oooo0080oooo00<0
1biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00H0oooo00<0
1biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo0100oooo00<0
1biD0?ooo`3oool01@3oool00`07;U@0oooo00L^E00N0?ooo`P01biD0`3oool00`07;U@0oooo0?oo
o`0;0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?oo
o`030?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool0;@3oool00`07;U@0oooo0?oo
o`0M0?ooo`0300L^E03oool0oooo00X0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?oo
o`040?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool03P3oool00240oooo0P07;U@I
0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool02P3oool00`07;U@0oooo0?ooo`06
0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`06
0?ooo`0300L^E03oool0oooo0280oooo0P07;U@J0?ooo`0300L^E03oool0oooo00<0oooo00<01biD
0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00H0oooo00<01biD
0?ooo`3oool0103oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo0100oooo00<01biD
0?ooo`3oool01@3oool00`07;U@0oooo00L^E00U0?ooo`0500L^E03oool0oooo0?ooo`07;U@03@3o
ool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool0103o
ool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo02h0oooo0P07;U@M0?ooo`0300L^E03o
ool0oooo00X0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03o
ool0oooo00H0oooo00<01biD0?ooo`3oool03`3oool002<0oooo0P07;U@G0?ooo`0300L^E03oool0
oooo00D0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0
oooo00@0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0
oooo02@0oooo0P07;U@H0?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool02P3oool0
0`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0103oool0
0`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool0103oool0
0`07;U@0oooo00L^E00U0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool02P3oool0
0`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool0103oool0
0`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo0300oooo0P07;U@K0?ooo`0300L^E03oool0
oooo00/0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0
oooo00H0oooo00<01biD0?ooo`3oool03`3oool002D0oooo0P07;U@F0?ooo`0300L^E03oool0oooo
00D0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
00@0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
02H0oooo00<01biD0?ooo`3oool05@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo
00X0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo
00@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0B0?ooo`0300L^E03oool0oooo
00<0oooo00@01biD0?ooo`3oool01biD903oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0
oooo00T0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0
oooo00@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0c0?ooo`0300L^E03oool0
oooo01P0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0
oooo00D0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0?0?ooo`009`3oool200L^
E1D0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo
00L0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo
00D0oooo00<01biD0?ooo`3oool0:03oool200L^E1D0oooo00<01biD0?ooo`3oool01P3oool00`07
;U@0oooo0?ooo`090?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0103oool00`07
;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool04P3oool00`07
;U@0oooo0?ooo`030?ooo`0400L^E03oool0oooo00L^E2@0oooo00<01biD0?ooo`3oool01@3oool0
0`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool00`3oool0
0`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool0=03oool0
0`07;U@0oooo0?ooo`0G0?ooo`0300L^E03oool0oooo00`0oooo00<01biD0?ooo`3oool00`3oool0
0`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool03`3oool0
02T0oooo0P07;U@C0?ooo`0300L^E03oool0oooo00H0oooo0P07;U@90?ooo`0300L^E03oool0oooo
00H0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo
00D0oooo00<01biD0?ooo`3oool0:P3oool200L^E1@0oooo00<01biD0?ooo`3oool01P3oool00`07
;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool00`3oool00`07
;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool04P3oool00`07
;U@0oooo0?ooo`030?ooo`0400L^E03oool0oooo00L^E2D0oooo00<01biD0?ooo`3oool01@3oool2
00L^E0T0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0
oooo00@0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`0e0?ooo`0300L^E03oool0
oooo01L0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo0?ooo`030?ooo`0300L^E03oool0
oooo00D0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0@0?ooo`00:`3oool200L^
E180oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
00L0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo
00D0oooo00<01biD0?ooo`3oool0;03oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo
00L0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo
0080oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
01<0oooo00<01biD0?ooo`3oool00P3oool01007;U@0oooo0?ooo`07;U@U0?ooo`0300L^E03oool0
oooo00L0oooo00<01biD0?ooo`3oool01P3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0
oooo0080oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0
oooo03H0oooo00<01biD0?ooo`3oool05P3oool00`07;U@0oooo0?ooo`0<0?ooo`0300L^E03oool0
oooo0080oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0
oooo0100oooo000]0?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool0203oool00`07
;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00L0oooo00<01biD0?ooo`3oool00P3oool00`07
;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0;@3oool200L^
E180oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0oooo
00L0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo
00D0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`020?ooo`0400L^E03oool0oooo
00L^E2D0oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`060?ooo`0300L^E03oool0
oooo00H0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0
oooo00@0oooo00<01biD0?ooo`3oool0=`3oool00`07;U@0oooo0?ooo`0F0?ooo`0300L^E03oool0
oooo00`0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0
oooo00D0oooo00<01biD0?ooo`3oool0403oool002h0oooo00<01biD0?ooo`3oool03`3oool00`07
;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3oool0203oool00`07
;U@0oooo0?ooo`0200L^E0L0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?ooo`0_0?oo
o`801biD4@3oool00`07;U@0oooo0?ooo`070?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?oo
o`3oool01`3oool01@07;U@0oooo0?ooo`3oool01biD00L0oooo00<01biD0?ooo`3oool01@3oool0
0`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo0080oooo00@01biD0?ooo`3oool01biD9P3o
ool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool01`3o
ool200L^E0030?ooo`07;U@0oooo00L0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?oo
o`0h0?ooo`0300L^E03oool0oooo01D0oooo00<01biD0?ooo`3oool03@3oool01007;U@0oooo0?oo
o`07;U@80?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0403oool002l0oooo00<0
1biD0?ooo`3oool03`3oool00`07;U@0oooo0?ooo`080?ooo`0300L^E03oool0oooo00@0oooo00<0
1biD0?ooo`3oool0203oool300L^E0P0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo0?oo
o`0a0?ooo`0300L^E03oool0oooo00l0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?oo
o`050?ooo`0300L^E03oool0oooo00P0oooo00@01biD0?ooo`3oool01biD1`3oool00`07;U@0oooo
0?ooo`050?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool00P3oool01@07;U@0oooo
0?ooo`3oool01biD02D0oooo00<01biD0?ooo`3oool02@3oool00`07;U@0oooo0?ooo`040?ooo`03
00L^E03oool0oooo00P0oooo0`07;U@80?ooo`0300L^E03oool0oooo00@0oooo00<01biD0?ooo`3o
ool0>@3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo00h0oooo00<01biD0?ooo`07
;U@0203oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo0100oooo000`0?ooo`0300L^
E03oool0oooo00l0oooo00<01biD0?ooo`3oool0203oool00`07;U@0oooo0?ooo`030?ooo`0300L^
E03oool0oooo00T0oooo00<01biD0?ooo`3oool01`3oool00`07;U@0oooo0?ooo`050?ooo`0300L^
E03oool0oooo0380oooo0P07;U@?0?ooo`0300L^E03oool0oooo00P0oooo00<01biD0?ooo`3oool0
103oool00`07;U@0oooo0?ooo`090?ooo`801biD203oool00`07;U@0oooo0?ooo`050?ooo`0300L^
E03oool0oooo01@0oooo00<01biD0?ooo`3oool00P3oool01@07;U@0oooo0?ooo`3oool01biD02H0
oooo00<01biD0?ooo`3oool02@3oool200L^E0@0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0
oooo0?ooo`040?ooo`0300L^E03oool0oooo03X0oooo00<01biD0?ooo`3oool0503oool00`07;U@0
oooo0?ooo`0>0?ooo`801biD203oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03oool0oooo0100
oooo000?0?ooo`L01biD6`3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo00P0oooo
00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^E03oool0oooo00D0oooo
00<01biD0?ooo`3oool0=03oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00P0oooo
0P07;U@40?ooo`0300L^E03oool0oooo01<0oooo00<01biD0?ooo`3oool01@3oool00`07;U@0oooo
0?ooo`0D0?ooo`0300L^E03oool0oooo0080oooo00D01biD0?ooo`3oool0oooo00L^E00V0?ooo`03
00L^E03oool0oooo00/0oooo00D01biD0?ooo`3oool0oooo00L^E00E0?ooo`0300L^E03oool0oooo
00@0oooo00<01biD0?ooo`3oool04`3oool500L^E280oooo00<01biD0?ooo`3oool0503oool00`07
;U@0oooo0?ooo`0H0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0403oool000h0
oooo0P07;U@60?ooo`<01biD6@3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo00P0
oooo1@07;U@E0?ooo`0300L^E03oool0oooo0080oooo0P07;U@00`3oool01biD0?ooo`0A0?ooo`80
1biD8`3oool00`07;U@0oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00T0oooo00D01biD0?ooo`3o
ool0oooo00L^E00E0?ooo`0300L^E03oool0oooo00D0oooo00<01biD0?ooo`3oool0503oool00`07
;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool0903oool00`07
;U@0oooo0?ooo`0;0?ooo`@01biD5@3oool00`07;U@0oooo0?ooo`020?ooo`<01biD503oool00`07
;U@0oooo0?ooo`030?ooo`@01biD7P3oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^E03oool0oooo
01P0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo00L^E00B0?ooo`003P3oool00`07;U@0
oooo0?ooo`080?ooo`D01biD5@3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo0280
oooo00<01biD0?ooo`3oool00P3oool400L^E180oooo00<01biD0?ooo`07;U@08`3oool00`07;U@0
oooo0?ooo`0=0?ooo`0300L^E03oool0oooo00T0oooo1007;U@E0?ooo`0300L^E03oool0oooo0080
oooo1007;U@F0?ooo`0300L^E03oool0oooo0080oooo00<01biD0?ooo`3oool00P3oool00`07;U@0
oooo0?ooo`0U0?ooo`0300L^E03oool0oooo02<0oooo00H01biD0?ooo`3oool0oooo00L^E03oool2
00L^E1<0oooo00<01biD0?ooo`3oool0203oool200L^E1`0oooo00<01biD0?ooo`3oool05@3oool0
0`07;U@0oooo0?ooo`0G0?ooo`0300L^E03oool0oooo0080oooo1007;U@B0?ooo`003P3oool00`07
;U@0oooo0?ooo`0=0?ooo`801biD503oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo
0240oooo00D01biD0?ooo`3oool0oooo00L^E0020?ooo`801biD4P3oool00`07;U@0oooo0?ooo`02
00L^E280oooo00<01biD0?ooo`3oool03@3oool00`07;U@0oooo0?ooo`0Q0?ooo`0400L^E03oool0
oooo0?ooo`801biD00<0oooo00L^E007;U@05P3oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03o
ool0oooo0080oooo00<01biD0?ooo`3oool09P3oool00`07;U@0oooo0?ooo`0R0?ooo`0300L^E03o
ool0oooo00801biD0P3oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03oool0oooo00X0oooo1P07
;U@G0?ooo`0300L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool05`3oool01@07;U@0oooo0?oo
o`3oool01biD0080oooo0P07;U@B0?ooo`003P3oool00`07;U@0oooo0?ooo`0?0?ooo`<01biD4P3o
ool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo0200oooo00<01biD0?ooo`3oool00P07
;U@20?ooo`801biD4P3oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo00H0oooo1007
;U@F0?ooo`0300L^E03oool0oooo00d0oooo00<01biD0?ooo`3oool08@3oool01007;U@0oooo0?oo
o`07;U@20?ooo`801biD5P3oool00`07;U@0oooo0?ooo`020?ooo`0300L^E03oool0oooo00<0oooo
00<01biD0?ooo`3oool09@3oool00`07;U@0oooo0?ooo`0R0?ooo`0400L^E03oool0oooo00L^E0<0
oooo00<01biD0?ooo`3oool04@3oool00`07;U@0oooo0?ooo`0@0?ooo`801biD5@3oool00`07;U@0
oooo0?ooo`0D0?ooo`0300L^E03oool0oooo01L0oooo00<01biD0?ooo`3oool00P07;U@20?ooo`80
1biD4P3oool000h0oooo00<01biD0?ooo`3oool04P3oool200L^E140oooo00<01biD0?ooo`3oool0
3P3oool00`07;U@0oooo0?ooo`0P0?ooo`<01biD103oool00`07;U@0oooo0?ooo`0@0?ooo`0300L^
E03oool0oooo00<0oooo00<01biD0?ooo`3oool0103oool200L^E0<0oooo0`07;U@C0?ooo`0300L^
E03oool0oooo00h0oooo00<01biD0?ooo`3oool0803oool01007;U@0oooo0?ooo`07;U@30?ooo`03
00L^E03oool0oooo01@0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`030?ooo`03
00L^E03oool0oooo02H0oooo00<01biD0?ooo`3oool08P3oool300L^E0<0oooo00<01biD0?ooo`3o
ool04P3oool00`07;U@0oooo0?ooo`0A0?ooo`<01biD4P3oool00`07;U@0oooo0?ooo`0D0?ooo`03
00L^E03oool0oooo01P0oooo00<01biD0?ooo`07;U@0103oool00`07;U@0oooo0?ooo`0@0?ooo`00
3P3oool00`07;U@0oooo0?ooo`0D0?ooo`<01biD3`3oool00`07;U@0oooo0?ooo`0>0?ooo`0300L^
E03oool0oooo01l0oooo0P07;U@50?ooo`0300L^E03oool0oooo0140oooo00<01biD0?ooo`3oool0
0`3oool00`07;U@0oooo0?ooo`030?ooo`801biD1P3oool300L^E140oooo00<01biD0?ooo`3oool0
3P3oool00`07;U@0oooo0?ooo`0O0?ooo`<01biD103oool00`07;U@0oooo0?ooo`0D0?ooo`0300L^
E03oool0oooo0080oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0U0?ooo`0300L^
E03oool0oooo0280oooo0P07;U@40?ooo`0300L^E03oool0oooo0180oooo00<01biD0?ooo`3oool0
503oool200L^E100oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`0H0?ooo`801biD
1@3oool00`07;U@0oooo0?ooo`0@0?ooo`003`3oool00`07;U@0oooo0?ooo`0F0?ooo`D01biD2`3o
ool00`07;U@0oooo0?ooo`0>0?ooo`0300L^E03oool0oooo02D0oooo00<01biD0?ooo`3oool04@3o
ool00`07;U@0oooo0?ooo`040?ooo`801biD103oool00`07;U@0oooo0?ooo`070?ooo`801biD3`3o
ool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo01h0oooo0P07;U@50?ooo`0300L^E03o
ool0oooo01@0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`050?ooo`0300L^E03o
ool0oooo02D0oooo00<01biD0?ooo`3oool0:03oool00`07;U@0oooo0?ooo`0A0?ooo`0300L^E03o
ool0oooo01H0oooo0`07;U@=0?ooo`0300L^E03oool0oooo01D0oooo00<01biD0?ooo`3oool07P3o
ool00`07;U@0oooo0?ooo`0@0?ooo`003`3oool00`07;U@0oooo0?ooo`0K0?ooo`@01biD103oool3
00L^E0030?ooo`07;U@01biD00l0oooo00<01biD0?ooo`3oool0>@3oool00`07;U@0oooo0?ooo`04
0?ooo`0300L^E03oool0oooo00<0oooo00<01biD0?ooo`3oool0203oool300L^E0d0oooo0P07;U@?
0?ooo`0300L^E03oool0oooo02D0oooo00<01biD0?ooo`3oool0503oool00`07;U@0oooo0?ooo`02
0?ooo`0300L^E03oool0oooo00H0oooo00<01biD0?ooo`3oool09@3oool00`07;U@0oooo0?ooo`0k
0?ooo`0300L^E03oool0oooo01T0oooo1@07;U@60?ooo`@01biD5@3oool00`07;U@0oooo0?ooo`0O
0?ooo`0300L^E03oool0oooo0100oooo000@0?ooo`0300L^E03oool0oooo01h0oooo1007;U@00`3o
ool01biD0?ooo`030?ooo`801biD3@3oool00`07;U@0oooo0?ooo`0i0?ooo`0300L^E03oool0oooo
00D0oooo00<01biD0?ooo`3oool00P3oool00`07;U@0oooo0?ooo`0;0?ooo`@01biD2@3oool00`07
;U@0oooo00L^E00200L^E0d0oooo00<01biD0?ooo`3oool0?03oool01007;U@0oooo0?ooo`07;U@:
0?ooo`0300L^E03oool0oooo02D0oooo00<01biD0?ooo`3oool0>`3oool00`07;U@0oooo0?ooo`0M
0?ooo`P01biD0P3oool200L^E1<0oooo00<01biD0?ooo`3oool0<P3oool00100oooo00<01biD0?oo
o`3oool08`3oool200L^E0D0oooo0`07;U@;0?ooo`0300L^E03oool0oooo03T0oooo00<01biD0?oo
o`3oool01@3oool200L^E0<0oooo00<01biD0?ooo`3oool03P3oool200L^E0L0oooo0P07;U@30?oo
o`801biD2`3oool00`07;U@0oooo0?ooo`0l0?ooo`0400L^E03oool0oooo00L^E0/0oooo0P07;U@V
0?ooo`0300L^E03oool0oooo03/0oooo00<01biD0?ooo`3oool08`3oool00`07;U@0oooo0?ooo`02
0?ooo`@01biD3`3oool00`07;U@0oooo0?ooo`0b0?ooo`00403oool00`07;U@0oooo0?ooo`0T0?oo
o`0300L^E03oool0oooo00H0oooo1007;U@70?ooo`0300L^E03oool0oooo03T0oooo00<01biD0?oo
o`3oool01P3oool01@07;U@0oooo0?ooo`3oool01biD0180oooo2007;U@00`3oool01biD0?ooo`03
0?ooo`801biD2P3oool200L^E3`0oooo00@01biD0?ooo`3oool01biD3@3oool200L^E2D0oooo00<0
1biD0?ooo`3oool0>P3oool00`07;U@0oooo0?ooo`0S0?ooo`801biD1`3oool400L^E0X0oooo0P07
;U@d0?ooo`004@3oool00`07;U@0oooo0?ooo`0T0?ooo`801biD2P3oool300L^E0@0oooo00<01biD
0?ooo`3oool0>P3oool00`07;U@0oooo0?ooo`060?ooo`0400L^E03oool0oooo0?ooo`801biD6P3o
ool00`07;U@0oooo0?ooo`030?ooo`<01biD203oool00`07;U@0oooo0?ooo`0k0?ooo`<01biD3`3o
ool600L^E200oooo00<01biD0?ooo`3oool0>P3oool00`07;U@0oooo0?ooo`0S0?ooo`0300L^E03o
ool0oooo00T0oooo1007;U@40?ooo`<01biD=@3oool00180oooo00<01biD0?ooo`3oool09@3oool0
0`07;U@0oooo0?ooo`0:0?ooo`D01biD?03oool00`07;U@0oooo0?ooo`070?ooo`801biD0`3oool0
0`07;U@0oooo0?ooo`0H0?ooo`0300L^E03oool0oooo00D0oooo0`07;U@40?ooo`801biD?P3oool0
0`07;U@0oooo0?ooo`0D0?ooo`@01biD703oool00`07;U@0oooo0?ooo`0j0?ooo`0300L^E03oool0
oooo02@0oooo00<01biD0?ooo`3oool0303oool500L^E3L0oooo000C0?ooo`0300L^E03oool0oooo
02D0oooo00<01biD0?ooo`3oool0B`3oool00`07;U@0oooo0?ooo`080?ooo`0500L^E03oool0oooo
0?ooo`07;U@06P3oool00`07;U@0oooo0?ooo`070?ooo`D01biDFP3oool500L^E1P0oooo00<01biD
0?ooo`3oool0>P3oool00`07;U@0oooo0?ooo`0T0?ooo`0300L^E03oool0oooo04L0oooo000D0?oo
o`0300L^E03oool0oooo02D0oooo00<01biD0?ooo`3oool0BP3oool00`07;U@0oooo0?ooo`090?oo
o`0500L^E03oool0oooo0?ooo`07;U@06P3oool200L^E6/0oooo0P07;U@G0?ooo`0300L^E03oool0
oooo03X0oooo0P07;U@U0?ooo`801biDA`3oool001D0oooo0P07;U@V0?ooo`801biDB`3oool00`07
;U@0oooo0?ooo`090?ooo`<01biD00<0oooo00L^E03oool06P3oool00`07;U@0oooo0?ooo`1Z0?oo
o`801biD5P3oool00`07;U@0oooo0?ooo`0k0?ooo`0300L^E03oool0oooo02@0oooo0P07;UA50?oo
o`005`3oool200L^E2H0oooo0`07;UA80?ooo`0300L^E03oool0oooo00/0oooo1007;U@K0?ooo`03
00L^E03oool0oooo06/0oooo00<01biD0?ooo`3oool04`3oool00`07;U@0oooo0?ooo`0l0?ooo`80
1biD9P3oool300L^E480oooo000I0?ooo`0300L^E03oool0oooo02H0oooo0P07;UA70?ooo`0300L^
E03oool0oooo00`0oooo0P07;U@L0?ooo`801biDK03oool00`07;U@0oooo0?ooo`0C0?ooo`0300L^
E03oool0oooo03d0oooo0P07;U@W0?ooo`801biD@03oool001X0oooo1007;U@V0?ooo`801biDAP3o
ool00`07;U@0oooo0?ooo`0;0?ooo`0300L^E03oool01biD01d0oooo0`07;UAZ0?ooo`801biD4`3o
ool00`07;U@0oooo0?ooo`0o0?ooo`@01biD9@3oool200L^E3h0oooo000N0?ooo`T01biD7`3oool2
00L^E4D0oooo00<01biD0?ooo`3oool02`3oool00`07;U@0oooo00L^E00O0?ooo`801biDJP3oool0
0`07;U@0oooo0?ooo`0@0?ooo`801biDA03oool800L^E1l0oooo0P07;U@l0?ooo`009`3oool900L^
E1P0oooo0P07;UA40?ooo`0300L^E03oool0oooo00/0oooo00<01biD0?ooo`07;U@0803oool00`07
;U@0oooo0?ooo`1X0?ooo`0300L^E03oool0oooo0100oooo00<01biD0?ooo`3oool0BP3oool:00L^
E1L0oooo0P07;U@j0?ooo`00<03oool500L^E1D0oooo0P07;UA30?ooo`801biD303oool01007;U@0
oooo00L^E007;U@O0?ooo`801biDJ@3oool00`07;U@0oooo0?ooo`0?0?ooo`0300L^E03oool0oooo
05@0oooo1@07;U@D0?ooo`801biD>03oool003D0oooo0`07;U@D0?ooo`0300L^E03oool0oooo0480
oooo0P07;U@:0?ooo`0500L^E03oool0oooo0?ooo`07;U@0803oool200L^E6L0oooo00<01biD0?oo
o`3oool03P3oool200L^E5/0oooo0P07;U@D0?ooo`0300L^E03oool0oooo03D0oooo000h0?ooo`80
1biD4`3oool200L^E4@0oooo0P07;U@90?ooo`0500L^E03oool0oooo0?ooo`07;U@08@3oool200L^
E6H0oooo00<01biD0?ooo`3oool0303oool200L^E5h0oooo0P07;U@C0?ooo`801biD=@3oool003X0
oooo0`07;U@A0?ooo`801biDA@3oool00`07;U@0oooo0?ooo`070?ooo`0500L^E03oool0oooo0?oo
o`07;U@08P3oool200L^E6D0oooo00<01biD0?ooo`3oool02P3oool200L^E640oooo0`07;U@A0?oo
o`801biD=03oool003d0oooo0P07;U@>0?ooo`801biDA`3oool200L^E0L0oooo00<01biD0?ooo`3o
ool00P3oool200L^E280oooo0P07;UAS0?ooo`0300L^E03oool0oooo00D0oooo1@07;UAV0?ooo`80
1biD3`3oool00`07;U@0oooo0?ooo`0c0?ooo`00?`3oool00`07;U@0oooo0?ooo`080?ooo`@01biD
BP3oool200L^E0H0oooo00<01biD0?ooo`3oool00`3oool00`07;U@0oooo0?ooo`0Q0?ooo`801biD
HP3oool700L^E6d0oooo00<01biD0?ooo`3oool0203oool500L^E3D0oooo00100?ooo`X01biDD03o
ool00`07;U@0oooo0?ooo`040?ooo`801biD103oool200L^E2<0oooo0P07;UAN0?ooo`@01biDL`3o
ool:00L^E3X0oooo000n0?ooo`D01biDF03oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0
oooo00@0oooo0P07;U@S0?ooo`0300L^E03oool0oooo05L0oooo1@07;U@20?ooo`H01biDK03oool5
00L^E440oooo000h0?ooo`H01biD1@3oool600L^E5<0oooo0P07;U@50?ooo`0300L^E03oool0oooo
00D0oooo0P07;U@R0?ooo`0300L^E03oool0oooo04D0oooo4@07;U@=0?oooa001biDEP3oool600L^
E0D0oooo1P07;U@k0?ooo`00:@3oool?00L^E140oooo3`07;UA50?ooo`0300L^E03oool0oooo00@0
oooo00<01biD0?ooo`3oool01P3ooolD00L^E0l0oooo00<01biD0?ooo`3oool0@@3oool300L^E2h0
oooo0`07;UA40?ooo`l01biD4@3oool?00L^E2`0oooo000V0?ooo`<01biD;`3oool300L^E4<0oooo
00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`0I0?ooo`<01biD303oool00`07;U@0oooo
0?ooo`110?ooo`801biD<@3oool00`07;U@0oooo0?ooo`0o0?ooo`<01biD;`3oool300L^E2T0oooo
000V0?ooo`0300L^E03oool0oooo0340oooo00<01biD0?ooo`3oool0@P3oool00`07;U@0oooo0?oo
o`040?ooo`0300L^E03oool0oooo01/0oooo0P07;U@:0?ooo`0300L^E03oool0oooo0480oooo0P07
;U@^0?ooo`801biD@P3oool200L^E380oooo00<01biD0?ooo`3oool09`3oool002L0oooo0P07;U@_
0?ooo`801biDAP3oool00`07;U@0oooo0?ooo`040?ooo`0300L^E03oool0oooo01`0oooo0P07;U@7
0?ooo`0300L^E03oool0oooo04D0oooo0P07;U@[0?ooo`0300L^E03oool0oooo04<0oooo0P07;U@_
0?ooo`801biD:P3oool002T0oooo0P07;U@[0?ooo`801biDB@3oool00`07;U@0oooo0?ooo`040?oo
o`0300L^E03oool0oooo01d0oooo00<01biD0?ooo`3oool0103oool00`07;U@0oooo0?ooo`170?oo
o`801biD6`3oool>00L^E4P0oooo0P07;U@[0?ooo`801biD;03oool002/0oooo0P07;U@J0?ooo`l0
1biDB`3oool00`07;U@0oooo0?ooo`040?ooo`801biD7`3oool200L^E080oooo0P07;UA<0?ooo`80
1biD503oool500L^E5P0oooo0P07;U@J0?ooo`l01biD;P3oool002d0oooo0P07;U@E0?ooo`<01biD
F`3oool200L^E0D0oooo00<01biD0?ooo`3oool07`3oool200L^E500oooo1007;U@=0?ooo`<01biD
G`3oool300L^E1@0oooo0`07;U@m0?ooo`00;`3oool400L^E0d0oooo1007;UAP0?ooo`H01biDM`3o
ool=00L^E6D0oooo1007;U@<0?ooo`@01biD@03oool003<0oooo3@07;UCo0?oooeP0oooo3007;UA4
0?ooo`00o`3ooooX0?ooo`00o`3ooooX0?ooo`00o`3ooooX0?ooo`00o`3ooooX0?ooo`00o`3ooooX
0?ooo`00o`3ooooX0?ooo`00o`3ooooX0?ooo`00o`3ooooX0?ooo`00o`3ooooX0?ooo`00o`3ooooX
0?ooo`00o`3ooooX0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 486}, {361.375, 0}} -> {-0.101772, -0.0744342, \
0.00864928, 0.00864928}, {{11.75, 119.313}, {352.75, 245.188}} -> {-1.13061, \
-1.0767, 0.0172531, 0.0172531}, {{130.063, 237.563}, {352.75, 245.188}} -> \
{-3.26411, -1.09084, 0.0177578, 0.0177578}, {{248.375, 355.875}, {352.75, \
245.188}} -> {-5.36508, -1.1082, 0.0177578, 0.0177578}, {{366.625, 474.188}, \
{352.75, 245.188}} -> {-7.46116, -1.10755, 0.0177475, 0.0177475}, {{11.75, \
119.313}, {234.438, 126.875}} -> {-1.13415, -3.15794, 0.0175003, 0.0175003}, \
{{130.063, 237.563}, {234.438, 126.875}} -> {-3.26411, -3.20917, 0.0177578, \
0.0177578}, {{248.375, 355.875}, {234.438, 126.875}} -> {-5.27769, -3.16447, \
0.0175105, 0.0175105}, {{366.625, 474.188}, {234.438, 126.875}} -> {-7.34457, \
-3.17529, 0.0175003, 0.0175003}, {{11.75, 119.313}, {116.125, 8.5625}} -> \
{-1.12345, -5.18837, 0.0174086, 0.0174086}, {{130.063, 237.563}, {116.125, \
8.5625}} -> {-3.20598, -5.23148, 0.0175105, 0.0175105}, {{248.375, 355.875}, \
{116.125, 8.5625}} -> {-5.36508, -5.29279, 0.0177578, 0.0177578}, {{366.625, \
474.188}, {116.125, 8.5625}} -> {-7.34457, -5.22047, 0.0175003, 0.0175003}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inflating and Deflating Brackets", "Subsection"],

Cell[TextData[{
  "Following the left-associative rule (that is, the convention that holds \
that redundant left-most brackets are to be omitted) in writing a bracketed \
expression we can substantially simplify its representation. Function ",
  StyleBox["deflate ",
    FontSlant->"Italic"],
  "computes this simplified form"
}], "Text"],

Cell[BoxData[{
    \(red[{}] := {}\), "\[IndentingNewLine]", 
    \(red[{"\<(\>", x__, "\<)\>", "\<(\>", y___, "\<)\>"}] := 
      Join[red[{x}], {"\<(\>"}, red[{y}], {"\<)\>"}]\  /; \ 
        SyntaxQ[StringJoin[{x}]]\), "\[IndentingNewLine]", 
    \(red[{"\<(\>", x__, "\<)\>", y___}] := 
      Join[red[{x}], {y}]\  /; \ 
        SyntaxQ[StringJoin[{x}]]\), "\[IndentingNewLine]", 
    \(red[{x__, "\<(\>", y__, "\<)\>"}] := 
      Join[{x, "\<(\>"}, red[{y}], {"\<)\>"}]\), "\n", 
    \(\(\(red[s_] := s\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(deflate[s_] := StringJoin[Flatten[red[Characters[s]]]]\)}], "Input",
  CellLabel->"In[214]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[\[IndentingNewLine]Print[n, "\<  \>", 
        deflate /@ \ 
          brackets[Take[CharacterRange["\<a\>", "\<z\>"], n]]], {n, 
        5}]\)], "Input",
  CellLabel->"In[277]:="],

Cell[BoxData[
    InterpretationBox[\(1\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 1, "  ", {}],
      Editable->False]], "Print",
  CellLabel->"From In[277]:="],

Cell[BoxData[
    InterpretationBox[\(2\[InvisibleSpace]"  "\[InvisibleSpace]{"ab"}\),
      SequenceForm[ 2, "  ", {"ab"}],
      Editable->False]], "Print",
  CellLabel->"From In[277]:="],

Cell[BoxData[
    InterpretationBox[\(3\[InvisibleSpace]"  "\[InvisibleSpace]{"abc", 
          "a(bc)"}\),
      SequenceForm[ 3, "  ", {"abc", "a(bc)"}],
      Editable->False]], "Print",
  CellLabel->"From In[277]:="],

Cell[BoxData[
    InterpretationBox[\(4\[InvisibleSpace]"  "\[InvisibleSpace]{"abcd", 
          "a(bc)d", "ab(cd)", "a(bcd)", "a(b(cd))"}\),
      SequenceForm[ 
      4, "  ", {"abcd", "a(bc)d", "ab(cd)", "a(bcd)", "a(b(cd))"}],
      Editable->False]], "Print",
  CellLabel->"From In[277]:="],

Cell[BoxData[
    InterpretationBox[\(5\[InvisibleSpace]"  "\[InvisibleSpace]{"abcde", 
          "a(bc)de", "ab(cd)e", "abc(de)", "a(bcd)e", "a(b(cd))e", 
          "a(bc)(de)", "ab(cde)", "ab(c(de))", "a(bcde)", "a(b(cd)e)", 
          "a(bc(de))", "a(b(cde))", "a(b(c(de)))"}\),
      SequenceForm[ 
      5, "  ", {"abcde", "a(bc)de", "ab(cd)e", "abc(de)", "a(bcd)e", 
        "a(b(cd))e", "a(bc)(de)", "ab(cde)", "ab(c(de))", "a(bcde)", 
        "a(b(cd)e)", "a(bc(de))", "a(b(cde))", "a(b(c(de)))"}],
      Editable->False]], "Print",
  CellLabel->"From In[277]:="]
}, Open  ]],

Cell[BoxData[{
    \(inf[{x___, "\<(\>", y__, "\<)\>"}] := {"\<(\>", inf[{x}], 
          inf[{y}], "\<)\>"}\  /; \ 
        SyntaxQ[StringJoin[{y}]]\), "\[IndentingNewLine]", 
    \(inf[{c__, x_}] := {"\<(\>", inf[{c}], 
        x <> "\<)\>"}\), "\[IndentingNewLine]", 
    \(inf[{a_, b_, c_}] := {"\<((\>" <> a <> b <> "\<)\>" <> 
          c <> "\<)\>"}\), "\[IndentingNewLine]", 
    \(\(\(inf[s_] := s\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(inflate[s_] := StringJoin[Flatten[inf[Characters[s]]]]\)}], "Input",
  CellLabel->"In[220]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(inflate["\<abcd\>"]\)], "Input",
  CellLabel->"In[278]:="],

Cell[BoxData[
    \("(((ab)c)d)"\)], "Output",
  CellLabel->"Out[278]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Behaviours", "Section"],

Cell[TextData[{
  "Those values of x such that f(x) = x are called ",
  StyleBox["fixed points",
    FontSlant->"Italic"],
  " of f. For instance, f(x) = 2x-1 has a unique fixed point at x = 1. In \
general, fixed points of real functions are intersections with the straight \
line of slope 1 passing through the origin. Consider the following question: \
for what f it is true that f(f(x)) = x?. One answer is f being the identity, \
that is f(x) = x. Another one is f(x) = -x or, more generally, f(x) = -x+b \
for any b; can you think of a third answer? f(x) = 1/x. Some functions have \
no fixed points, or at least not within the normal rules. For instance, f(x) \
= ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "+1 has no real fixed points but two complex fixed points. Fixed points \
play an important part in combinatory logic. We say that bird B is a fixed \
point of bird A if AB = B (or, as Smullyan says, A is ",
  StyleBox["fond of",
    FontSlant->"Italic"],
  "  B). Within this formalism, all functions (birds) have a fixed point. We \
can even give a constructive proof! Let us assume that Smullyan axioms hold, \
i. e., 1) Given birds A and B, there exist a bird C such that Cx = A(Bx) for \
all x (composition condition) and 2)  There is a Mockingbird in the forrest."
}], "Text"],

Cell["\<\
Theorem. Given a bird A, there exist another B such that AB = B
Proof. Let H the composition of A and M, that is, such that Hx = A(Mx). Then, \
taking x=H we have that HH = A(MH), as MH = HH, this implies that HH = A(HH), \
hence B = HH.  \[Square]\
\>", "Text"],

Cell[TextData[{
  "What about other kind of \"fixed points\"? For instance, f(f(x)) = f(x)?. \
f(x) = x is a solution and another one is f(x) = b for any b, a constant \
function. What about an f such that f(f(x)) =",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(x\^2\)\)\)]],
  "? The answer will be given at the end of this notebook. \n\nThe behaviour \
of a bird is its response to a chain of arguments. This chain has to be of \
the smallest size needed to completely satisfy the bird, that is, such that \
its response does not include other birds except for the arguments given. In \
other words, a bird is given as a string of upper-case letters and its \
behaviour will be a string of lower-case letters. For instance, as Mx = xx, \
the response of the Mockingbird is xx. In general, the response of a given \
bird will depend of the responses of the birds forming its genealogy. The \
contribution of each bird is considered in function ",
  StyleBox["beh",
    FontSlant->"Italic"],
  " below. We have included several prominent members of the forrest, namely, \
M, I, B, T, S, K and V. Their common names and definitions are:"
}], "Text"],

Cell["\<\
Mockingbird\t\t\tMx = xx
Identity bird\t\t\tIx = x
Bluebird\t\t\tBxy = x(yz)
Thrush\t\t\t\tTxy = yx
Starling\t\t\tSxyz = xz(yz)
Kestrel\t\t\t\tKxy = x
Vireo\t\t\t\tVxyz = zxy
\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Birds have fascinating properties; for instance, SII(SII) is a \
self-generating program. The following function obtains the behaviour of any \
bird descending from the above birds.\
\>", "Text"],

Cell[BoxData[{
    \(beh[{a___, "\<(\>", "\<M\>", x__, "\<)\>", b___}] := {a, "\<(\>", x, 
          x, "\<)\>", b}\  /; \ 
        SyntaxQ[StringJoin[{x}]]\), "\[IndentingNewLine]", 
    \(beh[{a___, "\<(\>", "\<I\>", x__, "\<)\>", b___}] := {a, x, b}\  /; \ 
        SyntaxQ[StringJoin[{x}]]\), "\[IndentingNewLine]", 
    \(beh[{a___, "\<(\>", "\<(\>", "\<(\>", "\<B\>", x__, "\<)\>", 
          y__, "\<)\>", z__, "\<)\>", b___}] := {a, "\<(\>", x, "\<(\>", y, 
          z, "\<)\>", "\<)\>", b}\  /; \ 
        SyntaxQ[StringJoin[{x}]] && SyntaxQ[StringJoin[{y}]] && 
          SyntaxQ[StringJoin[{z}]]\), "\[IndentingNewLine]", 
    \(beh[{a___, "\<(\>", "\<(\>", "\<T\>", x__, "\<)\>", y__, "\<)\>", 
          b___}] := {a, "\<(\>", y, x, "\<)\>", b}\  /; \ 
        SyntaxQ[StringJoin[{x}]] && 
          SyntaxQ[StringJoin[{y}]]\), "\[IndentingNewLine]", 
    \(beh[{a___, "\<(\>", "\<(\>", "\<(\>", "\<S\>", x__, "\<)\>", 
          y__, "\<)\>", z__, "\<)\>", b___}] := {a, "\<(\>", "\<(\>", x, 
          z, "\<)\>", "\<(\>", y, z, "\<)\>", "\<)\>", b}\  /; \ 
        SyntaxQ[StringJoin[{x}]] && SyntaxQ[StringJoin[{y}]] && 
          SyntaxQ[StringJoin[{z}]]\), "\[IndentingNewLine]", 
    \(beh[{a___, "\<(\>", "\<(\>", "\<K\>", x__, "\<)\>", y__, "\<)\>", 
          b___}] := {a, x, b}\  /; \ 
        SyntaxQ[StringJoin[{x}]] && 
          SyntaxQ[StringJoin[{y}]]\), "\[IndentingNewLine]", 
    \(beh[{a___, "\<(\>", "\<(\>", "\<(\>", "\<V\>", x__, "\<)\>", 
          y__, "\<)\>", z__, "\<)\>", b___}] := {a, "\<(\>", "\<(\>", z, 
          x, "\<)\>", y, "\<)\>", b}\  /; \ 
        SyntaxQ[StringJoin[{x}]] && SyntaxQ[StringJoin[{y}]] && 
          SyntaxQ[StringJoin[{z}]]\), "\[IndentingNewLine]", 
    \(\(\(beh[x_] := x\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(behaviour[s_] := 
      deflate[StringJoin[
          FixedPoint[beh, Characters[inflate[s]]]]]\)}], "Input",
  CellLabel->"In[225]:=",
  InitializationCell->True],

Cell["\<\
For instance, the behaviour of the bird B(B(T(BBT))B)T is x(zy), obtained \
through the following sequence of transformations\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(s = "\<B(B(T(BBT))B)Txyz\>";\)\), "\[IndentingNewLine]", 
    \(\(deflate[StringJoin[#]] &\) /@ 
        FixedPointList[beh, Characters[inflate[s]]] // TableForm\)}], "Input",\

  CellLabel->"In[279]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"B(B(T(BBT))B)Txyz\"\>"},
          {"\<\"B(T(BBT))B(Tx)yz\"\>"},
          {"\<\"T(BBT)(B(Tx))yz\"\>"},
          {"\<\"B(Tx)(BBT)yz\"\>"},
          {"\<\"Tx(BBTy)z\"\>"},
          {"\<\"Tx(B(Ty))z\"\>"},
          {"\<\"B(Ty)xz\"\>"},
          {"\<\"Ty(xz)\"\>"},
          {"\<\"xzy\"\>"},
          {"\<\"xzy\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {"B(B(T(BBT))B)Txyz", "B(T(BBT))B(Tx)yz", "T(BBT)(B(Tx))yz", 
        "B(Tx)(BBT)yz", "Tx(BBTy)z", "Tx(B(Ty))z", "B(Ty)xz", "Ty(xz)", "xzy",
         "xzy"}]]], "Output",
  CellLabel->"Out[280]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(behaviour["\<B(B(T(BBT))B)Txyz\>"]\)], "Input",
  CellLabel->"In[281]:="],

Cell[BoxData[
    \("xzy"\)], "Output",
  CellLabel->"Out[281]="]
}, Open  ]],

Cell["\<\
Not all birds behave (f. i., M(B(SI)M)). Different birds can have the same \
behaviour. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(behaviour\  /@ \ {"\<MIx\>", "\<M(MI)x\>", "\<MI(MI)x\>", "\<M(MI)(MI)x\
\>"}\)], "Input",
  CellLabel->"In[282]:="],

Cell[BoxData[
    \({"x", "x", "x", "x"}\)], "Output",
  CellLabel->"Out[282]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(behaviour\  /@ \ {"\<Bxyz\>", "\<BBxyzw\>", "\<B(BB)xyzwv\>", \
"\<BBBxyzw\>", "\<B(BB)Bxyzw\>", "\<B(BBB)xyzwv\>", "\<B(BBB)Bxyzwv\>"}\)], \
"Input",
  CellLabel->"In[283]:="],

Cell[BoxData[
    \({"x(yz)", "xy(zw)", "xyz(wv)", "x(yzw)", "x(y(zw))", "xy(zwv)", 
      "x(yzwv)"}\)], "Output",
  CellLabel->"Out[283]="]
}, Open  ]],

Cell["\<\
For some birds, although their responses converge, they have no behaviour\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(behaviour["\<Ma(M(bcM)x)\>"]\)], "Input",
  CellLabel->"In[155]:="],

Cell[BoxData[
    \("aa(bcM(bcM)x)"\)], "Output",
  CellLabel->"Out[155]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(behaviour["\<TMx(M(yzM)w)\>"]\)], "Input",
  CellLabel->"In[156]:="],

Cell[BoxData[
    \("xM(yzM(yzM)w)"\)], "Output",
  CellLabel->"Out[156]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(behaviour["\<IMIIx(M(Iyz))\>"]\)], "Input",
  CellLabel->"In[157]:="],

Cell[BoxData[
    \("x(yz(yz))"\)], "Output",
  CellLabel->"Out[157]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(behaviour["\<MTIx(MTI)y\>"]\)], "Input",
  CellLabel->"In[158]:="],

Cell[BoxData[
    \("yx"\)], "Output",
  CellLabel->"Out[158]="]
}, Open  ]],

Cell["These species are interesting:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(behaviour\  /@ \ {"\<MTx\>", "\<MTMx\>", "\<MTMTx\>", "\<MTMTMx\>"}\)], \
"Input",
  CellLabel->"In[284]:="],

Cell[BoxData[
    \({"xT", "xT", "xT", "xT"}\)], "Output",
  CellLabel->"Out[284]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(behaviour\  /@ \ {"\<MTIx\>", "\<MTIMx\>", "\<MTIMTIx\>", \
"\<MTIMTIMx\>"}\)], "Input",
  CellLabel->"In[285]:="],

Cell[BoxData[
    \({"Tx", "xM", "xx", "MMx"}\)], "Output",
  CellLabel->"Out[285]="]
}, Open  ]],

Cell["Note the last one cannot be further reduced.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(behaviour\  /@ \ {"\<SIIx\>", "\<SKKx\>", "\<S(KS)Kxyz\>", \
"\<S(K(SI))Kxy\>", "\<S(K(SI))(S(KK)I)xy\>"}\)], "Input",
  CellLabel->"In[286]:="],

Cell[BoxData[
    \({"xx", "x", "x(yz)", "yx", "yx"}\)], "Output",
  CellLabel->"Out[286]="]
}, Open  ]],

Cell[TextData[{
  "Note T has several genealogies in term of K, S and I.\n\nFor birds that \
behave, we would like to know the number of arguments we have to give to them \
in order to find it. This number is called their ",
  StyleBox["lineage",
    FontSlant->"Italic"],
  ". As some have no lineage, function ",
  StyleBox["deg",
    FontSlant->"Italic"],
  " below contains a safety net to compute it."
}], "Text"],

Cell[BoxData[
    \(lineage[bird_, depth_:  10] := 
      Module[{i = 1, b = bird, 
          r = CharacterRange["\<a\>", "\<z\>"]}, \
\[IndentingNewLine]While[\((i \[LessEqual] 
                depth)\) && \((Select[Characters[b], 
                  UpperCaseQ] \[NotEqual] {})\), \[IndentingNewLine]b = 
            b <> r\[LeftDoubleBracket]
                i\[RightDoubleBracket]; \[IndentingNewLine]\(i++\); \ \
\[IndentingNewLine]b = behaviour[b]]; \[IndentingNewLine]If[
          Select[Characters[b], UpperCaseQ] \[Equal] {}, 
          i - 1, "\<No lineage found\>"]]\)], "Input",
  CellLabel->"In[234]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(lineage["\<B(B(TB)B)T\>"]\)], "Input",
  CellLabel->"In[287]:="],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[287]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lineage["\<BT(BT)\>"]\)], "Input",
  CellLabel->"In[288]:="],

Cell[BoxData[
    \("No lineage found"\)], "Output",
  CellLabel->"Out[288]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Genealogies", "Section"],

Cell[CellGroupData[{

Cell["The Forrest of Compositor Birds", "Subsection"],

Cell[TextData[{
  "The Bluebird B has the property that it does not changes the order of its \
arguments. All such birds are called ",
  StyleBox["compositors",
    FontSlant->"Italic"],
  " and all of them descend from B, that is, they have a genealogy in terms \
of B only. Function ",
  StyleBox["h",
    FontSlant->"Italic"],
  " cuts down the freed variables."
}], "Text"],

Cell[BoxData[{
    \(\(\(Clear[h, ruleB]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(ruleB[{"\<(\>", x__, "\<(\>", y__, 
          z__, "\<)\>", "\<)\>"}] := {"\<(\>", "\<(\>", "\<(\>", "\<B\>", 
          x, "\<)\>", y, "\<)\>", z, "\<)\>"}\  /; \ 
        SyntaxQ[StringJoin[{x}]] && SyntaxQ[StringJoin[{y}]] && 
          SyntaxQ[StringJoin[{z}]]\), "\[IndentingNewLine]", 
    \(\(\(ruleB[x_] := x\)\(\[IndentingNewLine]\)
    \)\ \), "\[IndentingNewLine]", 
    \(h[{a___, A_, b__}] := {a, A}\  /; \ 
        Not[LowerCaseQ[A]] && 
          LowerCaseQ[StringJoin[{b}]]\), "\[IndentingNewLine]", 
    \(\(\(h[x_] := x\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(genealogyB[bird_] := 
      Module[{s = bird}, \[IndentingNewLine]While[
          Characters[s] \[Intersection] 
              CharacterRange["\<a\>", "\<z\>"] \[NotEqual] {}, \
\[IndentingNewLine]s = 
            StringJoin[
              h[Characters[
                  deflate[
                    StringJoin[
                      ruleB[Characters[
                          inflate[
                            s]]]]]]]]]; \[IndentingNewLine]s]\)}], "Input",
  CellLabel->"In[235]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(genealogyB["\<x(yz)wv\>"]\)], "Input",
  CellLabel->"In[289]:="],

Cell[BoxData[
    \("B"\)], "Output",
  CellLabel->"Out[289]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(genealogyB\  /@ \ {"\<xy(zw)\>", "\<xyz(wv)\>", "\<x(yzw)\>", \
"\<x(y(zw))\>", "\<xy(zwv)\>", "\<x(yzwv)\>", "\<x(yz)(wv)\>", "\<x(yzw)(abc)\
\>"}\), "\[IndentingNewLine]", 
    \(lineage /@ \ %\)}], "Input",
  CellLabel->"In[290]:="],

Cell[BoxData[
    \({"BB", "B(BB)", "BBB", "B(BB)B", "B(BBB)", "B(BBB)B", "BB(BB)", 
      "B(BBB)(B(BBB))"}\)], "Output",
  CellLabel->"Out[290]="],

Cell[BoxData[
    \({4, 5, 4, 4, 5, 5, 5, 7}\)], "Output",
  CellLabel->"Out[291]="]
}, Open  ]],

Cell["Several theorems can be verified, some examples follow:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Theorem", ":", 
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox[\(x\_1\),
                "TraditionalForm"], 
              FormBox[\(x\_2\),
                "TraditionalForm"]}], "..."}], 
          RowBox[{"(", 
            RowBox[{
              FormBox[\(x\_\(n - 1\)\),
                "TraditionalForm"], 
              FormBox[\(x\_n\),
                "TraditionalForm"]}], ")"}]}]}], 
      "=", \(B \((B \((\(\(...\) \((BB)\)\) .. )\))\)\ \ \ \ \ \ \ \((n - 
            2)\)\ B\.b4s\)}]], "DisplayFormula"],

Cell[CellGroupData[{

Cell[BoxData[
    \(genealogyB\  /@ \ {"\<x(yz)\>", "\<xy(zw)\>", "\<xyz(wv)\>", \
"\<xyzw(va)\>", "\<xyzwv(ab)\>", "\<xyzwva(bc)\>"}\)], "Input",
  CellLabel->"In[292]:="],

Cell[BoxData[
    \({"B", "BB", "B(BB)", "B(B(BB))", "B(B(B(BB)))", 
      "B(B(B(B(BB))))"}\)], "Output",
  CellLabel->"Out[292]="]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Theorem", ":", 
        RowBox[{
          FormBox[\(x\_1\),
            "TraditionalForm"], 
          RowBox[{"(", 
            RowBox[{\(x\_2 ... \), \(x\_\(n - 1\)\), 
              FormBox[\(x\_n\),
                "TraditionalForm"]}], ")"}]}]}], 
      "=", \(B \((B \((\(\(\(...\) \((B \((BBB)\) B)\)\) .. \) B)\) 
            B)\)\ \ \ \ \ \ \ \ \ \((2  n - 
            5)\)\ \ B\.b4s\)}]], "DisplayFormula"],

Cell[CellGroupData[{

Cell[BoxData[
    \(genealogyB\  /@ \ {"\<x(yz)\>", "\<x(yzw)\>", "\<x(yzwv)\>", \
"\<x(yzwva)\>", "\<x(yzwvab)\>", "\<x(yzwvabc)\>"}\)], "Input",
  CellLabel->"In[293]:="],

Cell[BoxData[
    \({"B", "BBB", "B(BBB)B", "B(B(BBB)B)B", "B(B(B(BBB)B)B)B", 
      "B(B(B(B(BBB)B)B)B)B"}\)], "Output",
  CellLabel->"Out[293]="]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"Theorem", ":", 
              RowBox[{
                FormBox[\(x\_1\),
                  "TraditionalForm"], 
                RowBox[{"(", 
                  RowBox[{\(x\_2\), \((\(...\) \(x\_\(n - 1\)\))\), 
                    FormBox[\(x\_n\),
                      "TraditionalForm"]}], ")"}]}]}], 
            "=", \(\(B \((B \((\(...\) \((B \((B \((BB)\) 
                                  B)\))\) \(B\))\))\) .. \) B\)}], ")"}], 
        ")"}], "B", "       ", \((3  n - 8)\), "  ", 
      "B\.b4s"}]], "DisplayFormula"],

Cell[CellGroupData[{

Cell[BoxData[
    \(genealogyB\  /@ \ {"\<x(yz)\>", "\<x(y(zw))\>", "\<x(y(z(wv)))\>", \
"\<x(y(z(w(va))))\>", "\<x(y(z(w(v(ab)))))\>"}\)], "Input",
  CellLabel->"In[294]:="],

Cell[BoxData[
    \({"B", "B(BB)B", "B(B(B(BB)B))B", "B(B(B(B(B(BB)B))B))B", 
      "B(B(B(B(B(B(B(BB)B))B))B))B"}\)], "Output",
  CellLabel->"Out[294]="]
}, Open  ]],

Cell["Note all of the above end with a bracket", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(deflate\  /@ 
      brackets[CharacterRange["\<a\>", "\<e\>"]]\), "\[IndentingNewLine]", 
    \(genealogyB\  /@ \ Rest[%]\)}], "Input",
  CellLabel->"In[295]:="],

Cell[BoxData[
    \({"abcde", "a(bc)de", "ab(cd)e", "abc(de)", "a(bcd)e", "a(b(cd))e", 
      "a(bc)(de)", "ab(cde)", "ab(c(de))", "a(bcde)", "a(b(cd)e)", 
      "a(bc(de))", "a(b(cde))", "a(b(c(de)))"}\)], "Output",
  CellLabel->"Out[295]="],

Cell[BoxData[
    \({"B", "BB", "B(BB)", "BBB", "B(BB)B", "BB(BB)", "B(BBB)", "B(B(BB)B)", 
      "B(BBB)B", "B(B(BB)B)B", "B(BB(BB))B", "B(B(BBB))B", 
      "B(B(B(BB)B))B"}\)], "Output",
  CellLabel->"Out[296]="]
}, Open  ]],

Cell["\<\
We took the Rest in the above because the first of their genealogies is I. We \
should really choose those that end in a bracket as those that do not are \
genealogically redundant, that is, their lineage is the same for all of them.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lineage\  /@ \ %\)], "Input",
  CellLabel->"In[297]:="],

Cell[BoxData[
    \({3, 4, 5, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5}\)], "Output",
  CellLabel->"Out[297]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(deflate\  /@ 
        brackets[
          CharacterRange["\<a\>", "\<e\>"]];\)\), "\[IndentingNewLine]", 
    \(genealogyB\  /@ \ 
      Select[Rest[%], \((StringTake[#, \(-1\)] \[Equal] "\<)\>")\) &]\)}], \
"Input",
  CellLabel->"In[298]:="],

Cell[BoxData[
    \({"B(BB)", "BB(BB)", "B(BBB)", "B(B(BB)B)", "B(BBB)B", "B(B(BB)B)B", 
      "B(BB(BB))B", "B(B(BBB))B", "B(B(B(BB)B))B"}\)], "Output",
  CellLabel->"Out[299]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Drawing Footprints", "Subsection"],

Cell["\<\
Using the allegory of turtle graphics, we provide compositor birds with a \
graphical depictions. B means a (drawing) forward movement and \
opening/closing brackets mean left/right turns.\
\>", "Text"],

Cell[BoxData[
    RowBox[{\(showB[s_]\), ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({p = {{0, 0}}, x = {0, 0}, d = {1, 0}}\), ",", 
          RowBox[{
            RowBox[{"Map", "[", 
              RowBox[{
                RowBox[{
                  RowBox[{"If", "[", 
                    
                    RowBox[{\(# \[Equal] "\<B\>"\), 
                      ",", \(AppendTo[p, x = x + d]\), ",", 
                      RowBox[{"If", "[", 
                        RowBox[{\(# \[Equal] "\<(\>"\), ",", 
                          RowBox[{"d", "=", 
                            RowBox[{
                              RowBox[{"(", GridBox[{
                                    {"0", \(-1\)},
                                    {"1", "0"}
                                    }], ")"}], ".", "d"}]}], ",", 
                          RowBox[{"d", "=", 
                            RowBox[{
                              RowBox[{"(", GridBox[{
                                    {"0", "1"},
                                    {\(-1\), "0"}
                                    }], ")"}], ".", "d"}]}]}], "]"}]}], "]"}],
                   "&"}], ",", \(Characters[s]\)}], "]"}], ";", 
            "\[IndentingNewLine]", \(Graphics[Line[p], 
              DisplayFunction \[Rule] Identity]\)}]}], "]"}]}]], "Input",
  CellLabel->"In[241]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
Show[showB[\"B(B(B(BBB)B))B\"],DisplayFunction\[Rule]$DisplayFunction];\
\>", "Input",
  CellLabel->"In[300]:=",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.988095 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .9881 m
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.5 .5119 L
.5 .03571 L
.02381 .03571 L
.5 .03571 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[300]:=",
  ImageSize->{192, 288},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400030000182000`400?l00000o`00003o`03oool0
0<00oooo00300?ooo`00`03oool00<00oooo00300?ooo`00`03oool00<00oooo00040?oooe`00000
H03oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool0
05l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo
00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<00000
0?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3o
ool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3o
ool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0
oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<0
00000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?oo
o`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0
GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool0
05l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo
00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<00000
0?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3o
ool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3o
ool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0
oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<0
00000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?oo
o`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0
GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool0
05l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo
00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<00000
0?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3o
ool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3o
ool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0
oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<0
00000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?oo
o`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0
GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool0
05l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo
00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<00000
0?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3o
ool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3o
ool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0
oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<0
00000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?oo
o`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0
GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool0
05l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo
00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<00000
0?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3o
ool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3o
ool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0
oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<0
00000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?oo
o`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0
GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool0
05l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo
00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<00000
0?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3o
ool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3o
ool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0
oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<0
00000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?oo
o`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0
GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool0
05l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo
00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<00000
0?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3o
ool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3o
ool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0
oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<0
00000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?oo
o`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0
GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool0
05l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo
00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<00000
0?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3o
ool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3o
ool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0
oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<0
00000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?oo
o`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0
GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool0
05l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo
00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<00000
0?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3o
ool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3o
ool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0
oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<0
00000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?oo
o`3oool0GP3oool005l0oooo00<000000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0
GP3oool005l0ooooG00000050?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool005l0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool00`3oool005l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`03
0?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool005l0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool0
05l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool00`3oool005l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool005l0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3o
ool005l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool00`3oool005l0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool005l0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
0`3oool005l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`00G`3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool00`3oool005l0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo
001O0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool005l0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool00`3oool005l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`00G`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool00`3oool005l0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0
oooo001O0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool005l0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool00`3oool005l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`00
G`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool00`3oool005l0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
00<0oooo001O0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool005l0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool00`3oool005l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`030?oo
o`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool005l0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool005l0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool00`3oool005l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`03
0?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool005l0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool0
05l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool00`3oool005l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool005l0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3o
ool005l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool00`3oool005l0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo001O
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool005l0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`030?ooo`00G`3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
0`3oool005l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`00G`3ooomL
000000D0oooo00300?ooo`00`03oool00<00oooo00300?ooo`00`03oool00<00oooo00300?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 191}, {287, 0}} -> {-1.05001, -2.07777, 0.0109949, \
0.0109949}}]
}, Open  ]],

Cell["\<\
There should be eight segments (one for each B) but only seven are apparent \
because the last two overlap.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(deflate\  /@ brackets[CharacterRange["\<a\>", "\<h\>"]];\)\), "\n", 
    \(g = 
      genealogyB\  /@ \ 
        Select[Rest[%], \((StringTake[#, \(-1\)] \[Equal] "\<)\>")\) &]; 
    Show[GraphicsArray[Partition[showB\  /@ g, 11]]];\)}], "Input",
  CellLabel->"In[301]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.23333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0865801 0.0293651 0.0865801 [
[ 0 0 0 0 ]
[ 1 1.23333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.23333 L
0 1.23333 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0293651 0.103175 0.0690476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.190476 0.0047619 0.190476 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.78571 .00476 m
.97619 .00476 L
.97619 .19524 L
.78571 .19524 L
.78571 .00476 L
.97619 .00476 L
.97619 .19524 L
.78571 .19524 L
.59524 .19524 L
.40476 .19524 L
.21429 .19524 L
.02381 .19524 L
.21429 .19524 L
.02381 .19524 L
.21429 .19524 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.0293651 0.190476 0.0690476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 1.97619 0.952381 [
[ 0 0 0 0 ]
[ 1 3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.97619 m
.97619 1.97619 L
.97619 2.92857 L
.02381 2.92857 L
.02381 1.97619 L
.97619 1.97619 L
.97619 2.92857 L
.02381 2.92857 L
.02381 1.97619 L
.02381 1.02381 L
.02381 .07143 L
.02381 1.02381 L
.97619 1.02381 L
.02381 1.02381 L
.97619 1.02381 L
s
0 0 m
1 0 L
1 3 L
0 3 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.0293651 0.277778 0.0690476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .33333 m
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.65873 .33333 L
.65873 .01587 L
.65873 .33333 L
.97619 .33333 L
.65873 .33333 L
.97619 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.0293651 0.365079 0.0690476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.25 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .25 m
.97619 .25 L
.97619 .4881 L
.7381 .4881 L
.7381 .25 L
.97619 .25 L
.97619 .4881 L
.7381 .4881 L
.7381 .25 L
.7381 .0119 L
.5 .0119 L
.2619 .0119 L
.02381 .0119 L
.2619 .0119 L
.02381 .0119 L
.2619 .0119 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.0293651 0.452381 0.0690476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 1.02381 0.952381 [
[ 0 0 0 0 ]
[ 1 3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.02381 m
.97619 1.02381 L
.97619 1.97619 L
.02381 1.97619 L
.02381 1.02381 L
.97619 1.02381 L
.97619 1.97619 L
.97619 2.92857 L
.02381 2.92857 L
.02381 1.97619 L
.02381 1.02381 L
.02381 .07143 L
.97619 .07143 L
.02381 .07143 L
.97619 .07143 L
s
0 0 m
1 0 L
1 3 L
0 3 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.0293651 0.539683 0.0690476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01587 m
.34127 .01587 L
.34127 .33333 L
.02381 .33333 L
.02381 .01587 L
.34127 .01587 L
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.65873 .33333 L
.65873 .01587 L
.97619 .01587 L
.65873 .01587 L
.97619 .01587 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.0293651 0.626984 0.0690476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.988095 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .9881 m
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.5 .5119 L
.5 .03571 L
.02381 .03571 L
.5 .03571 L
.02381 .03571 L
.5 .03571 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.0293651 0.714286 0.0690476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5 m
.5 .5 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.5 .5 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.5 .5 L
.97619 .5 L
.97619 .02381 L
.5 .02381 L
.97619 .02381 L
.5 .02381 L
.97619 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.0293651 0.801587 0.0690476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5 m
.5 .5 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.5 .5 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.97619 .02381 L
.5 .02381 L
.97619 .02381 L
.5 .02381 L
.97619 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.0293651 0.888889 0.0690476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00793651 0.31746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00794 m
.34127 .00794 L
.34127 .3254 L
.02381 .3254 L
.02381 .00794 L
.34127 .00794 L
.34127 .3254 L
.02381 .3254 L
.02381 .00794 L
.34127 .00794 L
.65873 .00794 L
.97619 .00794 L
.65873 .00794 L
.97619 .00794 L
.65873 .00794 L
.97619 .00794 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.0293651 0.97619 0.0690476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.5 .5 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.5 .5 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.5 .5 L
.5 .97619 L
.97619 .97619 L
.5 .97619 L
.97619 .97619 L
.5 .97619 L
.97619 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.0730159 0.103175 0.112698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .33333 m
.65873 .33333 L
.65873 .65079 L
.34127 .65079 L
.34127 .33333 L
.65873 .33333 L
.65873 .65079 L
.34127 .65079 L
.34127 .33333 L
.34127 .01587 L
.02381 .01587 L
.34127 .01587 L
.65873 .01587 L
.97619 .01587 L
.65873 .01587 L
.97619 .01587 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.0730159 0.190476 0.112698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0396825 0.31746 [
[ 0 0 0 0 ]
[ 1 1.66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .03968 m
.34127 .03968 L
.34127 .35714 L
.02381 .35714 L
.02381 .03968 L
.34127 .03968 L
.34127 .35714 L
.34127 .6746 L
.65873 .6746 L
.97619 .6746 L
.97619 .99206 L
.97619 1.30952 L
.97619 1.62698 L
.65873 1.62698 L
.97619 1.62698 L
s
0 0 m
1 0 L
1 1.66667 L
0 1.66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.0730159 0.277778 0.112698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.031746 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .03175 m
.34127 .03175 L
.34127 .34921 L
.02381 .34921 L
.02381 .03175 L
.34127 .03175 L
.34127 .34921 L
.34127 .66667 L
.65873 .66667 L
.97619 .66667 L
.97619 .98413 L
.65873 .98413 L
.34127 .98413 L
.34127 1.30159 L
.02381 1.30159 L
.34127 1.30159 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.0730159 0.365079 0.112698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.25 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .25 m
.97619 .25 L
.97619 .4881 L
.7381 .4881 L
.7381 .25 L
.7381 .0119 L
.97619 .0119 L
.97619 .25 L
.7381 .25 L
.5 .25 L
.2619 .25 L
.2619 .4881 L
.02381 .4881 L
.2619 .4881 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.0730159 0.452381 0.112698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.65873 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .65873 m
.97619 .65873 L
.97619 .97619 L
.65873 .97619 L
.65873 .65873 L
.65873 .34127 L
.97619 .34127 L
.97619 .65873 L
.65873 .65873 L
.65873 .34127 L
.65873 .02381 L
.34127 .02381 L
.34127 .34127 L
.02381 .34127 L
.34127 .34127 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.0730159 0.539683 0.112698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.65873 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .65873 m
.97619 .65873 L
.97619 .97619 L
.65873 .97619 L
.65873 .65873 L
.65873 .34127 L
.97619 .34127 L
.97619 .65873 L
.65873 .65873 L
.34127 .65873 L
.34127 .34127 L
.34127 .02381 L
.34127 .34127 L
.02381 .34127 L
.34127 .34127 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.0730159 0.626984 0.112698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 1.47619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 1.47619 m
.97619 1.47619 L
.97619 1.95238 L
.5 1.95238 L
.5 1.47619 L
.5 1 L
.97619 1 L
.97619 1.47619 L
.5 1.47619 L
.5 1 L
.5 .52381 L
.5 .04762 L
.5 .52381 L
.02381 .52381 L
.5 .52381 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.0730159 0.714286 0.112698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.988095 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .9881 m
.5 .9881 L
.5 1.46429 L
.02381 1.46429 L
.02381 .9881 L
.02381 .5119 L
.5 .5119 L
.5 .9881 L
.02381 .9881 L
.02381 .5119 L
.5 .5119 L
.97619 .5119 L
.97619 .03571 L
.97619 .5119 L
.5 .5119 L
.97619 .5119 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.0730159 0.801587 0.112698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .01587 m
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.34127 .33333 L
.02381 .33333 L
.02381 .65079 L
.34127 .65079 L
.02381 .65079 L
.34127 .65079 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.0730159 0.888889 0.112698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .5 m
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.5 .02381 L
.02381 .02381 L
.02381 .5 L
.5 .5 L
.02381 .5 L
.5 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.0730159 0.97619 0.112698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .5 m
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.02381 .02381 L
.02381 .5 L
.5 .5 L
.02381 .5 L
.5 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.116667 0.103175 0.156349 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.00595238 0.238095 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .00595 m
.7381 .00595 L
.7381 .24405 L
.5 .24405 L
.5 .00595 L
.7381 .00595 L
.97619 .00595 L
.97619 .24405 L
.7381 .24405 L
.5 .24405 L
.2619 .24405 L
.2619 .00595 L
.02381 .00595 L
.2619 .00595 L
s
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.116667 0.190476 0.156349 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.65873 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .65873 m
.65873 .65873 L
.65873 .97619 L
.34127 .97619 L
.34127 .65873 L
.65873 .65873 L
.97619 .65873 L
.97619 .97619 L
.65873 .97619 L
.65873 .65873 L
.65873 .34127 L
.34127 .34127 L
.34127 .02381 L
.02381 .02381 L
.34127 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.116667 0.277778 0.156349 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .01587 m
.65873 .01587 L
.65873 .33333 L
.34127 .33333 L
.34127 .01587 L
.65873 .01587 L
.65873 .33333 L
.65873 .65079 L
.34127 .65079 L
.02381 .65079 L
.34127 .65079 L
.65873 .65079 L
.97619 .65079 L
.65873 .65079 L
.97619 .65079 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.116667 0.365079 0.156349 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0178571 0.238095 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01786 m
.2619 .01786 L
.2619 .25595 L
.02381 .25595 L
.02381 .01786 L
.2619 .01786 L
.5 .01786 L
.7381 .01786 L
.97619 .01786 L
.97619 .25595 L
.97619 .49405 L
.97619 .73214 L
.7381 .73214 L
.97619 .73214 L
s
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.116667 0.452381 0.156349 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0119048 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .0119 m
.2619 .0119 L
.2619 .25 L
.02381 .25 L
.02381 .0119 L
.2619 .0119 L
.5 .0119 L
.7381 .0119 L
.97619 .0119 L
.97619 .25 L
.7381 .25 L
.5 .25 L
.5 .4881 L
.2619 .4881 L
.5 .4881 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.116667 0.539683 0.156349 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.0119048 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .0119 m
.97619 .0119 L
.97619 .25 L
.7381 .25 L
.7381 .0119 L
.97619 .0119 L
.97619 .25 L
.7381 .25 L
.5 .25 L
.2619 .25 L
.2619 .4881 L
.2619 .25 L
.02381 .25 L
.2619 .25 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.116667 0.626984 0.156349 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .33333 m
.97619 .33333 L
.97619 .65079 L
.65873 .65079 L
.65873 .33333 L
.97619 .33333 L
.97619 .65079 L
.65873 .65079 L
.65873 .33333 L
.65873 .01587 L
.34127 .01587 L
.34127 .33333 L
.34127 .01587 L
.02381 .01587 L
.34127 .01587 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.116667 0.714286 0.156349 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .33333 m
.97619 .33333 L
.97619 .65079 L
.65873 .65079 L
.65873 .33333 L
.97619 .33333 L
.97619 .65079 L
.65873 .65079 L
.34127 .65079 L
.34127 .33333 L
.34127 .01587 L
.34127 .33333 L
.34127 .01587 L
.02381 .01587 L
.34127 .01587 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.116667 0.801587 0.156349 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.00793651 0.31746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .00794 m
.97619 .00794 L
.97619 .3254 L
.65873 .3254 L
.65873 .00794 L
.97619 .00794 L
.97619 .3254 L
.65873 .3254 L
.34127 .3254 L
.02381 .3254 L
.34127 .3254 L
.65873 .3254 L
.97619 .3254 L
.65873 .3254 L
.97619 .3254 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.116667 0.888889 0.156349 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.988095 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .9881 m
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.5 .5119 L
.5 .03571 L
.5 .5119 L
.5 .03571 L
.02381 .03571 L
.5 .03571 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.116667 0.97619 0.156349 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5 m
.5 .5 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.5 .5 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.5 .5 L
.97619 .5 L
.97619 .02381 L
.97619 .5 L
.97619 .02381 L
.5 .02381 L
.97619 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.160317 0.103175 0.2 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 1.02381 0.952381 [
[ 0 0 0 0 ]
[ 1 3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.02381 m
.97619 1.02381 L
.97619 1.97619 L
.97619 2.92857 L
.02381 2.92857 L
.02381 1.97619 L
.97619 1.97619 L
.97619 2.92857 L
.02381 2.92857 L
.02381 1.97619 L
.02381 1.02381 L
.02381 .07143 L
.02381 1.02381 L
.02381 .07143 L
.97619 .07143 L
s
0 0 m
1 0 L
1 3 L
0 3 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.160317 0.190476 0.2 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01587 m
.34127 .01587 L
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.65873 .33333 L
.65873 .01587 L
.65873 .33333 L
.65873 .01587 L
.97619 .01587 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.160317 0.277778 0.2 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .03571 m
.5 .03571 L
.5 .5119 L
.02381 .5119 L
.02381 .03571 L
.5 .03571 L
.5 .5119 L
.5 .9881 L
.5 1.46429 L
.97619 1.46429 L
.97619 .9881 L
.5 .9881 L
.97619 .9881 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.160317 0.365079 0.2 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .02381 m
.97619 .02381 L
.97619 .5 L
.5 .5 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.5 .5 L
.02381 .5 L
.02381 .97619 L
.5 .97619 L
.5 .5 L
.02381 .5 L
.5 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.160317 0.452381 0.2 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .02381 m
.97619 .02381 L
.97619 .5 L
.5 .5 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.02381 .97619 L
.5 .97619 L
.5 .5 L
.02381 .5 L
.5 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.160317 0.539683 0.2 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.119048 0.952381 [
[ 0 0 0 0 ]
[ 1 5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .11905 m
.97619 .11905 L
.97619 1.07143 L
.02381 1.07143 L
.02381 .11905 L
.97619 .11905 L
.97619 1.07143 L
.97619 2.02381 L
.97619 2.97619 L
.97619 3.92857 L
.97619 4.88095 L
.97619 3.92857 L
.02381 3.92857 L
.97619 3.92857 L
s
0 0 m
1 0 L
1 5 L
0 5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.160317 0.626984 0.2 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0178571 0.238095 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01786 m
.2619 .01786 L
.2619 .25595 L
.02381 .25595 L
.02381 .01786 L
.2619 .01786 L
.2619 .25595 L
.2619 .49405 L
.2619 .73214 L
.5 .73214 L
.7381 .73214 L
.97619 .73214 L
.7381 .73214 L
.97619 .73214 L
s
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.160317 0.714286 0.2 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.00793651 0.31746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .00794 m
.97619 .00794 L
.97619 .3254 L
.65873 .3254 L
.65873 .00794 L
.97619 .00794 L
.97619 .3254 L
.65873 .3254 L
.34127 .3254 L
.02381 .3254 L
.34127 .3254 L
.34127 .00794 L
.02381 .00794 L
.34127 .00794 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.160317 0.801587 0.2 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.988095 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .9881 m
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.5 .5119 L
.02381 .5119 L
.5 .5119 L
.5 .03571 L
.02381 .03571 L
.5 .03571 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.160317 0.888889 0.2 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.031746 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .03175 m
.97619 .03175 L
.97619 .34921 L
.65873 .34921 L
.65873 .03175 L
.97619 .03175 L
.97619 .34921 L
.65873 .34921 L
.34127 .34921 L
.34127 .66667 L
.34127 .98413 L
.34127 1.30159 L
.34127 .98413 L
.02381 .98413 L
.34127 .98413 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.160317 0.97619 0.2 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .01587 m
.65873 .01587 L
.65873 .33333 L
.34127 .33333 L
.34127 .01587 L
.65873 .01587 L
.65873 .33333 L
.34127 .33333 L
.02381 .33333 L
.02381 .65079 L
.34127 .65079 L
.65873 .65079 L
.97619 .65079 L
.65873 .65079 L
.97619 .65079 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.203968 0.103175 0.243651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .03571 m
.97619 .03571 L
.97619 .5119 L
.97619 .9881 L
.5 .9881 L
.5 .5119 L
.97619 .5119 L
.97619 .9881 L
.5 .9881 L
.02381 .9881 L
.02381 1.46429 L
.5 1.46429 L
.5 .9881 L
.97619 .9881 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.203968 0.190476 0.243651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .03571 m
.97619 .03571 L
.97619 .5119 L
.97619 .9881 L
.5 .9881 L
.5 .5119 L
.97619 .5119 L
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.02381 1.46429 L
.5 1.46429 L
.5 .9881 L
.97619 .9881 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.203968 0.277778 0.243651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0714286 0.47619 [
[ 0 0 0 0 ]
[ 1 3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .07143 m
.5 .07143 L
.5 .54762 L
.5 1.02381 L
.02381 1.02381 L
.02381 .54762 L
.5 .54762 L
.5 1.02381 L
.5 1.5 L
.5 1.97619 L
.5 2.45238 L
.5 2.92857 L
.5 2.45238 L
.97619 2.45238 L
s
0 0 m
1 0 L
1 3 L
0 3 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.203968 0.365079 0.243651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .01587 m
.97619 .01587 L
.97619 .33333 L
.97619 .65079 L
.65873 .65079 L
.65873 .33333 L
.97619 .33333 L
.97619 .65079 L
.65873 .65079 L
.34127 .65079 L
.02381 .65079 L
.34127 .65079 L
.34127 .33333 L
.65873 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.203968 0.452381 0.243651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.511905 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .5119 m
.97619 .5119 L
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.5 .5119 L
.02381 .5119 L
.5 .5119 L
.5 .03571 L
.97619 .03571 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.203968 0.539683 0.243651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0595238 0.47619 [
[ 0 0 0 0 ]
[ 1 2.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .05952 m
.97619 .05952 L
.97619 .53571 L
.97619 1.0119 L
.5 1.0119 L
.5 .53571 L
.97619 .53571 L
.97619 1.0119 L
.5 1.0119 L
.02381 1.0119 L
.02381 1.4881 L
.02381 1.96429 L
.02381 2.44048 L
.02381 1.96429 L
.5 1.96429 L
s
0 0 m
1 0 L
1 2.5 L
0 2.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.203968 0.626984 0.243651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .01587 m
.65873 .01587 L
.65873 .33333 L
.65873 .65079 L
.34127 .65079 L
.34127 .33333 L
.65873 .33333 L
.97619 .33333 L
.97619 .65079 L
.65873 .65079 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.203968 0.714286 0.243651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.511905 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5119 m
.5 .5119 L
.5 .9881 L
.5 1.46429 L
.02381 1.46429 L
.02381 .9881 L
.5 .9881 L
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.5 .5119 L
.02381 .5119 L
.02381 .03571 L
.5 .03571 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.203968 0.801587 0.243651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .02381 m
.97619 .02381 L
.97619 .34127 L
.97619 .65873 L
.65873 .65873 L
.65873 .34127 L
.97619 .34127 L
.97619 .65873 L
.65873 .65873 L
.34127 .65873 L
.02381 .65873 L
.02381 .97619 L
.02381 .65873 L
.34127 .65873 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.203968 0.888889 0.243651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .02381 m
.97619 .02381 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.5 .02381 L
.02381 .02381 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.203968 0.97619 0.243651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .02381 m
.97619 .02381 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.02381 .02381 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.247619 0.103175 0.287302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 1.97619 0.952381 [
[ 0 0 0 0 ]
[ 1 3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.97619 m
.97619 1.97619 L
.97619 2.92857 L
.02381 2.92857 L
.02381 1.97619 L
.97619 1.97619 L
.97619 2.92857 L
.02381 2.92857 L
.02381 1.97619 L
.02381 1.02381 L
.02381 .07143 L
.02381 1.02381 L
.02381 .07143 L
.02381 1.02381 L
.97619 1.02381 L
s
0 0 m
1 0 L
1 3 L
0 3 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.247619 0.190476 0.287302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .33333 m
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.65873 .33333 L
.65873 .01587 L
.65873 .33333 L
.65873 .01587 L
.65873 .33333 L
.97619 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.247619 0.277778 0.287302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.25 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .25 m
.97619 .25 L
.97619 .4881 L
.7381 .4881 L
.7381 .25 L
.97619 .25 L
.97619 .4881 L
.7381 .4881 L
.7381 .25 L
.7381 .0119 L
.5 .0119 L
.7381 .0119 L
.5 .0119 L
.2619 .0119 L
.02381 .0119 L
.2619 .0119 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.247619 0.365079 0.287302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.511905 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5119 m
.5 .5119 L
.5 .9881 L
.02381 .9881 L
.02381 .5119 L
.5 .5119 L
.5 .9881 L
.5 1.46429 L
.97619 1.46429 L
.5 1.46429 L
.02381 1.46429 L
.02381 .9881 L
.02381 .5119 L
.02381 .03571 L
.5 .03571 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.247619 0.452381 0.287302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01587 m
.34127 .01587 L
.34127 .33333 L
.02381 .33333 L
.02381 .01587 L
.34127 .01587 L
.34127 .33333 L
.34127 .65079 L
.65873 .65079 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.65873 .33333 L
.65873 .01587 L
.97619 .01587 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.247619 0.539683 0.287302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.738095 0.238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .7381 m
.7381 .7381 L
.7381 .97619 L
.5 .97619 L
.5 .7381 L
.5 .5 L
.2619 .5 L
.02381 .5 L
.02381 .2619 L
.2619 .2619 L
.5 .2619 L
.7381 .2619 L
.7381 .02381 L
.97619 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.247619 0.626984 0.287302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.65873 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .65873 m
.97619 .65873 L
.97619 .97619 L
.65873 .97619 L
.65873 .65873 L
.65873 .34127 L
.34127 .34127 L
.02381 .34127 L
.02381 .02381 L
.34127 .02381 L
.34127 .34127 L
.34127 .65873 L
.65873 .65873 L
.65873 .34127 L
.97619 .34127 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.247619 0.714286 0.287302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.65873 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .65873 m
.97619 .65873 L
.97619 .97619 L
.65873 .97619 L
.65873 .65873 L
.65873 .34127 L
.34127 .34127 L
.02381 .34127 L
.02381 .02381 L
.34127 .02381 L
.65873 .02381 L
.65873 .34127 L
.65873 .65873 L
.65873 .34127 L
.97619 .34127 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.247619 0.801587 0.287302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.65873 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .65873 m
.97619 .65873 L
.97619 .97619 L
.65873 .97619 L
.65873 .65873 L
.65873 .34127 L
.34127 .34127 L
.02381 .34127 L
.02381 .02381 L
.34127 .02381 L
.34127 .34127 L
.34127 .65873 L
.34127 .97619 L
.34127 .65873 L
.65873 .65873 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.247619 0.888889 0.287302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.494048 0.238095 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .49405 m
.97619 .49405 L
.97619 .73214 L
.7381 .73214 L
.7381 .49405 L
.7381 .25595 L
.5 .25595 L
.2619 .25595 L
.2619 .01786 L
.5 .01786 L
.5 .25595 L
.2619 .25595 L
.02381 .25595 L
.02381 .49405 L
.02381 .25595 L
.2619 .25595 L
s
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.247619 0.97619 0.287302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.031746 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .03175 m
.34127 .03175 L
.34127 .34921 L
.34127 .66667 L
.02381 .66667 L
.02381 .34921 L
.34127 .34921 L
.34127 .66667 L
.34127 .98413 L
.34127 1.30159 L
.65873 1.30159 L
.65873 .98413 L
.97619 .98413 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.29127 0.103175 0.330952 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.047619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .04762 m
.97619 .04762 L
.97619 .52381 L
.5 .52381 L
.5 .04762 L
.97619 .04762 L
.97619 .52381 L
.5 .52381 L
.02381 .52381 L
.02381 1 L
.02381 1.47619 L
.02381 1.95238 L
.02381 1.47619 L
.02381 1.95238 L
.5 1.95238 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.29127 0.190476 0.330952 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.0119048 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .0119 m
.97619 .0119 L
.97619 .25 L
.7381 .25 L
.7381 .0119 L
.97619 .0119 L
.97619 .25 L
.7381 .25 L
.5 .25 L
.5 .4881 L
.7381 .4881 L
.5 .4881 L
.2619 .4881 L
.02381 .4881 L
.2619 .4881 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.29127 0.277778 0.330952 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.00793651 0.31746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .00794 m
.65873 .00794 L
.65873 .3254 L
.34127 .3254 L
.34127 .00794 L
.65873 .00794 L
.97619 .00794 L
.97619 .3254 L
.65873 .3254 L
.34127 .3254 L
.02381 .3254 L
.02381 .00794 L
.02381 .3254 L
.34127 .3254 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.29127 0.365079 0.330952 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.988095 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .9881 m
.5 .9881 L
.5 1.46429 L
.02381 1.46429 L
.02381 .9881 L
.5 .9881 L
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.5 .5119 L
.02381 .5119 L
.02381 .03571 L
.02381 .5119 L
.5 .5119 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.29127 0.452381 0.330952 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.0119048 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .0119 m
.97619 .0119 L
.97619 .25 L
.7381 .25 L
.7381 .0119 L
.97619 .0119 L
.97619 .25 L
.97619 .4881 L
.7381 .4881 L
.5 .4881 L
.7381 .4881 L
.5 .4881 L
.2619 .4881 L
.02381 .4881 L
.2619 .4881 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.29127 0.539683 0.330952 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.984127 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .98413 m
.34127 .98413 L
.34127 1.30159 L
.02381 1.30159 L
.02381 .98413 L
.34127 .98413 L
.65873 .98413 L
.97619 .98413 L
.65873 .98413 L
.34127 .98413 L
.34127 .66667 L
.34127 .34921 L
.34127 .03175 L
.65873 .03175 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.29127 0.626984 0.330952 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.494048 0.238095 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .49405 m
.2619 .49405 L
.2619 .73214 L
.02381 .73214 L
.02381 .49405 L
.2619 .49405 L
.5 .49405 L
.7381 .49405 L
.5 .49405 L
.2619 .49405 L
.2619 .25595 L
.5 .25595 L
.7381 .25595 L
.7381 .01786 L
.97619 .01786 L
s
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.29127 0.714286 0.330952 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .01587 m
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.34127 .33333 L
.02381 .33333 L
.02381 .65079 L
.02381 .33333 L
.02381 .65079 L
.34127 .65079 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.29127 0.801587 0.330952 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .5 m
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.5 .02381 L
.02381 .02381 L
.02381 .5 L
.02381 .02381 L
.02381 .5 L
.5 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.29127 0.888889 0.330952 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .5 m
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.02381 .02381 L
.02381 .5 L
.02381 .02381 L
.02381 .5 L
.5 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.29127 0.97619 0.330952 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.190476 0.0047619 0.190476 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.78571 .00476 m
.97619 .00476 L
.97619 .19524 L
.78571 .19524 L
.78571 .00476 L
.97619 .00476 L
.97619 .19524 L
.78571 .19524 L
.59524 .19524 L
.40476 .19524 L
.59524 .19524 L
.40476 .19524 L
.21429 .19524 L
.02381 .19524 L
.21429 .19524 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.334921 0.103175 0.374603 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.0119048 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .0119 m
.97619 .0119 L
.97619 .25 L
.7381 .25 L
.5 .25 L
.2619 .25 L
.02381 .25 L
.02381 .0119 L
.2619 .0119 L
.2619 .25 L
.2619 .4881 L
.5 .4881 L
.5 .25 L
.7381 .25 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.334921 0.190476 0.374603 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.0119048 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .0119 m
.97619 .0119 L
.97619 .25 L
.7381 .25 L
.5 .25 L
.2619 .25 L
.02381 .25 L
.02381 .0119 L
.2619 .0119 L
.5 .0119 L
.5 .25 L
.5 .4881 L
.5 .25 L
.7381 .25 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.334921 0.277778 0.374603 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.0178571 0.238095 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .01786 m
.97619 .01786 L
.97619 .25595 L
.7381 .25595 L
.5 .25595 L
.2619 .25595 L
.02381 .25595 L
.02381 .01786 L
.2619 .01786 L
.2619 .25595 L
.2619 .49405 L
.2619 .73214 L
.2619 .49405 L
.5 .49405 L
s
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.334921 0.365079 0.374603 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.190476 0.00952381 0.190476 [
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.78571 .00952 m
.97619 .00952 L
.97619 .2 L
.78571 .2 L
.59524 .2 L
.40476 .2 L
.21429 .2 L
.21429 .00952 L
.40476 .00952 L
.40476 .2 L
.21429 .2 L
.02381 .2 L
.02381 .39048 L
.02381 .2 L
.21429 .2 L
s
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.334921 0.452381 0.374603 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.34127 .02381 L
.34127 .34127 L
.02381 .34127 L
.02381 .02381 L
.34127 .02381 L
.34127 .34127 L
.34127 .65873 L
.34127 .97619 L
.65873 .97619 L
.65873 .65873 L
.65873 .97619 L
.97619 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.334921 0.539683 0.374603 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .02381 m
.97619 .02381 L
.97619 .5 L
.5 .5 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.5 .5 L
.02381 .5 L
.02381 .97619 L
.5 .97619 L
.5 .5 L
.5 .97619 L
.97619 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.334921 0.626984 0.374603 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .02381 m
.97619 .02381 L
.97619 .5 L
.5 .5 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.02381 .97619 L
.5 .97619 L
.5 .5 L
.5 .97619 L
.97619 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.334921 0.714286 0.374603 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0595238 0.47619 [
[ 0 0 0 0 ]
[ 1 2.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .05952 m
.5 .05952 L
.5 .53571 L
.02381 .53571 L
.02381 .05952 L
.5 .05952 L
.5 .53571 L
.5 1.0119 L
.5 1.4881 L
.5 1.96429 L
.5 2.44048 L
.5 1.96429 L
.5 2.44048 L
.97619 2.44048 L
s
0 0 m
1 0 L
1 2.5 L
0 2.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.334921 0.801587 0.374603 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .02381 m
.65873 .02381 L
.65873 .34127 L
.34127 .34127 L
.34127 .02381 L
.65873 .02381 L
.65873 .34127 L
.65873 .65873 L
.65873 .97619 L
.97619 .97619 L
.65873 .97619 L
.34127 .97619 L
.02381 .97619 L
.34127 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.334921 0.888889 0.374603 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.00793651 0.31746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .00794 m
.97619 .00794 L
.97619 .3254 L
.65873 .3254 L
.65873 .00794 L
.97619 .00794 L
.97619 .3254 L
.65873 .3254 L
.34127 .3254 L
.02381 .3254 L
.34127 .3254 L
.34127 .00794 L
.34127 .3254 L
.65873 .3254 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.334921 0.97619 0.374603 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.988095 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .9881 m
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.5 .5119 L
.02381 .5119 L
.5 .5119 L
.5 .03571 L
.5 .5119 L
.97619 .5119 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.378571 0.103175 0.418254 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.984127 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .98413 m
.34127 .98413 L
.34127 1.30159 L
.02381 1.30159 L
.02381 .98413 L
.34127 .98413 L
.65873 .98413 L
.65873 .66667 L
.34127 .66667 L
.02381 .66667 L
.02381 .34921 L
.34127 .34921 L
.65873 .34921 L
.65873 .03175 L
.97619 .03175 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.378571 0.190476 0.418254 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.031746 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .03175 m
.65873 .03175 L
.65873 .34921 L
.34127 .34921 L
.02381 .34921 L
.02381 .03175 L
.34127 .03175 L
.34127 .34921 L
.34127 .66667 L
.34127 .98413 L
.65873 .98413 L
.65873 1.30159 L
.97619 1.30159 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.378571 0.277778 0.418254 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .02381 m
.97619 .02381 L
.97619 .34127 L
.65873 .34127 L
.34127 .34127 L
.34127 .02381 L
.65873 .02381 L
.65873 .34127 L
.34127 .34127 L
.02381 .34127 L
.02381 .65873 L
.34127 .65873 L
.34127 .97619 L
.65873 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.378571 0.365079 0.418254 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .02381 m
.97619 .02381 L
.97619 .34127 L
.65873 .34127 L
.34127 .34127 L
.34127 .02381 L
.65873 .02381 L
.65873 .34127 L
.65873 .65873 L
.34127 .65873 L
.02381 .65873 L
.34127 .65873 L
.34127 .97619 L
.65873 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.378571 0.452381 0.418254 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.34127 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .34127 m
.97619 .34127 L
.97619 .65873 L
.65873 .65873 L
.65873 .34127 L
.65873 .02381 L
.97619 .02381 L
.97619 .34127 L
.97619 .65873 L
.97619 .97619 L
.65873 .97619 L
.34127 .97619 L
.02381 .97619 L
.34127 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.378571 0.539683 0.418254 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.0119048 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .0119 m
.97619 .0119 L
.97619 .25 L
.7381 .25 L
.5 .25 L
.5 .0119 L
.7381 .0119 L
.7381 .25 L
.5 .25 L
.2619 .25 L
.02381 .25 L
.2619 .25 L
.2619 .4881 L
.5 .4881 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.378571 0.626984 0.418254 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .33333 m
.97619 .33333 L
.97619 .65079 L
.65873 .65079 L
.34127 .65079 L
.34127 .33333 L
.65873 .33333 L
.65873 .65079 L
.34127 .65079 L
.34127 .33333 L
.34127 .01587 L
.02381 .01587 L
.34127 .01587 L
.34127 .33333 L
.65873 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.378571 0.714286 0.418254 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.190476 0.2 0.190476 [
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.78571 .2 m
.97619 .2 L
.97619 .39048 L
.78571 .39048 L
.78571 .2 L
.78571 .00952 L
.97619 .00952 L
.97619 .2 L
.78571 .2 L
.59524 .2 L
.59524 .39048 L
.40476 .39048 L
.21429 .39048 L
.02381 .39048 L
.21429 .39048 L
s
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.378571 0.801587 0.418254 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 1.96429 0.47619 [
[ 0 0 0 0 ]
[ 1 2.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.96429 m
.5 1.96429 L
.5 2.44048 L
.02381 2.44048 L
.02381 1.96429 L
.02381 1.4881 L
.5 1.4881 L
.97619 1.4881 L
.5 1.4881 L
.02381 1.4881 L
.02381 1.0119 L
.02381 .53571 L
.02381 .05952 L
.5 .05952 L
s
0 0 m
1 0 L
1 2.5 L
0 2.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.378571 0.888889 0.418254 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.984127 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .98413 m
.34127 .98413 L
.34127 1.30159 L
.02381 1.30159 L
.02381 .98413 L
.02381 .66667 L
.34127 .66667 L
.65873 .66667 L
.34127 .66667 L
.02381 .66667 L
.02381 .34921 L
.34127 .34921 L
.65873 .34921 L
.65873 .03175 L
.97619 .03175 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.378571 0.97619 0.418254 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.25 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .25 m
.97619 .25 L
.97619 .4881 L
.7381 .4881 L
.5 .4881 L
.2619 .4881 L
.02381 .4881 L
.02381 .25 L
.2619 .25 L
.5 .25 L
.7381 .25 L
.7381 .0119 L
.97619 .0119 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.422222 0.103175 0.461905 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .03571 m
.97619 .03571 L
.97619 .5119 L
.5 .5119 L
.5 .03571 L
.97619 .03571 L
.97619 .5119 L
.97619 .9881 L
.5 .9881 L
.02381 .9881 L
.5 .9881 L
.02381 .9881 L
.02381 1.46429 L
.5 1.46429 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.422222 0.190476 0.461905 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .03571 m
.5 .03571 L
.5 .5119 L
.02381 .5119 L
.02381 .03571 L
.5 .03571 L
.5 .5119 L
.5 .9881 L
.5 1.46429 L
.5 .9881 L
.5 .5119 L
.5 .03571 L
.5 .5119 L
.97619 .5119 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.422222 0.277778 0.461905 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .02381 m
.97619 .02381 L
.97619 .34127 L
.65873 .34127 L
.65873 .02381 L
.97619 .02381 L
.97619 .34127 L
.97619 .65873 L
.97619 .97619 L
.97619 .65873 L
.65873 .65873 L
.34127 .65873 L
.02381 .65873 L
.34127 .65873 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.422222 0.365079 0.461905 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .01587 m
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.34127 .33333 L
.02381 .33333 L
.34127 .33333 L
.02381 .33333 L
.02381 .65079 L
.34127 .65079 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.422222 0.452381 0.461905 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .5 m
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.5 .02381 L
.02381 .02381 L
.5 .02381 L
.02381 .02381 L
.02381 .5 L
.5 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.422222 0.539683 0.461905 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.511905 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .5119 m
.97619 .5119 L
.97619 .9881 L
.5 .9881 L
.5 .5119 L
.97619 .5119 L
.97619 .9881 L
.5 .9881 L
.02381 .9881 L
.02381 1.46429 L
.02381 .9881 L
.02381 .5119 L
.02381 .03571 L
.02381 .5119 L
.5 .5119 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.422222 0.626984 0.461905 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.190476 0.00952381 0.190476 [
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.78571 .00952 m
.97619 .00952 L
.97619 .2 L
.78571 .2 L
.78571 .00952 L
.97619 .00952 L
.97619 .2 L
.78571 .2 L
.59524 .2 L
.59524 .39048 L
.59524 .2 L
.40476 .2 L
.21429 .2 L
.02381 .2 L
.21429 .2 L
s
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.422222 0.714286 0.461905 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.329365 0.15873 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .32937 m
.18254 .32937 L
.18254 .4881 L
.02381 .4881 L
.02381 .32937 L
.18254 .32937 L
.34127 .32937 L
.34127 .17063 L
.34127 .0119 L
.5 .0119 L
.65873 .0119 L
.81746 .0119 L
.81746 .17063 L
.97619 .17063 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.422222 0.801587 0.461905 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.395238 0.190476 [
[ 0 0 0 0 ]
[ 1 .6 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .39524 m
.21429 .39524 L
.21429 .58571 L
.02381 .58571 L
.02381 .39524 L
.21429 .39524 L
.40476 .39524 L
.40476 .20476 L
.40476 .01429 L
.59524 .01429 L
.59524 .20476 L
.59524 .39524 L
.78571 .39524 L
.78571 .58571 L
.97619 .58571 L
s
0 0 m
1 0 L
1 .6 L
0 .6 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.422222 0.888889 0.461905 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0119048 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .0119 m
.2619 .0119 L
.2619 .25 L
.02381 .25 L
.02381 .0119 L
.2619 .0119 L
.2619 .25 L
.2619 .4881 L
.5 .4881 L
.7381 .4881 L
.97619 .4881 L
.7381 .4881 L
.5 .4881 L
.2619 .4881 L
.5 .4881 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.422222 0.97619 0.461905 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 1.96429 0.47619 [
[ 0 0 0 0 ]
[ 1 2.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.96429 m
.5 1.96429 L
.5 2.44048 L
.02381 2.44048 L
.02381 1.96429 L
.5 1.96429 L
.97619 1.96429 L
.97619 1.4881 L
.5 1.4881 L
.02381 1.4881 L
.02381 1.0119 L
.02381 .53571 L
.02381 .05952 L
.5 .05952 L
s
0 0 m
1 0 L
1 2.5 L
0 2.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.465873 0.103175 0.505556 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 1.04762 0.952381 [
[ 0 0 0 0 ]
[ 1 4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.04762 m
.97619 1.04762 L
.97619 2 L
.02381 2 L
.02381 1.04762 L
.02381 .09524 L
.97619 .09524 L
.97619 1.04762 L
.97619 2 L
.97619 2.95238 L
.02381 2.95238 L
.02381 3.90476 L
.97619 3.90476 L
s
0 0 m
1 0 L
1 4 L
0 4 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.465873 0.190476 0.505556 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.34127 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .34127 m
.97619 .34127 L
.97619 .65873 L
.65873 .65873 L
.65873 .34127 L
.65873 .02381 L
.97619 .02381 L
.97619 .34127 L
.65873 .34127 L
.34127 .34127 L
.34127 .65873 L
.02381 .65873 L
.02381 .97619 L
.34127 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.465873 0.277778 0.505556 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.34127 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .34127 m
.34127 .34127 L
.34127 .65873 L
.02381 .65873 L
.02381 .34127 L
.34127 .34127 L
.65873 .34127 L
.65873 .65873 L
.65873 .97619 L
.65873 .65873 L
.65873 .34127 L
.65873 .02381 L
.65873 .34127 L
.97619 .34127 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.465873 0.365079 0.505556 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .01587 m
.65873 .01587 L
.65873 .33333 L
.34127 .33333 L
.34127 .01587 L
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.97619 .65079 L
.97619 .33333 L
.65873 .33333 L
.34127 .33333 L
.02381 .33333 L
.34127 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.465873 0.452381 0.505556 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.738095 0.238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .7381 m
.2619 .7381 L
.2619 .97619 L
.02381 .97619 L
.02381 .7381 L
.02381 .5 L
.02381 .2619 L
.02381 .02381 L
.2619 .02381 L
.5 .02381 L
.7381 .02381 L
.7381 .2619 L
.97619 .2619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.465873 0.539683 0.505556 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.984127 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .98413 m
.34127 .98413 L
.34127 1.30159 L
.02381 1.30159 L
.02381 .98413 L
.02381 .66667 L
.02381 .34921 L
.02381 .03175 L
.34127 .03175 L
.34127 .34921 L
.34127 .66667 L
.65873 .66667 L
.65873 .98413 L
.97619 .98413 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.465873 0.626984 0.505556 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0047619 0.190476 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00476 m
.21429 .00476 L
.21429 .19524 L
.02381 .19524 L
.02381 .00476 L
.21429 .00476 L
.40476 .00476 L
.59524 .00476 L
.78571 .00476 L
.97619 .00476 L
.78571 .00476 L
.59524 .00476 L
.40476 .00476 L
.59524 .00476 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.465873 0.714286 0.505556 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 1.63492 0.31746 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 1.63492 m
.97619 1.63492 L
.97619 1.95238 L
.65873 1.95238 L
.65873 1.63492 L
.65873 1.31746 L
.65873 1 L
.34127 1 L
.02381 1 L
.02381 .68254 L
.02381 .36508 L
.02381 .04762 L
.34127 .04762 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.465873 0.801587 0.505556 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 1.30952 0.31746 [
[ 0 0 0 0 ]
[ 1 1.66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 1.30952 m
.97619 1.30952 L
.97619 1.62698 L
.65873 1.62698 L
.65873 1.30952 L
.65873 .99206 L
.65873 .6746 L
.34127 .6746 L
.02381 .6746 L
.02381 .35714 L
.34127 .35714 L
.65873 .35714 L
.65873 .03968 L
.97619 .03968 L
s
0 0 m
1 0 L
1 1.66667 L
0 1.66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.465873 0.888889 0.505556 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.047619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .04762 m
.5 .04762 L
.5 .52381 L
.02381 .52381 L
.02381 .04762 L
.5 .04762 L
.5 .52381 L
.5 1 L
.5 1.47619 L
.97619 1.47619 L
.5 1.47619 L
.5 1.95238 L
.97619 1.95238 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.465873 0.97619 0.505556 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .03571 m
.97619 .03571 L
.97619 .5119 L
.5 .5119 L
.5 .03571 L
.97619 .03571 L
.97619 .5119 L
.5 .5119 L
.02381 .5119 L
.02381 .9881 L
.5 .9881 L
.02381 .9881 L
.02381 1.46429 L
.5 1.46429 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.509524 0.103175 0.549206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .33333 m
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.65873 .33333 L
.97619 .33333 L
.97619 .01587 L
.65873 .01587 L
.65873 .33333 L
.97619 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.509524 0.190476 0.549206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.5 .5 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.5 .5 L
.5 .97619 L
.97619 .97619 L
.97619 .5 L
.5 .5 L
.5 .97619 L
.97619 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.509524 0.277778 0.549206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.5 .5 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.97619 .97619 L
.97619 .5 L
.5 .5 L
.5 .97619 L
.97619 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.509524 0.365079 0.549206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0047619 0.190476 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00476 m
.21429 .00476 L
.21429 .19524 L
.02381 .19524 L
.02381 .00476 L
.21429 .00476 L
.40476 .00476 L
.59524 .00476 L
.78571 .00476 L
.97619 .00476 L
.78571 .00476 L
.78571 .19524 L
.97619 .19524 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.509524 0.452381 0.549206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.738095 0.238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .7381 m
.2619 .7381 L
.2619 .97619 L
.02381 .97619 L
.02381 .7381 L
.2619 .7381 L
.5 .7381 L
.7381 .7381 L
.7381 .5 L
.7381 .2619 L
.7381 .02381 L
.7381 .2619 L
.97619 .2619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.509524 0.539683 0.549206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .33333 m
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.65873 .33333 L
.97619 .33333 L
.97619 .01587 L
.65873 .01587 L
.34127 .01587 L
.02381 .01587 L
.34127 .01587 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.509524 0.626984 0.549206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0714286 0.952381 [
[ 0 0 0 0 ]
[ 1 3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .07143 m
.97619 .07143 L
.97619 1.02381 L
.02381 1.02381 L
.02381 .07143 L
.97619 .07143 L
.97619 1.02381 L
.97619 1.97619 L
.97619 2.92857 L
.97619 1.97619 L
.02381 1.97619 L
.02381 2.92857 L
.97619 2.92857 L
s
0 0 m
1 0 L
1 3 L
0 3 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.509524 0.714286 0.549206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .01587 m
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.34127 .33333 L
.34127 .65079 L
.34127 .33333 L
.02381 .33333 L
.02381 .65079 L
.34127 .65079 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.509524 0.801587 0.549206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0178571 0.238095 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01786 m
.2619 .01786 L
.2619 .25595 L
.02381 .25595 L
.02381 .01786 L
.2619 .01786 L
.2619 .25595 L
.2619 .49405 L
.5 .49405 L
.7381 .49405 L
.97619 .49405 L
.7381 .49405 L
.7381 .73214 L
.97619 .73214 L
s
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.509524 0.888889 0.549206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.34127 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .34127 m
.34127 .34127 L
.34127 .65873 L
.02381 .65873 L
.02381 .34127 L
.34127 .34127 L
.34127 .65873 L
.34127 .97619 L
.65873 .97619 L
.65873 .65873 L
.65873 .34127 L
.65873 .02381 L
.65873 .34127 L
.97619 .34127 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.509524 0.97619 0.549206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .01587 m
.65873 .01587 L
.65873 .33333 L
.34127 .33333 L
.34127 .01587 L
.65873 .01587 L
.65873 .33333 L
.65873 .65079 L
.97619 .65079 L
.97619 .33333 L
.65873 .33333 L
.34127 .33333 L
.02381 .33333 L
.34127 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.553175 0.103175 0.592857 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.119048 0.952381 [
[ 0 0 0 0 ]
[ 1 5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .11905 m
.97619 .11905 L
.97619 1.07143 L
.02381 1.07143 L
.02381 .11905 L
.97619 .11905 L
.97619 1.07143 L
.97619 2.02381 L
.97619 2.97619 L
.97619 3.92857 L
.97619 4.88095 L
.97619 3.92857 L
.97619 4.88095 L
s
0 0 m
1 0 L
1 5 L
0 5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.553175 0.190476 0.592857 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.00793651 0.31746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .00794 m
.97619 .00794 L
.97619 .3254 L
.65873 .3254 L
.65873 .00794 L
.97619 .00794 L
.97619 .3254 L
.65873 .3254 L
.34127 .3254 L
.02381 .3254 L
.34127 .3254 L
.34127 .00794 L
.34127 .3254 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.553175 0.277778 0.592857 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.988095 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .9881 m
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.5 .5119 L
.02381 .5119 L
.5 .5119 L
.5 .03571 L
.5 .5119 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.553175 0.365079 0.592857 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.047619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .04762 m
.97619 .04762 L
.97619 .52381 L
.5 .52381 L
.5 .04762 L
.97619 .04762 L
.97619 .52381 L
.5 .52381 L
.02381 .52381 L
.02381 1 L
.02381 1.47619 L
.02381 1.95238 L
.02381 1.47619 L
.02381 1.95238 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.553175 0.452381 0.592857 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.00793651 0.31746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .00794 m
.65873 .00794 L
.65873 .3254 L
.34127 .3254 L
.34127 .00794 L
.65873 .00794 L
.97619 .00794 L
.97619 .3254 L
.65873 .3254 L
.34127 .3254 L
.02381 .3254 L
.02381 .00794 L
.02381 .3254 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.553175 0.539683 0.592857 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.988095 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .9881 m
.5 .9881 L
.5 1.46429 L
.02381 1.46429 L
.02381 .9881 L
.5 .9881 L
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.5 .5119 L
.02381 .5119 L
.02381 .03571 L
.02381 .5119 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.553175 0.626984 0.592857 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .01587 m
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.34127 .33333 L
.02381 .33333 L
.02381 .65079 L
.02381 .33333 L
.02381 .65079 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.553175 0.714286 0.592857 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .5 m
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.5 .02381 L
.02381 .02381 L
.02381 .5 L
.02381 .02381 L
.02381 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.553175 0.801587 0.592857 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .5 m
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.02381 .02381 L
.02381 .5 L
.02381 .02381 L
.02381 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.553175 0.888889 0.592857 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 1.97619 0.952381 [
[ 0 0 0 0 ]
[ 1 3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.97619 m
.97619 1.97619 L
.97619 2.92857 L
.02381 2.92857 L
.02381 1.97619 L
.97619 1.97619 L
.97619 2.92857 L
.02381 2.92857 L
.02381 1.97619 L
.02381 1.02381 L
.02381 .07143 L
.02381 1.02381 L
.02381 .07143 L
.02381 1.02381 L
s
0 0 m
1 0 L
1 3 L
0 3 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.553175 0.97619 0.592857 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5 m
.5 .5 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.5 .5 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.5 .5 L
.97619 .5 L
.97619 .02381 L
.97619 .5 L
.97619 .02381 L
.97619 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.596825 0.103175 0.636508 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.511905 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .5119 m
.97619 .5119 L
.97619 .9881 L
.5 .9881 L
.5 .5119 L
.97619 .5119 L
.97619 .9881 L
.5 .9881 L
.02381 .9881 L
.02381 1.46429 L
.02381 .9881 L
.02381 .5119 L
.02381 .03571 L
.02381 .5119 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.596825 0.190476 0.636508 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.395238 0.190476 [
[ 0 0 0 0 ]
[ 1 .6 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .39524 m
.21429 .39524 L
.21429 .58571 L
.02381 .58571 L
.02381 .39524 L
.21429 .39524 L
.40476 .39524 L
.40476 .20476 L
.40476 .01429 L
.59524 .01429 L
.78571 .01429 L
.97619 .01429 L
.97619 .20476 L
s
0 0 m
1 0 L
1 .6 L
0 .6 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.596825 0.277778 0.636508 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.494048 0.238095 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .49405 m
.2619 .49405 L
.2619 .73214 L
.02381 .73214 L
.02381 .49405 L
.2619 .49405 L
.5 .49405 L
.5 .25595 L
.5 .01786 L
.7381 .01786 L
.7381 .25595 L
.7381 .49405 L
.97619 .49405 L
.97619 .73214 L
s
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.596825 0.365079 0.636508 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.047619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .04762 m
.97619 .04762 L
.97619 .52381 L
.5 .52381 L
.02381 .52381 L
.02381 .04762 L
.5 .04762 L
.5 .52381 L
.5 1 L
.5 1.47619 L
.97619 1.47619 L
.97619 1.95238 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.596825 0.452381 0.636508 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .02381 m
.97619 .02381 L
.97619 .34127 L
.65873 .34127 L
.34127 .34127 L
.34127 .02381 L
.65873 .02381 L
.65873 .34127 L
.34127 .34127 L
.02381 .34127 L
.02381 .65873 L
.34127 .65873 L
.34127 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.596825 0.539683 0.636508 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .02381 m
.97619 .02381 L
.97619 .34127 L
.65873 .34127 L
.34127 .34127 L
.34127 .02381 L
.65873 .02381 L
.65873 .34127 L
.65873 .65873 L
.34127 .65873 L
.02381 .65873 L
.34127 .65873 L
.34127 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.596825 0.626984 0.636508 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.0119048 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .0119 m
.97619 .0119 L
.97619 .25 L
.7381 .25 L
.5 .25 L
.5 .0119 L
.7381 .0119 L
.7381 .25 L
.5 .25 L
.2619 .25 L
.02381 .25 L
.2619 .25 L
.2619 .4881 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.596825 0.714286 0.636508 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .33333 m
.97619 .33333 L
.97619 .65079 L
.65873 .65079 L
.34127 .65079 L
.34127 .33333 L
.65873 .33333 L
.65873 .65079 L
.34127 .65079 L
.34127 .33333 L
.34127 .01587 L
.02381 .01587 L
.34127 .01587 L
.34127 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.596825 0.801587 0.636508 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .03571 m
.5 .03571 L
.5 .5119 L
.02381 .5119 L
.02381 .03571 L
.5 .03571 L
.5 .5119 L
.5 .9881 L
.5 1.46429 L
.97619 1.46429 L
.97619 .9881 L
.97619 1.46429 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.596825 0.888889 0.636508 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .02381 m
.97619 .02381 L
.97619 .5 L
.5 .5 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.5 .5 L
.02381 .5 L
.02381 .97619 L
.5 .97619 L
.5 .5 L
.5 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.596825 0.97619 0.636508 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .02381 m
.97619 .02381 L
.97619 .5 L
.5 .5 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.02381 .97619 L
.5 .97619 L
.5 .5 L
.5 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.640476 0.103175 0.680159 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 1.04762 0.952381 [
[ 0 0 0 0 ]
[ 1 4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.04762 m
.97619 1.04762 L
.97619 2 L
.02381 2 L
.02381 1.04762 L
.02381 .09524 L
.97619 .09524 L
.97619 1.04762 L
.97619 2 L
.97619 2.95238 L
.02381 2.95238 L
.02381 3.90476 L
s
0 0 m
1 0 L
1 4 L
0 4 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.640476 0.190476 0.680159 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.34127 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .34127 m
.97619 .34127 L
.97619 .65873 L
.65873 .65873 L
.65873 .34127 L
.65873 .02381 L
.97619 .02381 L
.97619 .34127 L
.65873 .34127 L
.34127 .34127 L
.34127 .65873 L
.02381 .65873 L
.02381 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.640476 0.277778 0.680159 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.511905 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5119 m
.5 .5119 L
.5 .9881 L
.02381 .9881 L
.02381 .5119 L
.5 .5119 L
.97619 .5119 L
.97619 .9881 L
.97619 1.46429 L
.97619 .9881 L
.97619 .5119 L
.97619 .03571 L
.97619 .5119 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.640476 0.365079 0.680159 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.984127 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .98413 m
.34127 .98413 L
.34127 1.30159 L
.02381 1.30159 L
.02381 .98413 L
.02381 .66667 L
.02381 .34921 L
.02381 .03175 L
.34127 .03175 L
.65873 .03175 L
.97619 .03175 L
.97619 .34921 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.640476 0.452381 0.680159 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 1.47619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.47619 m
.5 1.47619 L
.5 1.95238 L
.02381 1.95238 L
.02381 1.47619 L
.02381 1 L
.02381 .52381 L
.02381 .04762 L
.5 .04762 L
.5 .52381 L
.5 1 L
.97619 1 L
.97619 1.47619 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.640476 0.539683 0.680159 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.047619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .04762 m
.5 .04762 L
.5 .52381 L
.02381 .52381 L
.02381 .04762 L
.5 .04762 L
.5 .52381 L
.5 1 L
.5 1.47619 L
.97619 1.47619 L
.5 1.47619 L
.5 1.95238 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.640476 0.626984 0.680159 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .03571 m
.97619 .03571 L
.97619 .5119 L
.5 .5119 L
.5 .03571 L
.97619 .03571 L
.97619 .5119 L
.5 .5119 L
.02381 .5119 L
.02381 .9881 L
.5 .9881 L
.02381 .9881 L
.02381 1.46429 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.640476 0.714286 0.680159 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .03571 m
.97619 .03571 L
.97619 .5119 L
.5 .5119 L
.5 .03571 L
.97619 .03571 L
.97619 .5119 L
.97619 .9881 L
.5 .9881 L
.02381 .9881 L
.5 .9881 L
.02381 .9881 L
.02381 1.46429 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.640476 0.801587 0.680159 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0714286 0.952381 [
[ 0 0 0 0 ]
[ 1 3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .07143 m
.97619 .07143 L
.97619 1.02381 L
.02381 1.02381 L
.02381 .07143 L
.97619 .07143 L
.97619 1.02381 L
.97619 1.97619 L
.97619 2.92857 L
.97619 1.97619 L
.97619 1.02381 L
.97619 .07143 L
.97619 1.02381 L
s
0 0 m
1 0 L
1 3 L
0 3 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.640476 0.888889 0.680159 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .01587 m
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.34127 .33333 L
.02381 .33333 L
.34127 .33333 L
.02381 .33333 L
.02381 .65079 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.640476 0.97619 0.680159 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .5 m
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.5 .02381 L
.02381 .02381 L
.5 .02381 L
.02381 .02381 L
.02381 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.684127 0.103175 0.72381 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.00793651 0.31746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .00794 m
.65873 .00794 L
.97619 .00794 L
.97619 .3254 L
.65873 .3254 L
.65873 .00794 L
.97619 .00794 L
.97619 .3254 L
.65873 .3254 L
.34127 .3254 L
.02381 .3254 L
.34127 .3254 L
.02381 .3254 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.684127 0.190476 0.72381 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5 m
.5 .5 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.5 .02381 L
.02381 .02381 L
.5 .02381 L
.02381 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.684127 0.277778 0.72381 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .33333 m
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.65873 .33333 L
.97619 .33333 L
.97619 .01587 L
.65873 .01587 L
.65873 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.684127 0.365079 0.72381 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.5 .5 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.5 .5 L
.5 .97619 L
.97619 .97619 L
.97619 .5 L
.5 .5 L
.5 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.684127 0.452381 0.72381 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.5 .5 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.97619 .97619 L
.97619 .5 L
.5 .5 L
.5 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.684127 0.539683 0.72381 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0047619 0.190476 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00476 m
.21429 .00476 L
.21429 .19524 L
.02381 .19524 L
.02381 .00476 L
.21429 .00476 L
.40476 .00476 L
.59524 .00476 L
.78571 .00476 L
.97619 .00476 L
.78571 .00476 L
.78571 .19524 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.684127 0.626984 0.72381 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.984127 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .98413 m
.34127 .98413 L
.34127 1.30159 L
.02381 1.30159 L
.02381 .98413 L
.34127 .98413 L
.65873 .98413 L
.97619 .98413 L
.97619 .66667 L
.97619 .34921 L
.97619 .03175 L
.97619 .34921 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.684127 0.714286 0.72381 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0714286 0.952381 [
[ 0 0 0 0 ]
[ 1 3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .07143 m
.97619 .07143 L
.97619 1.02381 L
.02381 1.02381 L
.02381 .07143 L
.97619 .07143 L
.97619 1.02381 L
.97619 1.97619 L
.97619 2.92857 L
.97619 1.97619 L
.02381 1.97619 L
.02381 2.92857 L
s
0 0 m
1 0 L
1 3 L
0 3 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.684127 0.801587 0.72381 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .01587 m
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.34127 .33333 L
.34127 .65079 L
.34127 .33333 L
.02381 .33333 L
.02381 .65079 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.684127 0.888889 0.72381 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0178571 0.238095 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01786 m
.2619 .01786 L
.2619 .25595 L
.02381 .25595 L
.02381 .01786 L
.2619 .01786 L
.2619 .25595 L
.2619 .49405 L
.5 .49405 L
.7381 .49405 L
.97619 .49405 L
.7381 .49405 L
.7381 .73214 L
s
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.684127 0.97619 0.72381 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.511905 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5119 m
.5 .5119 L
.5 .9881 L
.02381 .9881 L
.02381 .5119 L
.5 .5119 L
.5 .9881 L
.5 1.46429 L
.97619 1.46429 L
.97619 .9881 L
.97619 .5119 L
.97619 .03571 L
.97619 .5119 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.727778 0.103175 0.76746 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01587 m
.34127 .01587 L
.65873 .01587 L
.65873 .33333 L
.34127 .33333 L
.34127 .01587 L
.65873 .01587 L
.65873 .33333 L
.65873 .65079 L
.97619 .65079 L
.97619 .33333 L
.65873 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.727778 0.190476 0.76746 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01587 m
.34127 .01587 L
.65873 .01587 L
.65873 .33333 L
.34127 .33333 L
.34127 .01587 L
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.97619 .65079 L
.97619 .33333 L
.65873 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.727778 0.277778 0.76746 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.00396825 0.15873 [
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00397 m
.18254 .00397 L
.34127 .00397 L
.34127 .1627 L
.18254 .1627 L
.18254 .00397 L
.34127 .00397 L
.5 .00397 L
.65873 .00397 L
.81746 .00397 L
.97619 .00397 L
.81746 .00397 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.727778 0.365079 0.76746 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .03571 m
.5 .03571 L
.97619 .03571 L
.97619 .5119 L
.5 .5119 L
.5 .03571 L
.97619 .03571 L
.97619 .5119 L
.97619 .9881 L
.97619 1.46429 L
.97619 .9881 L
.5 .9881 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.727778 0.452381 0.76746 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .01587 m
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.34127 .33333 L
.34127 .65079 L
.34127 .33333 L
.02381 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.727778 0.539683 0.76746 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.00952381 0.190476 [
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00952 m
.21429 .00952 L
.40476 .00952 L
.40476 .2 L
.21429 .2 L
.21429 .00952 L
.40476 .00952 L
.40476 .2 L
.40476 .39048 L
.59524 .39048 L
.78571 .39048 L
.97619 .39048 L
.78571 .39048 L
s
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.727778 0.626984 0.76746 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.511905 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5119 m
.5 .5119 L
.97619 .5119 L
.97619 .9881 L
.5 .9881 L
.5 .5119 L
.5 .03571 L
.97619 .03571 L
.97619 .5119 L
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.727778 0.714286 0.76746 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .33333 m
.65873 .33333 L
.97619 .33333 L
.97619 .65079 L
.65873 .65079 L
.65873 .33333 L
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.727778 0.801587 0.76746 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.34127 .02381 L
.65873 .02381 L
.65873 .34127 L
.34127 .34127 L
.34127 .02381 L
.65873 .02381 L
.65873 .34127 L
.65873 .65873 L
.65873 .97619 L
.97619 .97619 L
.65873 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.727778 0.888889 0.76746 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.5 .5 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.5 .5 L
.02381 .5 L
.02381 .97619 L
.5 .97619 L
.02381 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.727778 0.97619 0.76746 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.5 .5 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.02381 .97619 L
.5 .97619 L
.02381 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.771429 0.103175 0.811111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.65873 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .65873 m
.97619 .65873 L
.97619 .97619 L
.65873 .97619 L
.65873 .65873 L
.65873 .34127 L
.65873 .02381 L
.65873 .34127 L
.65873 .65873 L
.34127 .65873 L
.34127 .34127 L
.34127 .02381 L
.02381 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.771429 0.190476 0.811111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.119048 0.952381 [
[ 0 0 0 0 ]
[ 1 5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .11905 m
.97619 .11905 L
.97619 1.07143 L
.02381 1.07143 L
.02381 .11905 L
.97619 .11905 L
.97619 1.07143 L
.97619 2.02381 L
.97619 2.97619 L
.97619 2.02381 L
.97619 2.97619 L
.97619 3.92857 L
.97619 4.88095 L
s
0 0 m
1 0 L
1 5 L
0 5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.771429 0.277778 0.811111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.047619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .04762 m
.97619 .04762 L
.97619 .52381 L
.5 .52381 L
.5 .04762 L
.97619 .04762 L
.97619 .52381 L
.5 .52381 L
.02381 .52381 L
.02381 1 L
.02381 .52381 L
.02381 1 L
.02381 1.47619 L
.02381 1.95238 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.771429 0.365079 0.811111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .33333 m
.65873 .33333 L
.65873 .65079 L
.34127 .65079 L
.34127 .33333 L
.65873 .33333 L
.97619 .33333 L
.97619 .01587 L
.97619 .33333 L
.97619 .65079 L
.65873 .65079 L
.34127 .65079 L
.02381 .65079 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.771429 0.452381 0.811111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5 m
.5 .5 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.5 .5 L
.97619 .5 L
.97619 .02381 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.5 .02381 L
.02381 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.771429 0.539683 0.811111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.0178571 0.238095 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .01786 m
.97619 .01786 L
.97619 .25595 L
.7381 .25595 L
.5 .25595 L
.5 .49405 L
.5 .73214 L
.2619 .73214 L
.2619 .49405 L
.2619 .25595 L
.2619 .01786 L
.02381 .01786 L
s
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.771429 0.626984 0.811111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .02381 m
.97619 .02381 L
.97619 .34127 L
.65873 .34127 L
.34127 .34127 L
.34127 .65873 L
.34127 .97619 L
.02381 .97619 L
.02381 .65873 L
.34127 .65873 L
.65873 .65873 L
.65873 .34127 L
.34127 .34127 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.771429 0.714286 0.811111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .02381 m
.97619 .02381 L
.97619 .34127 L
.65873 .34127 L
.34127 .34127 L
.34127 .65873 L
.34127 .97619 L
.02381 .97619 L
.02381 .65873 L
.02381 .34127 L
.34127 .34127 L
.65873 .34127 L
.34127 .34127 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.771429 0.801587 0.811111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .02381 m
.97619 .02381 L
.97619 .34127 L
.65873 .34127 L
.34127 .34127 L
.34127 .65873 L
.34127 .97619 L
.02381 .97619 L
.02381 .65873 L
.34127 .65873 L
.65873 .65873 L
.97619 .65873 L
.65873 .65873 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.771429 0.888889 0.811111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.031746 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .03175 m
.97619 .03175 L
.97619 .34921 L
.65873 .34921 L
.34127 .34921 L
.34127 .66667 L
.34127 .98413 L
.02381 .98413 L
.02381 .66667 L
.34127 .66667 L
.34127 .98413 L
.34127 1.30159 L
.65873 1.30159 L
.34127 1.30159 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.771429 0.97619 0.811111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.25 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .25 m
.2619 .25 L
.5 .25 L
.5 .4881 L
.2619 .4881 L
.2619 .25 L
.5 .25 L
.7381 .25 L
.97619 .25 L
.97619 .0119 L
.7381 .0119 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.815079 0.103175 0.854762 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.190476 0.2 0.190476 [
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.78571 .2 m
.97619 .2 L
.97619 .39048 L
.78571 .39048 L
.59524 .39048 L
.59524 .2 L
.59524 .00952 L
.59524 .2 L
.59524 .39048 L
.40476 .39048 L
.21429 .39048 L
.02381 .39048 L
s
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.815079 0.190476 0.854762 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.25 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .25 m
.97619 .25 L
.97619 .4881 L
.7381 .4881 L
.5 .4881 L
.5 .25 L
.5 .0119 L
.5 .25 L
.5 .4881 L
.2619 .4881 L
.2619 .25 L
.2619 .0119 L
.02381 .0119 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.815079 0.277778 0.854762 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.047619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .04762 m
.97619 .04762 L
.97619 .52381 L
.97619 1 L
.97619 1.47619 L
.97619 1.95238 L
.5 1.95238 L
.5 1.47619 L
.5 1 L
.5 .52381 L
.02381 .52381 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.815079 0.365079 0.854762 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.047619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .04762 m
.5 .04762 L
.5 .52381 L
.5 1 L
.5 1.47619 L
.5 1.95238 L
.02381 1.95238 L
.02381 1.47619 L
.5 1.47619 L
.97619 1.47619 L
.97619 1 L
.5 1 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.815079 0.452381 0.854762 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.047619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .04762 m
.5 .04762 L
.5 .52381 L
.5 1 L
.5 1.47619 L
.5 1.95238 L
.02381 1.95238 L
.02381 1.47619 L
.02381 1 L
.5 1 L
.97619 1 L
.5 1 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.815079 0.539683 0.854762 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.031746 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .03175 m
.34127 .03175 L
.34127 .34921 L
.34127 .66667 L
.34127 .98413 L
.34127 1.30159 L
.02381 1.30159 L
.02381 .98413 L
.34127 .98413 L
.65873 .98413 L
.97619 .98413 L
.65873 .98413 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.815079 0.626984 0.854762 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0595238 0.47619 [
[ 0 0 0 0 ]
[ 1 2.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .05952 m
.5 .05952 L
.5 .53571 L
.5 1.0119 L
.5 1.4881 L
.5 1.96429 L
.02381 1.96429 L
.02381 1.4881 L
.5 1.4881 L
.5 1.96429 L
.5 2.44048 L
.97619 2.44048 L
.5 2.44048 L
s
0 0 m
1 0 L
1 2.5 L
0 2.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.815079 0.714286 0.854762 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.34127 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .34127 m
.34127 .34127 L
.34127 .65873 L
.02381 .65873 L
.02381 .34127 L
.34127 .34127 L
.65873 .34127 L
.97619 .34127 L
.97619 .02381 L
.97619 .34127 L
.97619 .65873 L
.97619 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.815079 0.801587 0.854762 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.047619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .04762 m
.5 .04762 L
.5 .52381 L
.02381 .52381 L
.02381 .04762 L
.5 .04762 L
.5 .52381 L
.5 1 L
.97619 1 L
.97619 .52381 L
.97619 1 L
.97619 1.47619 L
.97619 1.95238 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.815079 0.888889 0.854762 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.047619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .04762 m
.5 .04762 L
.5 .52381 L
.02381 .52381 L
.02381 .04762 L
.5 .04762 L
.97619 .04762 L
.97619 .52381 L
.97619 1 L
.97619 .52381 L
.97619 1 L
.97619 1.47619 L
.97619 1.95238 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.815079 0.97619 0.854762 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.494048 0.238095 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .49405 m
.97619 .49405 L
.97619 .73214 L
.7381 .73214 L
.7381 .49405 L
.7381 .25595 L
.7381 .01786 L
.7381 .25595 L
.7381 .49405 L
.5 .49405 L
.2619 .49405 L
.02381 .49405 L
s
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.85873 0.103175 0.898413 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.511905 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5119 m
.5 .5119 L
.5 .9881 L
.02381 .9881 L
.02381 .5119 L
.02381 .03571 L
.5 .03571 L
.97619 .03571 L
.5 .03571 L
.5 .5119 L
.5 .9881 L
.5 1.46429 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.85873 0.190476 0.898413 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 3.92857 0.952381 [
[ 0 0 0 0 ]
[ 1 5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 3.92857 m
.97619 3.92857 L
.97619 4.88095 L
.02381 4.88095 L
.02381 3.92857 L
.02381 2.97619 L
.02381 2.02381 L
.02381 1.07143 L
.02381 .11905 L
.02381 1.07143 L
.02381 2.02381 L
.02381 2.97619 L
s
0 0 m
1 0 L
1 5 L
0 5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.85873 0.277778 0.898413 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.81746 0.15873 0.0119048 0.15873 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.81746 .0119 m
.97619 .0119 L
.97619 .17063 L
.81746 .17063 L
.65873 .17063 L
.5 .17063 L
.5 .32937 L
.5 .4881 L
.34127 .4881 L
.18254 .4881 L
.02381 .4881 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.85873 0.365079 0.898413 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.190476 0.0142857 0.190476 [
[ 0 0 0 0 ]
[ 1 .6 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.78571 .01429 m
.97619 .01429 L
.97619 .20476 L
.78571 .20476 L
.59524 .20476 L
.40476 .20476 L
.40476 .39524 L
.40476 .58571 L
.21429 .58571 L
.21429 .39524 L
.21429 .20476 L
.02381 .20476 L
s
0 0 m
1 0 L
1 .6 L
0 .6 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.85873 0.452381 0.898413 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.34127 .02381 L
.34127 .34127 L
.02381 .34127 L
.02381 .02381 L
.34127 .02381 L
.65873 .02381 L
.97619 .02381 L
.65873 .02381 L
.65873 .34127 L
.65873 .65873 L
.65873 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.85873 0.539683 0.898413 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0595238 0.47619 [
[ 0 0 0 0 ]
[ 1 2.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .05952 m
.5 .05952 L
.5 .53571 L
.02381 .53571 L
.02381 .05952 L
.5 .05952 L
.5 .53571 L
.5 1.0119 L
.97619 1.0119 L
.5 1.0119 L
.5 1.4881 L
.5 1.96429 L
.5 2.44048 L
s
0 0 m
1 0 L
1 2.5 L
0 2.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.85873 0.626984 0.898413 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 1.47619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.47619 m
.5 1.47619 L
.5 1.95238 L
.02381 1.95238 L
.02381 1.47619 L
.5 1.47619 L
.97619 1.47619 L
.97619 1 L
.97619 .52381 L
.97619 .04762 L
.97619 .52381 L
.97619 1 L
.97619 1.47619 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.85873 0.714286 0.898413 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.190476 0.2 0.190476 [
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.78571 .2 m
.97619 .2 L
.97619 .39048 L
.78571 .39048 L
.78571 .2 L
.78571 .00952 L
.59524 .00952 L
.59524 .2 L
.59524 .39048 L
.40476 .39048 L
.21429 .39048 L
.02381 .39048 L
s
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.85873 0.801587 0.898413 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.25 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .25 m
.97619 .25 L
.97619 .4881 L
.7381 .4881 L
.7381 .25 L
.7381 .0119 L
.5 .0119 L
.5 .25 L
.5 .4881 L
.2619 .4881 L
.2619 .25 L
.2619 .0119 L
.02381 .0119 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.85873 0.888889 0.898413 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .02381 m
.65873 .02381 L
.65873 .34127 L
.34127 .34127 L
.02381 .34127 L
.02381 .02381 L
.34127 .02381 L
.65873 .02381 L
.97619 .02381 L
.97619 .34127 L
.97619 .65873 L
.97619 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.85873 0.97619 0.898413 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0595238 0.47619 [
[ 0 0 0 0 ]
[ 1 2.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .05952 m
.97619 .05952 L
.97619 .53571 L
.5 .53571 L
.02381 .53571 L
.02381 .05952 L
.5 .05952 L
.5 .53571 L
.5 1.0119 L
.97619 1.0119 L
.97619 1.4881 L
.97619 1.96429 L
.97619 2.44048 L
s
0 0 m
1 0 L
1 2.5 L
0 2.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.902381 0.103175 0.942063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .01587 m
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.34127 .33333 L
.34127 .65079 L
.34127 .33333 L
.02381 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.902381 0.190476 0.942063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0119048 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .0119 m
.2619 .0119 L
.2619 .25 L
.02381 .25 L
.02381 .0119 L
.2619 .0119 L
.2619 .25 L
.2619 .4881 L
.5 .4881 L
.7381 .4881 L
.97619 .4881 L
.7381 .4881 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.902381 0.277778 0.942063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 1.02381 0.952381 [
[ 0 0 0 0 ]
[ 1 3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.02381 m
.97619 1.02381 L
.97619 1.97619 L
.02381 1.97619 L
.02381 1.02381 L
.02381 .07143 L
.97619 .07143 L
.97619 1.02381 L
.97619 1.97619 L
.97619 2.92857 L
.02381 2.92857 L
s
0 0 m
1 0 L
1 3 L
0 3 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.902381 0.365079 0.942063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .33333 m
.97619 .33333 L
.97619 .65079 L
.65873 .65079 L
.65873 .33333 L
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.65873 .33333 L
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.902381 0.452381 0.942063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .03571 m
.5 .03571 L
.5 .5119 L
.02381 .5119 L
.02381 .03571 L
.5 .03571 L
.5 .5119 L
.5 .9881 L
.5 1.46429 L
.97619 1.46429 L
.5 1.46429 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.902381 0.539683 0.942063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .02381 m
.97619 .02381 L
.97619 .5 L
.5 .5 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.5 .5 L
.02381 .5 L
.02381 .97619 L
.5 .97619 L
.02381 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.902381 0.626984 0.942063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .02381 m
.97619 .02381 L
.97619 .5 L
.5 .5 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.02381 .97619 L
.5 .97619 L
.02381 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.902381 0.714286 0.942063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.00793651 0.31746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .00794 m
.97619 .00794 L
.97619 .3254 L
.65873 .3254 L
.65873 .00794 L
.97619 .00794 L
.97619 .3254 L
.65873 .3254 L
.34127 .3254 L
.02381 .3254 L
.34127 .3254 L
.02381 .3254 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.902381 0.801587 0.942063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .5 m
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.5 .5 L
.5 .02381 L
.02381 .02381 L
.5 .02381 L
.02381 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.902381 0.888889 0.942063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.988095 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .9881 m
.97619 .9881 L
.97619 1.46429 L
.5 1.46429 L
.5 .9881 L
.5 .5119 L
.5 .03571 L
.02381 .03571 L
.02381 .5119 L
.02381 .9881 L
.02381 1.46429 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.902381 0.97619 0.942063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.511905 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5119 m
.5 .5119 L
.5 .9881 L
.02381 .9881 L
.02381 .5119 L
.5 .5119 L
.97619 .5119 L
.97619 .03571 L
.5 .03571 L
.5 .5119 L
.5 .9881 L
.5 1.46429 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.946032 0.103175 0.985714 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.984127 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .98413 m
.97619 .98413 L
.97619 1.30159 L
.65873 1.30159 L
.65873 .98413 L
.65873 .66667 L
.34127 .66667 L
.02381 .66667 L
.02381 .34921 L
.34127 .34921 L
.65873 .34921 L
.65873 .03175 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.946032 0.190476 0.985714 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01587 m
.34127 .01587 L
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.65873 .33333 L
.97619 .33333 L
.97619 .01587 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.946032 0.277778 0.985714 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .03571 m
.5 .03571 L
.5 .5119 L
.5 .9881 L
.02381 .9881 L
.02381 .5119 L
.5 .5119 L
.5 .9881 L
.5 1.46429 L
.97619 1.46429 L
.97619 .9881 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.946032 0.365079 0.985714 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .03571 m
.5 .03571 L
.5 .5119 L
.5 .9881 L
.02381 .9881 L
.02381 .5119 L
.5 .5119 L
.97619 .5119 L
.97619 .9881 L
.97619 1.46429 L
.97619 .9881 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.946032 0.452381 0.985714 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0952381 0.952381 [
[ 0 0 0 0 ]
[ 1 4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .09524 m
.97619 .09524 L
.97619 1.04762 L
.97619 2 L
.02381 2 L
.02381 1.04762 L
.97619 1.04762 L
.97619 2 L
.97619 2.95238 L
.97619 3.90476 L
.97619 2.95238 L
s
0 0 m
1 0 L
1 4 L
0 4 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.946032 0.539683 0.985714 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .03571 m
.97619 .03571 L
.97619 .5119 L
.97619 .9881 L
.5 .9881 L
.5 .5119 L
.97619 .5119 L
.97619 .9881 L
.5 .9881 L
.02381 .9881 L
.02381 1.46429 L
.02381 .9881 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.946032 0.626984 0.985714 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .33333 m
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.65873 .33333 L
.97619 .33333 L
.97619 .01587 L
.65873 .01587 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.946032 0.714286 0.985714 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.5 .5 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.5 .5 L
.5 .97619 L
.97619 .97619 L
.97619 .5 L
.5 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.946032 0.801587 0.985714 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.5 .5 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.97619 .97619 L
.97619 .5 L
.5 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.946032 0.888889 0.985714 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0047619 0.190476 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00476 m
.21429 .00476 L
.21429 .19524 L
.02381 .19524 L
.02381 .00476 L
.21429 .00476 L
.40476 .00476 L
.59524 .00476 L
.78571 .00476 L
.97619 .00476 L
.78571 .00476 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.946032 0.97619 0.985714 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0714286 0.952381 [
[ 0 0 0 0 ]
[ 1 3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .07143 m
.97619 .07143 L
.97619 1.02381 L
.02381 1.02381 L
.02381 .07143 L
.97619 .07143 L
.97619 1.02381 L
.97619 1.97619 L
.97619 2.92857 L
.97619 1.97619 L
.02381 1.97619 L
s
0 0 m
1 0 L
1 3 L
0 3 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.989683 0.103175 1.02937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01587 m
.34127 .01587 L
.65873 .01587 L
.65873 .33333 L
.34127 .33333 L
.34127 .01587 L
.65873 .01587 L
.97619 .01587 L
.97619 .33333 L
.97619 .65079 L
.97619 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 0.989683 0.190476 1.02937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .03571 m
.5 .03571 L
.97619 .03571 L
.97619 .5119 L
.5 .5119 L
.5 .03571 L
.97619 .03571 L
.97619 .5119 L
.97619 .9881 L
.97619 1.46429 L
.97619 .9881 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 0.989683 0.277778 1.02937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.5 .5 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.5 .5 L
.02381 .5 L
.02381 .97619 L
.02381 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 0.989683 0.365079 1.02937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.494048 0.238095 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .49405 m
.97619 .49405 L
.97619 .73214 L
.7381 .73214 L
.7381 .49405 L
.7381 .25595 L
.7381 .01786 L
.5 .01786 L
.2619 .01786 L
.02381 .01786 L
s
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 0.989683 0.452381 1.02937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .33333 m
.65873 .33333 L
.65873 .65079 L
.34127 .65079 L
.34127 .33333 L
.65873 .33333 L
.97619 .33333 L
.97619 .01587 L
.65873 .01587 L
.34127 .01587 L
.02381 .01587 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 0.989683 0.539683 1.02937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .33333 m
.65873 .33333 L
.65873 .65079 L
.34127 .65079 L
.34127 .33333 L
.34127 .01587 L
.65873 .01587 L
.97619 .01587 L
.65873 .01587 L
.34127 .01587 L
.02381 .01587 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 0.989683 0.626984 1.02937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.494048 0.238095 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .49405 m
.97619 .49405 L
.97619 .73214 L
.7381 .73214 L
.5 .73214 L
.2619 .73214 L
.02381 .73214 L
.02381 .49405 L
.02381 .25595 L
.02381 .01786 L
s
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 0.989683 0.714286 1.02937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.25 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .25 m
.97619 .25 L
.97619 .4881 L
.7381 .4881 L
.5 .4881 L
.2619 .4881 L
.02381 .4881 L
.02381 .25 L
.2619 .25 L
.5 .25 L
.5 .0119 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 0.989683 0.801587 1.02937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00793651 0.31746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00794 m
.34127 .00794 L
.34127 .3254 L
.02381 .3254 L
.02381 .00794 L
.34127 .00794 L
.65873 .00794 L
.97619 .00794 L
.65873 .00794 L
.34127 .00794 L
.02381 .00794 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 0.989683 0.888889 1.02937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .01587 m
.65873 .01587 L
.65873 .33333 L
.34127 .33333 L
.34127 .01587 L
.65873 .01587 L
.65873 .33333 L
.65873 .65079 L
.97619 .65079 L
.65873 .65079 L
.34127 .65079 L
.02381 .65079 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 0.989683 0.97619 1.02937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 1.30952 0.31746 [
[ 0 0 0 0 ]
[ 1 1.66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 1.30952 m
.97619 1.30952 L
.97619 1.62698 L
.65873 1.62698 L
.65873 1.30952 L
.65873 .99206 L
.34127 .99206 L
.02381 .99206 L
.02381 .6746 L
.02381 .35714 L
.02381 .03968 L
s
0 0 m
1 0 L
1 1.66667 L
0 1.66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.03333 0.103175 1.07302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.65873 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .65873 m
.97619 .65873 L
.97619 .97619 L
.65873 .97619 L
.65873 .65873 L
.65873 .34127 L
.65873 .02381 L
.65873 .34127 L
.65873 .65873 L
.34127 .65873 L
.02381 .65873 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 1.03333 0.190476 1.07302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5 m
.5 .5 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.5 .5 L
.97619 .5 L
.97619 .02381 L
.97619 .5 L
.97619 .97619 L
.5 .97619 L
.02381 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 1.03333 0.277778 1.07302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.0178571 0.238095 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .01786 m
.97619 .01786 L
.97619 .25595 L
.7381 .25595 L
.5 .25595 L
.5 .49405 L
.5 .73214 L
.2619 .73214 L
.02381 .73214 L
.02381 .49405 L
.02381 .25595 L
s
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 1.03333 0.365079 1.07302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .02381 m
.97619 .02381 L
.97619 .34127 L
.65873 .34127 L
.34127 .34127 L
.34127 .65873 L
.34127 .97619 L
.02381 .97619 L
.02381 .65873 L
.02381 .34127 L
.02381 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 1.03333 0.452381 1.07302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .02381 m
.97619 .02381 L
.97619 .34127 L
.65873 .34127 L
.34127 .34127 L
.34127 .65873 L
.34127 .97619 L
.02381 .97619 L
.02381 .65873 L
.34127 .65873 L
.65873 .65873 L
.65873 .34127 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 1.03333 0.539683 1.07302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 1.96429 0.47619 [
[ 0 0 0 0 ]
[ 1 2.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.96429 m
.5 1.96429 L
.97619 1.96429 L
.97619 2.44048 L
.5 2.44048 L
.5 1.96429 L
.5 1.4881 L
.5 1.0119 L
.5 .53571 L
.5 .05952 L
s
0 0 m
1 0 L
1 2.5 L
0 2.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 1.03333 0.626984 1.07302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.984127 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .98413 m
.34127 .98413 L
.65873 .98413 L
.65873 1.30159 L
.34127 1.30159 L
.34127 .98413 L
.65873 .98413 L
.97619 .98413 L
.97619 .66667 L
.97619 .34921 L
.97619 .03175 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 1.03333 0.714286 1.07302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00793651 0.31746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00794 m
.34127 .00794 L
.65873 .00794 L
.65873 .3254 L
.34127 .3254 L
.02381 .3254 L
.02381 .00794 L
.34127 .00794 L
.65873 .00794 L
.97619 .00794 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 1.03333 0.801587 1.07302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.5 .5 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.5 .5 L
.5 .97619 L
.97619 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 1.03333 0.888889 1.07302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.25 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .25 m
.2619 .25 L
.5 .25 L
.5 .4881 L
.2619 .4881 L
.2619 .25 L
.5 .25 L
.7381 .25 L
.97619 .25 L
.97619 .0119 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 1.03333 0.97619 1.07302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01587 m
.34127 .01587 L
.65873 .01587 L
.65873 .33333 L
.34127 .33333 L
.34127 .01587 L
.65873 .01587 L
.65873 .33333 L
.65873 .65079 L
.97619 .65079 L
.97619 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.07698 0.103175 1.11667 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .33333 m
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.65873 .33333 L
.97619 .33333 L
.97619 .01587 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 1.07698 0.190476 1.11667 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.5 .5 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.5 .5 L
.5 .97619 L
.97619 .97619 L
.97619 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 1.07698 0.277778 1.11667 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.5 .5 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.97619 .97619 L
.97619 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 1.07698 0.365079 1.11667 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0714286 0.952381 [
[ 0 0 0 0 ]
[ 1 3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .07143 m
.97619 .07143 L
.97619 1.02381 L
.02381 1.02381 L
.02381 .07143 L
.97619 .07143 L
.97619 1.02381 L
.97619 1.97619 L
.97619 2.92857 L
.97619 1.97619 L
s
0 0 m
1 0 L
1 3 L
0 3 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 1.07698 0.452381 1.11667 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .02381 m
.97619 .02381 L
.97619 .5 L
.5 .5 L
.5 .02381 L
.97619 .02381 L
.97619 .5 L
.5 .5 L
.02381 .5 L
.02381 .97619 L
.02381 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 1.07698 0.539683 1.11667 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.190476 0.0142857 0.190476 [
[ 0 0 0 0 ]
[ 1 .6 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.78571 .01429 m
.97619 .01429 L
.97619 .20476 L
.78571 .20476 L
.59524 .20476 L
.40476 .20476 L
.40476 .39524 L
.40476 .58571 L
.21429 .58571 L
.02381 .58571 L
s
0 0 m
1 0 L
1 .6 L
0 .6 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 1.07698 0.626984 1.11667 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.25 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .25 m
.97619 .25 L
.97619 .4881 L
.7381 .4881 L
.7381 .25 L
.7381 .0119 L
.5 .0119 L
.5 .25 L
.5 .4881 L
.2619 .4881 L
.02381 .4881 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 1.07698 0.714286 1.11667 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.25 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .25 m
.97619 .25 L
.97619 .4881 L
.7381 .4881 L
.5 .4881 L
.5 .25 L
.5 .0119 L
.5 .25 L
.5 .4881 L
.2619 .4881 L
.02381 .4881 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 1.07698 0.801587 1.11667 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.047619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .04762 m
.97619 .04762 L
.97619 .52381 L
.97619 1 L
.97619 1.47619 L
.97619 1.95238 L
.5 1.95238 L
.02381 1.95238 L
.02381 1.47619 L
.02381 1 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 1.07698 0.888889 1.11667 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0952381 0.952381 [
[ 0 0 0 0 ]
[ 1 4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .09524 m
.97619 .09524 L
.97619 1.04762 L
.97619 2 L
.97619 2.95238 L
.97619 3.90476 L
.02381 3.90476 L
.02381 2.95238 L
.02381 2 L
.02381 1.04762 L
s
0 0 m
1 0 L
1 4 L
0 4 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 1.07698 0.97619 1.11667 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.047619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .04762 m
.5 .04762 L
.5 .52381 L
.5 1 L
.5 1.47619 L
.5 1.95238 L
.02381 1.95238 L
.02381 1.47619 L
.5 1.47619 L
.97619 1.47619 L
.97619 1 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.12063 0.103175 1.16032 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00595238 0.238095 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00595 m
.2619 .00595 L
.5 .00595 L
.5 .24405 L
.2619 .24405 L
.2619 .00595 L
.5 .00595 L
.7381 .00595 L
.97619 .00595 L
s
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 1.12063 0.190476 1.16032 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01587 m
.34127 .01587 L
.65873 .01587 L
.65873 .33333 L
.34127 .33333 L
.34127 .01587 L
.65873 .01587 L
.65873 .33333 L
.65873 .65079 L
.97619 .65079 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 1.12063 0.277778 1.16032 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.25 0.238095 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .25 m
.97619 .25 L
.97619 .4881 L
.7381 .4881 L
.5 .4881 L
.2619 .4881 L
.02381 .4881 L
.02381 .25 L
.02381 .0119 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 1.12063 0.365079 1.16032 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.984127 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .98413 m
.97619 .98413 L
.97619 1.30159 L
.65873 1.30159 L
.65873 .98413 L
.65873 .66667 L
.34127 .66667 L
.02381 .66667 L
.02381 .34921 L
.02381 .03175 L
s
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 1.12063 0.452381 1.16032 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.5 .5 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.97619 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 1.12063 0.539683 1.16032 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015873 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01587 m
.34127 .01587 L
.34127 .33333 L
.34127 .65079 L
.02381 .65079 L
.02381 .33333 L
.34127 .33333 L
.65873 .33333 L
.97619 .33333 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 1.12063 0.626984 1.16032 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0357143 0.47619 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .03571 m
.5 .03571 L
.5 .5119 L
.5 .9881 L
.02381 .9881 L
.02381 .5119 L
.5 .5119 L
.5 .9881 L
.5 1.46429 L
.97619 1.46429 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 1.12063 0.714286 1.16032 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 3.92857 0.952381 [
[ 0 0 0 0 ]
[ 1 5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 3.92857 m
.97619 3.92857 L
.97619 4.88095 L
.02381 4.88095 L
.02381 3.92857 L
.02381 2.97619 L
.02381 2.02381 L
.02381 1.07143 L
.02381 .11905 L
s
0 0 m
1 0 L
1 5 L
0 5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 1.12063 0.801587 1.16032 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 1.47619 0.47619 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.47619 m
.5 1.47619 L
.5 1.95238 L
.02381 1.95238 L
.02381 1.47619 L
.5 1.47619 L
.97619 1.47619 L
.97619 1 L
.97619 .52381 L
.97619 .04762 L
s
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 1.12063 0.888889 1.16032 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.00793651 0.31746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .00794 m
.65873 .00794 L
.65873 .3254 L
.34127 .3254 L
.02381 .3254 L
.02381 .00794 L
.34127 .00794 L
.65873 .00794 L
.97619 .00794 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 1.12063 0.97619 1.16032 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .02381 m
.97619 .02381 L
.97619 .5 L
.5 .5 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.5 .5 L
.5 .97619 L
.97619 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.16429 0.103175 1.20397 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0119048 0.47619 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .0119 m
.5 .0119 L
.5 .4881 L
.02381 .4881 L
.02381 .0119 L
.5 .0119 L
.97619 .0119 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.111111 1.16429 0.190476 1.20397 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00793651 0.31746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00794 m
.34127 .00794 L
.65873 .00794 L
.65873 .3254 L
.34127 .3254 L
.34127 .00794 L
.65873 .00794 L
.97619 .00794 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.198413 1.16429 0.277778 1.20397 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.5 .5 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.5 .5 L
.97619 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.285714 1.16429 0.365079 1.20397 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0119048 0.47619 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .0119 m
.97619 .0119 L
.97619 .4881 L
.5 .4881 L
.02381 .4881 L
.02381 .0119 L
.5 .0119 L
.97619 .0119 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.373016 1.16429 0.452381 1.20397 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5 m
.5 .5 L
.5 .97619 L
.02381 .97619 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.97619 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.460317 1.16429 0.539683 1.20397 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00793651 0.31746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00794 m
.34127 .00794 L
.34127 .3254 L
.02381 .3254 L
.02381 .00794 L
.34127 .00794 L
.65873 .00794 L
.97619 .00794 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.547619 1.16429 0.626984 1.20397 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.5 .02381 L
.5 .5 L
.02381 .5 L
.02381 .02381 L
.5 .02381 L
.5 .5 L
.5 .97619 L
.97619 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.634921 1.16429 0.714286 1.20397 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0952381 0.952381 [
[ 0 0 0 0 ]
[ 1 4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .09524 m
.97619 .09524 L
.97619 1.04762 L
.97619 2 L
.97619 2.95238 L
.97619 3.90476 L
.02381 3.90476 L
.02381 2.95238 L
.02381 2 L
s
0 0 m
1 0 L
1 4 L
0 4 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.722222 1.16429 0.801587 1.20397 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.65873 .02381 m
.97619 .02381 L
.97619 .34127 L
.65873 .34127 L
.34127 .34127 L
.34127 .65873 L
.34127 .97619 L
.02381 .97619 L
.02381 .65873 L
.02381 .34127 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.809524 1.16429 0.888889 1.20397 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0119048 0.47619 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .0119 m
.5 .0119 L
.97619 .0119 L
.97619 .4881 L
.5 .4881 L
.02381 .4881 L
.02381 .0119 L
.5 .0119 L
.97619 .0119 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.896825 1.16429 0.97619 1.20397 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.333333 0.31746 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .33333 m
.34127 .33333 L
.65873 .33333 L
.65873 .65079 L
.34127 .65079 L
.34127 .33333 L
.34127 .01587 L
.65873 .01587 L
.97619 .01587 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[301]:=",
  ImageSize->{411.438, 507.438},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006K0001nb000`400?l00000o`00003oo`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00>`3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00h0oooo6000000H0?ooo`H000005@3oool9000000L0oooo2000000B0?ooo`L00000
8P3oool9000001<0oooo4@00000g0?ooo`T000006P3oool003/0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01X0oooo8000000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool0
03/0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`008`3oool700000140
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`008`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00l0oooo1P00000T0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool05P3oool6000001D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool002<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`008`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603ooolH000001l0oooo2@00000@
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3ooolA000001l0oooo00<00000
0?ooo`3oool06@3oool@000001<0oooo2@00000D0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool07P3oool9000001X0oooo000S0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01P0oooo000S0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo01P0oooo000S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3`3oool6000001D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool6000001D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0U0?ooo`H000005P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0H0?ooo`002P3o
oolP00000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0603oool0
03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04P3oool;000002P0oooo00<000000?ooo`3oool0603oool003/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool6000001D0oooo
2000000_0?ooo`T00000403oool6000001D0oooo2@00000W0?ooo`H000005P3oool8000001/0oooo
2@0000170?ooo`T000004P3oool00?l0ooooW03oool00?l0ooooW03oool000h0oooo6000000C0?oo
o`@000007P3oool5000002d0oooo2@00000@0?ooo`H000007P3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool07`3oool9000000l0oooo2@00000K0?oo
o`030000003oool0oooo0200oooo000F0?ooo`030000003oool0oooo0200oooo00@000000?ooo`3o
ool000007P3oool01@000000oooo0?ooo`3oool0000002d0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo000F0?ooo`030000003oool0oooo
0200oooo00@000000?ooo`3oool000007P3oool01@000000oooo0?ooo`3oool0000002d0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo000F
0?ooo`030000003oool0oooo0200oooo1000000N0?ooo`D00000;@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0200oooo1@00000X0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0P0?ooo`005P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0803oool001H0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`090?ooo`H00000103oool7000001<0oooo1P0000040?ooo`H0
0000703oool00`000000oooo0?ooo`0K0?ooo``000008@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0200oooo000F0?ooo`030000003oool0oooo02<0oooo1`00000L0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo0200oooo000F0?ooo`P00000903oool00`000000oooo0?ooo`0J0?ooo`T000005@3o
oolI000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`@000006P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo6000000?0?oooa4000004`3o
oolA00000180oooo000F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0J0?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0@0?ooo`005P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool06P3oool010000000oooo0?ooo`00000J0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0403oool001H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool7
000001P0oooo2`00000L0?ooo`040000003oool0oooo000001X0oooo1P00000H0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`005P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool06P3oool9
000001D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool06P3oool4000001X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0@0?ooo`005P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01X0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0100oooo000F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool01000
0000oooo0?ooo`00000J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool0
01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo
000001X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`005P3oool80000
0240oooo1000000H0?ooo`D000005P3oool8000000l0oooo2@00000E0?ooo`L000007@3oool60000
01`0oooo1000000J0?ooo`H00000603oool8000002L0oooo2@00000C0?oooa4000004P3oool00?l0
ooooW03oool00?l0ooooW03oool003H0oooo1P00000Q0?ooo`T000005@3ooolE000000T0oooo8000
000K0?ooo`T00000203oool@000001@0oooo200000160?ooo`H000008`3oool900000180oooo000k
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0100oooo000k0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0:P3oool<000001<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0@0?oo
o`002P3oool9000000L0oooo4000000A0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0@0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0@0?ooo`004P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0?0?ooo`H00000703oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01<0oooo1P00000>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0100oooo000B0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0403oool00180oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0J0?ooo`T00000:@3oool00`000000oooo0?ooo`070?ooo`T000001`3oool@0000
00@0oooo8000000@0?ooo`030000003oool0oooo00@0oooo2@00000C0?ooo`030000003oool0oooo
00D0oooo2@00000L0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0I0?oooa4000004P3oool00180oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool00180oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0603oool00180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool;000001l0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`H000005P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01P0oooo000B0?oooaP000004@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo8000000C0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo000k0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01P0oooo000k0?ooo`/00000403ooolH000001`0oooo1P00000A0?ooo`T000006`3o
ool00`000000oooo0?ooo`0/0?ooo`T000004`3ooolA000003/0oooo1P00000F0?ooo`T000006P3o
ool00?l0ooooW03oool001L0oooo1P00000E0?ooo`P000001`3oool900000180oooo1P00000S0?oo
o`T000006`3oool9000001T0oooo1000000G0?ooo`H00000A`3oool6000002D0oooo1@00000I0?oo
o`T000005P3oool001L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01L0oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool08`3oool01@000000oooo0?ooo`3oool0
000001T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`005`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05`3oool01000
0000oooo0?ooo`00000G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000006@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01@0oooo000G0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`@000005`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01L0oooo2`00000:0?ooo`/000004`3oool00`000000oooo0?ooo`0S
0?ooo`050000003oool0oooo0?ooo`0000006@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01@0oooo000G0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01l0oooo2@00000I0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0503oool001L0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool001L0
oooo1P00000L0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool6000002<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0E0?ooo`H000008`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool600000240
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0
oooo000G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0D0?ooo`005`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo4000
000O0?ooo`030000003oool0oooo01T0oooo4@00000C0?oooa400000703oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0G0?oooa4000005P3oool001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0T
0?ooo`005`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02@0oooo000G0?ooo`H0
00005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02D0oooo1P00000F0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`H0
0000703oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02@0oooo000G0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool05P3oool5000001T0oooo00<000000?ooo`3oool0
903oool001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool05`3oool4000001`0oooo00<000000?ooo`3oool05`3o
oolP000001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0903oool001L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0903oool0
01L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0903oool001L0oooo1P00000E0?ooo`P000009`3oool6000001H0
oooo2@00000K0?oooa400000703oool00`000000oooo0?ooo`0J0?oooa400000?03oool6000001`0
oooo00<000000?ooo`3oool05`3ooolH000000l0oooo003o0?oooi`0oooo000J0?ooo`H000007@3o
ool7000001/0oooo0`00000W0?ooo`T000005`3oool6000001h0oooo1000000L0?ooo`P000006P3o
ool6000002H0oooo1P00000C0?oooa4000004`3ooolA00000180oooo000O0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0403oool001l0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0@0?ooo`007`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0
oooo0`00000_0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool08@3oool4000002<0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`007`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`000000;`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool000008`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo000J0?ooo`H000007@3oool7000001/0oooo
0`00000_0?ooo`030000003oool0oooo0100oooo2`00000N0?ooo`040000003oool0oooo000002<0
oooo00<000000?ooo`3oool0603oool6000002H0oooo1P00000C0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0403oool001X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0L0?ooo`040000003oool0oooo000002<0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo000J0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool06@3oool7000002<0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0100oooo000J0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool07@3ooolA000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo01P0oooo6000000G0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo2@00
000C0?ooo`030000003oool0oooo00D0oooo2@00000B0?ooo`006P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0100oooo000J0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0403oool001@0oooo3000000M0?ooo`L000007@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`H0
00006`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo3000000E0?oooa40
00006`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo000D0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`00503o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0K0?ooo`@00000703oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01T0oooo1000000G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo000D0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool001@0
oooo1`00000M0?ooo``000007@3oool00`000000oooo0?ooo`0E0?oooaT000005`3oool6000001/0
oooo00<000000?ooo`3oool0603ooolH00000180oooo3000000E0?ooo`030000003oool0oooo02T0
oooo2@00000C0?oooa4000004P3oool00?l0ooooW03oool001L0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0>0?oooaP000005P3oool6000001L0oooo2@0000070?ooo`P00000703o
ool4000001@0oooo1P00000N0?ooo`/00000603oool700000200oooo1P00000M0?ooo`D00000703o
ool001L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0J0?ooo`005`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01X0oooo000G0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool06P3oool001L0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool=000001L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`D00000703oool001L0oooo1P00
000T0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0503oool6000001L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool08@3oool@000001@0oooo4000000C0?ooo``000005P3oool@000001P0oooo00D0
00000?ooo`3oool0oooo0000000L0?ooo`005`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0F0?ooo`050000003o
ool0oooo0?ooo`000000703oool001L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?oo
o`3oool0000001`0oooo000G0?ooo`030000003oool0oooo01P0oooo6000000O0?ooo`T000003P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo4@00000G0?ooo`T00000803o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0F0?ooo`D00000703oool001L0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo000G0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`005`3oool6000001D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0303oool6000001L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo01h0oooo2`00000N0?ooo`H000006@3oool;00000140
oooo00<000000?ooo`3oool0303oool6000001L0oooo00<000000?ooo`3oool06P3oool001L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool09@3oool500000240oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool0oooo1@00000D0?ooo`00
5`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0U0?ooo`050000003oool0oooo0?ooo`0000008@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool01@000000
oooo0?ooo`3oool0000001P0oooo000G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo00D000000?ooo`3o
ool0oooo0000000Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`000000603oool001L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool09@3oool01@000000oooo0?ooo`3oool000000240oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo0000
000H0?ooo`005`3oool6000001D0oooo2000000_0?ooo`T000003P3oool;00000180oooo4@00000O
0?ooo`D000008@3oool6000001h0oooo1P00000I0?ooo`030000003oool0oooo0080oooo1P00000P
0?ooo`H000005`3oool5000001P0oooo003o0?oooi`0oooo000J0?ooo`@000009`3oool900000380
oooo00<000000?ooo`3oool0;P3oool800000180oooo1@00000V0?ooo`H00000703oool9000000l0
oooo2@00000K0?ooo`030000003oool0oooo04@0oooo000J0?ooo`040000003oool0oooo000002L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04@0
oooo000J0?ooo`040000003oool0oooo000002L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo04@0oooo000J0?ooo`040000003oool0oooo000002L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo5P00000>0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo04@0oooo000F0?ooo`P000009`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`140?ooo`005P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`H00000:`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool07@3oool<00000240oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0b0?ooo`L000002`3oool001H0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool001H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool001H0oooo00<000000?ooo`3o
ool0903ooolA000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0Y0?ooo`P0
00004P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo6000000?0?oooa40
00004`3ooolA000002@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`00
5P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2@3oool001H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00`0oooo2`00000]0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603o
oolA00000180oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`005P3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`090?ooob0000002`3oool001H0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool=0000
0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0d0?ooo`005P3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0180oooo8000000>0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0
oooo00D000000?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0=03oool001H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0=03oool001H0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000J0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0=03oool001H0oooo1@00000C0?oooaP0
0000>P3oool;000000h0oooo8000000>0?ooo`D000006P3oool6000001d0oooo2000000W0?ooo`T0
00004`3ooolA000003H0oooo003o0?oooi`0oooo000:0?ooo`T000003P3oool9000000@0oooo4000
00070?ooo`T000002@3oool6000000T0oooo1`00000d0?ooo`H000009P3oool8000001`0oooo2000
000H0?ooo`@000008@3oool6000004@0oooo00<000000?ooo`3oool0603oool000X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo00@00000
0?ooo`3oool000008@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0603oool000X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00d0oooo1`00000;0?ooo`P000002`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00
000Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0H0?ooo`002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05P3oool400000240oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00L0oooo3000000C0?ooo`030000003oool0oooo01P0oooo000:0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01P0oooo000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`070?oooaH000003`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool6000002H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0O0?ooo`H000006`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool;000001D0oooo000:0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0H0?ooo`002P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0603o
ool000X0oooo800000040?ooob0000003P3oool00`000000oooo0?ooo`0G0?ooob000000403oool0
0`000000oooo0?ooo`0L0?oooa000000703oool8000001/0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo000B0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
01P0oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0L0?ooo`H00000503oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool04@3oool6000001D0oooo000B0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`004P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool00180oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool03`3ooolP000001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C
0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool04`3oool00180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`00
4P3oool900000280oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`170?ooo``00000
4`3oool@000001@0oooo4000000K0?ooo`@00000603ooolA000003l0oooo1P00000E0?ooo`00o`3o
oonL0?ooo`006`3oool5000001P0oooo2000000O0?ooo`/00000603oool<000001d0oooo1`00000K
0?oooa000000203oool9000004L0oooo1000000U0?ooo`D000009@3oool8000000/0oooo000K0?oo
o`030000003oool0oooo01X0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0@
0?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0;P3oool700000100oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo0100oooo000K0?ooo`030000003oool0oooo01X0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0403oool001@0oooo2000000L0?ooo`P000007`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool07P3oool9000002T0oooo00<000000?oo
o`3oool0403oool001@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0K0?oooa40
0000603oool<000001d0oooo1`00000K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0@0?ooo`00503oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0403oool001@0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0100oooo000D0?ooo`P000007`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo8000000@0?oooa0000006P3oool>
00000100oooo00<000000?ooo`3oool07P3oool900000140oooo8000000;0?ooo`006`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0>0?ooo`L000006P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0K0?ooo`L000007@3oool<00000280oooo1`00000C0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02@3oool001@0oooo2000
000O0?ooo`D000007`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`@000007@3oool5000001D0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`090?ooo`00503oool01@000000oooo0?ooo`3o
ool0000002H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`040000003o
ool0oooo000001d0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool02@3oool001@0oooo00D000000?ooo`3oool0oooo0000000V0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3ooolC000000H0oooo1`00000@0?ooo`04
0000003oool0oooo000001d0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool02@3oool001@0oooo1@00000V0?ooo`D000006`3oool60000
01d0oooo1`00000H0?oooa4000004`3oool9000001l0oooo4000000h0?ooo`@000007@3oool50000
01D0oooo8000000;0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`006P3oool6000001P0oooo1P00
000V0?ooo`H000007`3oool9000000l0oooo2@00000N0?ooo`030000003oool0oooo04@0oooo4@00
000F0?ooo`H000004@3oool8000002P0oooo1000000J0?ooo`006P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo02l0oooo1`00000>0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01/0oooo000J0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool06`3oool001X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0K0?ooo`006P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo01/0oooo000J0?ooo`H00000603oool<00000200oooo1P00000O0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01`0oooo2`00000W0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0=0?ooo`H000004@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo01/0oooo000O0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0K0?ooo`007`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool06`3oool001l0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo6@00000?0?oooa4000005P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303ooolP000000h0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0
oooo2000000X0?ooo`030000003oool0oooo01/0oooo000O0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool09P3oool7000001L0oooo000D0?ooo``000007@3oool00`000000oooo0?oo
o`0I0?oooa4000003`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0503oool;00000240oooo00<000000?ooo`3oool03P3oool;000001/0oooo3000
00040?ooo`H000004`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01D0oooo000D
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0E
0?ooo`00503oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02H0oooo1`00000G0?oo
o`00503oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3o
ool000006P3oool001@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0V0?ooo`04
0000003oool0oooo000001X0oooo000D0?ooo`L000008P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00d0oooo2@00000W0?ooo`T000005P3oool00`000000oooo0?ooo`0j0?ooo`H0
0000803oool6000000l0oooo1P00000>0?oooaT00000403oool4000001X0oooo003o0?oooi`0oooo
003o0?oooi`0oooo000H0?ooo`@00000903oool6000001h0oooo00<000000?ooo`3oool06P3ooolA
000000l0oooo3@00000I0?ooo`D00000A03oool4000002H0oooo1000000J0?ooo`D000008`3oool6
000001D0oooo000H0?ooo`040000003oool0oooo000002@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`000000A03oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo0000000S0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04`3oool001P0oooo00@000000?ooo`3oool00000
903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0
oooo000000140?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool06`3oool01@000000
oooo0?ooo`3oool0000002<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?oo
o`00603oool010000000oooo0?ooo`00000T0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool05`3oool01@000000oooo0?ooo`3oool0000004@0oooo00<000000?ooo`3oool08@3oool7
000001d0oooo00D000000?ooo`3oool0oooo0000000S0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool04`3oool001P0oooo1000000T0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo1@00000E
0?ooo`050000003oool0oooo0?ooo`0000005@3ooolP000000l0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0Q0?ooo`D000008`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01<0oooo000H0?ooo`040000003oool0oooo000001l0oooo2`00000C0?oooa4000005`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000005@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo01`0oooo2`00000E0?ooo`00603oool010000000oooo0?oo
o`00000O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Q0?ooo`L0
00008@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo000H0?ooo`040000
003oool0oooo000001l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool08`3oool01@000000oooo0?ooo`3oool00000
01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01d0oooo000H0?ooo`@000007`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool04P3ooolI000000l0oooo00<000000?ooo`3oool08`3oool010000000
oooo0?ooo`3oool500000140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0V0?oo
o`L000008`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool07@3oool001/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`00
6`3oool00`000000oooo0?ooo`0H0?ooo`H00000103oool6000001<0oooo1`0000040?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo01`0oooo1P00000J0?ooo`00603oool4000001X0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00d0oooo1@00000Q0?ooo`D000000`3o
ool4000000h0oooo1`00000^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool07`3o
ool5000001X0oooo00<000000?ooo`3oool07@3oool001P0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool03@3oool0
1@000000oooo0?ooo`3oool000000240oooo00D000000?ooo`3oool0oooo0000001:0?ooo`030000
003oool0oooo0240oooo1000000N0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
7@3oool001P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000240oooo
00D000000?ooo`3oool0oooo0000001:0?ooo`<000008@3oool010000000oooo0?ooo`00000N0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool001P0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool03@3oool01@000000oooo0?ooo`3oool000000240oooo00D000000?ooo`3oool0oooo0000001:
0?ooo`030000003oool000000240oooo00@000000?ooo`3oool000007P3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01d0oooo000H0?ooo`@000006P3oool6000002P0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0=0?ooo`D000008@3oool5000004X0oooo0`00000Q
0?ooo`@000007P3oool5000001X0oooo1P00000J0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00
7@3oool900000100oooo2000000K0?oooa400000@`3oool00`000000oooo0?ooo`0A0?oooaP00000
5@3oool6000002@0oooo2@00000=0?ooo`H00000:`3oool00`000000oooo0?ooo`0J0?ooo`T00000
5P3oool001d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01@0oooo000M0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0D0?ooo`007@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0503oool001d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3ooolP000001L0
oooo1@00000V0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo000M0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0C0?ooo`H00000903oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00/0oooo1P00000P0?ooo`H000001@3oool6000001L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`007@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool000h0oooo6000000@
0?oooa0000004`3ooolA000000`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04@3ooolH000001X0oooo00<00000
0?ooo`3oool04`3ooolH00000180oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3ooolH000000l0oooo000>0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?oo
o`003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03@3oool000h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0280oooo1P00000E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
803ooolA00000100oooo1P0000050?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02P3oool700000140oooo2000000;0?ooo`d000004`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0e0?ooo`050000003oool0
oooo0?ooo`0000006`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo000>
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0e
0?ooo`050000003oool0oooo0?ooo`0000006`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00d0oooo000>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0e0?ooo`050000003oool0oooo0?ooo`0000006`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00d0oooo000>0?ooo`T000009P3oool9000001/0oooo2@00000g
0?ooo`D000006`3oool9000002@0oooo1P00000E0?ooo`P00000;03oool7000001D0oooo1`00000T
0?ooo`P000003`3oool00?l0ooooW03oool00?l0ooooW03oool001P0oooo100000150?ooo`030000
003oool0oooo0240oooo1@00000n0?ooo`030000003oool0oooo02T0oooo2@00000@0?ooo`P00000
6`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
403oool001P0oooo00@000000?ooo`3oool00000A@3oool00`000000oooo0?ooo`0Q0?ooo`050000
003oool0oooo0?ooo`000000?P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0100
oooo000H0?ooo`040000003oool0oooo000001`0oooo00<000000?ooo`3oool0203oool;000001<0
oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?oo
o`3oool0203ooolE000000l0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0@0?oo
o`00603oool4000001`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool00000
00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
0100oooo000K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07@3oool9000000l0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0100
oooo000K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00`0oooo1P00000O0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03@3oool6000002H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0403oool001/0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0100oooo000K
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3ooolH00000100oooo00<00000
0?ooo`3oool0103oool9000001<0oooo00<000000?ooo`3oool01@3oool9000001P0oooo00<00000
0?ooo`3oool0703ooolA00000180oooo000K0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0603oool001/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`00
6`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0A0?ooo`H000006P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo2`00000B0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0F0?ooo`L00000603oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01P0oooo000K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0H0?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0603oool001/0oooo00<000000?ooo`3oool0403ooolP0000
01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
01D0oooo8000000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo000K0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0603oool001/0oooo00<000000?ooo`3oool0@`3oool6000001X0oooo
00<000000?ooo`3oool0A03oool;00000180oooo00<000000?ooo`3oool0;03oool9000001<0oooo
4@00000H0?ooo`L00000603oool9000001X0oooo003o0?oooi`0oooo003o0?oooi`0oooo000D0?oo
o`030000003oool0oooo02@0oooo4000000F0?ooo`H000006P3oool9000001`0oooo3000000H0?oo
o`/00000703oool@000000P0oooo2000000R0?ooo`H000008`3oool9000001/0oooo2@00000B0?oo
o`00503oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool001@0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo000D0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0603oool9000001`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0403oool001@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0403oool001@0oooo00<000000?ooo`3oool00`3o
ool6000001/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0I0?oooa400000603o
ool;000001`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0803oool6000002<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403o
ool001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0100oooo000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0?0?ooob0000003`3ooolA000001L0oooo00<000000?ooo`3oool06@3ooolA0000
01/0oooo2@00000B0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0403oool001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0100oooo000D0?ooo``00000403oool<000001/0oooo2`00
00040?ooo`L00000603oool00`000000oooo0?ooo`0I0?ooo`H000007P3oool;000001T0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0403oool001@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo01H0oooo1@00000L0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`00503oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?oo
o`00503oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0@0?ooo`00503oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`00503o
ool00`000000oooo0?ooo`0I0?ooo`L00000803oool6000000l0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0T0?oooa4000005`3oool6000001H0oooo2@00000K0?oooa4000004P3o
ool00?l0ooooW03oool001P0oooo1000000T0?ooo`H00000803oool00`000000oooo0?ooo`0F0?oo
o`d000006@3oool5000001l0oooo1@00000S0?ooo`H000007@3oool7000001/0oooo1P00000T0?oo
o`T000003`3oool9000001X0oooo000H0?ooo`040000003oool0oooo000002@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`0000007`3oool0
1@000000oooo0?ooo`3oool0000002<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool001P0oooo00@00000
0?ooo`3oool00000903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00D0
00000?ooo`3oool0oooo0000000O0?ooo`050000003oool0oooo0?ooo`0000008`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0H0?ooo`00603oool010000000oooo0?ooo`00000T0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool05`3oool01@000000oooo0?ooo`3oool0000001l0oooo00D000000?oo
o`3oool0oooo0000000S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo000H0?ooo`@00000903oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0oooo0000000O
0?ooo`D000008`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`00603oool010000000oooo0?ooo`00000T
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo0000000S0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0603oool001P0oooo00@000000?ooo`3oool000007`3o
ool;000001H0oooo2`00000H0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo
0000000S0?ooo`030000003oool0oooo01/0oooo3000000M0?ooo`L000006`3oool6000002@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0603oool001P0oooo00@000000?ooo`3oool000007`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000008`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01P0oooo000H0?ooo`@000007`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0S0?ooo`040000
003oool0oooo0?ooo`D000007`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?oooaT000003`3oool00`000000
oooo0?ooo`050?ooo`T000004P3oool001/0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0@0?ooo`006`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo000K
0?ooo`030000003oool0oooo01P0oooo1P0000040?ooo`H000005P3oool6000000@0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`L000007@3oool<00000200oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0403oool001P0oooo1000000J0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool05P3oool500000240oooo1@0000030?ooo`030000003oool0oooo01d0oooo1@00000I0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?oo
o`00603oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool05P3oool01@000000oooo0?ooo`3oool000000240oooo00D000000?ooo`3oool0oooo0000000S
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0100oooo000H0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000008@3oool0
1@000000oooo0?ooo`3oool0000002<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool001P0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01H0oooo00D00000
0?ooo`3oool0oooo0000000Q0?ooo`050000003oool0oooo0?ooo`0000008`3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0@0?ooo`00603oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool05P3oool500000240oooo1@00000S0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0;@3oool900000180oooo003o0?oooi`0oooo000f0?ooo`P000009`3oool90000
00l0oooo2@00000K0?oooa400000A03oool00`000000oooo0?ooo`0I0?ooo`H00000903oool90000
00d0oooo1P00000]0?ooo`030000003oool0oooo01<0oooo000m0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0
oooo000m0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo01<0oooo000D0?oooaH000004`3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0C0?ooo`007`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool04`3oool001l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3ooolP000001T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0C0?ooo`007`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01T0oooo1P00000T0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02`3oool6000002<0oooo1P0000040?ooo`030000003oool0oooo01<0oooo000O0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`007`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo4000000@0?oooaP000003`3o
oolA000001<0oooo4@00000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3o
oolH00000180oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04`3oool001l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo000O0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`007`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`090?ooo`L000004P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01T0
oooo1P00000E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool@000001@0
oooo1P0000040?ooo`030000003oool0oooo01<0oooo000O0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03L0oooo
3000000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01<0oooo000:0?ooob0000004`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo03L0oooo00D000000?ooo`3oool0oooo0000000R0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01<0oooo000m0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0=`3o
ool01@000000oooo0?ooo`3oool000000280oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool003d0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`000000
8P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0C0?ooo`00?@3oool900000100oooo2000000W0?ooo`T000006`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03L0oooo1@00000R0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0703oool6000001D0oooo003o0?oooi`0oooo000>0?oo
oa000000503ooolH000003H0oooo2`00000J0?oooa000000?03oool600000240oooo2@00000?0?oo
o``00000603ooolA000001<0oooo4@00000B0?ooo`005P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`00
5P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool>000002H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0403oool001H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo000F0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`005P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo8000000C0?ooo`H000008P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0N0?ooo``000008@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01<0oooo1P00000P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo000F0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`005P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool001H0oooo4000
000C0?oooa4000003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0403ooolH000000h0oooo2000000V0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool05`3ooolA000001X0oooo00<000000?ooo`3oool05P3ooolA000001/0oooo2@00
000B0?ooo`007@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0@0?ooo`007@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0@0?oo
o`007@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool02`3oool6000002P0oooo1P00000J0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0903oool6000001T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo0100oooo000M0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0100oooo000M0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo0100oooo000M0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool08P3ooolC
000001T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0403oool001d0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo0100oooo000M0?ooo`T000008`3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0B@3oool600000180
oooo200000070?ooo`T000006P3oool6000001<0oooo2@00000K0?oooa4000004P3oool00?l0oooo
W03oool00180oooo1P0000040?ooo`030000003oool0oooo01d0oooo1000000Q0?ooo`D00000:`3o
ool00`000000oooo0?ooo`0=0?ooo`T000001`3oool00`000000oooo0?ooo`0>0?ooo`L000002@3o
ool6000001/0oooo1P00000N0?ooo`H000007P3oool6000001d0oooo1@00000U0?ooo`P000002`3o
ool001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`040000003oool0
oooo00000240oooo00D000000?ooo`3oool0oooo0000000[0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo
000G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool010000000oooo0?oo
o`00000Q0?ooo`050000003oool0oooo0?ooo`000000:`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`00
5`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo1000000Q0?ooo`050000
003oool0oooo0?ooo`000000:`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`005`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool06`3oool9000002/0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`T00000;03oool00`000000oooo
0?ooo`090?ooo`005`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo2`00
000F0?ooo`/00000503oool@000001T0oooo2`00000I0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool02@3oool001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02@3oool001L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool02@3oool001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool08@3ooolA000000l0oooo4@00000F0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo01d0oooo1@00000E0?ooob0000002`3oool001L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0M0?ooo`050000003oool0oooo0?ooo`0000007@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo000G0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool07@3oool01@000000oooo0?ooo`3oool0000001d0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0H0?ooo`005`3oool;000001d0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
6@3oool;000001T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?oooa400000
5@3oool01@000000oooo0?ooo`3oool0000001d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0H0?ooo`00703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool07@3oool5000001d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0H0?ooo`00703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0603oool001`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01P0oooo000L0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`00703oool6000001d0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0I0?oooaT000003`3ooolA000001H0oooo1P00000K0?ooo`H0
00007P3oool6000001d0oooo1`00000S0?ooo`D000006@3oool9000001X0oooo003o0?oooi`0oooo
000^0?ooo`T000001P3oool00`000000oooo0?ooo`0Q0?ooo`D000006`3oool5000001l0oooo1@00
000M0?ooo`D000008@3oool5000002X0oooo00<000000?ooo`3oool05@3oool5000001l0oooo2@00
000T0?ooo`030000003oool0oooo01<0oooo000f0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool05@3oool01@000000oooo0?ooo`3oool0000001l0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool04`3oool001d0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01D0oooo00D0
00000?ooo`3oool0oooo0000000O0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo01<0oooo000M0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`00
00007`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0C0?ooo`007@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool07@3oool5000000<0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo01D0oooo1@0000030?ooo`030000003oool0oooo01T0
oooo1@0000030?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool04`3oool001d0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo
00D000000?ooo`3oool0oooo0000000O0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01T0oooo4000000K0?ooo`05
0000003oool0oooo0?ooo`0000008`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01<0oooo000M0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0Q0?ooo`050000003oool0oooo0?ooo`0000007`3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?oo
o`050000003oool0oooo0?ooo`0000008`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo01<0oooo000M0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0Q0?ooo`050000003oool0oooo0?ooo`0000007`3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I
0?ooo`050000003oool0oooo0?ooo`0000008`3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo01<0oooo000M0?ooo`030000003oool0oooo00<0oooo1`00000<0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool9000001<0oooo00D000000?ooo`3oool0oooo0000
000O0?ooo`D000006`3oool9000001d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0I0?ooo`D000008`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01<0oooo000M
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3o
ool0000001l0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`050000003oool0oooo0?ooo`00
00008@3oool00`000000oooo0?ooo`0O0?ooo`D000006`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool04`3oool001d0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo0?ooo`0000007`3oool01@000000
oooo0?ooo`3oool0000001/0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003oool0
oooo01l0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`H000002@3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool04P3ooolF00000100oooo000M
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3o
ool0000001l0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`050000003oool0oooo0?ooo`00
00008@3oool00`000000oooo0?ooo`0O0?ooo`050000003oool0oooo0?ooo`000000:P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo000M0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool0000001/0oooo2@00000K0?oo
o`050000003oool0oooo0?ooo`0000007@3oool=000001T0oooo00D000000?ooo`3oool0oooo0000
000Z0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool001d0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo0?ooo`0000006`3o
ool01@000000oooo0?ooo`3oool0000001l0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`05
0000003oool0oooo0?ooo`0000008@3oool5000002X0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0>0?ooo`002P3ooolP000000`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00D000000?ooo`3oool0oooo0000000K0?oo
o`050000003oool0oooo0?ooo`0000007`3oool01@000000oooo0?ooo`3oool0000001d0oooo00D0
00000?ooo`3oool0oooo0000000U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`00=P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool0000001/0oooo
00D000000?ooo`3oool0oooo0000000O0?ooo`050000003oool0oooo0?ooo`0000007@3oool01@00
0000oooo0?ooo`3oool0000002D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00h0oooo000f0?oooaP000004`3oool5000001/0oooo1@00000O0?oo
o`D000007@3oool5000002D0oooo1000000W0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`H00000403oool00?l0ooooW03oool001@0oooo
3000000L0?ooo`030000003oool0oooo02d0oooo1P00000K0?ooo`H000003P3ooolA000001P0oooo
1000000V0?ooo`030000003oool0oooo0380oooo200000070?ooo`T000004`3ooolA000001P0oooo
1`00000G0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00@0
00000?ooo`3oool000009P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool05@3oool001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0L0?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0803oool800000140
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0E0?ooo`00503oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo1000000V0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`L000005`3oool001@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0603oool001@0oooo1`00000Q0?ooo`030000003oool0oooo0280oooo4@00
00060?ooo`H00000103ooolA000000h0oooo1P0000040?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool04@3oool<000000@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0H0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0O0?ooo`@000008`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0I
0?ooo`@000005`3oool001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool05@3oool001@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0103oool7000000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`T0
00006`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01D0oooo000D0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0E0?ooo`00503o
ool700000240oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool05@3oool001X0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0E0?ooo`006P3oool00`000000oooo0?ooo`0O0?ooo`@000008@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01d0oooo2000000R0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0E0?ooo`006P3oool00`000000
oooo0?ooo`0O0?ooo`040000003oool0oooo00000240oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0M0?ooo`050000003oool0oooo0?ooo`0000009@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05@3oool001X0oooo00<000000?oo
o`3oool07`3oool010000000oooo0?ooo`00000Q0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool07@3oool01@000000oooo0?ooo`3oool0000001<0oooo4`0000060?ooo`L000002`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05@3o
ool001X0oooo00<000000?ooo`3oool07`3oool010000000oooo0?ooo`00000Q0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool07@3oool01@000000oooo0?ooo`3oool0000003h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01D0oooo
000J0?ooo`030000003oool0oooo01l0oooo1000000B0?oooa0000006`3oool6000002P0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0M0?ooo`D00000?P3oool9000000L0oooo2@00
000K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05@3oool00?l0ooooW03oool0
01d0oooo2@0000080?ooo`T00000:03oool6000002@0oooo2@00000B0?ooo`H000008`3oool80000
01`0oooo2000000g0?ooo`T000007P3oool6000002<0oooo1P00000E0?ooo`007@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0C0?ooo`007@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`007@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01l0oooo2`00000C0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool04`3oool001d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01<0oooo000M0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02H0oooo1P00000T0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool6000002<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo2`00000E0?oo
o`007@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000M0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0603oool000h0oooo600000080?ooo`T00000:03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo4@00000G0?ooo`030000003o
ool0oooo01T0oooo4000000L0?ooo`P000008@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0140oooo2@00000F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo02H0oooo1P00000L0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool00P3oool6000001T0oooo1P00000J0?ooo`005P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo00X0oooo8000000C0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?oo
o`3oool07@3ooolH00000140oooo1P00000D0?ooo`T000001`3oool9000001L0oooo1P00000F0?oo
o`T000006`3oool@000003l0oooo2@00000F0?ooo`030000003oool0oooo0080oooo1P00000N0?oo
o`030000003oool0oooo01P0oooo003o0?oooi`0oooo003o0?oooi`0oooo000K0?ooo`030000003o
ool0oooo01@0oooo2000000?0?ooo`030000003oool0oooo0100oooo1P00000N0?ooo`H000008@3o
ool500000240oooo1P00000Q0?ooo`T00000403oool8000001/0oooo4@00000l0?ooo`H00000603o
ool001/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01H0oooo000K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool05P3oool001@0oooo2000000M0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01l0oooo
1@00000V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0403oool6000001h0oooo2`00000L0?ooo`050000003oool0oooo0?ooo`000000
8@3oool6000002T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00X0oooo8000000@0?ooo`H00000603oool001@0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`0000008@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool06P3oool01@000000oooo0?ooo`3oool000000240oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0F0?ooo`00503oool8000001H0oooo6000000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool06P3oool500000240oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?oooaP00000403oool@000001<0oooo4@00000<0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0F0?ooo`006`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0803oool6000000@0oooo00<000000?ooo`3oool05`3oool60000
00@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0J0?ooo`/000004P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0W0?ooo`H00000603oool001/0oooo1@00000B0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0:0?ooo`L00000;P3oool00`000000
oooo0?ooo`0F0?ooo`006`3oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool05P3oool001/0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01H0
oooo000K0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0F0?ooo`00
6`3oool500000180oooo2000000W0?ooo`H000008`3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool9000002H0oooo2@00000S0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool05P3oool00?l0ooooW03oool00?l0ooooW03oool0
00h0oooo6000000B0?ooo``000005@3ooolA00000140oooo4000000B0?oooaP00000303ooolH0000
00d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`110?ooo`T000006P3oool00`00
0000oooo0?ooo`0M0?ooo`005P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool07@3oool001H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0180oooo8000000?0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0M0?ooo`005P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo01d0oooo000F0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool07@3oool001H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01D0oooo1`00000M0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0M0?ooo`005P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0M0?ooo`00
5P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0M0?ooo`005P3oool8000000L0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0C0?oooa400000803oool00`000000oooo0?ooo`0H0?oooa000000503o
ool9000001@0oooo00<000000?ooo`3oool0703oool@000000L0oooo2@0000040?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool08P3oool9000001X0oooo00<000000?ooo`3oool07@3o
ool002D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0H0?ooo`L000006@3oool0
02D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
02h0oooo1P00000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03@3oool60000
00T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01L0oooo000U0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05`3oool002D0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool07P3oool4000001H0oooo000U0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo2`00
000/0?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3oool000005P3oool002D0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`0N0?ooo`040000003oool0oooo000001H0oooo
000U0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0^0?ooo`H000005@3oool9000001/0oooo2@00000D0?oooaH000002@3ooolP000002/0oooo6@00
000H0?ooo`@000005P3oool00?l0ooooW03oool00?l0ooooW03oool001`0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0N0?ooo`L00000403oool00`000000oooo0?ooo`080?ooo`H0
00007@3oool7000001/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0g0?oooa40
0000:`3oool00`000000oooo0?ooo`050?oooa4000005P3oool001`0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0D0?ooo`00703oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00`0oooo8000000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0D0?ooo`00703oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`00703oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0D0?ooo`00703oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool01`3oool<00000100oooo00<000000?ooo`3oool00P3oool<000001P0
oooo3000000K0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo000L0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`00703oool00`000000oooo0?oo
o`0G0?oooa0000004@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?oooa400000303ooolP000000l0oooo2@00
00060?ooo`030000003oool0oooo00d0oooo000L0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo000L0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00d0oooo000B0?oooa000000503oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`/0
00008@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03@3oool001`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo01/0oooo3000000>0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo000L0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool08@3oool7000001h0oooo00@000000?ooo`3oool00000
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0=0?ooo`00703oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02@0oooo00@000000?ooo`3oool000007P3oool010000000oooo0?ooo`00000B0?oooaH0
00007@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo000L0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000N0?ooo`04
0000003oool0oooo000004D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?oo
o`00703oool6000001@0oooo4000000A0?ooo`/000006`3oool6000001h0oooo1P00000V0?ooo`@0
00007P3oool4000004D0oooo2@00000C0?ooo`T000009`3oool8000000l0oooo003o0?oooi`0oooo
003o0?oooi`0oooo000U0?ooo`030000003oool0oooo00h0oooo2000000K0?oooa400000603oool7
00000200oooo2@00000R0?ooo`L000005P3oool8000001/0oooo00<000000?ooo`3oool08@3oool5
000001d0oooo1@00000M0?ooo`D000006P3oool002D0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0H0?ooo`009@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01P0
oooo000U0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0603oool002D0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01/0oooo00D0
00000?ooo`3oool0oooo0000000Q0?ooo`030000003oool0oooo01P0oooo000U0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`L00000803o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo4@00000F0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo01/0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003oool0oooo01P0oooo
000U0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool06`3oool01@000000oooo0?oo
o`3oool000000240oooo00<000000?ooo`3oool0603oool000h0oooo6000000@0?ooo`P000001`3o
ool00`000000oooo0?ooo`0A0?ooo`T000001`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01H0oooo4@00000H0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103o
ool9000001<0oooo00<000000?ooo`3oool01@3oool9000000l0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`050000003oool0oooo0?ooo`0000008@3oool01@000000oooo
0?ooo`3oool0000001H0oooo000>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0K0?ooo`050000003oool0oooo0?ooo`0000008@3oool01@000000
oooo0?ooo`3oool0000001H0oooo000>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0K0?ooo`050000003oool0oooo0?ooo`0000008@3oool01@00
0000oooo0?ooo`3oool0000001H0oooo000>0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0K0?ooo`050000003oool0oooo0?ooo`0000008@3oool0
1@000000oooo0?ooo`3oool0000001H0oooo000>0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0K0?ooo`050000003oool0oooo0?ooo`0000007@3o
ool9000001H0oooo000>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0K0?ooo`050000003oool0oooo0?ooo`0000007@3oool01@000000oooo0?oo
o`3oool0000001X0oooo000>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`050000003oool0oooo0?ooo`0000007@3oool01@000000oooo
0?ooo`3oool0000001X0oooo000>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0K0?ooo`050000003oool0oooo0?ooo`0000007@3oool01@000000
oooo0?ooo`3oool0000001X0oooo000>0?ooo`T000009P3oool9000002<0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01`0oooo2`00000F0?oooa40
00001P3oool9000000@0oooo8000000?0?ooo`T000007@3oool5000001d0oooo1@00000J0?ooo`00
o`3ooonL0?ooo`00o`3ooonL0?ooo`00<P3oool@00000100oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0O0?oooa4000003`3oool900000240oooo1`00000Q0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0>@3ooolA00000180oooo000i0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0100oooo000i0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00h0oooo8000000;0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`002P3ooolP000000l0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo
000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00180oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01l0oooo1`00000Q
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0100oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01`0oooo2@00000@0?ooo`030000003oool0oooo01@0oooo2@00000=0?ooo`T0
00006@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo6000000B0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0D0?oooa40
00004P3oool00180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`004P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo000B0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01l0oooo1`00000Q0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0603oool0
0180oooo2@00000V0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0C0?ooo`D000005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool07P3oool900000100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00110?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?oo
o`0000005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01l0oooo1000000M0?oo
o`050000003oool0oooo0?ooo`000000503ooolE000001h0oooo00<000000?ooo`3oool0603oool0
0440oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01<0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool07`3oool010000000oooo0?ooo`00000M0?ooo`050000003oool0oooo0?ooo`000000
A`3oool00`000000oooo0?ooo`0H0?ooo`00@@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0000001D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000001d0
oooo00D000000?ooo`3oool0oooo000000170?ooo`030000003oool0oooo01P0oooo00110?ooo`T0
0000203ooolP000001D0oooo1@00000E0?ooo`T000005`3oool9000002L0oooo1P00000L0?ooo`@0
00007@3oool5000004L0oooo2@00000B0?ooo`00o`3ooonL0?ooo`002P3ooolP000002l0oooo2@00
000D0?ooob0000002`3ooolA000003L0oooo2@00000P0?ooo`D00000903oool6000000`0oooo8000
000?0?oooa0000003`3oool000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0703oool000X0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0703oool000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooob00
00004`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0I0?ooob000000303oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0L0?ooo`00
2P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01`0oooo000:0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0703oool000X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`030?ooo`/00000303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0703oool000X0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01`0oooo000:0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01<0
oooo4@00000<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02@3oool9000001<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`T00000803oool01@000000
oooo0?ooo`3oool0000001T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01@3ooolA000001H0oooo000:0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`002P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000006@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool000X0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool07P3oool01@000000oooo0?ooo`3oool0000001T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo000:0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01h0
oooo00D000000?ooo`3oool0oooo0000000I0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`002P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo01/0oooo3000000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0A0?ooo``00000:03oool00`000000oooo0?ooo`0N0?ooo`05
0000003oool0oooo0?ooo`0000006@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0503oool000X0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo0000000I0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?oo
o`002P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool07P3oool01@000000oooo0?ooo`3oool0000001T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo000:0?oooa400000?P3oool9000001@0
oooo8000000;0?ooo`T00000A`3oool8000001T0oooo1@00000I0?ooo`L000005P3ooolP000000l0
oooo2@00000F0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?oo
o`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?oo
o`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 410.438}, {506.438, 0}} -> {-0.275057, -0.342511, \
0.028141, 0.028141}, {{9.75, 42.3125}, {494.25, 477.938}} -> {-5.69702, \
-2.78003, 0.16123, 0.16123}, {{45.5625, 78.125}, {494.25, 477.938}} -> \
{-11.4424, -4.42849, 0.193105, 0.193105}, {{81.4375, 114}, {494.25, 477.938}} -> \
{-11.0801, -2.619, 0.128738, 0.128738}, {{117.25, 149.813}, {494.25, \
477.938}} -> {-18.2234, -2.62402, 0.128984, 0.128984}, {{153.063, 185.625}, \
{494.25, 477.938}} -> {-32.2012, -3.42849, 0.193105, 0.193105}, {{188.875, \
221.5}, {494.25, 477.938}} -> {-24.9154, -1.619, 0.128738, 0.128738}, \
{{224.75, 257.313}, {494.25, 477.938}} -> {-46.5445, -4.42849, 0.193106, \
0.193106}, {{260.563, 293.125}, {494.25, 477.938}} -> {-34.64, -2.61899, \
0.128737, 0.128737}, {{296.375, 329}, {494.25, 477.938}} -> {-39.2545, \
-2.61899, 0.128737, 0.128737}, {{332.25, 364.813}, {494.25, 477.938}} -> \
{-32.2163, -1.46802, 0.0967381, 0.0967381}, {{368.063, 400.625}, {494.25, \
477.938}} -> {-48.4793, -1.61899, 0.128737, 0.128737}, {{9.75, 42.3125}, \
{476.313, 460.063}} -> {-2.86409, -4.94315, 0.129233, 0.129233}, {{45.5625, \
78.125}, {476.313, 460.063}} -> {-18.4805, -9.85785, 0.323081, 0.323081}, \
{{81.4375, 114}, {476.313, 460.063}} -> {-23.7568, -7.88624, 0.258464, \
0.258464}, {{117.25, 149.813}, {476.313, 460.063}} -> {-18.2565, -4.94313, \
0.129232, 0.129232}, {{153.063, 185.625}, {476.313, 460.063}} -> {-33.327, \
-7.9147, 0.193848, 0.193848}, {{188.875, 221.5}, {476.313, 460.063}} -> \
{-40.2752, -7.9147, 0.193848, 0.193848}, {{224.75, 257.313}, {476.313, \
460.063}} -> {-62.298, -10.8863, 0.258464, 0.258464}, {{260.563, 293.125}, \
{476.313, 460.063}} -> {-52.6657, -7.9147, 0.193848, 0.193848}, {{296.375, \
329}, {476.313, 460.063}} -> {-40.9095, -3.94315, 0.129233, 0.129233}, \
{{332.25, 364.813}, {476.313, 460.063}} -> {-45.0415, -4.94313, 0.129232, \
0.129232}, {{368.063, 400.625}, {476.313, 460.063}} -> {-49.6696, -4.94313, \
0.129232, 0.129232}, {{9.75, 42.3125}, {458.375, 442.125}} -> {-3.35762, \
-6.7473, 0.128984, 0.128984}, {{45.5625, 78.125}, {458.375, 442.125}} -> \
{-11.4883, -11.3919, 0.193848, 0.193848}, {{81.4375, 114}, {458.375, \
442.125}} -> {-12.1285, -6.26126, 0.129233, 0.129233}, {{117.25, 149.813}, \
{458.375, 442.125}} -> {-23.8848, -9.39185, 0.193848, 0.193848}, {{153.063, \
185.625}, {458.375, 442.125}} -> {-19.8847, -6.26123, 0.129232, 0.129232}, \
{{188.875, 221.5}, {458.375, 442.125}} -> {-27.5168, -6.26123, 0.129232, \
0.129232}, {{224.75, 257.313}, {458.375, 442.125}} -> {-31.6492, -7.26126, \
0.129233, 0.129233}, {{260.563, 293.125}, {458.375, 442.125}} -> {-36.2773, \
-7.26126, 0.129233, 0.129233}, {{296.375, 329}, {458.375, 442.125}} -> \
{-30.6908, -4.92506, 0.0965528, 0.0965528}, {{332.25, 364.813}, {458.375, \
442.125}} -> {-67.5622, -11.3919, 0.193848, 0.193848}, {{368.063, 400.625}, \
{458.375, 442.125}} -> {-48.6696, -7.26123, 0.129232, 0.129232}, {{9.75, \
42.3125}, {440.5, 424.188}} -> {-4.52677, -13.8079, 0.193105, 0.193105}, \
{{45.5625, 78.125}, {440.5, 424.188}} -> {-6.46162, -8.53865, 0.128738, \
0.128738}, {{81.4375, 114}, {440.5, 424.188}} -> {-17.87, -12.8079, 0.193106, \
0.193106}, {{117.25, 149.813}, {440.5, 424.188}} -> {-17.1904, -8.53861, \
0.128737, 0.128737}, {{153.063, 185.625}, {440.5, 424.188}} -> {-21.8008, \
-8.53861, 0.128737, 0.128737}, {{188.875, 221.5}, {440.5, 424.188}} -> \
{-65.538, -21.3465, 0.321842, 0.321842}, {{224.75, 257.313}, {440.5, \
424.188}} -> {-44.5445, -12.8079, 0.193106, 0.193106}, {{260.563, 293.125}, \
{440.5, 424.188}} -> {-27.2813, -6.66769, 0.0967381, 0.0967381}, {{296.375, \
329}, {440.5, 424.188}} -> {-60.3817, -14.8079, 0.193106, 0.193106}, \
{{332.25, 364.813}, {440.5, 424.188}} -> {-90.2375, -17.0772, 0.257473, \
0.257473}, {{368.063, 400.625}, {440.5, 424.188}} -> {-48.9795, -8.53865, \
0.128738, 0.128738}, {{9.75, 42.3125}, {422.563, 406.313}} -> {-5.04611, \
-16.334, 0.193848, 0.193848}, {{45.5625, 78.125}, {422.563, 406.313}} -> \
{-11.9883, -16.334, 0.193848, 0.193848}, {{81.4375, 114}, {422.563, 406.313}} -> \
{-36.8852, -32.6681, 0.387697, 0.387697}, {{117.25, 149.813}, {422.563, \
406.313}} -> {-17.7566, -10.8894, 0.129233, 0.129233}, {{153.063, 185.625}, \
{422.563, 406.313}} -> {-32.827, -17.334, 0.193848, 0.193848}, {{188.875, \
221.5}, {422.563, 406.313}} -> {-66.2921, -27.2234, 0.32308, 0.32308}, \
{{224.75, 257.313}, {422.563, 406.313}} -> {-30.6492, -10.8894, 0.129233, \
0.129233}, {{260.563, 293.125}, {422.563, 406.313}} -> {-52.6657, -17.334, \
0.193848, 0.193848}, {{296.375, 329}, {422.563, 406.313}} -> {-61.1139, \
-16.334, 0.193848, 0.193848}, {{332.25, 364.813}, {422.563, 406.313}} -> \
{-45.0415, -10.8894, 0.129232, 0.129232}, {{368.063, 400.625}, {422.563, \
406.313}} -> {-49.6696, -10.8894, 0.129232, 0.129232}, {{9.75, 42.3125}, \
{404.688, 388.375}} -> {-4.52677, -21.7235, 0.193105, 0.193105}, {{45.5625, \
78.125}, {404.688, 388.375}} -> {-6.46162, -14.1491, 0.128738, 0.128738}, \
{{81.4375, 114}, {404.688, 388.375}} -> {-13.6042, -14.1762, 0.128984, \
0.128984}, {{117.25, 149.813}, {404.688, 388.375}} -> {-24.7856, -20.7235, \
0.193106, 0.193106}, {{153.063, 185.625}, {404.688, 388.375}} -> {-20.3009, \
-13.1491, 0.128738, 0.128738}, {{188.875, 221.5}, {404.688, 388.375}} -> \
{-52.8305, -29.298, 0.257474, 0.257474}, {{224.75, 257.313}, {404.688, \
388.375}} -> {-47.0445, -21.7235, 0.193106, 0.193106}, {{260.563, 293.125}, \
{404.688, 388.375}} -> {-53.9601, -21.7235, 0.193106, 0.193106}, {{296.375, \
329}, {404.688, 388.375}} -> {-60.8817, -21.7235, 0.193106, 0.193106}, \
{{332.25, 364.813}, {404.688, 388.375}} -> {-68.3033, -21.7235, 0.193106, \
0.193106}, {{368.063, 400.625}, {404.688, 388.375}} -> {-97.4583, -26.2979, \
0.257473, 0.257473}, {{9.75, 42.3125}, {386.75, 370.438}} -> {-6.70237, \
-30.9165, 0.257474, 0.257474}, {{45.5625, 78.125}, {386.75, 370.438}} -> \
{-8.97686, -15.4898, 0.128984, 0.128984}, {{81.4375, 114}, {386.75, 370.438}} -> \
{-8.95313, -11.8674, 0.0967381, 0.0967381}, {{117.25, 149.813}, {386.75, \
370.438}} -> {-24.7856, -25.1873, 0.193106, 0.193106}, {{153.063, 185.625}, \
{386.75, 370.438}} -> {-22.8427, -15.4898, 0.128984, 0.128984}, {{188.875, \
221.5}, {386.75, 370.438}} -> {-51.3303, -33.9164, 0.257473, 0.257473}, \
{{224.75, 257.313}, {386.75, 370.438}} -> {-44.5445, -25.1873, 0.193106, \
0.193106}, {{260.563, 293.125}, {386.75, 370.438}} -> {-36.1402, -15.4583, \
0.128738, 0.128738}, {{296.375, 329}, {386.75, 370.438}} -> {-40.2545, \
-16.4582, 0.128737, 0.128737}, {{332.25, 364.813}, {386.75, 370.438}} -> \
{-44.8689, -16.4582, 0.128737, 0.128737}, {{368.063, 400.625}, {386.75, \
370.438}} -> {-63.4678, -20.1123, 0.16123, 0.16123}, {{9.75, 42.3125}, \
{368.813, 352.563}} -> {-4.36408, -17.8356, 0.129232, 0.129232}, {{45.5625, \
78.125}, {368.813, 352.563}} -> {-8.9922, -17.8356, 0.129232, 0.129232}, \
{{81.4375, 114}, {368.813, 352.563}} -> {-19.9426, -26.7534, 0.193848, \
0.193848}, {{117.25, 149.813}, {368.813, 352.563}} -> {-23.0293, -22.4993, \
0.16123, 0.16123}, {{153.063, 185.625}, {368.813, 352.563}} -> {-31.327, \
-26.7534, 0.193848, 0.193848}, {{188.875, 221.5}, {368.813, 352.563}} -> \
{-26.5168, -17.8356, 0.129232, 0.129232}, {{224.75, 257.313}, {368.813, \
352.563}} -> {-31.149, -17.8356, 0.129232, 0.129232}, {{260.563, 293.125}, \
{368.813, 352.563}} -> {-88.4428, -44.589, 0.32308, 0.32308}, {{296.375, \
329}, {368.813, 352.563}} -> {-60.1139, -26.7534, 0.193848, 0.193848}, \
{{332.25, 364.813}, {368.813, 352.563}} -> {-34.2163, -13.5996, 0.0967381, \
0.0967381}, {{368.063, 400.625}, {368.813, 352.563}} -> {-74.5044, -28.7534, \
0.193848, 0.193848}, {{9.75, 42.3125}, {350.938, 334.625}} -> {-5.20235, \
-43.1371, 0.257473, 0.257473}, {{45.5625, 78.125}, {350.938, 334.625}} -> \
{-15.4231, -40.1371, 0.257473, 0.257473}, {{81.4375, 114}, {350.938, \
334.625}} -> {-19.37, -30.1029, 0.193106, 0.193106}, {{117.25, 149.813}, \
{350.938, 334.625}} -> {-26.2856, -30.1029, 0.193106, 0.193106}, {{153.063, \
185.625}, {350.938, 334.625}} -> {-33.2012, -31.1029, 0.193106, 0.193106}, \
{{188.875, 221.5}, {350.938, 334.625}} -> {-27.4152, -20.0686, 0.128737, \
0.128737}, {{224.75, 257.313}, {350.938, 334.625}} -> {-31.5298, -21.0687, \
0.128738, 0.128738}, {{260.563, 293.125}, {350.938, 334.625}} -> {-46.1356, \
-26.3863, 0.16123, 0.16123}, {{296.375, 329}, {350.938, 334.625}} -> \
{-99.6362, -54.1716, 0.321843, 0.321843}, {{332.25, 364.813}, {350.938, \
334.625}} -> {-88.2375, -43.1371, 0.257473, 0.257473}, {{368.063, 400.625}, \
{350.938, 334.625}} -> {-50.5742, -21.1091, 0.128984, 0.128984}, {{9.75, \
42.3125}, {333, 316.688}} -> {-5.02678, -33.5668, 0.193106, 0.193106}, \
{{45.5625, 78.125}, {333, 316.688}} -> {-10.9424, -33.5668, 0.193106, \
0.193106}, {{81.4375, 114}, {333, 316.688}} -> {-19.37, -33.5668, 0.193106, \
0.193106}, {{117.25, 149.813}, {333, 316.688}} -> {-17.6905, -22.378, \
0.128738, 0.128738}, {{153.063, 185.625}, {333, 316.688}} -> {-21.8008, \
-23.3778, 0.128737, 0.128737}, {{188.875, 221.5}, {333, 316.688}} -> \
{-39.6228, -34.5668, 0.193106, 0.193106}, {{224.75, 257.313}, {333, 316.688}} -> \
{-40.3615, -28.2784, 0.16123, 0.16123}, {{260.563, 293.125}, {333, 316.688}} -> \
{-50.5627, -35.6341, 0.193476, 0.193476}, {{296.375, 329}, {333, 316.688}} -> \
{-57.8817, -35.5668, 0.193106, 0.193106}, {{332.25, 364.813}, {333, 316.688}} -> \
{-42.955, -22.4227, 0.128984, 0.128984}, {{368.063, 400.625}, {333, 316.688}} -> \
{-122.698, -59.9446, 0.321843, 0.321843}, {{9.75, 42.3125}, {315.063, \
298.813}} -> {-6.22814, -50.5636, 0.258464, 0.258464}, {{45.5625, 78.125}, \
{315.063, 298.813}} -> {-12.4883, -38.1727, 0.193848, 0.193848}, {{81.4375, \
114}, {315.063, 298.813}} -> {-17.4426, -38.1727, 0.193848, 0.193848}, \
{{117.25, 149.813}, {315.063, 298.813}} -> {-16.7566, -24.7819, 0.129233, \
0.129233}, {{153.063, 185.625}, {315.063, 298.813}} -> {-41.7693, -52.5636, \
0.258464, 0.258464}, {{188.875, 221.5}, {315.063, 298.813}} -> {-51.5335, \
-52.5635, 0.258464, 0.258464}, {{224.75, 257.313}, {315.063, 298.813}} -> \
{-36.3615, -31.6654, 0.16123, 0.16123}, {{260.563, 293.125}, {315.063, \
298.813}} -> {-107.831, -79.3455, 0.387697, 0.387697}, {{296.375, 329}, \
{315.063, 298.813}} -> {-101.523, -65.9547, 0.323081, 0.323081}, {{332.25, \
364.813}, {315.063, 298.813}} -> {-89.0829, -49.5636, 0.258464, 0.258464}, \
{{368.063, 400.625}, {315.063, 298.813}} -> {-74.5044, -37.1727, 0.193848, \
0.193848}, {{9.75, 42.3125}, {297.188, 280.875}} -> {-1.8512, -27.9884, \
0.128738, 0.128738}, {{45.5625, 78.125}, {297.188, 280.875}} -> {-6.96158, \
-26.9882, 0.128737, 0.128737}, {{81.4375, 114}, {297.188, 280.875}} -> \
{-11.58, -26.9882, 0.128737, 0.128737}, {{117.25, 149.813}, {297.188, \
280.875}} -> {-19.0293, -34.5524, 0.16123, 0.16123}, {{153.063, 185.625}, \
{297.188, 280.875}} -> {-41.6016, -56.9765, 0.257474, 0.257474}, {{188.875, \
221.5}, {297.188, 280.875}} -> {-24.9154, -27.9884, 0.128738, 0.128738}, \
{{224.75, 257.313}, {297.188, 280.875}} -> {-46.0444, -40.4823, 0.193105, \
0.193105}, {{260.563, 293.125}, {297.188, 280.875}} -> {-36.1402, -26.9884, \
0.128738, 0.128738}, {{296.375, 329}, {297.188, 280.875}} -> {-58.3817, \
-40.4824, 0.193106, 0.193106}, {{332.25, 364.813}, {297.188, 280.875}} -> \
{-65.8033, -41.4824, 0.193106, 0.193106}, {{368.063, 400.625}, {297.188, \
280.875}} -> {-48.9795, -26.9884, 0.128738, 0.128738}, {{9.75, 42.3125}, \
{279.25, 262.938}} -> {-7.87796, -73.2436, 0.321842, 0.321842}, {{45.5625, \
78.125}, {279.25, 262.938}} -> {-6.48265, -22.2667, 0.0967381, 0.0967381}, \
{{81.4375, 114}, {279.25, 262.938}} -> {-18.87, -45.9462, 0.193106, \
0.193106}, {{117.25, 149.813}, {279.25, 262.938}} -> {-34.3808, -58.5949, \
0.257474, 0.257474}, {{153.063, 185.625}, {279.25, 262.938}} -> {-15.882, \
-22.2667, 0.0967381, 0.0967381}, {{188.875, 221.5}, {279.25, 262.938}} -> \
{-38.6228, -45.9462, 0.193106, 0.193106}, {{224.75, 257.313}, {279.25, \
262.938}} -> {-31.5298, -29.2976, 0.128738, 0.128738}, {{260.563, 293.125}, \
{279.25, 262.938}} -> {-35.64, -30.2975, 0.128737, 0.128737}, {{296.375, \
329}, {279.25, 262.938}} -> {-40.2545, -30.2975, 0.128737, 0.128737}, \
{{332.25, 364.813}, {279.25, 262.938}} -> {-66.8033, -45.9461, 0.193105, \
0.193105}, {{368.063, 400.625}, {279.25, 262.938}} -> {-48.4793, -30.2975, \
0.128737, 0.128737}, {{9.75, 42.3125}, {261.313, 245.063}} -> {-5.04611, \
-48.5921, 0.193848, 0.193848}, {{45.5625, 78.125}, {261.313, 245.063}} -> \
{-9.4883, -49.5921, 0.193848, 0.193848}, {{81.4375, 114}, {261.313, 245.063}} -> \
{-16.9426, -49.5921, 0.193848, 0.193848}, {{117.25, 149.813}, {261.313, \
245.063}} -> {-34.5131, -63.4561, 0.258464, 0.258464}, {{153.063, 185.625}, \
{261.313, 245.063}} -> {-33.327, -47.5921, 0.193848, 0.193848}, {{188.875, \
221.5}, {261.313, 245.063}} -> {-40.2752, -47.5921, 0.193848, 0.193848}, \
{{224.75, 257.313}, {261.313, 245.063}} -> {-32.149, -31.7281, 0.129232, \
0.129232}, {{260.563, 293.125}, {261.313, 245.063}} -> {-36.2773, -32.7282, \
0.129233, 0.129233}, {{296.375, 329}, {261.313, 245.063}} -> {-59.6139, \
-47.5921, 0.193848, 0.193848}, {{332.25, 364.813}, {261.313, 245.063}} -> \
{-45.0415, -31.7281, 0.129232, 0.129232}, {{368.063, 400.625}, {261.313, \
245.063}} -> {-49.6696, -31.7281, 0.129232, 0.129232}, {{9.75, 42.3125}, \
{243.438, 227.125}} -> {-6.20237, -68.8156, 0.257474, 0.257474}, {{45.5625, \
78.125}, {243.438, 227.125}} -> {-12.4424, -51.8618, 0.193106, 0.193106}, \
{{81.4375, 114}, {243.438, 227.125}} -> {-17.87, -51.8618, 0.193106, \
0.193106}, {{117.25, 149.813}, {243.438, 227.125}} -> {-32.8807, -70.8155, \
0.257473, 0.257473}, {{153.063, 185.625}, {243.438, 227.125}} -> {-42.6016, \
-70.8157, 0.257474, 0.257474}, {{188.875, 221.5}, {243.438, 227.125}} -> \
{-51.8305, -67.8157, 0.257474, 0.257474}, {{224.75, 257.313}, {243.438, \
227.125}} -> {-46.5445, -50.8618, 0.193106, 0.193106}, {{260.563, 293.125}, \
{243.438, 227.125}} -> {-53.4601, -50.8618, 0.193106, 0.193106}, {{296.375, \
329}, {243.438, 227.125}} -> {-59.8816, -50.8617, 0.193105, 0.193105}, \
{{332.25, 364.813}, {243.438, 227.125}} -> {-45.3691, -33.908, 0.128738, \
0.128738}, {{368.063, 400.625}, {243.438, 227.125}} -> {-49.4793, -34.9079, \
0.128737, 0.128737}, {{9.75, 42.3125}, {225.5, 209.188}} -> {-2.01821, \
-27.4664, 0.0967381, 0.0967381}, {{45.5625, 78.125}, {225.5, 209.188}} -> \
{-6.96158, -37.2171, 0.128737, 0.128737}, {{81.4375, 114}, {225.5, 209.188}} -> \
{-11.0801, -37.2173, 0.128738, 0.128738}, {{117.25, 149.813}, {225.5, \
209.188}} -> {-16.1904, -36.2171, 0.128737, 0.128737}, {{153.063, 185.625}, \
{225.5, 209.188}} -> {-20.8008, -36.2171, 0.128737, 0.128737}, {{188.875, \
221.5}, {225.5, 209.188}} -> {-30.519, -46.0213, 0.160921, 0.160921}, \
{{224.75, 257.313}, {225.5, 209.188}} -> {-60.5591, -75.434, 0.257473, \
0.257473}, {{260.563, 293.125}, {225.5, 209.188}} -> {-52.96, -54.3256, \
0.193105, 0.193105}, {{296.375, 329}, {225.5, 209.188}} -> {-40.7547, \
-36.2173, 0.128738, 0.128738}, {{332.25, 364.813}, {225.5, 209.188}} -> \
{-65.3033, -54.3256, 0.193106, 0.193106}, {{368.063, 400.625}, {225.5, \
209.188}} -> {-73.2189, -55.3256, 0.193106, 0.193106}, {{9.75, 42.3125}, \
{207.563, 191.313}} -> {-1.86409, -38.6745, 0.129233, 0.129233}, {{45.5625, \
78.125}, {207.563, 191.313}} -> {-6.49224, -38.6745, 0.129233, 0.129233}, \
{{81.4375, 114}, {207.563, 191.313}} -> {-15.9063, -58.8972, 0.193476, \
0.193476}, {{117.25, 149.813}, {207.563, 191.313}} -> {-24.8848, -58.0114, \
0.193848, 0.193848}, {{153.063, 185.625}, {207.563, 191.313}} -> {-21.3848, \
-38.6745, 0.129233, 0.129233}, {{188.875, 221.5}, {207.563, 191.313}} -> \
{-30.519, -48.4028, 0.160921, 0.160921}, {{224.75, 257.313}, {207.563, \
191.313}} -> {-45.7235, -59.0114, 0.193848, 0.193848}, {{260.563, 293.125}, \
{207.563, 191.313}} -> {-35.2773, -39.6745, 0.129233, 0.129233}, {{296.375, \
329}, {207.563, 191.313}} -> {-59.1139, -58.0114, 0.193848, 0.193848}, \
{{332.25, 364.813}, {207.563, 191.313}} -> {-44.0415, -38.6743, 0.129232, \
0.129232}, {{368.063, 400.625}, {207.563, 191.313}} -> {-48.6696, -38.6743, \
0.129232, 0.129232}, {{9.75, 42.3125}, {189.688, 173.375}} -> {-5.52678, \
-63.2412, 0.193106, 0.193106}, {{45.5625, 78.125}, {189.688, 173.375}} -> \
{-19.4039, -102.069, 0.321842, 0.321842}, {{81.4375, 114}, {189.688, \
173.375}} -> {-25.16, -81.6549, 0.257474, 0.257474}, {{117.25, 149.813}, \
{189.688, 173.375}} -> {-16.6905, -41.8277, 0.128738, 0.128738}, {{153.063, \
185.625}, {189.688, 173.375}} -> {-20.8008, -41.8275, 0.128737, 0.128737}, \
{{188.875, 221.5}, {189.688, 173.375}} -> {-40.6228, -61.2412, 0.193106, \
0.193106}, {{224.75, 257.313}, {189.688, 173.375}} -> {-47.0445, -61.2412, \
0.193106, 0.193106}, {{260.563, 293.125}, {189.688, 173.375}} -> {-53.9601, \
-61.2412, 0.193106, 0.193106}, {{296.375, 329}, {189.688, 173.375}} -> \
{-60.8817, -61.2412, 0.193106, 0.193106}, {{332.25, 364.813}, {189.688, \
173.375}} -> {-90.2375, -81.6547, 0.257473, 0.257473}, {{368.063, 400.625}, \
{189.688, 173.375}} -> {-47.5742, -41.9078, 0.128984, 0.128984}, {{9.75, \
42.3125}, {171.75, 155.438}} -> {-5.69702, -55.2768, 0.16123, 0.16123}, \
{{45.5625, 78.125}, {171.75, 155.438}} -> {-8.97686, -44.2214, 0.128984, \
0.128984}, {{81.4375, 114}, {171.75, 155.438}} -> {-25.16, -86.2734, \
0.257474, 0.257474}, {{117.25, 149.813}, {171.75, 155.438}} -> {-33.3808, \
-86.2734, 0.257474, 0.257474}, {{153.063, 185.625}, {171.75, 155.438}} -> \
{-42.6016, -86.2734, 0.257474, 0.257474}, {{188.875, 221.5}, {171.75, \
155.438}} -> {-51.3303, -86.2732, 0.257473, 0.257473}, {{224.75, 257.313}, \
{171.75, 155.438}} -> {-76.5741, -107.842, 0.321843, 0.321843}, {{260.563, \
293.125}, {171.75, 155.438}} -> {-51.9601, -65.705, 0.193106, 0.193106}, \
{{296.375, 329}, {171.75, 155.438}} -> {-79.5089, -86.2734, 0.257474, \
0.257474}, {{332.25, 364.813}, {171.75, 155.438}} -> {-88.7378, -86.2734, \
0.257474, 0.257474}, {{368.063, 400.625}, {171.75, 155.438}} -> {-75.2189, \
-66.705, 0.193106, 0.193106}, {{9.75, 42.3125}, {153.813, 137.563}} -> \
{-4.04611, -69.4308, 0.193848, 0.193848}, {{45.5625, 78.125}, {153.813, \
137.563}} -> {-19.4805, -118.051, 0.32308, 0.32308}, {{81.4375, 114}, \
{153.813, 137.563}} -> {-20.9426, -68.4308, 0.193848, 0.193848}, {{117.25, \
149.813}, {153.813, 137.563}} -> {-27.3848, -68.4308, 0.193848, 0.193848}, \
{{153.063, 185.625}, {153.813, 137.563}} -> {-31.327, -68.4308, 0.193848, \
0.193848}, {{188.875, 221.5}, {153.813, 137.563}} -> {-65.2921, -114.051, \
0.32308, 0.32308}, {{224.75, 257.313}, {153.813, 137.563}} -> {-61.298, \
-94.241, 0.258464, 0.258464}, {{260.563, 293.125}, {153.813, 137.563}} -> \
{-46.1356, -58.1638, 0.16123, 0.16123}, {{296.375, 329}, {153.813, 137.563}} -> \
{-41.4093, -46.6205, 0.129232, 0.129232}, {{332.25, 364.813}, {153.813, \
137.563}} -> {-67.0622, -68.4308, 0.193848, 0.193848}, {{368.063, 400.625}, \
{153.813, 137.563}} -> {-124.174, -114.051, 0.32308, 0.32308}, {{9.75, \
42.3125}, {135.938, 119.625}} -> {-3.8512, -47.7473, 0.128738, 0.128738}, \
{{45.5625, 78.125}, {135.938, 119.625}} -> {-5.97686, -47.8407, 0.128984, \
0.128984}, {{81.4375, 114}, {135.938, 119.625}} -> {-18.37, -72.6206, \
0.193105, 0.193105}, {{117.25, 149.813}, {135.938, 119.625}} -> {-17.6905, \
-48.7473, 0.128738, 0.128738}, {{153.063, 185.625}, {135.938, 119.625}} -> \
{-31.7012, -71.6206, 0.193106, 0.193106}, {{188.875, 221.5}, {135.938, \
119.625}} -> {-26.4152, -47.7471, 0.128737, 0.128737}, {{224.75, 257.313}, \
{135.938, 119.625}} -> {-31.0297, -47.7471, 0.128737, 0.128737}, {{260.563, \
293.125}, {135.938, 119.625}} -> {-27.2813, -36.1305, 0.0967381, 0.0967381}, \
{{296.375, 329}, {135.938, 119.625}} -> {-40.2545, -48.7471, 0.128737, \
0.128737}, {{332.25, 364.813}, {135.938, 119.625}} -> {-67.3033, -73.6206, \
0.193106, 0.193106}, {{368.063, 400.625}, {135.938, 119.625}} -> {-73.2189, \
-72.6206, 0.193106, 0.193106}, {{9.75, 42.3125}, {118, 101.75}} -> {-7.22813, \
-103.497, 0.258464, 0.258464}, {{45.5625, 78.125}, {118, 101.75}} -> \
{-6.49224, -50.2489, 0.129233, 0.129233}, {{81.4375, 114}, {118, 101.75}} -> \
{-17.9426, -75.373, 0.193848, 0.193848}, {{117.25, 149.813}, {118, 101.75}} -> \
{-24.8848, -75.373, 0.193848, 0.193848}, {{153.063, 185.625}, {118, 101.75}} -> \
{-43.2693, -100.497, 0.258464, 0.258464}, {{188.875, 221.5}, {118, 101.75}} -> \
{-39.7752, -75.373, 0.193848, 0.193848}, {{224.75, 257.313}, {118, 101.75}} -> \
{-29.6492, -51.2489, 0.129233, 0.129233}, {{260.563, 293.125}, {118, 101.75}} -> \
{-34.7771, -50.2486, 0.129232, 0.129232}, {{296.375, 329}, {118, 101.75}} -> \
{-39.4093, -50.2486, 0.129232, 0.129232}, {{332.25, 364.813}, {118, 101.75}} -> \
{-53.6938, -63.4378, 0.16123, 0.16123}, {{368.063, 400.625}, {118, 101.75}} -> \
{-74.0043, -75.3729, 0.193848, 0.193848}, {{9.75, 42.3125}, {100.063, \
83.8125}} -> {-1.86409, -52.567, 0.129233, 0.129233}, {{45.5625, 78.125}, \
{100.063, 83.8125}} -> {-10.9883, -78.8501, 0.193848, 0.193848}, {{81.4375, \
114}, {100.063, 83.8125}} -> {-11.6284, -52.5667, 0.129232, 0.129232}, \
{{117.25, 149.813}, {100.063, 83.8125}} -> {-26.8848, -80.8501, 0.193848, \
0.193848}, {{153.063, 185.625}, {100.063, 83.8125}} -> {-21.3848, -53.567, \
0.129233, 0.129233}, {{188.875, 221.5}, {100.063, 83.8125}} -> {-26.017, \
-53.567, 0.129233, 0.129233}, {{224.75, 257.313}, {100.063, 83.8125}} -> \
{-47.7235, -80.8501, 0.193848, 0.193848}, {{260.563, 293.125}, {100.063, \
83.8125}} -> {-36.7771, -53.5667, 0.129232, 0.129232}, {{296.375, 329}, \
{100.063, 83.8125}} -> {-28.6908, -39.5211, 0.0965528, 0.0965528}, {{332.25, \
364.813}, {100.063, 83.8125}} -> {-44.5417, -52.567, 0.129233, 0.129233}, \
{{368.063, 400.625}, {100.063, 83.8125}} -> {-124.674, -135.417, 0.323081, \
0.323081}, {{9.75, 42.3125}, {82.1875, 65.875}} -> {-5.52678, -84.0001, \
0.193106, 0.193106}, {{45.5625, 78.125}, {82.1875, 65.875}} -> {-6.96158, \
-55.6667, 0.128737, 0.128737}, {{81.4375, 114}, {82.1875, 65.875}} -> \
{-19.87, -82.0001, 0.193106, 0.193106}, {{117.25, 149.813}, {82.1875, \
65.875}} -> {-26.2856, -82.0001, 0.193106, 0.193106}, {{153.063, 185.625}, \
{82.1875, 65.875}} -> {-33.2012, -82.0001, 0.193106, 0.193106}, {{188.875, \
221.5}, {82.1875, 65.875}} -> {-65.0381, -140.667, 0.321843, 0.321843}, \
{{224.75, 257.313}, {82.1875, 65.875}} -> {-60.5591, -112.333, 0.257473, \
0.257473}, {{260.563, 293.125}, {82.1875, 65.875}} -> {-25.2813, -41.3302, \
0.0967381, 0.0967381}, {{296.375, 329}, {82.1875, 65.875}} -> {-39.2545, \
-54.6667, 0.128737, 0.128737}, {{332.25, 364.813}, {82.1875, 65.875}} -> \
{-42.955, -55.7736, 0.128984, 0.128984}, {{368.063, 400.625}, {82.1875, \
65.875}} -> {-47.9795, -54.667, 0.128738, 0.128738}, {{9.75, 42.3125}, \
{64.25, 48}} -> {-1.86409, -58.1952, 0.129233, 0.129233}, {{45.5625, 78.125}, \
{64.25, 48}} -> {-6.9922, -57.1949, 0.129232, 0.129232}, {{81.4375, 114}, \
{64.25, 48}} -> {-11.6284, -57.1949, 0.129232, 0.129232}, {{117.25, 149.813}, \
{64.25, 48}} -> {-25.3848, -85.7922, 0.193848, 0.193848}, {{153.063, \
185.625}, {64.25, 48}} -> {-21.8847, -57.1949, 0.129232, 0.129232}, \
{{188.875, 221.5}, {64.25, 48}} -> {-41.2752, -85.7923, 0.193848, 0.193848}, \
{{224.75, 257.313}, {64.25, 48}} -> {-32.149, -58.1949, 0.129232, 0.129232}, \
{{260.563, 293.125}, {64.25, 48}} -> {-36.7771, -58.1949, 0.129232, \
0.129232}, {{296.375, 329}, {64.25, 48}} -> {-80.8186, -114.39, 0.258464, \
0.258464}, {{332.25, 364.813}, {64.25, 48}} -> {-89.5828, -114.39, 0.258464, \
0.258464}, {{368.063, 400.625}, {64.25, 48}} -> {-98.3392, -114.39, 0.258464, \
0.258464}, {{9.75, 42.3125}, {46.375, 30.0625}} -> {-1.35762, -59.8928, \
0.128984, 0.128984}, {{45.5625, 78.125}, {46.375, 30.0625}} -> {-6.46162, \
-59.2774, 0.128738, 0.128738}, {{81.4375, 114}, {46.375, 30.0625}} -> \
{-13.6042, -60.3928, 0.128984, 0.128984}, {{117.25, 149.813}, {46.375, \
30.0625}} -> {-34.8808, -121.554, 0.257473, 0.257473}, {{153.063, 185.625}, \
{46.375, 30.0625}} -> {-20.8008, -59.2771, 0.128737, 0.128737}, {{188.875, \
221.5}, {46.375, 30.0625}} -> {-24.9154, -59.2774, 0.128738, 0.128738}, \
{{224.75, 257.313}, {46.375, 30.0625}} -> {-45.5445, -88.9156, 0.193106, \
0.193106}, {{260.563, 293.125}, {46.375, 30.0625}} -> {-88.6, -152.193, \
0.321842, 0.321842}, {{296.375, 329}, {46.375, 30.0625}} -> {-79.5089, \
-121.554, 0.257474, 0.257474}, {{332.25, 364.813}, {46.375, 30.0625}} -> \
{-33.2163, -44.7946, 0.0967381, 0.0967381}, {{368.063, 400.625}, {46.375, \
30.0625}} -> {-49.4793, -59.2771, 0.128737, 0.128737}, {{9.75, 42.3125}, \
{28.4375, 12.125}} -> {-0.678808, -30.8532, 0.0644921, 0.0644921}, {{45.5625, \
78.125}, {28.4375, 12.125}} -> {-4.48265, -46.5298, 0.0967381, 0.0967381}, \
{{81.4375, 114}, {28.4375, 12.125}} -> {-11.58, -61.5863, 0.128737, \
0.128737}, {{117.25, 149.813}, {28.4375, 12.125}} -> {-8.61171, -30.8532, \
0.0644921, 0.0644921}, {{153.063, 185.625}, {28.4375, 12.125}} -> {-20.8008, \
-62.5863, 0.128737, 0.128737}, {{188.875, 221.5}, {28.4375, 12.125}} -> \
{-18.3114, -46.4397, 0.0965528, 0.0965528}, {{224.75, 257.313}, {28.4375, \
12.125}} -> {-30.0296, -61.5863, 0.128737, 0.128737}, {{260.563, 293.125}, \
{28.4375, 12.125}} -> {-70.78, -123.173, 0.257474, 0.257474}, {{296.375, \
329}, {28.4375, 12.125}} -> {-60.8817, -92.3795, 0.193106, 0.193106}, \
{{332.25, 364.813}, {28.4375, 12.125}} -> {-21.4775, -30.8532, 0.0644921, \
0.0644921}, {{368.063, 400.625}, {28.4375, 12.125}} -> {-47.9795, -62.5866, \
0.128738, 0.128738}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Forrest of Permutator Birds", "Subsection"],

Cell["\<\
We cannot simply issue a definition like:
      
      u[{\"(\",y__,x__,\")\"}]:={\"(\",\"(\",\"T\",x,\")\",y,\")\"} /; \
SyntaxQ[StringJoin[{y}]]
      
      We need to control when such a rule or the previous one for B will \
apply. We need to separate both.\
\>", "Text"],

Cell[BoxData[{
    \(ruleT[{"\<(\>", y__, x__, "\<)\>"}] := {"\<(\>", "\<(\>", "\<T\>", 
          x, "\<)\>", y, "\<)\>"} /; 
        SyntaxQ[StringJoin[{y}]]\), "\[IndentingNewLine]", 
    \(ruleT[x_] := x\)}], "Input",
  CellLabel->"In[242]:=",
  InitializationCell->True],

Cell["\<\
We generate all possible code chains up to a given limit, writing 0 for ruleB \
and 1 for ruleT\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 3;\)\), "\[IndentingNewLine]", 
    \(\(IntegerDigits[#, 2, n] &\)\  /@ \ Range[0, 2\^n - 1]\)}], "Input",
  CellLabel->"In[303]:="],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 1}, {0, 1, 0}, {0, 1, 1}, {1, 0, 0}, {1, 0, 1}, {1, 
        1, 0}, {1, 1, 1}}\)], "Output",
  CellLabel->"Out[304]="]
}, Open  ]],

Cell["\<\
We need only the rest of the above as we are interested in unordered \
arguments\
\>", "Text"],

Cell[BoxData[{
    \(\(\(chains[n_] := 
      Rest[\(IntegerDigits[#, 2, n] &\)\  /@ \ 
          Range[0, 2\^n - 1]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(genealogyBT[bird_, _ : 10] := 
      genealogyB[bird]\  /; \ 
        OrderedQ[
          Select[Characters[bird], LowerCaseQ]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(genealogyBT[bird_, depth_:  10] := 
      Module[{s = bird}, \[IndentingNewLine]While[
          Characters[s] \[Intersection] 
              CharacterRange["\<a\>", "\<z\>"] \[NotEqual] {}, \
\[IndentingNewLine]s = 
            StringJoin[
              h[Characters[
                  deflate[
                    StringJoin[
                      ruleB[Characters[
                          inflate[
                            s]]]]]]]]]; \[IndentingNewLine]s]\)}], "Input",
  CellLabel->"In[305]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(genealogyBT["\<w((xy)z)\>", 2]\)], "Input",
  CellLabel->"In[308]:="],

Cell[BoxData[
    \("BBB"\)], "Output",
  CellLabel->"Out[308]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["ALL BIRDS", "Subsubsection"],

Cell[BoxData[
    \(permutatorBirds[c_] := 
      Module[{v}, \[IndentingNewLine]v = 
          Rest[Permutations[c]]; \[IndentingNewLine]v = 
          Map[Thread[c \[Rule] #] &, 
            v]; \[IndentingNewLine]Flatten[\(StringReplace[
                deflate\  /@ brackets[c], #] &\)\  /@ \ v]]\)], "Input",
  CellLabel->"In[244]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(permutatorBirds[
      CharacterRange["\<a\>", "\<d\>"]]\), "\[IndentingNewLine]", 
    \(Length[%]\)}], "Input",
  CellLabel->"In[309]:="],

Cell[BoxData[
    \({"abdc", "a(bd)c", "ab(dc)", "a(bdc)", "a(b(dc))", "acbd", "a(cb)d", 
      "ac(bd)", "a(cbd)", "a(c(bd))", "acdb", "a(cd)b", "ac(db)", "a(cdb)", 
      "a(c(db))", "adbc", "a(db)c", "ad(bc)", "a(dbc)", "a(d(bc))", "adcb", 
      "a(dc)b", "ad(cb)", "a(dcb)", "a(d(cb))", "bacd", "b(ac)d", "ba(cd)", 
      "b(acd)", "b(a(cd))", "badc", "b(ad)c", "ba(dc)", "b(adc)", "b(a(dc))", 
      "bcad", "b(ca)d", "bc(ad)", "b(cad)", "b(c(ad))", "bcda", "b(cd)a", 
      "bc(da)", "b(cda)", "b(c(da))", "bdac", "b(da)c", "bd(ac)", "b(dac)", 
      "b(d(ac))", "bdca", "b(dc)a", "bd(ca)", "b(dca)", "b(d(ca))", "cabd", 
      "c(ab)d", "ca(bd)", "c(abd)", "c(a(bd))", "cadb", "c(ad)b", "ca(db)", 
      "c(adb)", "c(a(db))", "cbad", "c(ba)d", "cb(ad)", "c(bad)", "c(b(ad))", 
      "cbda", "c(bd)a", "cb(da)", "c(bda)", "c(b(da))", "cdab", "c(da)b", 
      "cd(ab)", "c(dab)", "c(d(ab))", "cdba", "c(db)a", "cd(ba)", "c(dba)", 
      "c(d(ba))", "dabc", "d(ab)c", "da(bc)", "d(abc)", "d(a(bc))", "dacb", 
      "d(ac)b", "da(cb)", "d(acb)", "d(a(cb))", "dbac", "d(ba)c", "db(ac)", 
      "d(bac)", "d(b(ac))", "dbca", "d(bc)a", "db(ca)", "d(bca)", "d(b(ca))", 
      "dcab", "d(ca)b", "dc(ab)", "d(cab)", "d(c(ab))", "dcba", "d(cb)a", 
      "dc(ba)", "d(cba)", "d(c(ba))"}\)], "Output",
  CellLabel->"Out[309]="],

Cell[BoxData[
    \(115\)], "Output",
  CellLabel->"Out[310]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Arbitrary Genealogies", "Section"],

Cell["\<\
Method to obtain the genealogy of arbitrary birds from birds S, K and I by \
computing \[Alpha]-free terms.\
\>", "Text"],

Cell[BoxData[{
    \(cover[{x_}] := x\), "\[IndentingNewLine]", 
    \(\(\(cover[x_] := "\<(\>" <> 
        StringJoin[x] <> "\<)\>"\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(alphaFree[\[Alpha]_, X_] := 
      alphaFree[StringDrop[\[Alpha], \(-1\)], 
          Characters[
            alphaFree[StringTake[\[Alpha], \(-1\)], 
              X]]]\  /; \((StringLength[\[Alpha]] > 
            1)\)\), "\[IndentingNewLine]", 
    \(alphaFree[\[Alpha]_, {"\<(\>", x__, "\<)\>"}] := 
      alphaFree[\[Alpha], {x}]\), "\[IndentingNewLine]", 
    \(alphaFree[\[Alpha]_, {\[Alpha]_}] := "\<I\>"\), "\[IndentingNewLine]", 
    \(alphaFree[\[Alpha]_, X_] := "\<K\>" <> cover[X] /; 
        Not[MemberQ[X, \[Alpha]]]\), "\[IndentingNewLine]", 
    \(alphaFree[\[Alpha]_, {Y__, \[Alpha]_}] := 
      StringJoin[{Y}] /; 
        Not[MemberQ[{Y}, \[Alpha]]]\), "\[IndentingNewLine]", 
    \(alphaFree[\[Alpha]_, {Y__, "\<(\>", Z__, "\<)\>"}] := "\<S\>" <> 
          cover[Characters[alphaFree[\[Alpha], {Y}]]] <> 
          cover[Characters[alphaFree[\[Alpha], {Z}]]] /; 
        SyntaxQ[StringJoin[{Z}]]\), "\[IndentingNewLine]", 
    \(alphaFree[\[Alpha]_, {Y__, Z_}] := "\<S\>" <> 
        cover[Characters[alphaFree[\[Alpha], {Y}]]] <> 
        cover[Characters[alphaFree[\[Alpha], {Z}]]]\)}], "Input",
  CellLabel->"In[245]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(alphaFree["\<x\>", Characters["\<x(xx)\>"]]\), "\[IndentingNewLine]", 
    \(behaviour[% <> "\<x\>"]\)}], "Input",
  CellLabel->"In[311]:="],

Cell[BoxData[
    \("SI(SII)"\)], "Output",
  CellLabel->"Out[311]="],

Cell[BoxData[
    \("x(xx)"\)], "Output",
  CellLabel->"Out[312]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(alphaFree["\<xx\>", Characters["\<x(xx)\>"]]\), "\[IndentingNewLine]", 
    \(behaviour[% <> "\<xx\>"]\)}], "Input",
  CellLabel->"In[313]:="],

Cell[BoxData[
    \("K(SI(SII))"\)], "Output",
  CellLabel->"Out[313]="],

Cell[BoxData[
    \("x(xx)"\)], "Output",
  CellLabel->"Out[314]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(alphaFree["\<xy\>", 
      Characters["\<yx(xy)\>"]]\), "\[IndentingNewLine]", 
    \(behaviour[% <> "\<xy\>"]\)}], "Input",
  CellLabel->"In[222]:="],

Cell[BoxData[
    \("S(S(KS)(S(K(SI))K))I"\)], "Output",
  CellLabel->"Out[222]="],

Cell[BoxData[
    \("yx(xy)"\)], "Output",
  CellLabel->"Out[223]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(alphaFree["\<xyz\>", 
      Characters["\<xz(zy)\>"]]\), "\[IndentingNewLine]", 
    \(behaviour[% <> "\<xyz\>"]\)}], "Input",
  CellLabel->"In[224]:="],

Cell[BoxData[
    \("S(S(KS)(S(KK)S))(K(S(K(SI))K))"\)], "Output",
  CellLabel->"Out[224]="],

Cell[BoxData[
    \("xz(zy)"\)], "Output",
  CellLabel->"Out[225]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(alphaFree["\<xyzyx\>", 
      Characters["\<xz(zy)\>"]]\), "\[IndentingNewLine]", 
    \(behaviour[% <> "\<xyzyx\>"]\)}], "Input",
  CellLabel->"In[226]:="],

Cell[BoxData[
    \("K(K(S(S(KS)(S(KK)(S(KS)(S(K(SI))K))))(S(KK))))"\)], "Output",
  CellLabel->"Out[226]="],

Cell[BoxData[
    \("xz(zy)"\)], "Output",
  CellLabel->"Out[227]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(alphaFree["\<a\>", Characters["\<a\>"]]\)], "Input",
  CellLabel->"In[228]:="],

Cell[BoxData[
    \("I"\)], "Output",
  CellLabel->"Out[228]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(alphaFree["\<ab\>", Characters["\<b\>"]]\)], "Input",
  CellLabel->"In[229]:="],

Cell[BoxData[
    \("KI"\)], "Output",
  CellLabel->"Out[229]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(alphaFree["\<abc\>", Characters["\<c\>"]]\)], "Input",
  CellLabel->"In[230]:="],

Cell[BoxData[
    \("K(KI)"\)], "Output",
  CellLabel->"Out[230]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(alphaFree["\<abcd\>", Characters["\<d\>"]]\)], "Input",
  CellLabel->"In[231]:="],

Cell[BoxData[
    \("K(K(KI))"\)], "Output",
  CellLabel->"Out[231]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(alphaFree["\<x\>", Characters["\<x\>"]]\), "\[IndentingNewLine]", 
    \(alphaFree["\<x\>", Characters["\<xx\>"]]\), "\[IndentingNewLine]", 
    \(alphaFree["\<x\>", Characters["\<xxx\>"]]\), "\[IndentingNewLine]", 
    \(alphaFree["\<x\>", Characters["\<xxxx\>"]]\)}], "Input",
  CellLabel->"In[315]:="],

Cell[BoxData[
    \("I"\)], "Output",
  CellLabel->"Out[315]="],

Cell[BoxData[
    \("SII"\)], "Output",
  CellLabel->"Out[316]="],

Cell[BoxData[
    \("S(SII)I"\)], "Output",
  CellLabel->"Out[317]="],

Cell[BoxData[
    \("S(S(SII)I)I"\)], "Output",
  CellLabel->"Out[318]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(alphaFree["\<a\>", Characters["\<a\>"]]\), "\[IndentingNewLine]", 
    \(alphaFree["\<ab\>", Characters["\<ba\>"]]\), "\[IndentingNewLine]", 
    \(alphaFree["\<abc\>", Characters["\<cba\>"]]\), "\[IndentingNewLine]", 
    \(alphaFree["\<abcd\>", Characters["\<dcba\>"]]\)}], "Input",
  CellLabel->"In[319]:="],

Cell[BoxData[
    \("I"\)], "Output",
  CellLabel->"Out[319]="],

Cell[BoxData[
    \("S(K(SI))K"\)], "Output",
  CellLabel->"Out[320]="],

Cell[BoxData[
    \("S(K(S(S(KS)(S(K(SI))K))))(S(KK)K)"\)], "Output",
  CellLabel->"Out[321]="],

Cell[BoxData[
    \("S(K(S(S(KS)(S(K(S(KS)))(S(K(S(S(KS)(S(K(SI))K))))(S(KK)K))))))(S(KK)(S(\
KK)K))"\)], "Output",
  CellLabel->"Out[322]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(alphaFree["\<a\>", Characters["\<a\>"]]\), "\[IndentingNewLine]", 
    \(alphaFree["\<ab\>", Characters["\<a\>"]]\), "\[IndentingNewLine]", 
    \(alphaFree["\<abc\>", Characters["\<a\>"]]\), "\[IndentingNewLine]", 
    \(alphaFree["\<abcd\>", Characters["\<a\>"]]\)}], "Input",
  CellLabel->"In[323]:="],

Cell[BoxData[
    \("I"\)], "Output",
  CellLabel->"Out[323]="],

Cell[BoxData[
    \("K"\)], "Output",
  CellLabel->"Out[324]="],

Cell[BoxData[
    \("S(KK)K"\)], "Output",
  CellLabel->"Out[325]="],

Cell[BoxData[
    \("S(KK)(S(KK)K)"\)], "Output",
  CellLabel->"Out[326]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(alphaFree["\<ab\>", Characters["\<ab\>"]]\), "\[IndentingNewLine]", 
    \(alphaFree["\<ab\>", Characters["\<abab\>"]]\), "\[IndentingNewLine]", 
    \(alphaFree["\<ab\>", 
      Characters["\<ababab\>"]]\), "\[IndentingNewLine]", 
    \(alphaFree["\<ab\>", Characters["\<abababab\>"]]\)}], "Input",
  CellLabel->"In[327]:="],

Cell[BoxData[
    \("I"\)], "Output",
  CellLabel->"Out[327]="],

Cell[BoxData[
    \("S(S(KS)(SSK))(KI)"\)], "Output",
  CellLabel->"Out[328]="],

Cell[BoxData[
    \("S(S(KS)(S(S(KS)(S(S(KS)(SSK))(KI)))K))(KI)"\)], "Output",
  CellLabel->"Out[329]="],

Cell[BoxData[
    \("S(S(KS)(S(S(KS)(S(S(KS)(S(S(KS)(S(S(KS)(SSK))(KI)))K))(KI)))K))(KI)"\)]\
, "Output",
  CellLabel->"Out[330]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Fixed Points. Solving combinatorial equations in one variable\
\>", "Section"],

Cell["\<\
Assume we want to solve ornithological equations, that is, equations \
involving birds. With the help of the previous function alphaFree we can \
readily accomplish it (if the solution exists). \
\>", "Text"],

Cell[BoxData[{
    \(solveBird[lS_, rS_] := 
      alphaFree[StringDrop[lS, 1], Characters[rS]]\  /; \ 
        Not[StringMatchQ[
            rS, "\<*\>" <> 
              StringTake[lS, 1] <> "\<*\>"]]\), "\[IndentingNewLine]", 
    \(solveBird[lS_, rS_] := 
      Module[{v = 
            First[Select[Characters[lS], 
                UpperCaseQ]]}, \[IndentingNewLine]"\<M(B\>" <> 
          cover[Characters[
              solveBird["\<A\>" <> StringReplace[lS, v \[Rule] "\<o\>"], 
                StringReplace[rS, 
                  v \[Rule] "\<o\>"]]]] <> "\<M)\>"]\)}], "Input",
  CellLabel->"In[254]:=",
  InitializationCell->True],

Cell["\<\
For instance, to solve the obtain bird A such that Axyz = z(yx) we proceed as \
follows:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(solveBird["\<Axyz\>", "\<z(yx)\>"]\), "\[IndentingNewLine]", 
    \(behaviour[% <> "\<xyz\>"]\)}], "Input",
  CellLabel->"In[331]:="],

Cell[BoxData[
    \("S(K(S(K(SI))))(S(K(S(KK)))(S(K(SI))K))"\)], "Output",
  CellLabel->"Out[331]="],

Cell[BoxData[
    \("z(yx)"\)], "Output",
  CellLabel->"Out[332]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(solveBird["\<Axyz\>", "\<z\>"]\), "\[IndentingNewLine]", 
    \(behaviour[% <> "\<xyz\>"]\)}], "Input",
  CellLabel->"In[252]:="],

Cell[BoxData[
    \("K(KI)"\)], "Output",
  CellLabel->"Out[252]="],

Cell[BoxData[
    \("z"\)], "Output",
  CellLabel->"Out[253]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(solveBird["\<Ayz\>", "\<z(yA)(yAz)\>"]\)], "Input",
  CellLabel->"In[254]:="],

Cell[BoxData[
    \("M(B(S(S(KS)(S(K(S(KS)))(S(K(S(K(SI))))(S(K(S(KK)))(S(K(SI))K)))))(S(K(\
SI))K))M)"\)], "Output",
  CellLabel->"Out[254]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(solveBird["\<Ax\>", "\<xA\>"]\), "\[IndentingNewLine]", 
    \(solveBird["\<Axy\>", "\<Ayx\>"]\), "\[IndentingNewLine]", 
    \(solveBird["\<Ay\>", "\<yA(AyA)\>"]\), "\[IndentingNewLine]", 
    \(solveBird["\<Ayz\>", "\<z(yA)(yAz)\>"]\), "\[IndentingNewLine]", 
    \(solveBird["\<Ax\>", "\<A\>"]\), "\[IndentingNewLine]", 
    \(solveBird["\<Ax\>", "\<Axx\>"]\), "\[IndentingNewLine]", 
    \(solveBird["\<Ax\>", "\<A(xx)\>"]\), "\[IndentingNewLine]", 
    \(solveBird["\<Ax\>", "\<AA\>"]\), "\[IndentingNewLine]", 
    \(solveBird["\<Axy\>", "\<A\>"]\), "\[IndentingNewLine]", 
    \(solveBird["\<Axy\>", "\<yxA\>"]\), "\[IndentingNewLine]", 
    \(solveBird["\<Axy\>", "\<Ayx\>"]\), "\[IndentingNewLine]", 
    \(solveBird["\<Axy\>", "\<x(Ay)\>"]\)}], "Input",
  CellLabel->"In[333]:="],

Cell[BoxData[
    \("M(B(S(K(SI))K)M)"\)], "Output",
  CellLabel->"Out[333]="],

Cell[BoxData[
    \("M(B(S(S(KS)(S(KK)S))(KK))M)"\)], "Output",
  CellLabel->"Out[334]="],

Cell[BoxData[
    \("M(B(S(S(KS)(S(K(SI))K))(SSK))M)"\)], "Output",
  CellLabel->"Out[335]="],

Cell[BoxData[
    \("M(B(S(S(KS)(S(K(S(KS)))(S(K(S(K(SI))))(S(K(S(KK)))(S(K(SI))K)))))(S(K(\
SI))K))M)"\)], "Output",
  CellLabel->"Out[336]="],

Cell[BoxData[
    \("M(BKM)"\)], "Output",
  CellLabel->"Out[337]="],

Cell[BoxData[
    \("M(B(SS(KI))M)"\)], "Output",
  CellLabel->"Out[338]="],

Cell[BoxData[
    \("M(B(S(S(KS)K)(K(SII)))M)"\)], "Output",
  CellLabel->"Out[339]="],

Cell[BoxData[
    \("M(B(S(KK)(SII))M)"\)], "Output",
  CellLabel->"Out[340]="],

Cell[BoxData[
    \("M(B(S(KK)K)M)"\)], "Output",
  CellLabel->"Out[341]="],

Cell[BoxData[
    \("M(B(S(K(S(S(KS)(S(K(SI))K))))(S(KK)K))M)"\)], "Output",
  CellLabel->"Out[342]="],

Cell[BoxData[
    \("M(B(S(S(KS)(S(KK)S))(KK))M)"\)], "Output",
  CellLabel->"Out[343]="],

Cell[BoxData[
    \("M(B(S(K(S(S(KS)K)))K)M)"\)], "Output",
  CellLabel->"Out[344]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Propositional Birds", "Section"],

Cell["\<\
The formalism of Combinatory Logic allows some birds to follow the rules of \
the propositional calculus. Bird v = K represents the value true and f = KI \
the value false. 
Hence pqr means \"if p then q else r\".\
\>", "Text",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(true = "\<K\>"; false = "\<KI\>";\)], "Input",
  CellLabel->"In[345]:="],

Cell["\<\
Explicit expressions for other propositional birds can be obtained solving \
the appropriate equation as the following sections show.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Not", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(not = solveBird["\<Nx\>", "\<x(KI)K\>"]\)], "Input",
  CellLabel->"In[346]:="],

Cell[BoxData[
    \("S(SI(K(KI)))(KK)"\)], "Output",
  CellLabel->"Out[346]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(behaviour /@ {not <> true, not <> false}\)], "Input",
  CellLabel->"In[347]:="],

Cell[BoxData[
    \({"KI", "I"}\)], "Output",
  CellLabel->"Out[347]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["And", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(and = solveBird["\<Axy\>", "\<xy(KI)\>"]\)], "Input",
  CellLabel->"In[348]:="],

Cell[BoxData[
    \("SS(K(K(KI)))"\)], "Output",
  CellLabel->"Out[348]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(behaviour /@ {and <> "\<(\>" <> false <> "\<)\>" <> true}\)], "Input",
  CellLabel->"In[349]:="],

Cell[BoxData[
    \({"KI"}\)], "Output",
  CellLabel->"Out[349]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      Outer[behaviour[
            and <> "\<(\>" <> #1 <> "\<)\>" <> "\<(\>" <> #2 <> "\<)\>"] &, \
{true, false}, {true, false}], 
      TableHeadings \[Rule] {{"\<true\>", "\<false\>"}, {"\<true\>", "\<false\
\>"}}]\)], "Input",
  CellLabel->"In[350]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"true\"\>", "\<\"false\"\>"},
          {"\<\"true\"\>", "\<\"K\"\>", "\<\"KI\"\>"},
          {"\<\"false\"\>", "\<\"KI\"\>", "\<\"KI\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{"true", "false"}, {"true", 
          "false"}}]]]], "Output",
  CellLabel->"Out[350]//TableForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Or", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(or = solveBird["\<Oxy\>", "\<xKy\>"]\)], "Input",
  CellLabel->"In[273]:="],

Cell[BoxData[
    \("SI(KK)"\)], "Output",
  CellLabel->"Out[273]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      Outer[behaviour[
            or <> "\<(\>" <> #1 <> "\<)\>" <> "\<(\>" <> #2 <> "\<)\>"] &, \
{true, false}, {true, false}], 
      TableHeadings \[Rule] {{"\<true\>", "\<false\>"}, {"\<true\>", "\<false\
\>"}}]\)], "Input",
  CellLabel->"In[274]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"true\"\>", "\<\"false\"\>"},
          {"\<\"true\"\>", "\<\"K\"\>", "\<\"K\"\>"},
          {"\<\"false\"\>", "\<\"K\"\>", "\<\"KI\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{"true", "false"}, {"true", 
          "false"}}]]]], "Output",
  CellLabel->"Out[274]//TableForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["If", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(if = solveBird["\<Xxy\>", "\<xyK\>"]\)], "Input",
  CellLabel->"In[275]:="],

Cell[BoxData[
    \("SS(K(KK))"\)], "Output",
  CellLabel->"Out[275]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      Outer[behaviour[
            if <> "\<(\>" <> #1 <> "\<)\>" <> "\<(\>" <> #2 <> "\<)\>"] &, \
{true, false}, {true, false}], 
      TableHeadings \[Rule] {{"\<true\>", "\<false\>"}, {"\<true\>", "\<false\
\>"}}]\)], "Input",
  CellLabel->"In[276]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"true\"\>", "\<\"false\"\>"},
          {"\<\"true\"\>", "\<\"K\"\>", "\<\"KI\"\>"},
          {"\<\"false\"\>", "\<\"K\"\>", "\<\"K\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{"true", "false"}, {"true", 
          "false"}}]]]], "Output",
  CellLabel->"Out[276]//TableForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Iff", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(iff = solveBird["\<Xxy\>", "\<xy(S(SI(K(KI)))(KK)y)\>"]\)], "Input",
  CellLabel->"In[277]:="],

Cell[BoxData[
    \("SS(K(S(SI(K(KI)))(KK)))"\)], "Output",
  CellLabel->"Out[277]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      Outer[behaviour[
            iff <> "\<(\>" <> #1 <> "\<)\>" <> "\<(\>" <> #2 <> "\<)\>"] &, \
{true, false}, {true, false}], 
      TableHeadings \[Rule] {{"\<true\>", "\<false\>"}, {"\<true\>", "\<false\
\>"}}]\)], "Input",
  CellLabel->"In[278]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"true\"\>", "\<\"false\"\>"},
          {"\<\"true\"\>", "\<\"K\"\>", "\<\"KI\"\>"},
          {"\<\"false\"\>", "\<\"KI\"\>", "\<\"K\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{"true", "false"}, {"true", 
          "false"}}]]]], "Output",
  CellLabel->"Out[278]//TableForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["XOr", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xor = solveBird["\<Xxy\>", "\<x(S(SI(K(KI)))(KK)y)y\>"]\)], "Input",
  CellLabel->"In[279]:="],

Cell[BoxData[
    \("S(S(KS)(S(S(KS)K)(K(S(SI(K(KI)))(KK)))))(KI)"\)], "Output",
  CellLabel->"Out[279]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      Outer[behaviour[
            xor <> "\<(\>" <> #1 <> "\<)\>" <> "\<(\>" <> #2 <> "\<)\>"] &, \
{true, false}, {true, false}], 
      TableHeadings \[Rule] {{"\<true\>", "\<false\>"}, {"\<true\>", "\<false\
\>"}}]\)], "Input",
  CellLabel->"In[280]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"true\"\>", "\<\"false\"\>"},
          {"\<\"true\"\>", "\<\"KI\"\>", "\<\"K\"\>"},
          {"\<\"false\"\>", "\<\"K\"\>", "\<\"KI\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{"true", "false"}, {"true", 
          "false"}}]]]], "Output",
  CellLabel->"Out[280]//TableForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nand", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nand = behaviour[not <> "\<(\>" <> and <> "\<xy)\>"]\)], "Input",
  CellLabel->"In[281]:="],

Cell[BoxData[
    \("xy(KI)(KI)K"\)], "Output",
  CellLabel->"Out[281]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      Outer[behaviour[
            nand <> "\<(\>" <> #1 <> "\<)\>" <> "\<(\>" <> #2 <> "\<)\>"] &, \
{true, false}, {true, false}], 
      TableHeadings \[Rule] {{"\<true\>", "\<false\>"}, {"\<true\>", "\<false\
\>"}}]\)], "Input",
  CellLabel->"In[282]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"true\"\>", "\<\"false\"\>"},
          {"\<\"true\"\>", "\<\"xy(KI)(KI)KKK\"\>", \
"\<\"xy(KI)(KI)KK(KI)\"\>"},
          {"\<\"false\"\>", "\<\"xy(KI)(KI)K(KI)K\"\>", \
"\<\"xy(KI)(KI)K(KI)(KI)\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{"true", "false"}, {"true", 
          "false"}}]]]], "Output",
  CellLabel->"Out[282]//TableForm="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Universal Machines", "Section"],

Cell[TextData[{
  "Finally,we mention the use of birds as constructors of universal machines. \
A universal machine is one that can imitate any other machine.Formally,a \
machine U is said to be universal if, for all machines W, there exists a \
codification w such that U(w(x)) = W(x), for all instances of inputs x. Birds \
can be encoded using binary strings by a suitable set of substitutions. For \
the one adopted here, the length of the coded bird is equal to 3n-1, where n \
is the number of birds (I counted as three birds) appearing in its \
expression. Function ",
  StyleBox["code",
    FontSlant->"Italic"],
  " below accomplishes this codification on a given bird. "
}], "Text"],

Cell[BoxData[{
    \(code["\<S\>"] := "\<00\>"\), "\[IndentingNewLine]", 
    \(code["\<K\>"] := "\<01\>"\), "\[IndentingNewLine]", 
    \(code[bird_] := 
      code[StringReplace[bird, "\<I\>" \[Rule] "\<SKK\>"]]\  /; \ 
        StringMatchQ[bird, "\<*I*\>"]\), "\[IndentingNewLine]", 
    \(code[bird_] := 
      Module[{pairs, a, 
          b}, \[IndentingNewLine]pairs[{"\<(\>", a__, 
              b__, "\<)\>"}] := {StringJoin[a], StringJoin[b]}\  /; \ 
            SyntaxQ[StringJoin[a]]; \[IndentingNewLine]{a, b} = 
          pairs[Characters[inflate[bird]]]; \[IndentingNewLine]"\<1\>" <> 
          code[deflate[a]] <> code[deflate[b]]]\)}], "Input",
  CellLabel->"In[351]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(code["\<S(KSS)\>"]\)], "Input",
  CellLabel->"In[355]:="],

Cell[BoxData[
    \("10011010000"\)], "Output",
  CellLabel->"Out[355]="]
}, Open  ]],

Cell[BoxData[{
    \(complete[s_String] := 
      complete[Characters[s]]\), "\[IndentingNewLine]", 
    \(complete[{a___, "\<(\>", b_, c_, d___}] := 
      complete[{a, "\<(\>" <> b <> c <> "\<)\>", d}]\  /; \ 
        SyntaxQ[StringJoin[b]] && \ 
          SyntaxQ[StringJoin[c]]\), "\[IndentingNewLine]", 
    \(\(\(complete[l_List] := StringJoin[l]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(deCode[codedBird_] := 
      deflate[complete[
          StringReplace[
            codedBird, {"\<00\>" \[Rule] "\<S\>", "\<01\>" \[Rule] "\<K\>", "\
\<1\>" \[Rule] "\<(\>"}]]]\)}], "Input",
  CellLabel->"In[356]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(deCode[code["\<SS(K(KKS)(S(KK)SS)SS)\>"]]\)], "Input",
  CellLabel->"In[360]:="],

Cell[BoxData[
    \("SS(K(KKS)(S(KK)SS)SS)"\)], "Output",
  CellLabel->"Out[360]="]
}, Open  ]],

Cell["\<\
It can be proved that the binary coding mentioned above can be used to \
provide a universal bird. In doing so, birds provide an excellent medium on \
which to base Kolmogorov complexity of universal description. For a binary \
finite string x, its complexity C(x) is taken to be the length of the \
shortest program p such that U(p) = x, for some universal machine U. Indeed, \
Penrose provides an explicit description of a universal machine but Tromp, \
gives a smaller coding through 371 bits utilizing combinators.\
\>", "Text"],

Cell[TextData[{
  "Finally, the answer to the question previously posed on finding a function \
f(x) such that f(f(x)) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  " is f(x) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\(\@2\)\)]],
  ". \n\nPerhaps the reader will be interested now in the finding of an f(x) \
such that f(f(x)) =",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(x\^2 + 1\)\)\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Section"],

Cell["\<\
Barendregt, H. P.: The Lambda Calculus. Its syntax and Semantics. Studies in \
Logic 103, North Holland 1984
\t
Curry, H. B., Feys R.: Combinatory Logic. North-Holland 1958
\t
Graham, R.L., Knuth, D.E., Patashnik, O.: Concrete Mathematics. \
Addison-Wesley 1989
\t
Herken, R., ed. The Universal Turing Machine: a Half Century Survey. Kammerer \
& Unverzagt, Hamburg-Berlin 1988
\t
Hindley, J. R., Seldin, J. P.: Introduction to Combinators and \
\[Lambda]-Calculus. London Math Soc. Student Text. Cambridge University \
Press, London 1986
\t
John Tromp's  Combinatory Logic Playground. http://www.cwi.nl/ \
tromp/cl/cl.html
\t
Maeder, R. E.: The Mathematica Programmer II. Academic Press 1996
\t
Penrose, R.: The Emperor's New Mind. Oxford University Press 1989
\t
Rado, T.: On Non-computable Functions. Bell Sys. Tech. J. 877-884 (1962)
\t
R\[EAcute]v\[EAcute]tsz G. E. Lambda Calculus, Combinatorics and Functional \
Programming. Cambridge tracts in theoretical computer science v. 4. Cambridge \
University Press 1988
\t
Sch\[ODoubleDot]nfinkel, M.:  Uber die Bausteine der Mathematishen Logik. \
Math. Annalen 92: 305-316 (1924)
\t
Smullyan, R.:  To Mock a Mockingbird. Alfred A. Knopf, New York 1985
\t
Wolfram, S.: A New Kind of Science. Wolfram Media 2002

Bisecting a Convex Polygon. Mathematics Magazine 73, 3, June 2000\
\>", "Reference"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 971}},
AutoGeneratedPackage->None,
WindowToolbars->{},
WindowSize->{880, 791},
WindowMargins->{{140, Automatic}, {69, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1,
StyleDefinitions -> "ArticleClassic.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 115, 2, 93, "Title"],
Cell[1894, 57, 98, 2, 41, "Author"],
Cell[1995, 61, 175, 5, 72, "Address"],
Cell[2173, 68, 210, 6, 78, "Text"],

Cell[CellGroupData[{
Cell[2408, 78, 32, 0, 62, "SectionFirst"],
Cell[2443, 80, 819, 13, 139, "Abstract"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3299, 98, 34, 0, 56, "Section"],
Cell[3336, 100, 345, 6, 44, "Text"],
Cell[3684, 108, 240, 9, 94, "Reference"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3961, 122, 31, 0, 56, "Section"],
Cell[3995, 124, 5810, 101, 639, "Text"],
Cell[9808, 227, 187, 11, 146, "Text"],
Cell[9998, 240, 1497, 23, 180, "Text"],
Cell[11498, 265, 350, 7, 91, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[11885, 277, 40, 0, 56, "Section"],
Cell[11928, 279, 408, 8, 44, "Text"],
Cell[12339, 289, 416, 9, 111, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[12780, 302, 169, 5, 51, "Input"],
Cell[12952, 309, 242, 4, 49, "Output"],
Cell[13197, 315, 62, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13296, 322, 109, 2, 31, "Input"],
Cell[13408, 326, 105, 2, 30, "Output"]
}, Open  ]],
Cell[13528, 331, 418, 9, 61, "Text"],
Cell[13949, 342, 696, 14, 171, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[14670, 360, 146, 3, 51, "Input"],
Cell[14819, 365, 319, 5, 49, "Output"],
Cell[15141, 372, 62, 2, 30, "Output"]
}, Open  ]],
Cell[15218, 377, 256, 7, 44, "Text"],
Cell[15477, 386, 423, 11, 71, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[15925, 401, 132, 4, 31, "Input"],
Cell[16060, 407, 480, 8, 87, "Output"]
}, Open  ]],
Cell[16555, 418, 29, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[16609, 422, 110, 2, 45, "Input"],
Cell[16722, 426, 655, 13, 179, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17414, 444, 39, 0, 33, "Subsubsection"],
Cell[17456, 446, 186, 4, 27, "Text"],
Cell[17645, 452, 999, 20, 247, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[18669, 476, 208, 6, 31, "Input"],
Cell[18880, 484, 81040, 1645, 134, 11328, 778, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[99935, 2132, 67, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[100027, 2136, 155, 3, 31, "Input"],
Cell[100185, 2141, 1152, 16, 277, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[101386, 2163, 64, 0, 33, "Subsubsection"],
Cell[101453, 2165, 491, 8, 61, "Text"],
Cell[101947, 2175, 541, 11, 105, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[102513, 2190, 67, 2, 31, "Input"],
Cell[102583, 2194, 1542, 22, 144, "Output"]
}, Open  ]],
Cell[104140, 2219, 785, 17, 191, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[104950, 2240, 78, 2, 31, "Input"],
Cell[105031, 2244, 147, 3, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105215, 2252, 145, 4, 31, "Input"],
Cell[105363, 2258, 31134, 611, 77, 4090, 272, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136534, 2874, 145, 4, 31, "Input"],
Cell[136682, 2880, 89, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[136820, 2888, 50, 0, 33, "Subsubsection"],
Cell[136873, 2890, 369, 10, 44, "Text"],
Cell[137245, 2902, 1307, 25, 231, "Input",
  InitializationCell->True],
Cell[138555, 2929, 125, 3, 27, "Text"],
Cell[138683, 2934, 680, 12, 147, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[139388, 2950, 188, 5, 31, "Input"],
Cell[139579, 2957, 346635, 7684, 453, 61147, 4152, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[486229, 10644, 155, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[486409, 10651, 431, 10, 87, "Input"],
Cell[486843, 10663, 156, 3, 30, "Output"]
}, Open  ]],
Cell[487014, 10669, 405, 17, 32, "Text"],
Cell[487422, 10688, 1580, 34, 266, "Input"],

Cell[CellGroupData[{
Cell[489027, 10726, 335, 8, 125, "Input"],
Cell[489365, 10736, 1217, 20, 279, "Output"]
}, Open  ]],
Cell[490597, 10759, 647, 11, 168, "Input"],

Cell[CellGroupData[{
Cell[491269, 10774, 175, 5, 31, "Input"],
Cell[491447, 10781, 139137, 4281, 172, 40779, 3060, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[630599, 15065, 846, 15, 180, "Input"],

Cell[CellGroupData[{
Cell[631470, 15084, 174, 5, 31, "Input"],
Cell[631647, 15091, 321420, 11971, 371, 152788, 9884, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[953116, 27068, 54, 0, 43, "Subsection"],
Cell[953173, 27070, 338, 7, 44, "Text"],
Cell[953514, 27079, 695, 14, 151, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[954234, 27097, 203, 5, 51, "Input"],
Cell[954440, 27104, 181, 4, 25, "Print"],
Cell[954624, 27110, 189, 4, 25, "Print"],
Cell[954816, 27116, 220, 5, 25, "Print"],
Cell[955039, 27123, 295, 6, 25, "Print"],
Cell[955337, 27131, 571, 10, 44, "Print"]
}, Open  ]],
Cell[955923, 27144, 594, 12, 131, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[956542, 27160, 78, 2, 31, "Input"],
Cell[956623, 27164, 72, 2, 30, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[956756, 27173, 29, 0, 56, "Section"],
Cell[956788, 27175, 1309, 23, 129, "Text"],
Cell[958100, 27200, 272, 5, 61, "Text"],
Cell[958375, 27207, 1155, 19, 146, "Text"],
Cell[959533, 27228, 246, 11, 146, "Text"],
Cell[959782, 27241, 205, 4, 44, "Text"],
Cell[959990, 27247, 1976, 35, 371, "Input",
  InitializationCell->True],
Cell[961969, 27284, 149, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[962143, 27291, 226, 5, 51, "Input"],
Cell[962372, 27298, 739, 20, 170, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[963148, 27323, 93, 2, 31, "Input"],
Cell[963244, 27327, 65, 2, 30, "Output"]
}, Open  ]],
Cell[963324, 27332, 112, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[963461, 27339, 136, 3, 31, "Input"],
Cell[963600, 27344, 80, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[963717, 27351, 196, 4, 31, "Input"],
Cell[963916, 27357, 141, 3, 30, "Output"]
}, Open  ]],
Cell[964072, 27363, 97, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[964194, 27369, 87, 2, 31, "Input"],
Cell[964284, 27373, 75, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[964396, 27380, 88, 2, 31, "Input"],
Cell[964487, 27384, 75, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[964599, 27391, 89, 2, 31, "Input"],
Cell[964691, 27395, 71, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[964799, 27402, 86, 2, 31, "Input"],
Cell[964888, 27406, 64, 2, 30, "Output"]
}, Open  ]],
Cell[964967, 27411, 46, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[965038, 27415, 128, 3, 31, "Input"],
Cell[965169, 27420, 84, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[965290, 27427, 134, 3, 31, "Input"],
Cell[965427, 27432, 85, 2, 30, "Output"]
}, Open  ]],
Cell[965527, 27437, 60, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[965612, 27441, 164, 3, 31, "Input"],
Cell[965779, 27446, 92, 2, 30, "Output"]
}, Open  ]],
Cell[965886, 27451, 418, 10, 78, "Text"],
Cell[966307, 27463, 644, 13, 131, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[966976, 27480, 84, 2, 31, "Input"],
Cell[967063, 27484, 61, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[967161, 27491, 80, 2, 31, "Input"],
Cell[967244, 27495, 78, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[967371, 27503, 30, 0, 56, "Section"],

Cell[CellGroupData[{
Cell[967426, 27507, 53, 0, 43, "Subsection"],
Cell[967482, 27509, 377, 10, 44, "Text"],
Cell[967862, 27521, 1227, 28, 291, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[969114, 27553, 84, 2, 31, "Input"],
Cell[969201, 27557, 63, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[969301, 27564, 256, 5, 51, "Input"],
Cell[969560, 27571, 148, 3, 30, "Output"],
Cell[969711, 27576, 84, 2, 30, "Output"]
}, Open  ]],
Cell[969810, 27581, 71, 0, 27, "Text"],
Cell[969884, 27583, 591, 17, 29, "DisplayFormula"],

Cell[CellGroupData[{
Cell[970500, 27604, 172, 3, 31, "Input"],
Cell[970675, 27609, 132, 3, 30, "Output"]
}, Open  ]],
Cell[970822, 27615, 460, 12, 29, "DisplayFormula"],

Cell[CellGroupData[{
Cell[971307, 27631, 172, 3, 31, "Input"],
Cell[971482, 27636, 147, 3, 30, "Output"]
}, Open  ]],
Cell[971644, 27642, 628, 16, 29, "DisplayFormula"],

Cell[CellGroupData[{
Cell[972297, 27662, 174, 3, 31, "Input"],
Cell[972474, 27667, 154, 3, 30, "Output"]
}, Open  ]],
Cell[972643, 27673, 56, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[972724, 27677, 182, 4, 51, "Input"],
Cell[972909, 27683, 242, 4, 49, "Output"],
Cell[973154, 27689, 214, 4, 49, "Output"]
}, Open  ]],
Cell[973383, 27696, 259, 5, 44, "Text"],

Cell[CellGroupData[{
Cell[973667, 27705, 75, 2, 31, "Input"],
Cell[973745, 27709, 99, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[973881, 27716, 265, 7, 51, "Input"],
Cell[974149, 27725, 179, 3, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[974377, 27734, 40, 0, 43, "Subsection"],
Cell[974420, 27736, 212, 4, 44, "Text"],
Cell[974635, 27742, 1381, 30, 86, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[976041, 27776, 178, 5, 31, "Input"],
Cell[976222, 27783, 13546, 213, 296, 726, 49, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[989783, 27999, 131, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[989939, 28006, 295, 6, 71, "Input"],
Cell[990237, 28014, 405906, 15475, 516, 190173, 12785, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1396192, 43495, 53, 0, 43, "Subsection"],
Cell[1396248, 43497, 285, 8, 95, "Text"],
Cell[1396536, 43507, 275, 6, 51, "Input",
  InitializationCell->True],
Cell[1396814, 43515, 119, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[1396958, 43522, 159, 3, 51, "Input"],
Cell[1397120, 43527, 157, 3, 30, "Output"]
}, Open  ]],
Cell[1397292, 43533, 104, 3, 27, "Text"],
Cell[1397399, 43538, 884, 22, 171, "Input"],

Cell[CellGroupData[{
Cell[1398308, 43564, 89, 2, 31, "Input"],
Cell[1398400, 43568, 65, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1398502, 43575, 34, 0, 33, "Subsubsection"],
Cell[1398539, 43577, 367, 8, 91, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[1398931, 43589, 160, 4, 51, "Input"],
Cell[1399094, 43595, 1322, 18, 182, "Output"],
Cell[1400419, 43615, 63, 2, 30, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1400555, 43625, 40, 0, 56, "Section"],
Cell[1400598, 43627, 131, 3, 27, "Text"],
Cell[1400732, 43632, 1371, 27, 251, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[1402128, 43663, 161, 3, 51, "Input"],
Cell[1402292, 43668, 69, 2, 30, "Output"],
Cell[1402364, 43672, 67, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1402468, 43679, 163, 3, 51, "Input"],
Cell[1402634, 43684, 72, 2, 30, "Output"],
Cell[1402709, 43688, 67, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1402813, 43695, 171, 4, 51, "Input"],
Cell[1402987, 43701, 82, 2, 30, "Output"],
Cell[1403072, 43705, 68, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1403177, 43712, 173, 4, 51, "Input"],
Cell[1403353, 43718, 92, 2, 30, "Output"],
Cell[1403448, 43722, 68, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1403553, 43729, 177, 4, 51, "Input"],
Cell[1403733, 43735, 108, 2, 30, "Output"],
Cell[1403844, 43739, 68, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1403949, 43746, 98, 2, 31, "Input"],
Cell[1404050, 43750, 63, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1404150, 43757, 99, 2, 31, "Input"],
Cell[1404252, 43761, 64, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1404353, 43768, 100, 2, 31, "Input"],
Cell[1404456, 43772, 67, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1404560, 43779, 101, 2, 31, "Input"],
Cell[1404664, 43783, 70, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1404771, 43790, 325, 5, 91, "Input"],
Cell[1405099, 43797, 63, 2, 30, "Output"],
Cell[1405165, 43801, 65, 2, 30, "Output"],
Cell[1405233, 43805, 69, 2, 30, "Output"],
Cell[1405305, 43809, 73, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1405415, 43816, 331, 5, 91, "Input"],
Cell[1405749, 43823, 63, 2, 30, "Output"],
Cell[1405815, 43827, 71, 2, 30, "Output"],
Cell[1405889, 43831, 95, 2, 30, "Output"],
Cell[1405987, 43835, 141, 3, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1406165, 43843, 325, 5, 91, "Input"],
Cell[1406493, 43850, 63, 2, 30, "Output"],
Cell[1406559, 43854, 63, 2, 30, "Output"],
Cell[1406625, 43858, 68, 2, 30, "Output"],
Cell[1406696, 43862, 75, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1406808, 43869, 346, 6, 91, "Input"],
Cell[1407157, 43877, 63, 2, 30, "Output"],
Cell[1407223, 43881, 79, 2, 30, "Output"],
Cell[1407305, 43885, 104, 2, 30, "Output"],
Cell[1407412, 43889, 131, 3, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1407592, 43898, 88, 2, 56, "Section"],
Cell[1407683, 43902, 218, 4, 44, "Text"],
Cell[1407904, 43908, 642, 15, 91, "Input",
  InitializationCell->True],
Cell[1408549, 43925, 112, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[1408686, 43932, 154, 3, 51, "Input"],
Cell[1408843, 43937, 100, 2, 30, "Output"],
Cell[1408946, 43941, 67, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1409050, 43948, 150, 3, 51, "Input"],
Cell[1409203, 43953, 67, 2, 30, "Output"],
Cell[1409273, 43957, 63, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1409373, 43964, 97, 2, 31, "Input"],
Cell[1409473, 43968, 143, 3, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1409653, 43976, 810, 13, 251, "Input"],
Cell[1410466, 43991, 78, 2, 30, "Output"],
Cell[1410547, 43995, 89, 2, 30, "Output"],
Cell[1410639, 43999, 93, 2, 30, "Output"],
Cell[1410735, 44003, 143, 3, 30, "Output"],
Cell[1410881, 44008, 68, 2, 30, "Output"],
Cell[1410952, 44012, 75, 2, 30, "Output"],
Cell[1411030, 44016, 86, 2, 30, "Output"],
Cell[1411119, 44020, 79, 2, 30, "Output"],
Cell[1411201, 44024, 75, 2, 30, "Output"],
Cell[1411279, 44028, 102, 2, 30, "Output"],
Cell[1411384, 44032, 89, 2, 30, "Output"],
Cell[1411476, 44036, 85, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1411610, 44044, 38, 0, 56, "Section"],
Cell[1411651, 44046, 293, 7, 44, "Text"],
Cell[1411947, 44055, 92, 2, 31, "Input"],
Cell[1412042, 44059, 157, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[1412224, 44066, 25, 0, 43, "Subsection"],

Cell[CellGroupData[{
Cell[1412274, 44070, 98, 2, 31, "Input"],
Cell[1412375, 44074, 78, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1412490, 44081, 99, 2, 31, "Input"],
Cell[1412592, 44085, 71, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1412712, 44093, 25, 0, 43, "Subsection"],

Cell[CellGroupData[{
Cell[1412762, 44097, 99, 2, 31, "Input"],
Cell[1412864, 44101, 74, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1412975, 44108, 116, 2, 31, "Input"],
Cell[1413094, 44112, 66, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1413197, 44119, 288, 7, 51, "Input"],
Cell[1413488, 44128, 522, 14, 58, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1414059, 44148, 24, 0, 43, "Subsection"],

Cell[CellGroupData[{
Cell[1414108, 44152, 95, 2, 31, "Input"],
Cell[1414206, 44156, 68, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1414311, 44163, 287, 7, 51, "Input"],
Cell[1414601, 44172, 520, 14, 58, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1415170, 44192, 24, 0, 43, "Subsection"],

Cell[CellGroupData[{
Cell[1415219, 44196, 95, 2, 31, "Input"],
Cell[1415317, 44200, 71, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1415425, 44207, 287, 7, 51, "Input"],
Cell[1415715, 44216, 520, 14, 58, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1416284, 44236, 25, 0, 43, "Subsection"],

Cell[CellGroupData[{
Cell[1416334, 44240, 114, 2, 31, "Input"],
Cell[1416451, 44244, 85, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1416573, 44251, 288, 7, 51, "Input"],
Cell[1416864, 44260, 521, 14, 58, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1417434, 44280, 25, 0, 43, "Subsection"],

Cell[CellGroupData[{
Cell[1417484, 44284, 114, 2, 31, "Input"],
Cell[1417601, 44288, 106, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1417744, 44295, 288, 7, 51, "Input"],
Cell[1418035, 44304, 521, 14, 58, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1418605, 44324, 26, 0, 43, "Subsection"],

Cell[CellGroupData[{
Cell[1418656, 44328, 111, 2, 31, "Input"],
Cell[1418770, 44332, 73, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1418880, 44339, 289, 7, 51, "Input"],
Cell[1419172, 44348, 583, 16, 58, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1419816, 44371, 37, 0, 56, "Section"],
Cell[1419856, 44373, 692, 12, 78, "Text"],
Cell[1420551, 44387, 687, 13, 151, "Input"],

Cell[CellGroupData[{
Cell[1421263, 44404, 77, 2, 31, "Input"],
Cell[1421343, 44408, 73, 2, 30, "Output"]
}, Open  ]],
Cell[1421431, 44413, 635, 14, 131, "Input"],

Cell[CellGroupData[{
Cell[1422091, 44431, 100, 2, 31, "Input"],
Cell[1422194, 44435, 83, 2, 30, "Output"]
}, Open  ]],
Cell[1422292, 44440, 542, 8, 78, "Text"],
Cell[1422837, 44450, 436, 13, 66, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1423310, 44468, 29, 0, 56, "Section"],
Cell[1423342, 44470, 1358, 37, 424, "Reference"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

